## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Id.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Id.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Id;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Id> hyphenation pattern class

=cut

__DATA__
% This file is part of hyph-utf8 package and resulted from
% semi-manual conversions of hyphenation patterns into UTF-8 in June 2008.
%
% Source: inhyph.tex (1997-09-19)
% Author: Jörg Knappen <knappen@vkpmzd.kph.uni-mainz.de>, Terry Mart <mart@kph.uni-mainz.de>
%
% The above mentioned file should become obsolete,
% and the author of the original file should preferaby modify this file instead.
%
% Modificatios were needed in order to support native UTF-8 engines,
% but functionality (hopefully) didn't change in any way, at least not intentionally.
% This file is no longer stand-alone; at least for 8-bit engines
% you probably want to use loadhyph-foo.tex (which will load this file) instead.
%
% Modifications were done by Jonathan Kew, Mojca Miklavec & Arthur Reutenauer
% with help & support from:
% - Karl Berry, who gave us free hands and all resources
% - Taco Hoekwater, with useful macros
% - Hans Hagen, who did the unicodifisation of patterns already long before
%               and helped with testing, suggestions and bug reports
% - Norbert Preining, who tested & integrated patterns into TeX Live
%
% However, the "copyright/copyleft" owner of patterns remains the original author.
%
% The copyright statement of this file is thus:
%
%    Do with this file whatever needs to be done in future for the sake of
%    "a better world" as long as you respect the copyright of original file.
%    If you're the original author of patterns or taking over a new revolution,
%    plese remove all of the TUG comments & credits that we added here -
%    you are the Queen / the King, we are only the servants.
%
% If you want to change this file, rather than uploading directly to CTAN,
% we would be grateful if you could send it to us (http://tug.org/tex-hyphen)
% or ask for credentials for SVN repository and commit it yourself;
% we will then upload the whole "package" to CTAN.
%
% Before a new "pattern-revolution" starts,
% please try to follow some guidelines if possible:
%
% - \lccode is *forbidden*, and I really mean it
% - all the patterns should be in UTF-8
% - the only "allowed" TeX commands in this file are: \patterns, \hyphenation,
%   and if you really cannot do without, also \input and \message
% - in particular, please no \catcode or \lccode changes,
%   they belong to loadhyph-foo.tex,
%   and no \lefthyphenmin and \righthyphenmin,
%   they have no influence here and belong elsewhere
% - \begingroup and/or \endinput is not needed
% - feel free to do whatever you want inside comments
%
% We know that TeX is extremely powerful, but give a stupid parser
% at least a chance to read your patterns.
%
% For more unformation see
%
%    http://tug.org/tex-hyphen
%
%------------------------------------------------------------------------------
%
% inhyph.tex 
% Version 1.3 19-SEP-1997
%
% Hyphenation patterns for bahasa indonesia (probably also usable
% for bahasa melayu)
%
% (c) Copyright 1996, 1997 Jörg Knappen and Terry Mart
% 
% This patterns are free software according to the GNU General Public 
% licence version 2, June 1991.
%
% Please read the GNU licence for details. If you don't receive a GNU
% licence with these patterns, you can obtain it from 
%
%                          Free Software Foundation, Inc.
%                          675 Mass Ave, Cambridge, MA 02139, USA
%
% If you make any changes to this file, please rename it so that it
% cannot be confused with the original one, and change the contact
% address for bug reports and suggestions.
%
% For bug reports, improvements, and suggestions, contact
%
% Jörg Knappen
% jk Unternehmensberatung
% Barbarossaring 43
% 55118 Mainz
%
% knappen@vkpmzd.kph.uni-mainz.de
%
% or:
% Terry Mart
%
% Institut fuer Kernphysik
% Universitaet Mainz
% 55099 Mainz
% Germany
%
% phone : +49 6131 395174
% fax   : +49 6131 395474
% email : mart@kph.uni-mainz.de
%
%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*
%
% The patterns are best used with the following parameters
%
% \lefthyphenmin=2 \righthyphenmin=2 %
%
%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*%*
%
\patterns{%
a1 e1 i1 o1 u1 % allow hyphens after vowels
2b1d 2b1j 2b1k 2b1n 2b1s 2b1t
2c1k 2c1n
2d1k 2d1n 2d1p 
2f1d 2f1k 2f1n 2f1t
2g1g 2g1k 2g1n
2h1k 2h1l 2h1m 2h1n 2h1w
2j1k 2j1n
2k1b 2k1k 2k1m 2k1n 2k1r 2k1s 2k1t
2l1b 2l1f 2l1g 2l1h 2l1k 2l1m 2l1n 2l1s 2l1t 2l1q
2m1b 2m1k 2m1l 2m1m 2m1n 2m1p 2m1r 2m1s
2n1c 2n1d 2n1f 2n1j 2n1k 2n1n 2n1p 2n1s 2n1t 2n1v
2p1k 2p1n 2p1p 2p1r 2p1t
2r1b 2r1c 2r1f 2r1g 2r1h 2r1j 2r1k 2r1l 2r1m 2r1n 2r1p 2r1r 2r1s 2r1t 2r1w 2r1y
2s1b 2s1k 2s1l 2s1m 2s1n 2s1p 2s1r 2s1s 2s1t 2s1w
2t1k 2t1l 2t1n 2t1t  
2w1t                 % two consonant groups to be hyphenated between
                     % the consonants
2ng1g 2ng1h 2ng1k 2ng1n 2ng1s    % three consonant groups
2n3s2t % kon-stan-ta
.be2r3 .te2r3 .me2ng3 .pe2r3 % prefixes
2ng. 2ny. % don't hyphenate -ng and -ny at the end of word
i2o1n % in-ter-na-sio-nal
a2ir % ber-air 
1ba1ga2i % se-ba-gai-ma-na
2b1an. 2c1an. 2d1an. 2f1an. 2g1an. 2h1an. 2j1an. 2k1an. 2l1an.
2m1an. 2ng1an. 2n1an. 2p1an. 2r1an. 2s1an. 2t1an. 2v1an. 2z1an. 
3an. % suffix -an
.a2ta2u % atau-pan
.ta3ng4an. .le3ng4an. .ja3ng4an. .ma3ng4an. .pa3ng4an. .ri3ng4an. 
.de3ng4an. % Don't overload the exception list...
}
% Exeptions to the above rules, specially words beginning in ber...
% and ter..
\hyphenation{be-ra-be be-ra-hi be-rak be-ran-da be-ran-dal be-rang
             be-ra-ngas-an be-rang-sang be-ra-ngus be-ra-ni
             be-ran-tak-an be-ran-tam be-ran-tas be-ra-pa be-ras
             be-ren-deng be-re-ngut be-re-rot be-res be-re-wok
             be-ri be-ri-ngas be-ri-sik be-ri-ta be-rok be-ron-dong
             be-ron-tak be-ru-du be-ruk be-run-tun
             peng-eks-por peng-im-por
             te-ra te-rang te-ras te-ra-si te-ra-tai te-ra-wang te-ra-weh
             te-ri-ak te-ri-gu te-rik te-ri-ma te-ri-pang te-ro-bos
             te-ro-bos-an te-ro-mol te-rom-pah te-rom-pet te-ro-pong
             te-ro-wong-an te-ru-buk te-ru-na te-rus te-ru-si}

