## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Zu_ZA.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Zu_ZA.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Zu_ZA;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Zu_ZA> hyphenation pattern class

=cut

__DATA__
ISO08859-1
%  Ukwahlukanisela ngekhonco isiZulu: Ukulandisa kwokusebenza ne-OpenOffice.org
%  Hyphenation for Zulu: Version for OpenOffice.org
%  Copyright (C) 2005, 2007 Friedel Wolff
%
%  This library is free software; you can redistribute it and/or
%  modify it under the terms of the GNU Lesser General Public
%  License as published by the Free Software Foundation;
%  version 2.1 of the License.
%
%  This library is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%  Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public
%  License along with this library; if not, write to the Free Software
%  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
%

a1
e1
i1
o1
u1
%is'thandwa njalonjalo
'1

%iziphambuko ngenxa yamagama esiBhunu
1be2rg.
be1
1bu2rg.
bu1
1da2l.
da1
1do2rp.
do1
%angazi ngale: Modder-fo-ntein?
1fonte2i2n.
fo1
1ho2e2k.
1ho2f.
ho1
1klo2o2f.
klo1
1ko2p.
ko1
1kra2ns.
kra1
1kro2o2n.
kro1
1kru2i2n.
kru1
1la2nd.
la1
1pa2rk.
pa1
1ple2i2n.
ple1
1po2o2rt.
po1
1ra2nd.
ra1
1rivi2er.
ri1
1spru2i2t.
spru1
1sta2d.
sta1
1stra2nd.
stra1

%ukukhombisa
1no2o2rd.
no1
1o2o2s.
1su2i2d.
su1
1we2s.
we1

%iziphambuko ngenxa yamagama esiNgisi
1ba2y.
ba1
be2a2ch
e2a2ch.
cli2ffe.
1da2le.
1fi2e2ld.
fi1
%... Hill
i2ll.
1me2a2d.
%1pa2rk. - bona isiBhunu
1ri2dge.
%kodwa
b2ri2dge.
bri1
1to2n.
1to2wn.
to1
1vi2e2w.
1vi2lle.
vi1
1wo2o2d.
wo1

%ukukhombisa
no2rth.
e2a2st.
so2u2th.
so1
we2st.

%iziphambuko ngenxa yamagama esiSuthu
a2ng.
e2ng.
i2ng.
o2ng.
u2ng.

%iziphambuko ezinhlobonhlobo
%mhlawumbe amaphutha okupela angazohlupa
a2a1
a2e1
a2i1
a2o1
a2u1
e2a1
e2e1
e2i1
e2o1
e2u1
i2a1
i2e1
i2i1
i2o1
i2u1
o2a1
o2e1
o2i1
o2o1
o2u1
u2a1
u2e1
u2i1
u2o1
u2u1

2b.
2c.
2d.
2f.
2g.
2h.
2j.
2k.
2l.
2m.
2n.
2p.
2q.
2r.
2s.
2t.
2v.
2w.
2x.
2z.



