## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: It_IT.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/It_IT.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::It_IT;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<It_IT> hyphenation pattern class

=head1 Copyright

The data for this library is copied from the OpenOffice.org project and
modified to be used as a Perl module by Roland van Ipenburg.

L<http://svn.services.openoffice.org/ooo/trunk/dictionaries/it_IT/>

	Hyphenation dictionary
	----------------------

	Language: it_IT (Italian, Italy)
	Origin:   Based on the TeX hyphenation tables by Claudio Beccari
	License:  LGPL
	Author:   conversion author is Giuseppe Bilotta <giuseppe.bilotta@gmail.com>

	This dictionary should be usable under other Italian variants

	===============================================================================

	Dizionario sillabazione
	----------------------

	Language: it_IT (Italiano, Italia)
	Origin:   Basato sulle tabelle di sillabazione di Claudio Beccari per il TeX
	License:  LGPL
	Author:   conversione di Giuseppe Bilotta <giuseppe.bilotta@gmail.com>

	Questo dizionario dovrebbe essere valido anche per altre varianti di italiano

	===============================================================================

	HYPH it IT hyph_it_IT

=cut

__DATA__
ISO8859-1
.a3p2n
.a1p
.anti1
.a1n
.a2n1t
.a1nti3m2n
.anti1m
.bio1
.1b
.1c2
.ca4p3s2
.ca1p
.circu2m1
.ci1r
.1ci2r1c
.contro1
.co1n
.co2n1t
.cont2r
.1d2
.di2s3cine
.di1s2
.dis1c
.disci1n
.e2x1eu
.e1x
.fra2n2k3
.1f
.f2r
.fra1n
.free3
.narco1
.1n
.na1r
.na2r1c
.opto1
.o1p
.o2p1t
.orto3p2
.o1r
.o2r1t
.para1
.1p
.pa1r
.1poli3p2
.po1l
.pre1
.p2r
.2p2s2
.1re1i2sc2r
.1r
.rei1s2
.reis1c
.sha2re3
.1s2
.s1h
.sha1r
.tran2s3c
.1t
.t2r
.tra1n
.tra2n1s2
.tran2s3d
.tran2s3l
.tra1n2s3n
.tran2s3p
.t1ran2s3r
.1tran2s3t
.su2b3lu
.su1b
.sub2l
.su2b3r
.wa2g3n
.1w
.wa1g
.we2l2t1
.we1l
'2
a1ia
a1ie
a1io
a1iu
a1uo
a1ya
2a2t.
a1t
e1iu
e2w
o1ia
o1ie
o1io
o1iu
1b
2b1b
2b1c
2b1d
2b1f
2b1m
2b1n
2b1p
2b1s2
2b1t
2b1v
b2l
b2r
2b.
2b'2
1c
2c1b
2c1c
2c1d
2c1f
2c1k
2c1m
2c1n
2c1q
2c1s2
2c1t
2c1z
c2h
2c2h1h
2c2h1b
c2h2r
2c2h1n
c2l
c2r
2c.
2c'2
1d
2d1b
2d1d
2d1g
2d1l
2d1m
2d1n
2d1p
d2r
2d1s2
2d1t
2d1v
2d1w
2d.
2d'2
1f
2f1b
2f1g
2f1f
2f1n
f2l
f2r
2f1s2
2f1t
2f.
2f'2
1g
2g1b
2g1d
2g1f
2g1g
g2h
g2l
2g1m
g2n
2g1p
g2r
2g1s2
2g1t
2g1v
2g1w
2g1z
2gh2t
2g.
2g'2
1h
2h1b
2h1d
2h1h
hi3p2n
hi1p
h2l
2h1m
2h1n
2h1r
2h1v
2h.
2h'2
1j
2j.
2j'2
1k
2k1g
2k1f
k2h
2k1k
k2l
2k1m
k2r
2k1s2
2k1t
2k.
2k'2
1l
2l1b
2l1c
2l1d
2l3f2
2l1g
l2h
2l1k
2l1l
2l1m
2l1n
2l1p
2l1q
2l1r
2l1s2
2l1t
2l1v
2l1w
2l1z
2l.
2l'.
l'2
2l'2'2
1m
2m1b
2m1c
2m1f
2m1l
2m1m
2m1n
2m1p
2m1q
2m1r
2m1s2
2m1t
2m1v
2m1w
2m.
2m'2
1n
2n1b
2n1c
2n1d
2n1f
2n1g
2n1k
2n1l
2n1m
2n1n
2n1p
2n1q
2n1r
2n1s2
n2s3fe1r
ns1f
2n1t
2n1v
2n1z
1n2g3n
2nhei1t
n1h
2n.
2n'2
1p
2p1d
p2h
p2l
2p1n
3p2ne
2p1p
p2r
2p1s2
3p2si1c
2p1t
2p1z
2p.
2p'2
1q
2q1q
2q.
2q'2
1r
2r1b
2r1c
2r1d
2r1f
r2h
2r1g
2r1k
2r1l
2r1m
2r1n
2r1p
2r1q
2r1r
2r1s2
2r1t
r2t2s3
2r1v
2r1x
2r1w
2r1z
2r.
2r'2
1s2
2s2h1m
s1h
2s3s2
s4s3m
2s3p2n
s1p
2s2t1b
s1t
2s2t1c
2s2t1d
2s2t1f
2s2t1g
2s2t1m
2s2t1n
2s2t1p
2s2t2s2
2s2t1t
2s2t1v
2s1z
4s.
4s'.
s'2
4s'2'2
1t
2t1b
2t1c
2t1d
2t1f
2t1g
t2h
t2l
2t1m
2t1n
2t1p
t2r
t2s2
3t2sc2h
ts1c
2t1t
t2t3s2
2t1v
2t1w
t2z
2tz1k
t2z2s2
2t.
2t'.
t'2
2t'2'2
1v
2v1c
v2l
v2r
2v1v
2v.
2v'.
v'2
2v'2'2
1w
w2h
wa2r
2w1y
2w.
2w'2
1x
2x1b
2x1c
2x1f
2x1h
2x1m
2x1p
2x1t
2x1w
2x.
2x'2
y1ou
y1i
1z
2z1b
2z1d
2z1l
2z1n
2z1p
2z1t
2z1s2
2z1v
2z1z
2z.
2z'.
z'2
2z'2'2
.1z2

