## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Es.pm 118 2009-08-17 05:46:36Z roland $
# $Revision: 118 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Es.pm $
# $Date: 2009-08-17 07:46:36 +0200 (Mon, 17 Aug 2009) $
## use critic

package TeX::Hyphen::Pattern::Es;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Es> hyphenation pattern class

=cut

__DATA__
% DIVISI'ON DE PALABRAS
% ~~~~~~~~~~~~~~~~~~~~~
% hyph-es.tex 4.5
% This files corresponds to eshyph.tex 4.5.
%
% (c) Javier Bezos 1993 1997.
% (c) Javier Bezos and CervanTeX 2001-2009
% Some parts, (c) by Francesc Carmona
% Licence: LPPL
% 
% For further info, bug reports and comments:
%
%       http://www.tex-tipografia.com/spanish_hyphen.html
% 
% I would like to thanks Francesc Carmona for his permission
% to steal parts of his work without restrictions. 
% 
% 2009-08-01
% 
% _____________________________________________________________
% Javier Bezos                | http://www.cervantex.es/
% .............................................................
% TeX y tipografia            | http://www.tex-tipografia.com/

\patterns{
1b 2b. 2bb 2bc 2bd 2bf 2bg 2b1h 2bj 2bk b2l 2bl. 2bm 2bn 2bp 2bq b2r 2br. 2bs 2bt 2bv 2bw 2bx 2by 2bz
1c 2c. 2cb 2cc 2cd 2cf 2cg c4h 2ch. 2cj 2ck c2l 2cl. 2cm 2cn 2cp 2cq c2r 2cr. 2cs 2ct 2cv 2cw 2cx 2cy 2cz
1d 2d. 2db 2dc 2dd 2df 2dg 2d1h 2dj 2dk 2dl 2dm 2dn 2dp 2dq d2r 2dr. 2ds 2dt 2dv 2dw 2dx 2dy 2dz
1f 2f. 2fb 2fc 2fd 2ff 2fg 2f1h 2fj 2fk f2l 2fl. 2fm 2fn 2fp 2fq f2r 2fr. 2fs 2ft 2fv 2fw 2fx 2fy 2fz
1g 2g. 2gb 2gc 2gd 2gf 2gg 2g1h 2gj 2gk g2l 2gl. 2gm 2gn 2gp 2gq g2r 2gr. 2gs 2gt 2gv 2gw 2gx 2gy 2gz
2h. 2hb 2hc 2hd 2hf 2hg 2h1h 2hj 2hk 2hl 2hm 2hn 2hp 2hq 2hr 2hs 2ht 2hv 2hw 2hx 2hy 2hz
1j 2j. 2jb 2jc 2jd 2jf 2jg 2j1h 2jj 2jk 2jl 2jm 2jn 2jp 2jq 2jr 2js 2jt 2jv 2jw 2jx 2jy 2jz
1k 2k. 2kb 2kc 2kd 2kf 2kg 2k1h 2kj 2kk k2l 2kl. 2km 2kn 2kp 2kq k2r 2kr. 2ks 2kt 2kv 2kw 2kx 2ky 2kz
1l 2l. 2lb 2lc 2ld 2lf 2lg 2l1h 2lj 2lk l4l 2ll. 2lm 2ln 2lp 2lq 2lr 2ls 2lt 2lv 2lw 2lx 2ly 2lz
1m 2m. 2mb 2mc 2md 2mf 2mg 2m1h 2mj 2mk 2ml 2mm 2mn 2mp 2mq 2mr 2ms 2mt 2mv 2mw 2mx 2my 2mz
1n 2n. 2nb 2nc 2nd 2nf 2ng 2n1h 2nj 2nk 2nl 2nm 2nn 2np 2nq 2nr 2ns 2nt 2nv 2nw 2nx 2ny 2nz
1p 2p. 2pb 2pc 2pd 2pf 2pg 2p1h 2pj 2pk p2l 2pl. 2pm 2pn 2pp 2pq p2r 2pr. 2ps 2pt 2pv 2pw 2px 2py 2pz
1q 2q. 2qb 2qc 2qd 2qf 2qg 2q1h 2qj 2qk 2ql 2qm 2qn 2qp 2qq 2qr 2qs 2qt 2qv 2qw 2qx 2qy 2qz
1r 2r. 2rb 2rc 2rd 2rf 2rg 2r1h 2rj 2rk 2rl 2rm 2rn 2rp 2rq r2r 2rr. 2rs 2rt 2rv 2rw 2rx 2ry 2rz
1s 2s. 2sb 2sc 2sd 2sf 2sg 2s1h 2sj 2sk 2sl 2sm 2sn 2sp 2sq 2sr 2ss 2st 2sv 2sw 2sx 2sy 2sz
1t 2t. 2tb 2tc 2td 2tf 2tg 2t1h 2tj 2tk 2t2l 2tm 2tn 2tp 2tq t2r 2tr. 2ts 2tt 2tv 2tw 2tx 2ty 2tz
1v 2v. 2vb 2vc 2vd 2vf 2vg 2v1h 2vj 2vk v2l 2vl. 2vm 2vn 2vp 2vq v2r 2vr. 2vs 2vt 2vv 2vw 2vx 2vy 2vz
1w 2w. 2wb 2wc 2wd 2wf 2wg 2w1h 2wj 2wk 2wl 2wm 2wn 2wp 2wq 2wr 2ws 2wt 2wv 2ww 2wx 2wy 2wz
1x 2x. 2xb 2xc 2xd 2xf 2xg 2x1h 2xj 2xk 2xl 2xm 2xn 2xp 2xq 2xr 2xs 2xt 2xv 2xw 2xx 2xy 2xz
1y 2y. 2yb 2yc 2yd 2yf 2yg 2y1h 2yj 2yk 2yl 2ym 2yn 2yp 2yq 2yr 2ys 2yt 2yv 2yw 2yx 2yy 2yz
1z 2z. 2zb 2zc 2zd 2zf 2zg 2z1h 2zj 2zk 2zl 2zm 2zn 2zp 2zq 2zr 2zs 2zt 2zv 2zw 2zx 2zy 2zz
1ñ 2ñ.
2b3p2t 2c3p2t 2d3p2t 2l3p2t 2m3p2t 2n3p2t 2r3p2t 2s3p2t 2t3p2t 2x3p2t 2y3p2t 4pt.
2b3c2t 2c3c2t 2d3c2t 2l3c2t 2m3c2t 2n3c2t 2r3c2t 2s3c2t 2t3c2t 2x3c2t 2y3c2t 4ct.
2b3c2n 2c3c2n 2d3c2n 2l3c2n 2m3c2n 2n3c2n 2r3c2n 2s3c2n 2t3c2n 2x3c2n 2y3c2n 4cn.
2b3p2s 2c3p2s 2d3p2s 2l3p2s 2m3p2s 2n3p2s 2r3p2s 2s3p2s 2t3p2s 2x3p2s 2y3p2s 4ps.
2b3m2n 2c3m2n 2d3m2n 2l3m2n 2m3m2n 2n3m2n 2r3m2n 2s3m2n 2t3m2n 2x3m2n 2y3m2n 4mn.
2b3g2n 2c3g2n 2d3g2n 2l3g2n 2m3g2n 2n3g2n 2r3g2n 2s3g2n 2t3g2n 2x3g2n 2y3g2n 4gn.
2b3f2t 2c3f2t 2d3f2t 2l3f2t 2m3f2t 2n3f2t 2r3f2t 2s3f2t 2t3f2t 2x3f2t 2y3f2t 4ft.
2b3p2n 2c3p2n 2d3p2n 2l3p2n 2m3p2n 2n3p2n 2r3p2n 2s3p2n 2t3p2n 2x3p2n 2y3p2n 4pn.
2b3c2z 2c3c2z 2d3c2z 2l3c2z 2m3c2z 2n3c2z 2r3c2z 2s3c2z 2t3c2z 2x3c2z 2y3c2z 4cz.
2b3t2z 2c3t2z 2d3t2z 2l3t2z 2m3t2z 2n3t2z 2r3t2z 2s3t2z 2t3t2z 2x3t2z 2y3t2z 4tz.
2b3t2s 2c3t2s 2d3t2s 2l3t2s 2m3t2s 2n3t2s 2r3t2s 2s3t2s 2t3t2s 2x3t2s 2y3t2s 4ts.
san4c5t
plan4c5t
2no.
4caca4
4cago4
4caga4
4cagas.
4teta.
4tetas.
4puta4
4puto4
.hu4mea
.hu4meo
.he4mee
4meo.
4meable.
4meables.
4pedo4
4culo4
3mente.
4i3go.
4es.
4és
4e.
4e3mos.
4éis.
4en.
4ía.
4ías.
4ía3mos.
4íais.
4ían.
4í.
4í4s3te.
4í4s3tes.
4í3tes.
4í3mos.
4ís3teis.
4e3ré.
4e3rás.
4e3rés.
4e3rís.
4e3rá.
4e3re3mos.
4e3réis.
4e3rán.
4i3ga.
4i3gas.
4i3gás.
4i3gamos.
4i3gáis.
4a4i3gan.
4e3ría.
4e3rías.
4e3ríamos.
4e3ríais.
4e3rían.
4i3gá3mosme.
4i3gá3mosmele.
4i3gá3mosmelo.
4i3gá3mos3mela.
4i3gá3mosmeles.
4i3gá3mosmelos.
4i3gá3mos3melas.
4i3gá3moste.
4i3gá3mostele.
4i3gá3mostelo.
4i3gá3mos3tela.
4i3gá3mosteles.
4i3gá3mostelos.
4i3gá3mos3telas.
4i3gá3mosle.
4i3gá3mosla.
4i3gá3moslo.
4i3gá3mosele.
4i3gá3moselo.
4i3gá3mosela.
4i3gá3moseles.
4i3gá3moselos.
4i3gá3moselas.
4i3gá3monos.
4i3gá3monosle.
4i3gá3monoslo.
4i3gá3monosla.
4i3gá3monosles.
4i3gá3monoslos.
4i3gá3monoslas.
4i3gá3moos.
4i3gá3moosle.
4i3gá3mooslo.
4i3gá3moosla.
4i3gá3moosles.
4i3gá3mooslos.
4i3gá3mooslas.
4i3gá3mosles.
4i3gá3moslas.
4i3gá3moslos.
4ed.
4é.
4edme.
4édmele.
4édmelo.
4éd3mela.
4édmeles.
4édmelos.
4éd3melas.
4edte.
4édtele.
4édtelo.
4éd3tela.
4édteles.
4édtelos.
4éd3telas.
4edle.
4eedla.
4edlo.
4édsele.
4édselo.
4édsela.
4édseles.
4édselos.
4édselas.
4ednos.
4édnosle.
4édnoslo.
4édnosla.
4édnosles.
4édnoslos.
4édnoslas.
4eos.
4éosle.
4éoslo.
4éosla.
4éosles.
4éoslos.
4éoslas.
4edles.
4edlas.
4edlos.
4er.
4erme.
4érmele.
4érmelo.
4ér3mela.
4érmeles.
4érmelos.
4ér3melas.
4erte.
4értele.
4értelo.
4ér3tela.
4érteles.
4értelos.
4ér3telas.
4erle.
4erla.
4erlo.
4erse.
4érsele.
4érselo.
4érsela.
4érseles.
4érselos.
4érselas.
4ernos.
4érnosle.
4érnoslo.
4érnosla.
4érnosles.
4érnoslos.
4érnoslas.
4e3ros.
4é3rosle.
4é3roslo.
4é3rosla.
4é3rosles.
4é3roslos.
4é3roslas.
4erles.
4erlas.
4erlos.
4í3do.
4í3da.
4í3dos.
4í3das.
4o.
4as.
4a.
4ás.
4a3mos.
4áis.
4an.
4aste.
4astes.
4ó.
4ates.
4asteis.
4a3ron.
4a3ba.
4a3bas.
4á3bamos.
4a3bais.
4a3ban.
4a3ría.
4a3rías.
4a3ríamos.
4a3ríais
4a3rían.
4a3ré.
4a3rás.
4a3rés.
4a3rís.
4a3rá.
4a3remos.
4a3réis.
4a3rán.
4a3ra.
4a3ras.
4á3ramos.
4a3rais.
4a3ran.
4a3re.
4a3res.
4á3remos.
4a3reis.
4a3ren.
4a3se.
4a3ses.
4á3semos.
4a3seis.
4a3sen.
4ad.
e5r4as.
e5r4a3mos.
e5r4áis.
e5r4an.
e5r4aste.
e5r4astes.
e5r4ates.
e5r4asteis.
e5r4a3ron.
e5r4a3ba.
e5r4a3bas.
e5r4á3bamos.
e5r4a3bais.
e5r4a3ban.
e5r4a3ría.
e5r4a3rías.
e5r4a3ríamos.
e5r4a3ríais
e5r4a3rían.
e5r4a3ré.
e5r4a3rás.
e5r4a3rés.
e5r4a3rís.
e5r4a3rá.
e5r4a3remos.
e5r4a3réis.
e5r4a3rán.
e5r4a3ra.
e5r4a3ras.
e5r4á3ramos.
e5r4a3rais.
e5r4a3ran.
e5r4a3re.
e5r4a3res.
e5r4á3remos.
e5r4a3reis.
e5r4a3ren.
e5r4a3se.
e5r4a3ses.
e5r4á3semos.
e5r4a3seis.
e5r4a3sen.
e5r4ad.
4adme.
4ádmele.
4ádmelo.
4ád3mela.
4ádmeles.
4ádmelos.
4ád3melas.
4adte.
4ádtele.
4ádtelo.
4ád3tela.
4ádteles.
4ádtelos.
4ád3telas.
4adle.
4eadla.
4adlo.
4ádsele.
4ádselo.
4ádsela.
4ádseles.
4ádselos.
4ádselas.
4adnos.
4ádnosle.
4ádnoslo.
4ádnosla.
4ádnosles.
4ádnoslos.
4ádnoslas.
4aos.
4áosle.
4áoslo.
4áosla.
4áosles.
4áoslos.
4áoslas.
4adles.
4adlas.
4adlos.
4ar.
4a4rme.
4á4rmele.
4á4rmelo.
4á4r3mela.
4á4r3meles.
4á4r3melos.
4á4r3melas.
4a4r3te.
4á4r3tele.
4á4r3telo.
4á4r3tela.
4á4r3teles.
4á4r3telos.
4á4r3telas.
4a4r3le.
4a4r3la.
4a4r3lo.
4a4r3se.
4á4r3sele.
4á4r3selo.
4á4r3sela.
4á4r3seles.
4á4r3selos.
4á4r3selas.
4a4r3nos.
4á4r3nosle.
4á4r3noslo.
4á4r3nosla.
4á4r3nosles.
4á4r3noslos.
4á4r3noslas.
4a3ros.
4árosle.
4ároslo.
4árosla.
4árosles.
4ároslos.
4ároslas.
4a4r3les.
4a4r3las.
4a4r3los.
4a3do.
4a3da.
4a3dos.
4a3das.
e5r4a3do.
e5r4a3da.
e5r4a3dos.
e5r4a3das.
4ando
4ándole.
4ándolo.
4ándola.
4ándoles.
4ándolos.
4ándolas.
4ándonos.
4ándoos.
4ándome.
4ándomelo.
4ándomela.
4ándomele.
4ándomelos.
4ándomelas.
4ándomeles.
4ándote.
4ándoteme.
4ándotelo.
4ándotela.
4ándotele.
4ándotelos.
4ándotelas.
4ándoteles.
4ándotenos.
4ándose.
4ándoseme.
4ándoselo.
4ándosela.
4ándosele.
4ándoselos.
4ándoselas.
4ándoseles.
4ándosenos.
4a3dor.
4a3dora.
4a3dores.
4a3doras.
e5r4a3dor.
e5r4a3dora.
e5r4a3dores.
e5r4a3doras.
acto1h
acto1a2 acto1e2 acto1i2 acto1o2 acto1u2
acto1á2 acto1é2 acto1í2 acto1ó2 acto1ú2
afro1h
afro1a2 afro1e2 afro1i2 afro1o2 afro1u2
afro1á2 afro1é2 afro1í2 afro1ó2 afro1ú2
.a2
.an2a2
.an2e2
.an2i2
.an2o2
.an2u2
.an2á2
.an2é2
.an2í2
.an2ó2
.an2ú2.
ana3lí
.aná3li
.ana3li
.an3aero
.an3e2pigr
.ane3xa
.ane3xá
.ane3xe
.ane3xé
.ane3xio
.ane3xió
.an3h
.ani3mad
.ani3mád
.ani3dar
.ani3ll
.ani3m
.aniña
.ani3q
.an3i2so
.an3i2só
.ani3vel
.ano5che
.ano5din
.ano5mal
.ano5nad
.anó3nim
.anó5mal
.ano5nim
.ano5ta
.ano3tá
.anua3l
.anua4lm
.anu3bl
.anu3da
.anu3l
asu3b2
aero1h
aero1a2 aero1e2 aero1i2 aero1o2 aero1u2
aero1á2 aero1é2 aero1í2 aero1ó2 aero1ú2
anfi1h
anfi1a2 anfi1e2 anfi1i2 anfi1o2 anfi1u2
anfi1á2 anfi1é2 anfi1í2 anfi1ó2 anfi1ú2
anglo1h
anglo1a2 anglo1e2 anglo1i2 anglo1o2 anglo1u2
anglo1á2 anglo1é2 anglo1í2 anglo1ó2 anglo1ú2
ante1h
ante1a2 ante1e2 ante1i2 ante1o2 ante1u2
ante1á2 ante1é2 ante1í2 ante1ó2 ante1ú2
.ante2o3je
acante2
4ísmo.
4ísmos.
4ísta.
4ístas.
4ístico.
4ísticos.
4ística.
4ísticas.
t4eo3nes.
mante4a
e4a3miento
.anti1h
.anti1a2 .anti1e2 .anti1i2 .anti1o2 .anti1u2
.anti1á2 .anti1é2 .anti1í2 .anti1ó2 .anti1ú2
ti2o3qu
ti2o3co
archi1h
archi1a2 archi1e2 archi1i2 archi1o2 archi1u2
archi1á2 archi1é2 archi1í2 archi1ó2 archi1ú2
auto1h
auto1a2 auto1e2 auto1i2 auto1o2 auto1u2
auto1á2 auto1é2 auto1í2 auto1ó2 auto1ú2
biblio1h
biblio1a2 biblio1e2 biblio1i2 biblio1o2 biblio1u2
biblio1á2 biblio1é2 biblio1í2 biblio1ó2 biblio1ú2
bio1h
bio1a2 bio1e2 bio1i2 bio1o2 bio1u2
bio1á2 bio1é2 bio1í2 bio1ó2 bio1ú2
bi1u2ní
cardio1h
cardio1a2 cardio1e2 cardio1i2 cardio1o2 cardio1u2
cardio1á2 cardio1é2 cardio1í2 cardio1ó2 cardio1ú2
cefalo1h
cefalo1a2 cefalo1e2 cefalo1i2 cefalo1o2 cefalo1u2
cefalo1á2 cefalo1é2 cefalo1í2 cefalo1ó2 cefalo1ú2
centi1h
centi1a2 centi1e2 centi1i2 centi1o2 centi1u2
centi1á2 centi1é2 centi1í2 centi1ó2 centi1ú2
centi5área
ciclo1h
ciclo1a2 ciclo1e2 ciclo1i2 ciclo1o2 ciclo1u2
ciclo1á2 ciclo1é2 ciclo1í2 ciclo1ó2 ciclo1ú2
o4i3dea.
o4i3deas.
o4i3dal.
o4i3dales.
4o2i3de.
4o2i3des.
4i2dal.
4i2dales.
4i3deo.
4i3deos.
cito1h
cito1a2 cito1e2 cito1i2 cito1o2 cito1u2
cito1á2 cito1é2 cito1í2 cito1ó2 cito1ú2
3c2neor
cnico1h
cnico1a2 cnico1e2 cnico1i2 cnico1o2 cnico1u2
cnico1á2 cnico1é2 cnico1í2 cnico1ó2 cnico1ú2
.co2a2
.co2e2
.co2i2
.co3o4
.co2u2
.co2á2
.co2é2
.co2í2
.co2ó2
.co2ú2
co4á3gul
co4acci
co4acti
co4adju
co4a3dun
co4adyu
co3agen
co4a3gul
co4a3lic
co4aptac
co4art
co4árt
co4e3fic
co4erc
co4erz
co4e3tá
co3exis
co4imbr
co4inci
co4i3to
co3n4imbri
co4o3per
co4o3pér
co4opt
co4ord
con1imbr
con1urb
cripto1h
cripto1a2 cripto1e2 cripto1i2 cripto1o2 cripto1u2
cripto1á2 cripto1é2 cripto1í2 cripto1ó2 cripto1ú2
crono1h
crono1a2 crono1e2 crono1i2 crono1o2 crono1u2
crono1á2 crono1é2 crono1í2 crono1ó2 crono1ú2
contra1h
contra1a2 contra1e2 contra1i2 contra1o2 contra1u2
contra1á2 contra1é2 contra1í2 contra1ó2 contra1ú2
deca1h
deca1a2 deca1e2 deca1i2 deca1o2 deca1u2
deca1á2 deca1é2 deca1í2 deca1ó2 deca1ú2
4e3dro.
4e3dros.
4é3drico.
4é3dricos.
4é3drica.
4é3dricas.
.de2sa2 .de2se2 .de2si2 .de2so2 .de2su2
.de2sá2 .de2sé2 .de2sí2 .de2só2 .de2sú2
deca2i3mient
decimo1
3sa.
3sas.
de2s3órde
de2s3orde
de2s3abast
de2s3aboll
de2s3aboto
de2s3abr
desa3brid
de2s3abroch
de2s3aceit
de2s3aceler
desa3cert
desa3ciert
de2s3acobar
de2s3acomod
de2s3acomp
de2s3acons
de2s3acopl
de2s3acorr
de2s3acostum
de2s3acot
desa3craliz
de2s3acredit
de2s3activ
de2s3acuart
de2s3aderez
de2s3adeud
de2s3adorar
de2s3adormec
de2s3adorn
de2s3advert
de2s3aferr
de2s3afic
de2s3afil
de2s3afin
de2s3afor
desa3gú
desa3garr
de2s3agraci
de2s3agrad
de2s3agravi
de2s3agreg
de2s3agrup
de2s3agu
desa3guisado
de2s3aherr
de2s3ahij
de2s3ajust
de2s3alagar
de2s3alent
de2s3alfom
de2s3alfor
de2s3aliñ
desa3lin
de2s3alien
de2s3aline
desa3liv
de2s3alm
de2s3almid
de2s3aloj
de2s3alquil
de2s3alter
de2s3alumbr
desa3marr
desa3mobl
de2s3amold
de2s3amort
de2s3amuebl
de2s3ampa
de2s3and
de2s3angel
de3sangr
de2s3anid
de2s3anim
de2s3aním
de2s3anud
desa3pañ
desa3pacib
de2s3apadr
de2s3apare
de2s3aparec
de2s3aparic
de2s3apeg
de2s3apercib
de2s3apes
de2s3aplic
de2s3apolill
de2s3apoy
de2s3aprend
de2s3apret
de2s3apriet
de2s3aprob
de2s3apropi
de2s3aprovech
de2s3arbol
de2s3aren
de2s3arm
des4arme
de2s3arraig
de2s3arregl
de2s3arrend
de2s3arrim
desa3rroll
de2s3arrop
de2s3arrug
de2s3articul
de2s3asent
de2s3asist
de2s3asn
desa3soseg
desa3sosieg
de2s3atenc
de2s3atend
de2s3atiend
de2s3atent
desa3tin
de2s3atorn
de2s3atranc
de2s3autor
de2s3avis
desa3yun
desa3zón
desa3zon
de2s3embal
de2s3embál
de2s3embar
de2s3embár
de2s3embarg
de2s3embols
de2s3emborr
de2s3embosc
de2s3embot
de2s3embrag
de2s3embrág
de2s3embrave
de2s3embráve
de2s3embroll
de2s3embróll
de2s3embruj
de2s3embrúj
de3semej
de2s3empañ
de2s3empáñ
de2s3empac
de2s3empaquet
de2s3empaquét
de2s3emparej
de2s3emparéj
de2s3emparent
de2s3empat
de2s3empé
de2s3empedr
de2s3empeg
de2s3empeor
de2s3emperez
de2s3empern
de2s3emple
de2s3empolv
de2s3empotr
de2s3empoz
de2s3enam
de2s3encab
de2s3encad
de2s3encaj
de2s3encáj
de2s3encall
de2s3encáll
de2s3encam
de3sencant
de2s3encap
de2s3encar
de2s3encár
de2s3ench
de2s3encl
de2s3enco
de2s3encr
de2s3encu
de2s3end
de3senfad
de3senfád
de2s3enfi
de2s3enfo
de2s3enfó
de3senfren
de2s3enfund
de2s3enfur
de3sengañ
de3sengáñ
de2s3enganch
de2s3engar
de2s3engas
de2s3engom
de2s3engoz
de2s3engra
de2s3enhebr
de2s3enj
de2s3enlad
de2s3enlaz
de2s3enlo
de2s3enm
de2s3enr
de2s3ens
de2s3enta
de3sentend
de3sentien
de3sentién
de2s3enter
de2s3entier
de2s3entiér
de2s3ento
de2s3entr
de2s3entu
de2s3envain
de3senvolvim
de3seo
de2s3eq
de3s4erci
de3s4ert
de3s4ért
de2s3espa
de3sesperac
de2s3esperanz
de3sesper
de2s3estabil
de2s3estim
de3sider
de3sidia
de3sidio
de3siert
de3sign
de3sigual
de3silusi
de2s3imagin
de2s3iman
de2s3impon
de2s3impresX
de2s3incent
de2s3inclin
de2s3incorp
de2s3incrust
de3sinenc
de3sinfec
de3su3dar
de3su3das
de3su3dan
de2s3inflam
de2s3infl
de2s3inform
de2s3inhib
de2s3insect
de2s3instal
de3s4integr
de3s4inter
de2s3intox
de2s3inver
de2s3impres
de3sisten
de3isti
de2s3obedec
de2s3oblig
de2s3obstr
de3socup
de2s3odor
de3solac
de3solad
de3soll
de2s3orej
de2s3orient
de3sortij
de2s3organi
de3suell
de3sonce
de2s3ovi
de2s3oxi
de2s3oye
de2s3oyé
de3s4ubstan
de3s4ustan
de3s4oseg
de2s3ub4ic
de2s3unir
de2s3unier
de2s3unim
.dieci1o2
dodeca1h
dodeca1a2 dodeca1e2 dodeca1i2 dodeca1o2 dodeca1u2
dodeca1á2 dodeca1é2 dodeca1í2 dodeca1ó2 dodeca1ú2
ecano1h
ecano1a2 ecano1e2 ecano1i2 ecano1o2 ecano1u2
ecano1á2 ecano1é2 ecano1í2 ecano1ó2 ecano1ú2
eco1h
eco1a2 eco1e2 eco1i2 eco1o2 eco1u2
eco1á2 eco1é2 eco1í2 eco1ó2 eco1ú2
ectro1h
ectro1a2 ectro1e2 ectro1i2 ectro1o2 ectro1u2
ectro1á2 ectro1é2 ectro1í2 ectro1ó2 ectro1ú2
.en2a2 .en2e2 .en2i2 .en2o2 .en2u2
.en2á2 .en2é2 .en2í2 .en2ó2 .en2ú2
.ene3mist
.ene3míst
.eno3jar
.enu3mera
.enu3merá
.enu3mere
4o3lógico.
4o3lógica.
4o3lógicos.
4o3lógicas.
4o3lógicamente.
4o3logía.
4o3logías.
4ó3logo.
4ó3loga.
4ó3logos.
4ó3logas.
endo1h
endo1a2 endo1e2 endo1i2 endo1o2 endo1u2
endo1á2 endo1é2 endo1í2 endo1ó2 endo1ú2
ento1h
ento1a2 ento1e2 ento1i2 ento1o2 ento1u2
ento1á2 ento1é2 ento1í2 ento1ó2 ento1ú2
4emboca
entre1h
entre1a2 entre1e2 entre1i2 entre1o2 entre1u2
entre1á2 entre1é2 entre1í2 entre1ó2 entre1ú2
euco1h
euco1a2 euco1e2 euco1i2 euco1o2 euco1u2
euco1á2 euco1é2 euco1í2 euco1ó2 euco1ú2
euro1h
euro1a2 euro1e2 euro1i2 euro1o2 euro1u2
euro1á2 euro1é2 euro1í2 euro1ó2 euro1ú2
extra1h
extra1a2 extra1e2 extra1i2 extra1o2 extra1u2
extra1á2 extra1é2 extra1í2 extra1ó2 extra1ú2
u4teri
.cau5t
.deu5t
fono1h
fono1a2 fono1e2 fono1i2 fono1o2 fono1u2
fono1á2 fono1é2 fono1í2 fono1ó2 fono1ú2
foto1h
foto1a2 foto1e2 foto1i2 foto1o2 foto1u2
foto1á2 foto1é2 foto1í2 foto1ó2 foto1ú2
gastro1h
gastro1a2 gastro1e2 gastro1i2 gastro1o2 gastro1u2
gastro1á2 gastro1é2 gastro1í2 gastro1ó2 gastro1ú2
geo1h
geo1a2 geo1e2 geo1i2 geo1o2 geo1u2
geo1á2 geo1é2 geo1í2 geo1ó2 geo1ú2
gluco1h
gluco1a2 gluco1e2 gluco1i2 gluco1o2 gluco1u2
gluco1á2 gluco1é2 gluco1í2 gluco1ó2 gluco1ú2
hecto1h
hecto1a2 hecto1e2 hecto1i2 hecto1o2 hecto1u2
hecto1á2 hecto1é2 hecto1í2 hecto1ó2 hecto1ú2
helio1h
helio1a2 helio1e2 helio1i2 helio1o2 helio1u2
helio1á2 helio1é2 helio1í2 helio1ó2 helio1ú2
hemato1h
hemato1a2 hemato1e2 hemato1i2 hemato1o2 hemato1u2
hemato1á2 hemato1é2 hemato1í2 hemato1ó2 hemato1ú2
hemi1h
hemi1a2 hemi1e2 hemi1i2 hemi1o2 hemi1u2
hemi1á2 hemi1é2 hemi1í2 hemi1ó2 hemi1ú2
hemo1h
hemo1a2 hemo1e2 hemo1i2 hemo1o2 hemo1u2
hemo1á2 hemo1é2 hemo1í2 hemo1ó2 hemo1ú2
2al.
2ales.
hexa1h
hexa1a2 hexa1e2 hexa1i2 hexa1o2 hexa1u2
hexa1á2 hexa1é2 hexa1í2 hexa1ó2 hexa1ú2
hidro1h
hidro1a2 hidro1e2 hidro1i2 hidro1o2 hidro1u2
hidro1á2 hidro1é2 hidro1í2 hidro1ó2 hidro1ú2
hipe2r3r
hipe2r1a2 hipe2r1e2 hipe2r1i2 hipe2r1o2 hipe2r1u2
hipe2r1á2 hipe2r1é2 hipe2r1í2 hipe2r1ó2 hipe2r1ú2
pe3r4e3mia
histo1h
histo1a2 histo1e2 histo1i2 histo1o2 histo1u2
histo1á2 histo1é2 histo1í2 histo1ó2 histo1ú2
homo1h
homo1a2 homo1e2 homo1i2 homo1o2 homo1u2
homo1á2 homo1é2 homo1í2 homo1ó2 homo1ú2
icono1h
icono1a2 icono1e2 icono1i2 icono1o2 icono1u2
icono1á2 icono1é2 icono1í2 icono1ó2 icono1ú2
.i2n2a2
.i2n2e2
.i2n2i2
.i2n2o2
.i2n2u2
.i2n2á2
.i2n2é2
.i2n2í2
.i2n2ó2
.i2n2ú2
.in3abord
.in3abarc
.in3acent
.in3aguant
.in3adapt
.ina3movib
.in3analiz
.ina3nic
.in3anim
.iná3nim
.in3apel
.in3aplic
.in3aprens
.in3apreci
.in3arrug
.in3asist
.iné3dit
.in3efic
.in3efici
.in3eludi
.ine3narr
.ini3cia
.ini3ciá
.ini3cie
.ino3cuo
.ino3cua
.ino3cula
.ino3culá
.ino3cule
.inú3til
.inu3tiliz
infra1h
infra1a2 infra1e2 infra1i2 infra1o2 infra1u2
infra1á2 infra1é2 infra1í2 infra1ó2 infra1ú2
.inte2r3r
.inte2r1a2 .inte2r1e2 .inte2r1i2 .inte2r1o2 .inte2r1u2
.inte2r1á2 .inte2r1é2 .inte2r1í2 .inte2r1ó2 .inte2r1ú2
.in3ter2e3sa
.in3ter2e3se
.in3ter2e3so
.in3ter2e3sá
.in3ter2e3sé
.in3ter2e3só
.de3s4in3ter2e3sa
.de3s4in3ter2e3se
.de3s4in3ter2e3so
.de3s4in3ter2e3sá
.de3s4in3ter2e3sé
.de3s4in3ter2e3só
3te3ri3n
4te4r5i4nsu
.in3te3r4rog
.in3te3r4rupc
.in3te3r4rupt
.in3te3r4rump
intra1h
intra1a2 intra1e2 intra1i2 intra1o2 intra1u2
intra1á2 intra1é2 intra1í2 intra1ó2 intra1ú2
iso1h
iso1a2 iso1e2 iso1i2 iso1o2 iso1u2
iso1á2 iso1é2 iso1í2 iso1ó2 iso1ú2
kilo1h
kilo1a2 kilo1e2 kilo1i2 kilo1o2 kilo1u2
kilo1á2 kilo1é2 kilo1í2 kilo1ó2 kilo1ú2
macro1h
macro1a2 macro1e2 macro1i2 macro1o2 macro1u2
macro1á2 macro1é2 macro1í2 macro1ó2 macro1ú2
mal2
ma4l3h
.ma4l3e4du
mal3b
mal3c
mal3d
mal3f
mal3g
mal3m
mal3p
mal3q
mal3s
mal3t
mal3v
bien2
bien3h
bien3v
bien3q
bien3m
bien3t
b4ien3do.
.su3b4ien
b4ien3das.
maxi1h
maxi1a2 maxi1e2 maxi1i2 maxi1o2 maxi1u2
maxi1á2 maxi1é2 maxi1í2 maxi1ó2 maxi1ú2
megalo1h
megalo1a2 megalo1e2 megalo1i2 megalo1o2 megalo1u2
megalo1á2 megalo1é2 megalo1í2 megalo1ó2 megalo1ú2
mega1h
mega1a2 mega1e2 mega1i2 mega1o2 mega1u2
mega1á2 mega1é2 mega1í2 mega1ó2 mega1ú2
melano1h
melano1a2 melano1e2 melano1i2 melano1o2 melano1u2
melano1á2 melano1é2 melano1í2 melano1ó2 melano1ú2
micro1h
micro1a2 micro1e2 micro1i2 micro1o2 micro1u2
micro1á2 micro1é2 micro1í2 micro1ó2 micro1ú2
mili1h
mili1a2 mili1e2 mili1i2 mili1o2 mili1u2
mili1á2 mili1é2 mili1í2 mili1ó2 mili1ú2
familia3ri
ia5res.
amili6a
a3rio
li5área
mini1h
mini1a2 mini1e2 mini1i2 mini1o2 mini1u2
mini1á2 mini1é2 mini1í2 mini1ó2 mini1ú2
2os.
2o3so.
2o3sos.
2o3sa.
2o3sas.
2o3samente.
mini4a5tur
multi1h
multi1a2 multi1e2 multi1i2 multi1o2 multi1u2
multi1á2 multi1é2 multi1í2 multi1ó2 multi1ú2
miria1h
miria1a2 miria1e2 miria1i2 miria1o2 miria1u2
miria1á2 miria1é2 miria1í2 miria1ó2 miria1ú2
mono1h
mono1a2 mono1e2 mono1i2 mono1o2 mono1u2
mono1á2 mono1é2 mono1í2 mono1ó2 mono1ú2
2i3co.
2i3cos.
2i3ca.
2i3cas.
namo1h
namo1a2 namo1e2 namo1i2 namo1o2 namo1u2
namo1á2 namo1é2 namo1í2 namo1ó2 namo1ú2
necro1h
necro1a2 necro1e2 necro1i2 necro1o2 necro1u2
necro1á2 necro1é2 necro1í2 necro1ó2 necro1ú2
neo1h
neo1a2 neo1e2 neo1i2 neo1o2 neo1u2
neo1á2 neo1é2 neo1í2 neo1ó2 neo1ú2
neto1h
neto1a2 neto1e2 neto1i2 neto1o2 neto1u2
neto1á2 neto1é2 neto1í2 neto1ó2 neto1ú2
norte1h
norte1a2 norte1e2 norte1i2 norte1o2 norte1u2
norte1á2 norte1é2 norte1í2 norte1ó2 norte1ú2
octo1h
octo1a2 octo1e2 octo1i2 octo1o2 octo1u2
octo1á2 octo1é2 octo1í2 octo1ó2 octo1ú2
octa1h
octa1a2 octa1e2 octa1i2 octa1o2 octa1u2
octa1á2 octa1é2 octa1í2 octa1ó2 octa1ú2
oligo1h
oligo1a2 oligo1e2 oligo1i2 oligo1o2 oligo1u2
oligo1á2 oligo1é2 oligo1í2 oligo1ó2 oligo1ú2
omni1h
omni1a2 omni1e2 omni1i2 omni1o2 omni1u2
omni1á2 omni1é2 omni1í2 omni1ó2 omni1ú2
i2o.
i2os.
paleo1h
paleo1a2 paleo1e2 paleo1i2 paleo1o2 paleo1u2
paleo1á2 paleo1é2 paleo1í2 paleo1ó2 paleo1ú2
para1h
para1a2 para1e2 para1i2 para1o2 para1u2
para1á2 para1é2 para1í2 para1ó2 para1ú2
para2is.
aí5so.
aí5sos.
penta1h
penta1a2 penta1e2 penta1i2 penta1o2 penta1u2
penta1á2 penta1é2 penta1í2 penta1ó2 penta1ú2
piezo1h
piezo1a2 piezo1e2 piezo1i2 piezo1o2 piezo1u2
piezo1á2 piezo1é2 piezo1í2 piezo1ó2 piezo1ú2
pluri1h
pluri1a2 pluri1e2 pluri1i2 pluri1o2 pluri1u2
pluri1á2 pluri1é2 pluri1í2 pluri1ó2 pluri1ú2
poli1h
poli1a2 poli1e2 poli1i2 poli1o2 poli1u2
poli1á2 poli1é2 poli1í2 poli1ó2 poli1ú2
poli4u3r
poli4o5mie
poli4arq
poli4árq
poli4éste
poli4andr
poli4antea
expoli4
.pos2t2a2
.pos2t2e2
.pos2t2i2
.pos2t2o2
.pos2t2u2
.pos2t2á2
.pos2t2é2
.pos2t2í2
.pos2t2ó2
.pos2t2ú2
.pos3tin
.pos3tín
pos3ta.
pos3tas.
s3te.
s3tes.
s3tal.
s3ta3les.
s3ti3lla.
s3ti3llas.
s3ti3llón.
s3ti3llones.
.pos3tó3ni
.pos3terg
.pos3te3ri
.pos3ti3go
.pos3ti3la
.pos3ti3ne
.pos3ti3za
.pos3ti3zo
.pos3tu3ra
s3tor.
s3tora.
s3toras.
s3tores.
.pos3tu3la
.pos3tu3lá
.pos3tu3le
.pos3tu3lé
.post3elec
.post3impr
.post3ind
.post3ope
.post3rev
.pre2a2
.pre2e2
.pre2i2
.pre2o2
.pre2u2
.pre2h2
.pre2á2
.pre2é2
.pre2í2
.pre2ó2
.pre2ú2
pre3elij
pre3elig
pre3exis
pre3emin
preo3cup
preo2cúp
pre3olí
pre3opin
.pro2a2
.pro2e2
.pro2i2
.pro2o2
.pro2u2
.pro2h2
.pro2á2
.pro2é2
.pro2í2
.pro2ó2
.pro2ú2
proto1h
proto1a2 proto1e2 proto1i2 proto1o2 proto1u2
proto1á2 proto1é2 proto1í2 proto1ó2 proto1ú2
radio1h
radio1a2 radio1e2 radio1i2 radio1o2 radio1u2
radio1á2 radio1é2 radio1í2 radio1ó2 radio1ú2
ranco1h
ranco1a2 ranco1e2 ranco1i2 ranco1o2 ranco1u2
ranco1á2 ranco1é2 ranco1í2 ranco1ó2 ranco1ú2
.re2a2
.re3e4
.re2i2
.re2o2
.re2u2
.re2á2
.re2é2
.re2í2
.re2ó2
.re2ú2
ea3cio.
ea3cios.
ea3cia.
ea3cias.
.re3abr
.re3ábr
.re3afirm
.re3afírm
.re3ajust
.rea3júst
.rea3liza
.rea3lizá
.rea3líza
.re3alim
.rea3lism
.rea3list
.re3anim
.re3aním
.re3aparec
.re3ubica
.re3ubíca
.reu3mati
.reu3máti
.re3unir
.re3unír
.re3usar
.re3usár
.re3utiliz
.re3utilíz
rmano1h
rmano1a2 rmano1e2 rmano1i2 rmano1o2 rmano1u2
rmano1á2 rmano1é2 rmano1í2 rmano1ó2 rmano1ú2
retro1h
retro1a2 retro1e2 retro1i2 retro1o2 retro1u2
retro1á2 retro1é2 retro1í2 retro1ó2 retro1ú2
romo1h
romo1a2 romo1e2 romo1i2 romo1o2 romo1u2
romo1á2 romo1é2 romo1í2 romo1ó2 romo1ú2
sobre1h
sobre1a2 sobre1e2 sobre1i2 sobre1o2 sobre1u2
sobre1á2 sobre1é2 sobre1í2 sobre1ó2 sobre1ú2
semi1h
semi1a2 semi1e2 semi1i2 semi1o2 semi1u2
semi1á2 semi1é2 semi1í2 semi1ó2 semi1ú2
i2a.
i2as.
2ótic
emi2o2
seudo1h
seudo1a2 seudo1e2 seudo1i2 seudo1o2 seudo1u2
seudo1á2 seudo1é2 seudo1í2 seudo1ó2 seudo1ú2
o2os.
.so3a4s
socio1h
socio1a2 socio1e2 socio1i2 socio1o2 socio1u2
socio1á2 socio1é2 socio1í2 socio1ó2 socio1ú2
a3rio.
a3rios.
3logía
4ón.
4ones.
4i4er.
4o2ico.
4o2icos.
4o2ica.
4o2icas.
.su2b2a2
.su2b2e2
.su2b2i2
.su2b2o2
.su2b2u2
.su2b2á2
.su2b2é2
.su2b2í2
.su2b2ó2
.su2b2ú2
.sub2i3ll
.sub2i3mien
.sub3índ
.sub3ími
.su4b3ray
.sub3aflue
.sub3arr
.sub3enten
.sub3estim
.sub3estím
.sub3ofici
.sub3urba
.sub3alter
.sub3insp
.su3bién
.su3bir
.su3bam
.su3bordin
.su3bordín
.sub3acuá
.sub3espe
.sub3esta
.su3burbi
.su4b5rein
supe2r3r
supe2r1a2 supe2r1e2 supe2r1i2 supe2r1o2 supe2r1u2
supe2r1á2 supe2r1é2 supe2r1í2 supe2r1ó2 supe2r1ú2
supe3r4a4r
supe3r4á4r
supe3r4á3vit.
supe3r4á3vits.
4a3ción.
4a3ciones.
4e3rior.
4e3riores.
4e3riora.
4e3rioras.
4e3riormente.
4e3rioridad.
4e3rioridades.
4e3ra3ble.
4e3ra3bles.
4e3ra3blemente.
pe5r4ante
perpon5d6r
supra1h
supra1a2 supra1e2 supra1i2 supra1o2 supra1u2
supra1á2 supra1é2 supra1í2 supra1ó2 supra1ú2
sup6ra
talmo1h
talmo1a2 talmo1e2 talmo1i2 talmo1o2 talmo1u2
talmo1á2 talmo1é2 talmo1í2 talmo1ó2 talmo1ú2
tele1h
tele1a2 tele1e2 tele1i2 tele1o2 tele1u2
tele1á2 tele1é2 tele1í2 tele1ó2 tele1ú2
4ósteo.
4ósteos.
termo1h
termo1a2 termo1e2 termo1i2 termo1o2 termo1u2
termo1á2 termo1é2 termo1í2 termo1ó2 termo1ú2
tetra1h
tetra1a2 tetra1e2 tetra1i2 tetra1o2 tetra1u2
tetra1á2 tetra1é2 tetra1í2 tetra1ó2 tetra1ú2
topo1h
topo1a2 topo1e2 topo1i2 topo1o2 topo1u2
topo1á2 topo1é2 topo1í2 topo1ó2 topo1ú2
tropo1h
tropo1a2 tropo1e2 tropo1i2 tropo1o2 tropo1u2
tropo1á2 tropo1é2 tropo1í2 tropo1ó2 tropo1ú2
poi3de.
poi3des.
ultra1h
ultra1a2 ultra1e2 ultra1i2 ultra1o2 ultra1u2
ultra1á2 ultra1é2 ultra1í2 ultra1ó2 ultra1ú2
xeno1h
xeno1a2 xeno1e2 xeno1i2 xeno1o2 xeno1u2
xeno1á2 xeno1é2 xeno1í2 xeno1ó2 xeno1ú2
inter4és
inter4esar
inter4in
inter4ino
inter4ior
mili4ar
mili4ario
para4íso
para4ulata
super4able
super4ación
super4ior
tran4sacc
trans4ar
trans4eúnte
trans4iber
trans4ición
trans4ido
trans4igen
trans4igir
trans4istor
trans4itab
trans4it
trans4itorio
trans4ubsta
ultra4ísmo
wa3s4h
.bi1anual
.bi1aur
.bien1and
.bien1apa
.bien1ave
.bien1est
.bien1int
.bi1ox
.bi1ó2x
.bi1un
.en1aceit
.en1aciy
.en1aguach
.en1aguaz
.en1anch
.en1apa
.en1arb
.en1art
.en2artr
.en1ej
.hepta1e
.intra1o
.intra1u
.mal1acon
.mal1acos
.mala1e
.mal1andant
.mal1andanz
.mal1est
.mal1int
.pa4n1a4meri
.pa4n1europ
.pa4n1afri
.pa4n1ópti
3p2sic
3p2siq
.re3a2eg
.re3a2q
.re3a2z
.re3a2grup
.re3i2m
.re3inc
.re3ing
.re3ins
.re3int
.re3o2b
.re1oc
.re1oj
.re3orga
.re1unt
.retro1a
.su2d1a2fr
.su2d1a2me
.su2d1est
su4d3oes
.sur1a2me
.sur1est
.sur1oes
.tele1imp
.tele1obj
.tra2s1a
.tra2s1o
.tra2s2oñ
.tran2s1alp
.tran2s1and
.tran2s1atl
.tran2s1oce
.tran2s1ur
.tri1ó2x
}
