## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Sh_latn.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Sh_latn.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Sh_latn;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Sh_latn> hyphenation pattern class

=cut

__DATA__
% This is `hyph-sh-latn.tex' version 2.02 as of Jun 22, 2008.
%
% Copyright (C) 1990,2008 Dejan Muhamedagi\'c
%               [hyphen patterns for Serbocroatian language]
%
%%% ====================================================================
%%%  @TeX-hyphen-file{
%%%     author          = "Dejan Muhamedagi\'c",
%%%     version         = "2.02",
%%%     date            = "22 June 2008",
%%%     filename        = "hyph-sh-latn.tex",
%%%     email           = "dejan@hello-penguin.com",
%%%     codetable       = "UTF-8",
%%%     keywords        = "TeX, hyphen, serbocroatian, latinic",
%%%     supported       = "yes",
%%%     abstract        = "Serbocroatian hyphenation patterns",
%%%     docstring       = "This file contains the hyphenation patterns
%%%                        for the Serbocroatian language and the
%%%                        latinic alphabet."
%%%  }
%%% ====================================================================
%
% Just the usual stuff:  This work is published without any
% waranty, express or implied. And in hope that it will be useful.
%
% This file can be redistributed and/or modified under the terms
% of the LaTeX Project Public License distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or any later version.
%
% NB:
% It is allowed to leave one character at the end of the row.
% If you find that awkward these patterns will work well with
% \lefthyphenmin=2.
% \lefthyphenmin=1 \righthyphenmin=2
%
% Osnovni skup paterna dobijen je na osnovu fonolo\v skih osobina
% srpskohrvatskog jezika.  Pravila i preporuke sam preuzeo iz:
% 
% M. Pe\v sikan, J. Jerkovi\'c, M. Pi\v zurica:
% Pravopis srpskoga jezika
% Matica srpska, Novi Sad, 1995.
% 
% U drugom delu se nalaze izuzeci od fonolo\v skih pravila bazirani
% na boljem psiholo\v skom prelomu re\v ci. Izradjen je kori\v s\'cenjem
% slede\'cih re\v cnika:
% 
% Re\v cnik srpskohrvatskoga knji\v zevnog jezika
% Matica srpska, Matica hrvatska, Novi Sad, Zagreb, 1967-1976.
%
% Milan Vujaklija: Leksikon stranih re\v ci i izraza
% Prosveta, Beograd, 1992.
%
% -----------------------------------------------------------------
%
% \message{Serbocroatian Hyphenation Patterns `hyph-sh-latn' Version 2.02 <2008/06/22>}
%
\patterns{%
t2j
t2l
t2lj
t2r
t2v
d2j
d2l
d2lj
d2r
d2v
g2j
g2l
g2lj
g2r
g2v
h2j
h2l
h2lj
h2r
h2v
k2j
k2l
k2lj
k2r
k2v
2d1b
2d1c
2d1d
2d1f
2d1g
2d1h
2d1k
2d1m
2d1n
2d1p
2d1s
2d1t
2d1nj
2d1dž
2d1z
2d1š
2d1đ
2d1ć
2d1č
2g1ž
2g1b
2g1c
2g1d
2g1f
2g1g
2g1h
2g1k
2g1m
2g1n
2g1p
2g1s
2g1t
2g1nj
2g1dž
2g1z
2g1š
2g1đ
2g1ć
2g1č
2h1ž
2h1b
2h1c
2h1d
2h1f
2h1g
2h1h
2h1k
2h1m
2h1n
2h1p
2h1s
2h1t
2h1nj
2h1dž
2h1z
2h1š
2h1đ
2h1ć
2h1č
2k1ž
2k1b
2k1c
2k1d
2k1f
2k1g
2k1h
2k1k
2k1m
2k1n
2k1p
2k1s
2k1t
2k1nj
2k1dž
2k1z
2k1š
2k1đ
2k1ć
2k1č
2t1ž
2t1b
2t1c
2t1d
2t1f
2t1g
2t1h
2t1k
2t1m
2t1n
2t1p
2t1s
2t1t
2t1nj
2t1dž
2t1z
2t1š
2t1đ
2t1ć
2t1č
2dj.
2dl.
2dlj.
2dr.
2dv.
2gj.
2gl.
2glj.
2gr.
2gv.
2hj.
2hl.
2hlj.
2hr.
2hv.
2kj.
2kl.
2klj.
2kr.
2kv.
2tj.
2tl.
2tlj.
2tr.
2tv.
p2j
p2l
p2lj
p2r
v2j
v2l
v2lj
v2r
b2j
b2l
b2lj
b2r
f2j
f2l
f2lj
f2r
m2j
m2l
m2lj
m2r
2b1ž
2b1b
2b1c
2b1d
2b1f
2b1g
2b1h
2b1k
2b1m
2b1n
2b1p
2b1s
2b1t
2b1v
2b1nj
2b1dž
2b1z
2b1š
2b1đ
2b1ć
2b1č
2f1ž
2f1b
2f1c
2f1d
2f1f
2f1g
2f1h
2f1k
2f1m
2f1n
2f1p
2f1s
2f1t
2f1v
2f1nj
2f1dž
2f1z
2f1š
2f1đ
2f1ć
2f1č
2m1ž
2m1b
2m1c
2m1d
2m1f
2m1g
2m1h
2m1k
2m1m
2m1n
2m1p
2m1s
2m1t
2m1v
2m1nj
2m1dž
2m1z
2m1š
2m1đ
2m1ć
2m1č
2p1ž
2p1b
2p1c
2p1d
2p1f
2p1g
2p1h
2p1k
2p1m
2p1n
2p1p
2p1s
2p1t
2p1v
2p1nj
2p1dž
2p1z
2p1š
2p1đ
2p1ć
2p1č
2v1ž
2v1b
2v1c
2v1d
2v1f
2v1g
2v1h
2v1k
2v1m
2v1n
2v1p
2v1s
2v1t
2v1v
2v1nj
2v1dž
2v1z
2v1š
2v1đ
2v1ć
2v1č
2bj.
2bl.
2blj.
2br.
2fj.
2fl.
2flj.
2fr.
2mj.
2ml.
2mlj.
2mr.
2pj.
2pl.
2plj.
2pr.
2vj.
2vl.
2vlj.
2vr.
s2c
s2j
s2k
s2l
s2m
s2n
s2p
s2lj
s2r
s2t
s2v
s2nj
2s1ž
2s1b
2s1d
2s1f
2s1g
2s1h
2s1s
2s1dž
2s1z
2s1š
2s1đ
2s1ć
2s1č
2sj.
2sk.
2sl.
2sm.
2sn.
2sp.
2slj.
2sr.
2st.
2sv.
2snj.
2sc.
z2b
z2d
z2g
z2j
z2l
z2m
z2n
z2lj
z2r
z2v
z2nj
2z1ž
2z1c
2z1f
2z1h
2z1k
2z1p
2z1s
2z1t
2z1dž
2z1z
2z1š
2z1đ
2z1ć
2z1č
2zj.
2zl.
2zm.
2zn.
2zlj.
2zr.
2zv.
2znj.
2zb.
2zd.
2zg.
š2c
š2k
š2l
š2m
š2n
š2p
š2lj
š2t
š2v
š2nj
š2ć
š2č
2š1ž
2š1b
2š1d
2š1f
2š1g
2š1h
2š1s
2š1dž
2š1z
2š1š
2š1đ
2š1j
2š1r
2šk.
2šl.
2šm.
2šn.
2šp.
2šlj.
2št.
2šv.
2šnj.
2šć.
2šč.
2šc.
ž2b
ž2d
ž2g
ž2l
ž2m
ž2n
ž2lj
ž2v
ž2nj
ž2đ
2ž1ž
2ž1c
2ž1f
2ž1h
2ž1k
2ž1p
2ž1s
2ž1t
2ž1dž
2ž1z
2ž1š
2ž1ć
2ž1č
2ž1j
2ž1r
2žl.
2žm.
2žn.
2žlj.
2žv.
2žnj.
2žđ.
2žb.
2žd.
2žg.
c2j
c2r
c2v
2c1ž
2c1b
2c1c
2c1d
2c1f
2c1g
2c1h
2c1k
2c1l
2c1m
2c1n
2c1p
2c1lj
2c1s
2c1t
2c1nj
2c1dž
2c1z
2c1š
2c1đ
2c1ć
2c1č
2cj.
2cr.
2cv.
č2v
2č1ž
2č1b
2č1c
2č1d
2č1f
2č1g
2č1h
2č1j
2č1k
2č1l
2č1m
2č1n
2č1p
2č1lj
2č1r
2č1s
2č1t
2č1nj
2č1dž
2č1z
2č1š
2č1đ
2č1ć
2č1č
2čv.
2j1ž
2j1b
2j1c
2j1d
2j1f
2j1g
2j1h
2j1j
2j1k
2j1l
2j1m
2j1n
2j1p
2j1lj
2j1r
2j1s
2j1t
2j1v
2j1nj
2j1dž
2j1z
2j1š
2j1đ
2j1ć
2j1č
2l1ž
2l1b
2l1c
2l1d
2l1f
2l1g
2l1h
2l1k
2l1l
2l1m
2l1n
2l1p
2l1lj
2l1r
2l1s
2l1t
2l1v
2l1nj
2l1dž
2l1z
2l1š
2l1đ
2l1ć
2l1č
2n1ž
2n1b
2n1c
2n1d
2n1f
2n1g
2n1h
2n1k
2n1l
2n1m
2n1n
2n1p
2n1lj
2n1r
2n1s
2n1t
2n1v
2n1nj
2n1dž
2n1z
2n1š
2n1đ
2n1ć
2n1č
2lj1ž
2lj1b
2lj1c
2lj1d
2lj1f
2lj1g
2lj1h
2lj1j
2lj1k
2lj1l
2lj1m
2lj1n
2lj1p
2lj1lj
2lj1r
2lj1s
2lj1t
2lj1v
2lj1nj
2lj1dž
2lj1z
2lj1š
2lj1đ
2lj1ć
2lj1č
2r1ž
2r1b
2r1c
2r1d
2r1f
2r1g
2r1h
2r1j
2r1k
2r1l
2r1m
2r1n
2r1p
2r1lj
2r1r
2r1s
2r1t
2r1v
2r1nj
2r1dž
2r1z
2r1š
2r1đ
2r1ć
2r1č
2nj1ž
2nj1b
2nj1c
2nj1d
2nj1f
2nj1g
2nj1h
2nj1j
2nj1k
2nj1l
2nj1m
2nj1n
2nj1p
2nj1lj
2nj1r
2nj1s
2nj1t
2nj1v
2nj1nj
2nj1dž
2nj1z
2nj1š
2nj1đ
2nj1ć
2nj1č
2dž1ž
2dž1b
2dž1c
2dž1d
2dž1f
2dž1g
2dž1h
2dž1j
2dž1k
2dž1l
2dž1m
2dž1n
2dž1p
2dž1lj
2dž1r
2dž1s
2dž1t
2dž1v
2dž1nj
2dž1dž
2dž1z
2dž1š
2dž1đ
2dž1ć
2dž1č
2đ1ž
2đ1b
2đ1c
2đ1d
2đ1f
2đ1g
2đ1h
2đ1j
2đ1k
2đ1l
2đ1m
2đ1n
2đ1p
2đ1lj
2đ1r
2đ1s
2đ1t
2đ1v
2đ1nj
2đ1dž
2đ1z
2đ1š
2đ1đ
2đ1ć
2đ1č
2ć1ž
2ć1b
2ć1c
2ć1d
2ć1f
2ć1g
2ć1h
2ć1j
2ć1k
2ć1l
2ć1m
2ć1n
2ć1p
2ć1lj
2ć1r
2ć1s
2ć1t
2ć1v
2ć1nj
2ć1dž
2ć1z
2ć1š
2ć1đ
2ć1ć
2ć1č
.h2
.j2
.k2
.l2
.m2
.n2
.p2
.lj2
.r2
.s2
.t2
.v2
.nj2
.dž2
.z2
.š2
.đ2
.ć2
.č2
.ž2
.b2
.c2
.d2
.f2
.g2
o3a
o3e
o3i
o3o
o3u
u3a
u3e
u3i
u3o
u3u
a3a
a3e
a3i
a3o
a3u
e3a
e3e
e3i
e3o
e3u
i3a
i3e
i3i
i3o
i3u
2a1
2e1
2i1
2o1
2u1
2skb
2skc
2skd
2skf
2skg
2skh
2skk
2skm
2skn
2skp
2sks
2skt
2sknj
2skdž
2skz
2skš
2skđ
2skć
2skč
2skž
2stb
2stc
2std
2stf
2stg
2sth
2stk
2stm
2stn
2stp
2sts
2stt
2stnj
2stdž
2stz
2stš
2stđ
2stć
2stč
2stž
2škb
2škc
2škd
2škf
2škg
2škh
2škk
2škm
2škn
2škp
2šks
2škt
2šknj
2škdž
2škz
2škš
2škđ
2škć
2škč
2škž
2štb
2štc
2štd
2štf
2štg
2šth
2štk
2štm
2štn
2štp
2šts
2štt
2štnj
2štdž
2štz
2štš
2štđ
2štć
2štč
2štž
2spb
2spc
2spd
2spf
2spg
2sph
2spk
2spm
2spn
2spp
2sps
2spt
2spv
2spnj
2spdž
2spz
2spš
2spđ
2spć
2spč
2spž
2svb
2svc
2svd
2svf
2svg
2svh
2svk
2svm
2svn
2svp
2svs
2svt
2svv
2svnj
2svdž
2svz
2svš
2svđ
2svć
2svč
2svž
2špb
2špc
2špd
2špf
2špg
2šph
2špk
2špm
2špn
2špp
2šps
2špt
2špv
2špnj
2špdž
2špz
2špš
2špđ
2špć
2špč
2špž
2švb
2švc
2švd
2švf
2švg
2švh
2švk
2švm
2švn
2švp
2švs
2švt
2švv
2švnj
2švdž
2švz
2švš
2švđ
2švć
2švč
2švž
2ždb
2ždc
2ždd
2ždf
2ždg
2ždh
2ždk
2ždm
2ždn
2ždp
2žds
2ždt
2ždnj
2žddž
2ždz
2ždš
2ždđ
2ždć
2ždč
2žgb
2žgc
2žgd
2žgf
2žgg
2žgh
2žgk
2žgm
2žgn
2žgp
2žgs
2žgt
2žgnj
2žgdž
2žgz
2žgš
2žgđ
2žgć
2žgč
2žgž
2zdb
2zdc
2zdd
2zdf
2zdg
2zdh
2zdk
2zdm
2zdn
2zdp
2zds
2zdt
2zdnj
2zddž
2zdz
2zdš
2zdđ
2zdć
2zdč
2zgb
2zgc
2zgd
2zgf
2zgg
2zgh
2zgk
2zgm
2zgn
2zgp
2zgs
2zgt
2zgnj
2zgdž
2zgz
2zgš
2zgđ
2zgć
2zgč
2zgž
2žvb
2žvc
2žvd
2žvf
2žvg
2žvh
2žvk
2žvm
2žvn
2žvp
2žvs
2žvt
2žvv
2žvnj
2žvdž
2žvz
2žvš
2žvđ
2žvć
2žvč
2žvž
2žbb
2žbc
2žbd
2žbf
2žbg
2žbh
2žbk
2žbm
2žbn
2žbp
2žbs
2žbt
2žbv
2žbnj
2žbdž
2žbz
2žbš
2žbđ
2žbć
2žbč
2žbž
2zvb
2zvc
2zvd
2zvf
2zvg
2zvh
2zvk
2zvm
2zvn
2zvp
2zvs
2zvt
2zvv
2zvnj
2zvdž
2zvz
2zvš
2zvđ
2zvć
2zvč
2zvž
2zbb
2zbc
2zbd
2zbf
2zbg
2zbh
2zbk
2zbm
2zbn
2zbp
2zbs
2zbt
2zbv
2zbnj
2zbdž
2zbz
2zbš
2zbđ
2zbć
2zbč
2zbž
2žmb
2žmc
2žmd
2žmf
2žmg
2žmh
2žmk
2žmm
2žmn
2žmp
2žms
2žmt
2žmv
2žmnj
2žmdž
2žmz
2žmš
2žmđ
2žmć
2žmč
2žmž
2smb
2smc
2smd
2smf
2smg
2smh
2smk
2smm
2smn
2smp
2sms
2smt
2smv
2smnj
2smdž
2smz
2smš
2smđ
2smć
2smč
2smž
2zmb
2zmc
2zmd
2zmf
2zmg
2zmh
2zmk
2zmm
2zmn
2zmp
2zms
2zmt
2zmv
2zmnj
2zmdž
2zmz
2zmš
2zmđ
2zmć
2zmč
2zmž
2šmb
2šmc
2šmd
2šmf
2šmg
2šmh
2šmk
2šmm
2šmn
2šmp
2šms
2šmt
2šmv
2šmnj
2šmdž
2šmz
2šmš
2šmđ
2šmć
2šmč
2šmž
2scb
2scc
2scd
2scf
2scg
2sch
2sck
2scl
2scm
2scn
2scp
2sclj
2scr
2scs
2sct
2scnj
2scdž
2scz
2scš
2scđ
2scć
2scč
2scž
2šcb
2šcc
2šcd
2šcf
2šcg
2šch
2šck
2šcl
2šcm
2šcn
2šcp
2šclj
2šcr
2šcs
2šct
2šcnj
2šcdž
2šcz
2šcš
2šcđ
2šcć
2šcč
2šcž
2ščb
2ščc
2ščd
2ščf
2ščg
2ščh
2ščj
2ščk
2ščl
2ščm
2ščn
2ščp
2ščlj
2ščr
2ščs
2ščt
2ščnj
2ščdž
2ščz
2ščš
2ščđ
2ščć
2ščč
2ščž
2hvb
2hvc
2hvd
2hvf
2hvg
2hvh
2hvk
2hvm
2hvn
2hvp
2hvs
2hvt
2hvnj
2hvdž
2hvz
2hvš
2hvđ
2hvć
2hvč
2hvž
2ž3vl
2ž3vlj
2c3vl
2c3vlj
2z3vl
2z3vlj
2š3vl
2š3vlj
2č3vl
2č3vlj
2č3vj
2s3vlj
2d3vl
2d3vlj
2d3vr
2k3vj
2k3vl
2k3vlj
2t3vj
2t3vl
2t3vlj
2g3vj
2g3vl
2g3vlj
2g3vr
2h3vj
2h3vl
2h3vlj
2h3vr
2ž3mj
2ž3ml
2ž3mlj
2ž3mr
2z3ml
2z3mr
2š3mj
2š3ml
2š3mlj
2š3cj
2š3cv
2š3čv
2š3tj
2š3tl
2š3tlj
2s3tl
2s3kj
2s3klj
2š3pj
2š3pl
2š3plj
2ž3dj
2ž3dl
2ž3dlj
2ž3dv
2ž3gj
2ž3gl
2ž3glj
2ž3gr
2ž3gv
2z3dl
2z3dlj
2z3dv
2z3gj
2z3glj
2ž3bj
2ž3bl
2ž3blj
2ž3br
2z3blj
.a4e2ro
.be4o
.bi4o
.ge4o
.za3g2n
.za3t2ka
.iza3g2n
.iza3t2k
.iz3g2n
.izd2no
.izd2nu
.izd2na
.izr2k
.ist2k
.nag2n
.nag2nj
.na3d2nev
.na3d2nič
.na3d2nic
.na3t2kah
.na3t2kam
.na3t2kasm
.na3t2kast
.oda3g2n
.oda3d2n
.od3g2n
.od3m2n
.o3t2kah
.o3t2kam
.o3t2kasm
.o3t2kast
.po3g2n
.po3d2nev
.po3m2n
.po3m2nj
.po3r2v
.po3r2đ
.po3t2kah
.po3t2kam
.po3t2kat
.po3t2kav
.pred3m2n
.pred3m2nj
.pre3t2kah
.pre3t2kam
.pre3t2kat
.pro3g2n
.pro3t2ki
.pro3t2ka
.raza3g2n
.raz3g2n
.raz3d2ni
.raza3t2ka
.u3g2mi
.u3g2n
.uza3t2ka
3h2teti
3h2tjeti
3h2tel
3h2tev
3h2tenj
3h2tjel
3h2tjev
3h2tjenj
3g2degod.
3g2djegod.
3g2dekak
3g2dekad
3g2djekak
3g2djekad
ni3g2de.
ne3g2de.
ni3g2dje.
ne3g2dje.
3b2det
3b2denj
3b2djet
3b2djenj
3g2mil
3g2milj
3g2miz
3g2nos
3g2noz
3g2noj
3g2naj
3g2nezd
3g2nijezd
3g2nežđ
3g2niježđ
3g2nev
3g2njev
3g2njav
3g2njes
3g2njet
3g2nječ
3g2njil
3g2njio
3g2njilj
3g2njit
3g2njur
3k2nez
3k2než
3k2njiž
3k2njig
3m2nož
3m2nog
3m2naž
3p2sik
3p2sič
3p2sov
3p2suj
3r2đa
3s2fer
3t2mast
3t2mul
3t2muo
3t2mulj
3t2mur
3c2miz
3c2mak
3c2mač
3c2mok
3č2lan
3č2lanj
3r2je
4r3jem
4r3je.
.be2z3j
.be2z3l
.be2z3m
.be2z3n
.be2z3lj
.be2z3r
.be2z3v
.be2z3nj
.be2z3b
.be2z3d
.be2z3g
.be2z3i
.be2z3o
.be2z3u
.be2z3alkohol
.be2z3atomsk
.be3z4bedn
.be3z4beda
.be3z4bjedn
.be3z4bjeda
.be3z4beli
.be3z4bol
.be3z4vučn
.be3z4vuča
.be3z4istan
.be3z4isten
.be3z4jak
.be3z4jač
.be3z4lobn
.be3z4loba
.be3z4načaj
.be3z4račn
.be3z4rača
.be3z4up
.be3z4ub
.be2s3c
.be2s3k
.be2s3p
.be2s3t
.be3s4krupul
.be3s4pokojn
.be3s4pokoja
.be3s4porn
.be3s4pora
.be3s4tvar
.be3s4tid
.be3s4tija
.be3s4tilu
.be3s4tilj
.be3s4trana
.be3s4tras
.bes4tseler
.be2š3ć
.be2š3č
.va2n3evr
.va2n3ustav
.i2z3b
.i2z3d
.i2z3g
.i2z3j
.i2z3l
.i2z3m
.i2z3n
.i2z3lj
.i2z3r
.i2z3v
.i2z3nj
.i2z3i
.i2z3o
.i2z3u
.i2z3bija
.i2z3biva
.i2z3vedi
.i2z3vedn
.i2z3vedb
.i2z3vede
.i2z3daj
.i2z3aba
.i2z3aka
.i2z3anal
.i3z4bav
.i3z4bičkava
.i3z4bleušan
.i3z4bojak
.i3z4bojk
.i3z4vali
.i3z4valu
.i3z4vala
.i3z4vale
.i3z4valji
.i3z4vižd
.i3z4viiskr
.i3z4vija
.i3z4vijen
.i3z4vin
.i3z4vir
.i3z4vinj
.i3z4vitop
.i3z4vjed
.i3z4vojac
.i3z4vojc
.i3z4vor
.i3z4gomet
.i3z4gred
.i3z4grn
.i3z4grt
.i3z4drav
.i3z4iđ
.i3z4id
.i3z4imi
.i3z4ježlj
.i3z4loz
.i3z4lož
.i3z4log
.i3z4lopać
.i3z4nim
.i3z4noj
.iz4oanem
.iz4oanom
.iz4obat
.iz4obron
.iz4ogam
.iz4ogeo
.iz4oglos
.iz4ogon
.iz4ograf
.iz4odim
.iz4odin
.iz4odoz
.iz4oklin
.iz4okolon
.i3z4olat
.i3z4olac
.i3z4olir
.i3z4olov
.iz4oleks
.iz4oluks
.iz4omer
.iz4ometr
.iz4omorf
.iz4onef
.iz4onom
.iz4opat
.iz4oper
.iz4ople
.iz4opol
.iz4opsef
.iz4orah
.iz4osei
.iz4osint
.iz4osist
.iz4oskel
.iz4oskop
.iz4ostaz
.iz4oste
.iz4otah
.iz4otal
.iz4oter
.iz4oton
.iz4otop
.iz4otro
.iz4ofon
.iz4ofot
.iz4ohal
.iz4ohaz
.iz4ohel
.iz4ohij
.iz4ohim
.iz4ohit
.iz4ohips
.iz4ohor
.iz4ohro
.i3z4rael
.i3z4railj
.i3z4rači
.i3z4un
.i3z4upč
.i2s3c
.i2s3k
.i2s3p
.i2s3t
.i3s4kak
.i3s4kat
.i3s4kanj
.i3s4kariot
.i3s4kvas
.i3s4kvrč
.i3s4kin
.i3s4kita
.i3s4konsk
.i3s4koč
.i3s4kram
.i3s4krit
.i3s4kriš
.i3s4krič
.i3s4kric
.i3s4krat
.i3s4kren
.i3s4krenj
.i3s4kroj
.i3s4krsn
.i3s4krsa
.i3s4kuplja
.i3s4lam
.i3s4lab
.i3s4leđ
.i3s4led
.i3s4lijeđ
.i3s4lijed
.i3s4ljeđ
.i3s4ljed
.i3s4lik
.i3s4lin
.i3s4lov
.i3s4luš
.i3s4luž
.i3s4me
.i3s4mije
.i3s4mje
.i3s4pav
.i3s4paljiv
.i3s4pira
.i3s4plit
.i3s4plić
.i3s4pokoj
.i3s4polin
.i3s4pon
.i3s4porav
.i3s4pravi
.i3s4pravk
.i3s4pravn
.i3s4pravlj
.i3s4prava
.i3s4pupč
.i3s4pur
.i3s4red
.i3s4rk
.i3s4tavi
.i3s4tavlj
.i3s4takn
.i3s4tam
.i3s4tar
.i3s4tas
.i3s4tać
.i3s4tin
.i3s4tir
.i3s4tic
.i3s4tifan
.i3s4tok
.i3s4tori
.i3s4točn
.i3s4točnj
.i3s4toča
.i3s4trav
.i3s4trad
.i3s4tran
.i3s4trić
.i3s4triž
.i3s4tric
.i3s4trug
.i3s4tup
.i3s4uk
.i3s4us
.i3s4ut
.i3s4uš
.i2ž3đ
.i2š3ć
.i2š3č
.iz3be2z3obr
.iz3be2z3um
.iz3va2n3evr
.na2d3l
.na2d3lj
.na2d3v
.na3d4val
.na3d4vesi
.na3d4vest
.na3d4vij
.na3d4vit
.na3d4vla
.na3d4voje
.na3d4vor
.na2d3igr
.na2d3inž
.na2d3ina
.na2d3isk
.na2d3jah
.na2d3jač
.na2d3jek
.na2d3jez
.na2d3ječ
.na2d3jun
.na3d4lan
.na3d4leš
.na3d4lež
.na2d3ora
.na2d3oso
.na2d3ose
.na2d3osje
.na2d3ofi
.na2d3oč
.na2d3ran
.na2d3rač
.na2d3rast
.na2d3rašć
.na2d3real
.na2d3rep
.na2d3ruk
.na2d3ruč
.na2d3rug
.na2d3udar
.na2d3um
.na2d3uč
.na2j3a
.na2j3e
.na2j3i
.na2j3o
.na2j3u
.na3j4avi
.na3j4avlj
.na3j4ava
.na3j4ave
.na3j4adi
.na3j4ada
.na3j4ade
.na3j4aži
.na3j4azi
.na3j4ako
.na3j4aka
.na3j4alo
.na3j4ami
.na3j4aml
.na3j4amn
.na3j4ari
.na3j4arm
.na3j4arc
.na3j4ati
.na3j4auk
.na3j4ah
.na3j4aš
.na3j4edi
.na3j4edn
.na3j4edr
.na3j4eda
.na3j4eži
.na3j4ežu
.na3j4eže
.na3j4ezn
.na3j4ezd
.na3j4esti
.na3j4etk
.na3j4ec
.na3j4uri
.na3j4uren
.o2b3j
.o2b3lj
.o2b3r
.obe2z3b
.obe2z3d
.obe2z3g
.obe2z3j
.obe2z3l
.obe2z3m
.obe2z3n
.obe2z3o
.obe2z3lj
.obe2z3r
.obe2z3u
.obe2z3v
.obe3z4vij
.obe3z4nan
.obe3z4nanj
.obe3z4nač
.obe3z4ub
.obe2s3c
.obe2s3k
.obe2s3p
.obe2s3t
.obe3s4tan
.obe3s4tij
.obe3s4tran
.obe2š3ć
.obe2š3č
.o2b3igr
.o2b3istin
.o2b3istinj
.o3b4jek
.o3b4jer
.o3b4jesi
.o3b4jet
.o3b4ješ
.o2b3laj
.o2b3lam
.o2b3lakš
.o2b3lask
.o2b3lep
.o2b3let
.o2b3leć
.o2b3lež
.o2b3leg
.o2b3lijep
.o2b3lijet
.o2b3lijež
.o2b3lijeg
.o2b3leden
.o2b3liv
.o2b3lizat
.o2b3lizav
.o2b3lizi
.o2b3list
.o2b3loka
.o2b3luk
.o2b3luč
.o3b4ljan
.o3b4ljut
.o3b4ljuz
.o2b3oru
.o3b4raže
.o3b4razi
.o3b4razn
.o3b4razo
.o3b4razu
.o3b4raza
.o3b4razd
.o3b4ramb
.o3b4ran
.o3b4ranj
.o3b4rat
.o3b4rać
.o3b4rašn
.o3b4rašč
.o3b4rv
.o3b4rđ
.o3b4rem
.o3b4res
.o3b4ređ
.o3b4reč
.o3b4rež
.o3b4rec
.o3b4red
.o3b4reti
.o3b4retn
.o3b4rij
.o3b4ris
.o3b4rit
.o3b4riv
.o3b4rič
.o3b4ric
.o3b4rk
.o3b4rl
.o3b4rn
.o3b4rlj
.o3b4rs
.o3b4rt
.o3b4rš
.o3b4rč
.o3b4rok
.o3b4ron
.o3b4ronj
.o3b4roć
.o3b4roč
.o3b4rova
.o3b4rovc
.o3b4ruk
.o3b4run
.o3b4rus
.o3b4runj
.o3b4ruš
.o3b4ruč
.o2b3ubož
.o2b3uz
.o2b3už
.o2b3ud
.o2b3umi
.o2b3umj
.o2b3umr
.o2b3ume
.o2d3j
.o2d3l
.o2d3lj
.o2d3r
.o2d3v
.o2d3arg
.o3d4vaj
.o3d4važ
.o3d4vesn
.o3d4vest
.o3d4vesa
.o3d4vikav
.o3d4vikn
.o3d4vis
.o3d4vić
.o3d4voj
.o2d3igr
.o2d3i2z3v
.o2d3i2z3d
.o2d3isk
.o2d3isti
.o3d4jel
.o3d4jen
.o3d4jev
.o3d4jeć
.o3d4laz
.o3d4laž
.o3d4lag
.o3d4laka
.o3d4luk
.o3d4luč
.o2d3ozd
.o2d3ozg
.o2d3ok
.o2d3onl
.o2d3ono
.o2d3onu
.o2d3ond
.o3d4rani
.o3d4rano
.o3d4ranu
.o3d4rana
.o3d4rane
.o3d4raz
.o3d4rać
.o3d4raž
.o3d4rapi
.o3d4raplj
.o3d4rapa
.o3d4rači
.o3d4rven
.o3d4rvenj
.o3d4rveč
.o3d4rem
.o3d4ren
.o3d4ret
.o3d4ređ
.o3d4red
.o3d4rl
.o3d4rn
.o3d4rp
.o3d4rlj
.o3d4rt
.o3d4rž
.o3d4rin
.o3d4rinj
.o3d4riš
.o3d4rič
.o3d4rib
.o3d4ric
.o3d4ron
.o3d4ronj
.o3d4ruž
.o3d4rug
.o2d3uvi
.o2d3uve
.o2d3uzi
.o2d3uzl
.o2d3uzd
.o2d3uze
.o2d3uk
.o2d3ul
.o2d3um
.o2d3uč
.po2d3adm
.po2d3varij
.po2d3vez
.po2d3več
.po2d3vež
.po2d3vik
.po2d3vil
.po2d3vir
.po2d3vinj
.po2d3vlas
.po2d3vlaš
.po2d3voz
.po2d3vođ
.po2d3vož
.po2d3vod
.po2d3vrat
.po2d3vrać
.po2d3vrć
.po2d3vrž
.po2d3vrg
.po2d3vris
.po2d3vrs
.po2d3vuć
.po2d3igr
.po2d3izv
.po2d3j
.po3d4jen
.po3d4ječ
.po2d3lakat
.po2d3lakt
.po2d3lep
.po2d3let
.po2d3leć
.po2d3lež
.po2d3leg
.po2d3liz
.po2d3lijep
.po2d3lijet
.po2d3lijeć
.po2d3lijež
.po2d3lijeg
.po2d3list
.po2d3lok
.po2d3lom
.po2d3lup
.po2d3luč
.po2d3luž
.po2d3ljut
.po2d3okn
.po2d3oš
.po2d3oč
.po2d3of
.po2d3ravn
.po2d3ravnj
.po2d3rad
.po2d3ra2z3d
.po2d3razr
.po2d3razu
.po2d3ram
.po2d3ran
.po2d3ras
.po2d3ranj
.po2d3rep
.po2d3res
.po2d3rez
.po2d3rik
.po2d3rit
.po2d3ron
.po2d3rov
.po2d3rož
.po2d3ruk
.po2d3rub
.po2d3ruči
.po2d3ručn
.po2d3ruča
.po2d3upla
.po2d3usm
.po2d3usn
.pre2d3j
.pre2d3v
.pre3d4vaj
.pre3d4var
.pre3d4vest
.pre3d4voji
.pre3d4voja
.pre3d4voje
.pre3d4vor
.pre3d4vos
.pre3d4jen
.pre2d3igr
.pre2d3id
.pre2d3izb
.pre2d3ispi
.pre2d3isto
.pre2d3istr
.pre2d3obj
.pre2d3odre
.pre2d3okus
.pre2d3osv
.pre2d3ose
.pre2d3osje
.pre2d3rat
.pre2d3rač
.pre2d3rad
.pre2d3ruč
.pre2d3ubeđ
.pre2d3ubijeđ
.pre2d3ubjeđ
.pre2d3uver
.pre2d3uvjer
.pre2d3uvjet
.pre2d3ugov
.pre2d3udar
.pre2d3upis
.pre2d3uslo
.proti2v3akc
.proti2v3otr
.proti2v3of
.proti2v3r
.proti2v3us
.proti2v3ud
.ra2ž3đ
.ra2z3b
.ra2z3d
.ra2z3e
.ra2z3g
.ra2z3i
.ra2z3j
.ra2z3l
.ra2z3m
.ra2z3n
.ra2z3lj
.ra2z3r
.ra2z3v
.ra2z3nj
.ra2z3anal
.ra3z4ban
.ra3z4bar
.ra3z4bau
.ra3z4bad
.ra3z4bašur
.ra3z4boj
.ra3z4bor
.ra3z4val
.ra3z4vede
.ra3z4vest
.ra3z4vigo
.ra3z4viju
.ra3z4vija
.ra3z4vije
.ra3z4vit
.ra3z4vić
.ra3z4voj
.ra3z4von
.ra3z4vrat
.ra3z4vrać
.ra3z4vrt
.ra3z4vrć
.ra3z4gađ
.ra3z4grt
.ra3z4ev
.ra3z4ij
.ra3z4il
.ra3z4in
.ra3z4ir
.ra3z4it
.ra3z4iz
.ra3z4iđ
.ra3z4ić
.ra3z4id
.ra3z4laz
.ra3z4lag
.ra3z4lik
.ra3z4lič
.ra3z4loz
.ra3z4lož
.ra3z4log
.ra3z4met
.ra3z4meć
.ra3z4mrsk
.ra3z4nat
.ra2z3obl
.ra2z3obr
.ra2z3oba
.ra2z3od
.ra2z3orat
.ra2z3orav
.ra2z3ort
.ra2z3oru
.ra2z3ot
.ra3z4red
.ra3z4rok
.ra3z4roč
.ra2z3uve
.ra2z3udi
.ra2z3uda
.ra2z3udb
.ra2z3uzi
.ra2z3uzd
.ra2z3uze
.ra2z3ular
.ra2z3umr
.ra2s3c
.ra2s3k
.ra2s3p
.ra2s3t
.ra3s4kak
.ra3s4kand
.ra3s4kin
.ra3s4klap
.ra3s4klanj
.ra3s4klad
.ra3s4klon
.ra3s4klopi
.ra3s4kloplj
.ra3s4klopa
.ra3s4koš
.ra3s4krop
.ra3s4paj
.ra3s4pav
.ra3s4peti
.ra3s4peto
.ra3s4peta
.ra3s4pete
.ra3s4piku
.ra3s4pinj
.ra3s4plin
.ra3s4plinj
.ra3s4pn
.ra3s4polož
.ra3s4pon
.ra3s4por
.ra3s4prav
.ra3s4prem
.ra3s4rđ
.ra3s4rd
.ra3s4re
.ra3s4taj
.ra3s4tan
.ra3s4tat
.ra3s4tav
.ra3s4tenj
.ra3s4til
.ra3s4tir
.ra3s4tis
.ra3s4tit
.ra3s4tinj
.ra3s4toj
.ra3s4trel
.ra3s4tret
.ra3s4troj
.ra3s4trt
.ra3s4tup
.ra3s4tur
.ra3s4tuć
.ra4s5turč
.ra2š3ć
.ra2š3č
.ra3š4ćenj
.ra3š4čić
.u2z3b
.u2z3d
.u2z3g
.u2z3i
.u2z3j
.u2z3l
.u2z3m
.u2z3n
.u2z3lj
.u2z3r
.u2z3v
.u2z3nj
.u3z4bor
.u3z4van
.u3z4vat
.u3z4viž
.u3z4vijo
.u3z4viju
.u3z4vija
.u3z4vije
.u3z4voj
.u3z4dic
.u2z3igr
.u2z3inat
.u2z3iskr
.u3z4lan
.u3z4lat
.u3z4lim
.u3z4lit
.u3z4lić
.u3z4lic
.u3z4lov
.u3z4ludob
.u3z4nak
.u3z4nač
.u3z4neve
.u3z4nevje
.u3z4nič
.u3z4nic
.u3z4noj
.u2z3obest
.u2z3obijest
.u2z3orat
.u2z3orav
.u2z3oho
.u3z4ret
.u3z4rev
.u3z4rijet
.u3z4rijev
.u3z4rn
.u3z4rnj
.u3z4roko
.u3z4roku
.u3z4roka
.u3z4roč
.u3z4ruj
.u2z3ugar
.u2s3c
.u2s3k
.u2s3p
.u3s4kak
.u3s4klađ
.u3s4klad
.u3s4ko
.u4s5kom
.u4s5kov
.u4s5koš
.u4s5koko
.u4s5kolu
.u4s5kole
.u4s5kopa
.u4s5kora
.u4s5kosi
.u4s5kotr
.u3s4kup
.u3s4pav
.u3s4palo
.u3s4peh
.u3s4pel
.u3s4pem
.u3s4pet
.u3s4pev
.u3s4peš
.u3s4pjeh
.u3s4pjel
.u3s4pjem
.u3s4pjet
.u3s4pjev
.u3s4pješ
.u3s4pent
.u3s4pija
.u3s4pije
.u3s4pijuš
.u3s4pikuš
.u3s4pon
.u3s4pori
.u3s4pora
.u3s4poren
.u3s4porenj
.u3s4poreč
.u3s4posob
.u3s4premi
.u3s4prema
.u3s4rk
.u3s4rn
.u3s4rp
.u3s4rlj
.u3s4rt
.u3s4rđ
.u3s4rž
.u3s4ra
.u3s4rd
.u3s4re
.u3s4rijed
.u2s3talas
.u2s3tara
.u2s3tvrđ
.u2s3tvrd
.u2s3ter
.u2s3teć
.u2s3teg
.u2s3tov
.u2s3traj
.u2s3tral
.u2s3trg
.u2s3trep
.u2s3tres
.u2s3treb
.u2s3trk
.u2s3trn
.u2s3trp
.u2s3trć
.u2s3trč
.u2s3tum
.u2s3tur
.u2s3tuć
.u2š3ć
.u2š3č
.a2b3alij
.a2b3anac
.a2b3evak
.a2b3erac
.a2b3erir
.a2b3irit
.a2b3ju
.a2b3la
.a2b3leg
.a2b3lep
.a2b3lok
.a2b3lu
.a2b3orig
.a2b3reak
.a2b3rog
.a2b3uzus
.a2d3erac
.a2d3verb
.a2d3j
.a2d3lat
.a2d3ren
.a2d3rog
.a3g2nos
.a3g2noz
.a2nabap
.a2nabaz
.a2nabat
.a2nabio
.a2nabol
.a2nagen
.a2nagno
.a2n3ago
.a2nagra
.a2nadem
.a2nadipl
.a2nadoz
.a2n3a4e2ro
.a2nakal
.a2nakam
.a2nakat
.a2nakef
.a2nakla
.a2nakli
.a2nakoj
.a2n3akuz
.a2n3alg
.a2n3ald
.a2nalep
.a2naliz
.a2nalis
.a2nalit
.a2n3amert
.a2namne
.a2n3andr
.a2naneo
.a2n3ant
.a2napla
.a2naple
.a2napne
.a2napno
.a2napro
.a2napti
.a2n3apto
.a2nart
.a2n3arh
.a2nasar
.a2nasei
.a2naspaz
.a2nasta
.a2nastig
.a2nastom
.a2natim
.a2natom
.a2natoc
.a2natre
.a2natri
.a2natro
.a2nafaz
.a2n3afij
.a2nafila
.a2nafon
.a2n3afrod
.a2nakol
.a2nakron
.a2nakru
.a2n3alfa
.a2nafor
.a2nahor
.a2nahro
.a2n3eger
.a2n3ekl
.a2n3ekum
.a2n3elek
.a2n3ener
.a2n3epi
.a2neor
.a2n3erg
.a2n3erit
.a2n3este
.a2n3idr
.a2n3izog
.a2n3izom
.a2n3izur
.a2n3irid
.a2n3ovar
.a2n3oks
.a2n3opis
.a2n3orh
.a2n3oft
.a2n3org
.di2s3akor
.di2s3junk
.di2s3kval
.di2s3kont
.di2s3kord
.di2s3kre
.di2s3kri
.di2s3kur
.di2s3lo
.di2s3orij
.di2s3parit
.di2s3poz
.di2s3pon
.di2s3prop
.di2s3ton
.di2s3trak
.i2n3abrup
.i2n3adek
.i2n3akur
.i2n3akce
.i2n3amor
.i2n3anic
.i2n3aplik
.i2n3apst
.i2n3art
.i2n3augur
.i2n3aura
.i2n3afek
.i2n3evid
.i2n3eg
.i2n3ed
.i2n3ekv
.i2n3eks
.i2n3elig
.i2n3epc
.i2n3efek
.i2n3obl
.i2nogen
.i2nokor
.i2n3okup
.i2n3oper
.i2n3opor
.i2n3opse
.i2n3ofic
.i2n3umbr
.i2n3unda
.i2n3unk
.i2n3util
.inte2r3i
.inte2r3o
.inte2r3u
.inte2r3a
.inte2r3e
.inte3r4egn
.inte3r4esi
.inte3r4esn
.inte3r4eso
.inte3r4esu
.inte3r4esa
.inte3r4ese
.inte3r4eždž
.inte3r4ije
.inte2r3je
.inte3r4ogat
.juri2s3k
.juri2s3p
.nu2z3bel
.nu2z3bilj
.nu2z3ljub
.nu2z3re
.nu2z3rje
.nu2z3už
.nu2s3pos
.nu2s3pro
.po2st3egz
.po2st3indu
.po2st3lim
.po2st3onk
.po2st3oper
.su2b3a
.su2b3l
.su3b4aš
.su2b3inv
.su2b3junk
.su2b3oks
.su2b3rep
.su2b3rog
.su2b3ord
.supe2r3i
.supe2r3o
.supe2r3u
.supe2r3a
.supe2r3e
.supe3r4ior
.tran2s3a
.tran2s3c
.tran2s3e
.tran2s3k
.tran2s3l
.tran2s3m
.tran2s3n
.tran2s3o
.tran2s3p
.tran2s3t
.tran2s3u
.tran2s3v
.tran2s3nj
.tran3s4ep
.tran3s4kri
.tran3s4um
.tran3s4ud
.a2n3jon
.i2n3jek
.i2n3jur
.i2n3just
.o2d3žal
.o2d3žalj
.o2d3ži
.o2d3žv
.o2d3že
.pre2d3ži
.pre2d3že
.na2d3ždr
.na2d3žnj
.na2d3že
.na2d3žanj
.na2d3žir
.na2d3živ
.na2d3žup
l2j
n2j
d2ž
2dž.
}
\hyphenation{%
na-dno
na-tka
na-tka-ti
na-tka-še
o-dno
o-tka
o-tka-ti
o-tka-še
po-dno
po-dne
po-tki
po-tku
po-tka
po-tke
u-dno
i-gde
i-gdje
svu-gde
sve-gde
svu-gdje
sve-gdje
po-ne-gde
po-ne-gdje
i-zbi
i-zba
i-zbe
i-zbi-ci
i-zbi-ca
i-zbi-ce
i-zvit
i-zim
izo-ba-ri
izo-ba-ru
izo-ba-ra
izo-ba-re
i-skok
i-sko-ku
i-sko-ka
i-skon
i-sko-ni
i-sko-nu
i-sko-na
i-skri
i-skru
i-skra
i-skre
i-skrav
i-spod
i-spo-da
i-stri
i-stro
i-stru
i-stra
i-stre
na-ji
na-jo
na-ju
na-ja
na-je
na-jam
na-jest
o-braz
o-bret
o-dvi-ka
o-dran
o-dra-ti
pre-dvoj
ra-zmi
ra-zmo
ra-zmu
ra-zma
ra-zme
ra-zni
ra-zno
ra-znu
ra-zna
ra-zne
ra-sklop
ra-spe-lo
ra-spe-lu
ra-spe-la
ra-spe-ću
ra-spe-ća
ra-spe-će
ra-sti
ra-stu
ra-sta
ra-ste
ra-stom
ra-ster
ra-šći
ra-šćo
ra-šću
ra-šća
ra-šće
u-zni
u-zno
u-zna
u-znik
u-zrok
u-ski
u-sko
u-sku
u-ska
u-ske
us-kos
u-spio
u-speo
u-spor
u-šću
u-šća
u-šće
in-te-res
tran-su
tran-sa
tran-som
}
%
%% End of file `hyph-sh-latn.tex'.

