## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Zh_latn.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Zh_latn.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Zh_latn;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Zh_latn> hyphenation pattern class

=cut

__DATA__
% This file is part of hyph-utf8 package and resulted from
% semi-manual conversions of hyphenation patterns into UTF-8 in June 2008.
%
% Source: pyhyph.tex (yyyy-mm-dd)
% Author: Werner Lemberg <wl at gnu.org>
%
% The above mentioned file should become obsolete,
% and the author of the original file should preferaby modify this file instead.
%
% Modificatios were needed in order to support native UTF-8 engines,
% but functionality (hopefully) didn't change in any way, at least not intentionally.
% This file is no longer stand-alone; at least for 8-bit engines
% you probably want to use loadhyph-foo.tex (which will load this file) instead.
%
% Modifications were done by Jonathan Kew, Mojca Miklavec & Arthur Reutenauer
% with help & support from:
% - Karl Berry, who gave us free hands and all resources
% - Taco Hoekwater, with useful macros
% - Hans Hagen, who did the unicodifisation of patterns already long before
%               and helped with testing, suggestions and bug reports
% - Norbert Preining, who tested & integrated patterns into TeX Live
%
% However, the "copyright/copyleft" owner of patterns remains the original author.
%
% The copyright statement of this file is thus:
%
%    Do with this file whatever needs to be done in future for the sake of
%    "a better world" as long as you respect the copyright of original file.
%    If you're the original author of patterns or taking over a new revolution,
%    plese remove all of the TUG comments & credits that we added here -
%    you are the Queen / the King, we are only the servants.
%
% If you want to change this file, rather than uploading directly to CTAN,
% we would be grateful if you could send it to us (http://tug.org/tex-hyphen)
% or ask for credentials for SVN repository and commit it yourself;
% we will then upload the whole "package" to CTAN.
%
% Before a new "pattern-revolution" starts,
% please try to follow some guidelines if possible:
%
% - \lccode is *forbidden*, and I really mean it
% - all the patterns should be in UTF-8
% - the only "allowed" TeX commands in this file are: \patterns, \hyphenation,
%   and if you really cannot do without, also \input and \message
% - in particular, please no \catcode or \lccode changes,
%   they belong to loadhyph-foo.tex,
%   and no \lefthyphenmin and \righthyphenmin,
%   they have no influence here and belong elsewhere
% - \begingroup and/or \endinput is not needed
% - feel free to do whatever you want inside comments
%
% We know that TeX is extremely powerful, but give a stupid parser
% at least a chance to read your patterns.
%
% For more unformation see
%
%    http://tug.org/tex-hyphen
%
%------------------------------------------------------------------------------
%
% This is the file pyhyph.tex of the CJK package
%   for hyphenating Chinese pinyin syllables.
% 
% created by Werner Lemberg <wl@gnu.org>
% 
% Version 4.8.0 (22-May-2008)
% 
% Copyright (C) 1994-2008  Werner Lemberg <wl@gnu.org>
% 
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program in doc/COPYING; if not, write to the Free
% Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
% MA 02110-1301 USA
% 
% \message{Hyphenation patterns for unaccented pinyin syllables (CJK 4.7.0)}
%
\patterns{
a1b
a1c
a1d
a1f
a1g
a1h
a1j
a1k
a1l
a1m
a1p
a1q
a1r
a1s
a1t
a1w
a1x
a1y
a1z
e1b
e1c
e1d
e1f
e1g
e1h
e1j
e1k
e1l
e1m
e1p
e1q
e1s
e1t
e1w
e1x
e1y
e1z
1ga
g1b
g1c
g1d
1ge
g1f
g1g
g1h
g1j
g1k
g1l
g1m
g1n
1go
g1p
g1q
g1r
g1s
g1t
1gu
g1w
g1x
g1y
g1z
i1b
i1c
i1d
i1f
i1g
i1h
i1j
i1k
i1l
i1m
i1p
i1q
i1r
i1s
i1t
i1w
i1x
i1y
i1z
1na
n1b
n1c
n1d
1ne
n1f
n1h
1ni
n1j
n1k
n1l
n1m
n1n
1no
n1p
n1q
n1r
n1s
n1t
1nu
1nü
n1w
n1x
n1y
n1z
o1b
o1c
o1d
o1f
o1g
o1h
o1j
o1k
o1l
o1m
o1p
o1q
o1r
o1s
o1t
o1w
o1x
o1y
o1z
1ra
r1b
r1c
r1d
1re
r1f
r1g
r1h
1ri
r1j
r1k
r1l
r1m
r1n
1ro
r1p
r1q
r1r
r1s
r1t
1ru
r1w
r1x
r1y
r1z
u1b
u1c
u1d
u1f
u1g
u1h
u1j
u1k
u1l
u1m
u1p
u1q
u1r
u1s
u1t
u1w
u1x
u1y
u1z
ü1b
ü1c
ü1d
ü1f
ü1g
ü1h
ü1j
ü1k
ü1l
ü1m
ü1n
ü1p
ü1q
ü1r
ü1s
ü1t
ü1w
ü1x
ü1y
ü1z
'1a
'1e
'1o
}

