## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Mn_cyrl.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Mn_cyrl.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Mn_cyrl;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.00';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Mn_cyrl> hyphenation pattern class

=cut

__DATA__
% This file is part of hyph-utf8 package and resulted from
% semi-manual conversions of hyphenation patterns into UTF-8 in June 2008.
%
% Source: mnhyphen.tex (2002-06-30)
% Author: Oliver Corff, Dorjpalam Dorj
%
% The above mentioned file should become obsolete,
% and the author of the original file should preferaby modify this file instead.
%
% Modificatios were needed in order to support native UTF-8 engines,
% but functionality (hopefully) didn't change in any way, at least not intentionally.
% This file is no longer stand-alone; at least for 8-bit engines
% you probably want to use loadhyph-foo.tex (which will load this file) instead.
%
% Modifications were done by Jonathan Kew, Mojca Miklavec & Arthur Reutenauer
% with help & support from:
% - Karl Berry, who gave us free hands and all resources
% - Taco Hoekwater, with useful macros
% - Hans Hagen, who did the unicodifisation of patterns already long before
%               and helped with testing, suggestions and bug reports
% - Norbert Preining, who tested & integrated patterns into TeX Live
%
% However, the "copyright/copyleft" owner of patterns remains the original author.
%
% The copyright statement of this file is thus:
%
%    Do with this file whatever needs to be done in future for the sake of
%    "a better world" as long as you respect the copyright of original file.
%    If you're the original author of patterns or taking over a new revolution,
%    plese remove all of the TUG comments & credits that we added here -
%    you are the Queen / the King, we are only the servants.
%
% If you want to change this file, rather than uploading directly to CTAN,
% we would be grateful if you could send it to us (http://tug.org/tex-hyphen)
% or ask for credentials for SVN repository and commit it yourself;
% we will then upload the whole "package" to CTAN.
%
% Before a new "pattern-revolution" starts,
% please try to follow some guidelines if possible:
%
% - \lccode is *forbidden*, and I really mean it
% - all the patterns should be in UTF-8
% - the only "allowed" TeX commands in this file are: \patterns, \hyphenation,
%   and if you really cannot do without, also \input and \message
% - in particular, please no \catcode or \lccode changes,
%   they belong to loadhyph-foo.tex,
%   and no \lefthyphenmin and \righthyphenmin,
%   they have no influence here and belong elsewhere
% - \begingroup and/or \endinput is not needed
% - feel free to do whatever you want inside comments
%
% We know that TeX is extremely powerful, but give a stupid parser
% at least a chance to read your patterns.
%
% For more unformation see
%
%    http://tug.org/tex-hyphen
%
%------------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: mnhyphen.tex
%      Author: Oliver Corff and Dorjpalam Dorj
%        Date: February 26th, 1999		% mls.sty prevails
%     Version: \VersionRelease			% see mls.sty!
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: The Mongolian Hyphenation Pattern File
%	       to be used together with LMC encoding.
%	       Hyphenation exceptions should be stored
%              in mnhyphex.tex.
%
%              It may well be possible that the hyphenation
%              patterns given below are incomplete or plainly
%              wrong. It should also be mentioned that TeX
%              sometimes ignores correct hyphenation information
%              and makes up its own mind. Anyway, please con-
%              sider all hyphenation data strictly experimental
%              and *not yet stable*.
%
%              This file is mostly based on Cäwäl's Mongol
%              Xälniï Towq Taïlbar Tol' (MXTTT for short;
%              ``Short Explanatory Dictionary of Mongolian)
%              but contains a few other sources as well.
%
%              Comments, corrections and suggestions are
%              highly appreciated and should be directed to
%              the authors at corff@zedat.fu-berlin.de
%
%              U/B/B, February 1999
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
% \message{mnhyphen.tex - Hyphenation Patterns for
% 			Xalx Mongolian, LMC Encoding}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The following code is closely modelled after russian.sty and
% its accompanying hyphenation file.
% 
% We first must make some of the non-ASCII range characters known
% as characters to TeX, and include case mapping information.
%
\patterns{%
.аа2
.ин2
.оё2
.оо2
.өө2
.уу2
.үү2
.ээ2
аа2ж
а1д
а2ди
ай2б
а1п
асаа3
а1т
а1ф
а1х
а1ц
а3ц2д
а1ч
а1ш
а1ю
а2яал
1ба
бай2ду
ба3ми
2б1г
1би
2бл
2б1р
бу3ж
1ва
в1б
2в1г
2в1д
1ве
ве2д
в1ж
в1з
1ви
2в1л
2в1н
1во
1вө
2в1р
в1с
2в1т
1ву
1вү
в1ц
2в1ш
1вэ
1вя
1га
г1б
г1в
2г1г
2г1д
2г1ж
1ги
2г1л
2г1м
2г1н
1го
го2ди
1гө
г1р
г2рам
3гре
2гс
2г1т
1гу
гуулиу2
1гү
г1х
г1ц
2г1ч
2г1ш
г3ши
1гы
1гэ
гэ2нү
гял3
да1вы
д1б
2д1в
2д1г
2д1д
2дек
2д1ж
диа1
2дит
2д1л
2д1м
2д1н
2д1р
2д1с
2д1т
3дүү.
2д1х
2д1ц
2д1ч
2дъ
2дı
е1б
е1в
е1г2
е1д
е1з
е1и
е1л
е1м
ео1
е1п
е1ре
е3т2ру
е1х
е1ц
еци1
е1ш
ё1д
ё1з
ёо2ч
ёх2
1жа
2ж1в
2ж1г
2ж1д
2ж1ж
1жи
3жиг
3жин
2ж1л
2ж1м
2ж1н
1жө
2ж1р
2ж1с
2ж1т
1жу
1жү
1жы
1жэ
1за
2з1в
2з1г
2з1д
2з1ж
1зи
2з1л
2з1м
2з1н
1зо
1зө
2з1р
2з1с
2з1т
1зу
1зү
з1х
з1ц
з1ч
2з1ш
1зы
2зı
1зэ
иг2ра
и1д
и3дал
и2ды
и1ж
и1з
ил2ди
ис3п
и1т
и1х
и1ц
и1ш
й1б
й1в
й1г
й2гр
й1д
й1ж
й1п
й2пл
й1р
й1с
й1т
й1х
й1ц
й1ч
1ка
1ке
к1ж
1ки
к1к
к1л
к1н
ко1о
кс3п
к1т
1ку
2к1ц
1кэ
1ла
2л1б
л1в
2л1г
2л1д
1ле
2л1ж
2л1з
1ли
2л1л
лли1
2л1м
2лн
1ло
ло2д
1лө
2л1р
2л1с
2л1т
1лу
1лү
2л1х
2л1ц
2лч
2лш
2лъ
1лы
2лı
1лэ
л1ю
1ма
м1б
м1г
м1д
1ме
1ми
2мин
м1к2
м1л
м1н
1мо
1мө
2м1п
м1р
1му
1мү
м1ф
м1х
м1ц
м1ш
1мы
1мэ
1на
н1б
н1в
н1г
н2гр
нг2ре
н1д
1нёврл	% Thе оццасионал Rуссиан лоан
1ни
н1к
н1л
н1м
1но
1нө
н1п
н1с
н3с2д
н1т
1ну
1нү
н1х
н1ц
1ны
1нэ
н1я
о1а
о1б
о1г2р
о1д
о1е
о1ж
о1не
он3ст
он3т
о1п2
о2пе
о1сп
о1т
о1ф
о1х
о1ц
о1э
ө1д
ө1ж
ө2ри
ө1х
ө1ц
ө1ч
2п1д
по1
по3с
2п1п
2пра
п2ро
2п1т
1ра
2раб
р1б
р1в
2р1г
2р1д
1ри
2р1л
р1м
2р1н
1ро
1рө
р1п
р1р
2р1с
2р1т
1ру
2рук
1рү
2р1х
р1ц
2рч
2р1ш
1ры
1рэ
1са
с1б
2с1в
2с1г
2с1д
1се
2с1ж
с1з
1си
1ск2
2скв
2с1л
2с1м
2с1н
1со
1сө
с1п
с2пе
с2пи
2с1р
2с1с
2с1т
1су
1сү
с1ф
2с1х
с1ц
2с1ч
с3ш2т
1сы
1сэ
1та
2т1б
2т1в
2т1г
2т1д
2т1ж
2т1з
1ти
2т1л
2т1м
2т1н
1то
1тө
2т1р
т2ро
1тру
2т1с
2т1т
1тү
2т1х
2т1ц
2т1ч
2т1ш
1ты
1тэ
у1д
у2жи
у1з
у1л
у1т
у1ф
у1х
у1ц
у1ш
ү1д
ү1з
ү2зэ
ү1л
ү1п
үс2д
ү1х
ү1ц
ү1ш
ф1д
ф1м
1фо
1ха
хаа2ды
ха2ю
2х1б
2х1в
2х1г
2х1д
2х1ж
2х1з
1хи
хи2да
2хиı
2х1л
2х1м
2х1н
1хо
1хө
2х1р
2х1с
2х1т
1ху
ху3ж
1хү
2х1х
2х1ц
2хч
2х1ш
1хы
2хı
1хэ
1ца
2ц1в
2ц1г
2ц1д
2ц1ж
2ц1л
2ц1м
2ц1н
2ц1р
2ц1с
2ц1т
2ц1х
2ц1ч
2цъ
1ча
ч1в
2ч1г
2ч1д
1чи
2ч1л
2ч1м
2ч1н
1чо
2ч1р
2ч1с
2ч1т
1чу
1чү
2ч1х
1чэ
1ша
ш1б
2ш1в
2ш1г
2ш1д
2ш1ж
1ши
2ш1к
2ш1л
2ш1м
2ш1н
1шо
1шө
2ш1р
2ш1с
2ш1т
1шу
1шү
шүү3лı
2ш1х
2ш1ч
1шэ
ъ1е2
ъ1ё2
ъ1я2
ы1г
ы1с
ы1х
ı1б
ı1д
ı1к
ı1т
ı1х
ı1ц
ı1ч
ı1ш
ı1я2
э1д
э1ж
э1з
э2нэхи
э1х
э1ц
2юд
1яа
я1д
янш2д
я1т
я1х
я1ш
}

