## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Bg.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Bg.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Bg;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.00';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Bg> hyphenation pattern class

=cut

__DATA__
% Bulgarian hyphenation patterns, version 1.7, July 2008
%   Copyright 1994-2008 Georgi Boshnakov
%   Georgi dot Boshnakov at manchester dot ac dot uk
% 
% This file can be redistributed and/or modified under the terms
% of the LaTeX Project Public License distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or any later version.
%
%
%   First version:  1994
%   Modified:  June 2000 (minor changes)
%   Modified:  May  2006 (added copyright notice)
%   Modified:  June 2008 (changed encoding to utf-8)
%
%   Please send wrongly hyphenated words and suggestions for
%   corrections to the address given towards the beginning of this
%   file.
%
%
% Note: The original name of this file was 'bghyphsi.tex' which is
%   part of the package 'bghyphen'. The package 'bghyphen' is now
%   obsolete but it is still available on CTAN and currently (June 2008)
%   gives the same hyphenation results.
%   
%
%
% To make TeX use these patterns:
%
%    (1) Make sure that the hyph-utf8 package is present in your TeX
%        system.
%
%    (2) generate the necessary formats (TeX, LaTeX, pdfLaTeX, etc),
%        instructing TeX to load 'loadhyph-bg.tex' for Bulgarian
%        hyphenation.
%
% The LaTeX babel package sets \lefthyphenmin and \righthyphenmin to 2
%   when the language is switched to Bulgarian.  Developers who write
%   support for Bulgarian outside LaTeX and/or babel need to take care
%   of this.
% 
\patterns{%
1а1
1б1
1в1
1г1
1д1
1е1
1ж1
1з1
1и1
1й1
1к1
1л1
1м1
1н1
1о1
1п1
1р1
1с1
1т1
1у1
1ф1
1х1
1ц1
1ч1
1ш1
1щ1
1ъ1
0ь0
1ю1
1я1
б4а б4е б4и б4о б4у б4ъ б4ю б4я 
в4а в4е в4и в4о в4у в4ъ в4ю в4я 
г4а г4е г4и г4о г4у г4ъ г4ю г4я 
д4а д4е д4и д4о д4у д4ъ д4ю д4я 
ж4а ж4е ж4и ж4о ж4у ж4ъ ж4ю ж4я 
з4а з4е з4и з4о з4у з4ъ з4ю з4я 
й4а й4е й4и й4о й4у й4ъ й4ю й4я 
к4а к4е к4и к4о к4у к4ъ к4ю к4я 
л4а л4е л4и л4о л4у л4ъ л4ю л4я 
м4а м4е м4и м4о м4у м4ъ м4ю м4я 
н4а н4е н4и н4о н4у н4ъ н4ю н4я 
п4а п4е п4и п4о п4у п4ъ п4ю п4я 
р4а р4е р4и р4о р4у р4ъ р4ю р4я 
с4а с4е с4и с4о с4у с4ъ с4ю с4я 
т4а т4е т4и т4о т4у т4ъ т4ю т4я 
ф4а ф4е ф4и ф4о ф4у ф4ъ ф4ю ф4я 
х4а х4е х4и х4о х4у х4ъ х4ю х4я 
ц4а ц4е ц4и ц4о ц4у ц4ъ ц4ю ц4я 
ч4а ч4е ч4и ч4о ч4у ч4ъ ч4ю ч4я 
ш4а ш4е ш4и ш4о ш4у ш4ъ ш4ю ш4я 
щ4а щ4е щ4и щ4о щ4у щ4ъ щ4ю щ4я 
ь4а ь4е ь4и ь4о ь4у ь4ъ ь4ю ь4я 
4б3б4
2б3в2
2б3г2
2б3д2
2б3ж2
2б3з2
2б3й2
2б3к2
2б3л2
2б3м2
2б3н2
2б3п2
2б3р2
2б3с2
2б3т2
2б3ф2
2б3х2
2б3ц2
2б3ч2
2б3ш2
2б3щ2
2в3б2
4в3в4
2в3г2
2в3д2
2в3ж2
2в3з2
2в3й2
2в3к2
2в3л2
2в3м2
2в3н2
2в3п2
2в3р2
2в3с2
2в3т2
2в3ф2
2в3х2
2в3ц2
2в3ч2
2в3ш2
2в3щ2
2г3б2
2г3в2
4г3г4
2г3д2
2г3ж2
2г3з2
2г3й2
2г3к2
2г3л2
2г3м2
2г3н2
2г3п2
2г3р2
2г3с2
2г3т2
2г3ф2
2г3х2
2г3ц2
2г3ч2
2г3ш2
2г3щ2
2д3б2
2д3в2
2д3г2
4д3д4
3д4ж
2д3з2
2д3й2
2д3к2
2д3л2
2д3м2
2д3н2
2д3п2
2д3р2
2д3с2
2д3т2
2д3ф2
2д3х2
2д3ц2
2д3ч2
2д3ш2
2д3щ2
2ж3б2
2ж3в2
2ж3г2
2ж3д2
4ж3ж4
2ж3з2
2ж3й2
2ж3к2
2ж3л2
2ж3м2
2ж3н2
2ж3п2
2ж3р2
2ж3с2
2ж3т2
2ж3ф2
2ж3х2
2ж3ц2
2ж3ч2
2ж3ш2
2ж3щ2
2з3б2
2з3в2
2з3г2
2з3д2
2з3ж2
4з3з4
2з3й2
2з3к2
2з3л2
2з3м2
2з3н2
2з3п2
2з3р2
2з3с2
2з3т2
2з3ф2
2з3х2
2з3ц2
2з3ч2
2з3ш2
2з3щ2
2й3б2
2й3в2
2й3г2
2й3д2
2й3ж2
2й3з2
4й3й4
2й3к2
2й3л2
2й3м2
2й3н2
2й3п2
2й3р2
2й3с2
2й3т2
2й3ф2
2й3х2
2й3ц2
2й3ч2
2й3ш2
2й3щ2
2к3б2
2к3в2
2к3г2
2к3д2
2к3ж2
2к3з2
2к3й2
4к3к4
2к3л2
2к3м2
2к3н2
2к3п2
2к3р2
2к3с2
2к3т2
2к3ф2
2к3х2
2к3ц2
2к3ч2
2к3ш2
2к3щ2
2л3б2
2л3в2
2л3г2
2л3д2
2л3ж2
2л3з2
2л3й2
2л3к2
4л3л4
2л3м2
2л3н2
2л3п2
2л3р2
2л3с2
2л3т2
2л3ф2
2л3х2
2л3ц2
2л3ч2
2л3ш2
2л3щ2
2м3б2
2м3в2
2м3г2
2м3д2
2м3ж2
2м3з2
2м3й2
2м3к2
2м3л2
4м3м4
2м3н2
2м3п2
2м3р2
2м3с2
2м3т2
2м3ф2
2м3х2
2м3ц2
2м3ч2
2м3ш2
2м3щ2
2н3б2
2н3в2
2н3г2
2н3д2
2н3ж2
2н3з2
2н3й2
2н3к2
2н3л2
2н3м2
4н3н4
2н3п2
2н3р2
2н3с2
2н3т2
2н3ф2
2н3х2
2н3ц2
2н3ч2
2н3ш2
2н3щ2
2п3б2
2п3в2
2п3г2
2п3д2
2п3ж2
2п3з2
2п3й2
2п3к2
2п3л2
2п3м2
2п3н2
4п3п4
2п3р2
2п3с2
2п3т2
2п3ф2
2п3х2
2п3ц2
2п3ч2
2п3ш2
2п3щ2
2р3б2
2р3в2
2р3г2
2р3д2
2р3ж2
2р3з2
2р3й2
2р3к2
2р3л2
2р3м2
2р3н2
2р3п2
4р3р4
2р3с2
2р3т2
2р3ф2
2р3х2
2р3ц2
2р3ч2
2р3ш2
2р3щ2
2с3б2
2с3в2
2с3г2
2с3д2
2с3ж2
2с3з2
2с3й2
2с3к2
2с3л2
2с3м2
2с3н2
2с3п2
2с3р2
4с3с4
2с3т2
2с3ф2
2с3х2
2с3ц2
2с3ч2
2с3ш2
2с3щ2
2т3б2
2т3в2
2т3г2
2т3д2
2т3ж2
2т3з2
2т3й2
2т3к2
2т3л2
2т3м2
2т3н2
2т3п2
2т3р2
2т3с2
4т3т4
2т3ф2
2т3х2
2т3ц2
2т3ч2
2т3ш2
2т3щ2
2ф3б2
2ф3в2
2ф3г2
2ф3д2
2ф3ж2
2ф3з2
2ф3й2
2ф3к2
2ф3л2
2ф3м2
2ф3н2
2ф3п2
2ф3р2
2ф3с2
2ф3т2
4ф3ф4
2ф3х2
2ф3ц2
2ф3ч2
2ф3ш2
2ф3щ2
2х3б2
2х3в2
2х3г2
2х3д2
2х3ж2
2х3з2
2х3й2
2х3к2
2х3л2
2х3м2
2х3н2
2х3п2
2х3р2
2х3с2
2х3т2
2х3ф2
4х3х4
2х3ц2
2х3ч2
2х3ш2
2х3щ2
2ц3б2
2ц3в2
2ц3г2
2ц3д2
2ц3ж2
2ц3з2
2ц3й2
2ц3к2
2ц3л2
2ц3м2
2ц3н2
2ц3п2
2ц3р2
2ц3с2
2ц3т2
2ц3ф2
2ц3х2
4ц3ц4
2ц3ч2
2ц3ш2
2ц3щ2
2ч3б2
2ч3в2
2ч3г2
2ч3д2
2ч3ж2
2ч3з2
2ч3й2
2ч3к2
2ч3л2
2ч3м2
2ч3н2
2ч3п2
2ч3р2
2ч3с2
2ч3т2
2ч3ф2
2ч3х2
2ч3ц2
4ч3ч4
2ч3ш2
2ч3щ2
2ш3б2
2ш3в2
2ш3г2
2ш3д2
2ш3ж2
2ш3з2
2ш3й2
2ш3к2
2ш3л2
2ш3м2
2ш3н2
2ш3п2
2ш3р2
2ш3с2
2ш3т2
2ш3ф2
2ш3х2
2ш3ц2
2ш3ч2
4ш3ш4
2ш3щ2
2щ3б2
2щ3в2
2щ3г2
2щ3д2
2щ3ж2
2щ3з2
2щ3й2
2щ3к2
2щ3л2
2щ3м2
2щ3н2
2щ3п2
2щ3р2
2щ3с2
2щ3т2
2щ3ф2
2щ3х2
2щ3ц2
2щ3ч2
2щ3ш2
4щ3щ4
ааа4
аае4
ааи4
аао4
аау4
ааъ4
ааю4
аая4
аеа4
аее4
аеи4
аео4
аеу4
аеъ4
аею4
аея4
аиа4
аие4
аии4
аио4
аиу4
аиъ4
аию4
аия4
аоа4
аое4
аои4
аоо4
аоу4
аоъ4
аою4
аоя4
ауа4
ауе4
ауи4
ауо4
ауу4
ауъ4
аую4
ауя4
аъа4
аъе4
аъи4
аъо4
аъу4
аъъ4
аъю4
аъя4
аюа4
аюе4
аюи4
аюо4
аюу4
аюъ4
аюю4
аюя4
аяа4
аяе4
аяи4
аяо4
аяу4
аяъ4
аяю4
аяя4
еаа4
еае4
еаи4
еао4
еау4
еаъ4
еаю4
еая4
ееа4
еее4
ееи4
еео4
ееу4
ееъ4
еею4
еея4
еиа4
еие4
еии4
еио4
еиу4
еиъ4
еию4
еия4
еоа4
еое4
еои4
еоо4
еоу4
еоъ4
еою4
еоя4
еуа4
еуе4
еуи4
еуо4
еуу4
еуъ4
еую4
еуя4
еъа4
еъе4
еъи4
еъо4
еъу4
еъъ4
еъю4
еъя4
еюа4
еюе4
еюи4
еюо4
еюу4
еюъ4
еюю4
еюя4
еяа4
еяе4
еяи4
еяо4
еяу4
еяъ4
еяю4
еяя4
иаа4
иае4
иаи4
иао4
иау4
иаъ4
иаю4
иая4
иеа4
иее4
иеи4
иео4
иеу4
иеъ4
иею4
иея4
ииа4
иие4
иии4
иио4
ииу4
ииъ4
иию4
иия4
иоа4
иое4
иои4
иоо4
иоу4
иоъ4
иою4
иоя4
иуа4
иуе4
иуи4
иуо4
иуу4
иуъ4
иую4
иуя4
иъа4
иъе4
иъи4
иъо4
иъу4
иъъ4
иъю4
иъя4
июа4
июе4
июи4
июо4
июу4
июъ4
июю4
июя4
ияа4
ияе4
ияи4
ияо4
ияу4
ияъ4
ияю4
ияя4
оаа4
оае4
оаи4
оао4
оау4
оаъ4
оаю4
оая4
оеа4
оее4
оеи4
оео4
оеу4
оеъ4
оею4
оея4
оиа4
оие4
оии4
оио4
оиу4
оиъ4
оию4
оия4
ооа4
оое4
оои4
ооо4
ооу4
ооъ4
оою4
ооя4
оуа4
оуе4
оуи4
оуо4
оуу4
оуъ4
оую4
оуя4
оъа4
оъе4
оъи4
оъо4
оъу4
оъъ4
оъю4
оъя4
оюа4
оюе4
оюи4
оюо4
оюу4
оюъ4
оюю4
оюя4
ояа4
ояе4
ояи4
ояо4
ояу4
ояъ4
ояю4
ояя4
уаа4
уае4
уаи4
уао4
уау4
уаъ4
уаю4
уая4
уеа4
уее4
уеи4
уео4
уеу4
уеъ4
уею4
уея4
уиа4
уие4
уии4
уио4
уиу4
уиъ4
уию4
уия4
уоа4
уое4
уои4
уоо4
уоу4
уоъ4
уою4
уоя4
ууа4
ууе4
ууи4
ууо4
ууу4
ууъ4
уую4
ууя4
уъа4
уъе4
уъи4
уъо4
уъу4
уъъ4
уъю4
уъя4
уюа4
уюе4
уюи4
уюо4
уюу4
уюъ4
уюю4
уюя4
уяа4
уяе4
уяи4
уяо4
уяу4
уяъ4
уяю4
уяя4
ъаа4
ъае4
ъаи4
ъао4
ъау4
ъаъ4
ъаю4
ъая4
ъеа4
ъее4
ъеи4
ъео4
ъеу4
ъеъ4
ъею4
ъея4
ъиа4
ъие4
ъии4
ъио4
ъиу4
ъиъ4
ъию4
ъия4
ъоа4
ъое4
ъои4
ъоо4
ъоу4
ъоъ4
ъою4
ъоя4
ъуа4
ъуе4
ъуи4
ъуо4
ъуу4
ъуъ4
ъую4
ъуя4
ъъа4
ъъе4
ъъи4
ъъо4
ъъу4
ъъъ4
ъъю4
ъъя4
ъюа4
ъюе4
ъюи4
ъюо4
ъюу4
ъюъ4
ъюю4
ъюя4
ъяа4
ъяе4
ъяи4
ъяо4
ъяу4
ъяъ4
ъяю4
ъяя4
юаа4
юае4
юаи4
юао4
юау4
юаъ4
юаю4
юая4
юеа4
юее4
юеи4
юео4
юеу4
юеъ4
юею4
юея4
юиа4
юие4
юии4
юио4
юиу4
юиъ4
юию4
юия4
юоа4
юое4
юои4
юоо4
юоу4
юоъ4
юою4
юоя4
юуа4
юуе4
юуи4
юуо4
юуу4
юуъ4
юую4
юуя4
юъа4
юъе4
юъи4
юъо4
юъу4
юъъ4
юъю4
юъя4
ююа4
ююе4
ююи4
ююо4
ююу4
ююъ4
ююю4
ююя4
юяа4
юяе4
юяи4
юяо4
юяу4
юяъ4
юяю4
юяя4
яаа4
яае4
яаи4
яао4
яау4
яаъ4
яаю4
яая4
яеа4
яее4
яеи4
яео4
яеу4
яеъ4
яею4
яея4
яиа4
яие4
яии4
яио4
яиу4
яиъ4
яию4
яия4
яоа4
яое4
яои4
яоо4
яоу4
яоъ4
яою4
яоя4
яуа4
яуе4
яуи4
яуо4
яуу4
яуъ4
яую4
яуя4
яъа4
яъе4
яъи4
яъо4
яъу4
яъъ4
яъю4
яъя4
яюа4
яюе4
яюи4
яюо4
яюу4
яюъ4
яюю4
яюя4
яяа4
яяе4
яяи4
яяо4
яяу4
яяъ4
яяю4
яяя4
й4бб
й4бв
й4бг
й4бд
й4бж
й4бз
й4бй
й4бк
й4бл
й4бм
й4бн
й4бп
й4бр
й4бс
й4бт
й4бф
й4бх
й4бц
й4бч
й4бш
й4бщ
й4вб
й4вв
й4вг
й4вд
й4вж
й4вз
й4вй
й4вк
й4вл
й4вм
й4вн
й4вп
й4вр
й4вс
й4вт
й4вф
й4вх
й4вц
й4вч
й4вш
й4вщ
й4гб
й4гв
й4гг
й4гд
й4гж
й4гз
й4гй
й4гк
й4гл
й4гм
й4гн
й4гп
й4гр
й4гс
й4гт
й4гф
й4гх
й4гц
й4гч
й4гш
й4гщ
й4дб
й4дв
й4дг
й4дд
й4дж
й4дз
й4дй
й4дк
й4дл
й4дм
й4дн
й4дп
й4др
й4дс
й4дт
й4дф
й4дх
й4дц
й4дч
й4дш
й4дщ
й4жб
й4жв
й4жг
й4жд
й4жж
й4жз
й4жй
й4жк
й4жл
й4жм
й4жн
й4жп
й4жр
й4жс
й4жт
й4жф
й4жх
й4жц
й4жч
й4жш
й4жщ
й4зб
й4зв
й4зг
й4зд
й4зж
й4зз
й4зй
й4зк
й4зл
й4зм
й4зн
й4зп
й4зр
й4зс
й4зт
й4зф
й4зх
й4зц
й4зч
й4зш
й4зщ
й4йб
й4йв
й4йг
й4йд
й4йж
й4йз
й4йй
й4йк
й4йл
й4йм
й4йн
й4йп
й4йр
й4йс
й4йт
й4йф
й4йх
й4йц
й4йч
й4йш
й4йщ
й4кб
й4кв
й4кг
й4кд
й4кж
й4кз
й4кй
й4кк
й4кл
й4км
й4кн
й4кп
й4кр
й4кс
й4кт
й4кф
й4кх
й4кц
й4кч
й4кш
й4кщ
й4лб
й4лв
й4лг
й4лд
й4лж
й4лз
й4лй
й4лк
й4лл
й4лм
й4лн
й4лп
й4лр
й4лс
й4лт
й4лф
й4лх
й4лц
й4лч
й4лш
й4лщ
й4мб
й4мв
й4мг
й4мд
й4мж
й4мз
й4мй
й4мк
й4мл
й4мм
й4мн
й4мп
й4мр
й4мс
й4мт
й4мф
й4мх
й4мц
й4мч
й4мш
й4мщ
й4нб
й4нв
й4нг
й4нд
й4нж
й4нз
й4нй
й4нк
й4нл
й4нм
й4нн
й4нп
й4нр
й4нс
й4нт
й4нф
й4нх
й4нц
й4нч
й4нш
й4нщ
й4пб
й4пв
й4пг
й4пд
й4пж
й4пз
й4пй
й4пк
й4пл
й4пм
й4пн
й4пп
й4пр
й4пс
й4пт
й4пф
й4пх
й4пц
й4пч
й4пш
й4пщ
й4рб
й4рв
й4рг
й4рд
й4рж
й4рз
й4рй
й4рк
й4рл
й4рм
й4рн
й4рп
й4рр
й4рс
й4рт
й4рф
й4рх
й4рц
й4рч
й4рш
й4рщ
й4сб
й4св
й4сг
й4сд
й4сж
й4сз
й4сй
й4ск
й4сл
й4см
й4сн
й4сп
й4ср
й4сс
й4ст
й4сф
й4сх
й4сц
й4сч
й4сш
й4сщ
й4тб
й4тв
й4тг
й4тд
й4тж
й4тз
й4тй
й4тк
й4тл
й4тм
й4тн
й4тп
й4тр
й4тс
й4тт
й4тф
й4тх
й4тц
й4тч
й4тш
й4тщ
й4фб
й4фв
й4фг
й4фд
й4фж
й4фз
й4фй
й4фк
й4фл
й4фм
й4фн
й4фп
й4фр
й4фс
й4фт
й4фф
й4фх
й4фц
й4фч
й4фш
й4фщ
й4хб
й4хв
й4хг
й4хд
й4хж
й4хз
й4хй
й4хк
й4хл
й4хм
й4хн
й4хп
й4хр
й4хс
й4хт
й4хф
й4хх
й4хц
й4хч
й4хш
й4хщ
й4цб
й4цв
й4цг
й4цд
й4цж
й4цз
й4цй
й4цк
й4цл
й4цм
й4цн
й4цп
й4цр
й4цс
й4цт
й4цф
й4цх
й4цц
й4цч
й4цш
й4цщ
й4чб
й4чв
й4чг
й4чд
й4чж
й4чз
й4чй
й4чк
й4чл
й4чм
й4чн
й4чп
й4чр
й4чс
й4чт
й4чф
й4чх
й4чц
й4чч
й4чш
й4чщ
й4шб
й4шв
й4шг
й4шд
й4шж
й4шз
й4шй
й4шк
й4шл
й4шм
й4шн
й4шп
й4шр
й4шс
й4шт
й4шф
й4шх
й4шц
й4шч
й4шш
й4шщ
й4щб
й4щв
й4щг
й4щд
й4щж
й4щз
й4щй
й4щк
й4щл
й4щм
й4щн
й4щп
й4щр
й4щс
й4щт
й4щф
й4щх
й4щц
й4щч
й4щш
й4щщ
б4ь
в4ь
г4ь
д4ь
ж4ь
з4ь
й4ь
к4ь
л4ь
м4ь
н4ь
п4ь
р4ь
с4ь
т4ь
ф4ь
х4ь
ц4ь
ч4ь
ш4ь
щ4ь
ь4ь
.дз4в
.дж4р
.дж4л
.вг4л
.вд4л
.вг4р
.вг4н
.вп4л
.вк4л
.вк4р
.вт4р
.сг4л
.зд4р
.сг4р
.сб4р
.сд4р
.жд4р
.ск4л
.сп4л
.сп4р
.ст4р
.ск4р
.шп4р
.ск4в
.вз4р
.вс4л
.вс4м
.вс4р
.св4р
.сх4л
.сх4р
.хв4р
.вс4т
.сх4в
.см4р
н4кт.
н4кс.
к4ст.
}

%%% Local Variables:
%%% coding: utf-8
%%% End: 

