## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Eu.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Eu.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Eu;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Eu> hyphenation pattern class

=cut

__DATA__
% Hyphenation patterns for Basque.
%
% This file has first been written by Juan M. Aguirregabiria
% (juanmari.aguirregabiria@ehu.es) on February 1997 based on the
% shyphen.sh script that generates the Spanish patterns as compiled
% by Julio Sanchez (jsanchez@gmv.es) on September 1991.
%
% In June 2008 the generating script has been rewritten into ruby and
% adapted for native UTF-8 TeX engines. Patterns became part of hyph-utf8
% package and were renamed from bahyph.tex into hyph-eu.tex.
% Functionality should not change apart from adding ñ by default.
%
% The original Copyright followed and applied also to precessor of this file
% whose last version will be always available by anonymous ftp
% from tp.lc.ehu.es or by poynting your Web browser to
%     http://tp.lc.ehu.es/jma/basque.html
%
% For more information about the new UTF-8 hyphenation patterns and
% links to this file see
%     http://www.tug.org/tex-hyphen/
%
%          COPYRIGHT NOTICE
%
% These patterns and the generating script are Copyright (c) JMA 1997, 2008
% These patterns are made public in the hope that they will benefit others.
% You can use this software for any purpose.
% However, this is given for free and WITHOUT ANY WARRANTY.
%
% You are kindly requested to send any changes to the author.
% If you change the generating script, you must include code
% in it such that any output is clearly labeled as generated
% by a modified script.
%
%               END OF COPYRIGHT NOTICE
%
% Open vowels: a e o
% Closed vowels: i u
% Consonants: b c d f g j k l m n ñ p q r s t v w x y z
%
% Some of the patterns below represent combinations that never
% happen in Basque. Would they happen, they would be hyphenated
% according to the rules.
% 
\patterns{
% Rule SR1
% Vowels are kept together by the defaults
% Rule SR2
% Attach vowel groups to left consonant
1ba 1be 1bo 1bi 1bu
1ca 1ce 1co 1ci 1cu
1da 1de 1do 1di 1du
1fa 1fe 1fo 1fi 1fu
1ga 1ge 1go 1gi 1gu
1ja 1je 1jo 1ji 1ju
1ka 1ke 1ko 1ki 1ku
1la 1le 1lo 1li 1lu
1ma 1me 1mo 1mi 1mu
1na 1ne 1no 1ni 1nu
1ña 1ñe 1ño 1ñi 1ñu
1pa 1pe 1po 1pi 1pu
1qa 1qe 1qo 1qi 1qu
1ra 1re 1ro 1ri 1ru
1sa 1se 1so 1si 1su
1ta 1te 1to 1ti 1tu
1va 1ve 1vo 1vi 1vu
1wa 1we 1wo 1wi 1wu
1xa 1xe 1xo 1xi 1xu
1ya 1ye 1yo 1yi 1yu
1za 1ze 1zo 1zi 1zu
% Rule SR3
% Build legal consonant groups, leave other consonants bound to 
% the previous group. This overrides part of the SR2 pattern group.
1l2la 1l2le 1l2lo 1l2li 1l2lu
1r2ra 1r2re 1r2ro 1r2ri 1r2ru
1t2sa 1t2se 1t2so 1t2si 1t2su
1t2xa 1t2xe 1t2xo 1t2xi 1t2xu
1t2za 1t2ze 1t2zo 1t2zi 1t2zu
1b2la 1b2le 1b2lo 1b2li 1b2lu
1b2ra 1b2re 1b2ro 1b2ri 1b2ru
1d2ra 1d2re 1d2ro 1d2ri 1d2ru
1f2la 1f2le 1f2lo 1f2li 1f2lu
1f2ra 1f2re 1f2ro 1f2ri 1f2ru
1g2la 1g2le 1g2lo 1g2li 1g2lu
1g2ra 1g2re 1g2ro 1g2ri 1g2ru
1k2la 1k2le 1k2lo 1k2li 1k2lu
1k2ra 1k2re 1k2ro 1k2ri 1k2ru
1p2la 1p2le 1p2lo 1p2li 1p2lu
1p2ra 1p2re 1p2ro 1p2ri 1p2ru
1t2ra 1t2re 1t2ro 1t2ri 1t2ru
% We now avoid some problematic breaks.
su2b2r su2b2l
}

