## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Ru_RU.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Ru_RU.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Ru_RU;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.00';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Ru_RU> hyphenation pattern class

=head1 Copyright

The data for this library is copied from the OpenOffice.org project and
modified to be used as a Perl module by Roland van Ipenburg.

L<http://svn.services.openoffice.org/ooo/trunk/dictionaries/ru_RU/>

	Russian Thesaurus Dictionary for OpenOffice.org 2
	-------------------------------------------------

	Language: Russian (ru RU)
	License:  GNU LGPL
	Author:   Mikhail Korolyov <mkorolyov@yandex.ru>
	Origin:   Абрамовъ, Н. Словарь русскихъ синонимовъ и сходныхъ по смыслу выраженiй. Изд. 3-е, доп., Пг., 1911
	Packager: Rail Aliev <rail@i-rs.ru>

=cut

__DATA__
KOI8-R
.ави2
.ад1р
.ади2
.аи2
.ак1в
.ак1р
.аль5
.ас1п
.ау2
.аш1х
.аэ2
.бе2з1а2
.бе2з1у2
.бе2з3о2
.бе2с1т
.без1на
.без1р
.би2б1л
.бу1г
.взъ2
.во1в2
.во2п1л
.во2с3тор
.во2ск
.во3п2ло
.воз1на
.вс6п
.въ2
.вып2ле
.выс2п
.гос1к
.дво2е
.де2зи
.ди2а
.ди2сто
.до1см
.за3в2ра
.за3п2н
.зас2
.зау2
.заш2
.звуко3
.зо2о3
.иг1л
.иг1р
.ие2
.из1н
.из1р
.изо2бл
.ии2
.ио2
.ис1ти
.ис1то
.ис5тр
.иу2
.ию2
.кон2трн
.ле1м
.ль2
.ме2ж3
.ме3ж4ам
.ме3ж4ах
.ме3ж4е
.ме6жи2о
.мо2г1л
.на1ч2н
.на1ш2ко
.на2и
.на5в6
.не1в
.не1з2
.не1х
.не3о2тр
.не5л
.неа2
.небе2з1о2
.нем2но
.ни1с2к
.нос5к
.оа2
.об1ла
.об1ле
.об1ло
.об1лу
.об1ре
.об1ру
.об3о2ст
.об5лив
.об5лит
.обе2з1о2
.обе2с1т
.обо1ль
.ог5н
.оз2
.ос1пин
.ос2пар
.от1р
.от1хл
.от3в
.ото1м2
.по1в2
.по1ж2
.по2дыг
.по2дым
.по2дын
.по2дыс1
.по2дыт
.по2дыщ
.по2ст1ин
.по3дыми
.под1во
.пре1л
.пре2ж1д
.при1г2н
.при1м2н
.при3к2н
.прис2к
.про1сну
.про3сл
.прос2
.ра2зо
.ра2с1та
.ра2с1те
.ра2с1тек
.ра2с1теч
.ра2с1ти
.реги6о
.ро2х1
.сек1с2т
.сеп5т
.соп1л
.тек1с
.топ1л
.тран2с1
.трех1
.ть2
.уг1ле
.уг1ло
.уд2л
.уд2р
.уе2
.ук2
.ур6в
.ую2
.фи2зо
.хим1ч
.хла2
.ча2е
.че2ст1в
.чер2ст1
.четырех1
.эо2
.эя2
.юа2
.яи2
1адм
1апп
1атак
1б2лаго
1бв
1бе
1бл
1бри
1бу
1бю
1бя
1в2нук
1в2нуч
1в2сп
1в2сх
1в2сю
1в2шив
1ваг
1вак
1вег
1велл
1вер.
1вз2
1вих
1вич
1вл
1вок
1воя
1вп
1вр2
1вуд
1вы
1вю
1га
1гор
1гр
1д2ворь
1д2лев
1д2невк
1д2невок
1д2раж
1д2разн
1движ
1двиз
1дж
1дзе.
1дневн
1дняш
1дов
1дот
1доч
1дресс
1дро2г1н
1дроб
1дром
1дун
1дье
1дья
1жг
1жд
1жму
1зву
1зол
1зри
1зу
1кав
1кае
1кап
1кат
1каю
1кив
1кл
1ковы
1комп
1кон
1коо
1кос
1кош
1кр
1ла2пь
1ланд
1леде
1ли2п1т
1льо
1лью
1лют.
1м2нож
1маг
1мед
1мей
1мен.
1мкн
1мон
1мще
1мы.
1на.
1на1г
1на1с2
1над
1ниц
1но.
1ной
1ном
1нох
1ною.
1нрав
1ньо
1нью
1ня
1о2б1лач
1о2биж
1о2боз
1обес
1объ
1окт
1отд
1отп
1п2ленк
1п2ленок
1п2леноч
1п2лет
1п2салм
1пе.
1пенз
1печ
1пис
1плав
1плаз
1пле2с1к
1плик
1плос1к
1плы
1по
1пр
1птих
1пу.
1пя
1р2ви.
1р2вите.
1раб
1ралг
1реги
1реза
1рекла
1рисо
1росш
1рыб
1с2каф
1с2клон
1с2кре1ст
1с2креб
1с2паль
1с2посаб
1с4творч
1са
1св
1се
1сж
1си
1скоп
1сл
1со
1сп2лю.
1ср
1сто
1стров
1су
1сфе
1схе
1счас
1счит
1съ2
1сы
1ся
1т2кан
1т2ре2з1в
1т2ряс
1т2рях
1т4верд
1т4вор
1такт
1тека
1текш
1терл
1тече
1ткн
1тле
1толк
1торс
1торц
1точн
1тощ
1тре2с1к
1треб
1триб
1труб
1тяну
1узл
1ф2тор
1фа
1фи
1фл
1фо
1фр6
1фтонг
1фы
1х2лын
1хв
1хи
1хлеб
1хлор
1хр
1ху.
1цам
1цах.
1цв
1це
1ци
1цо
1цу.
1цы
1чел
1чив
1чик
1чла
1чле
1чо
1чт
1чх
1ш2в
1ш2кол
1ш2мы2г1н
1ши2б1л
1шпе
1шпил
1ште
1шту
1шю
1щи
1э2к
2а1ма
2а3о
2б1д
2б1лен
2б1ля
2б1н
2б1т
2б1ц
2б1ш
2б5к
2блас
2бль
2бр.
2брь
2в1лаб
2в1лен
2в1ли
2в1лю
2в1ляе
2в1лял
2в1ляю
2в1ми
2в1ре.
2в1ро
2в1ры.
2в1терп
2вль
2вр.
2г1б
2г1к
2г1м
2г1п
2г1с
2г1ш
2г5т
2гроп
2д1инсти
2д1к
2д1м
2д1ро.
2д1с
2д1ф
2д3ш2
2джс
2дны
2доблач
2докт
2дрс
2дь3те.
2е1ко
2е1о
2енр
2ж1к
2ж1ц
2жаве
2жавл
2ждл
2ждь
2з1б
2з1да
2з1инт
2з1инф
2з1к
2з1с
2здн
2зна.
2зны
2и1вы
2имене
2к1б
2к1г
2к1к
2к1ла.
2к1лак
2к1ли.
2к1ло.
2к1м
2к1т
2к1ц
2к1ш
2казк
2кл.
2кль
2кн
2кс
2л1н
2л1орг
2м1в2
2м1изд
2м1л
2м1ш
2н1с
2н1ц
2н1ш
2нбе
2невн
2нотд
2няш
2о1а2
2о1г
2о1за
2о1и
2о1ры
2о1со
2о1те
2о1тр
2о1у2
2о1хи
2о1э
2о5хро
2ов
2ол
2ом
2опир
2остал
2осф
2оф
2п1к
2п1лю.
2п1люсь.
2п1м
2п1н
2п1п
2п1сис
2п1ст
2п1том
2п1ф
2п1ц
2п1ч
2п1ш
2п3ту
2пс.
2псе
2псо
2псу
2псы
2р1орг
2р1укс
2рисп
2с1лиру
2с1лок
2с1лоц
2с1му
2сбу
2ск.
2скн
2сль
2смен.
2сны
2сск
2ств.
2стерл
2стк
2стн
2сть.
2сфор
2сэ2
2сяз
2т1вей
2т1г
2т1инф
2т1м
2т1н
2т1п
2т1с
2т1ф
2т1ц
2т1щ
2т1э
2тамп
2томщ
2тонг
2тр.
2трабо
2трб
2трг
2трд
2трм
2трп
2трр
2трф
2туч
2ть.
2ф1в
2ф1лен
2ф1н
2ф1орг
2ф1с
2х1ве
2х1г
2х1с
2х1у2г
2ц1г
2ц1з
2ц1к
2ц1л
2ц1м
2ц1о2д
2ц1от
2ц1п
2ц1с
2ц1т
2ч1м
2чтм
2ш1ф
2щ1н
2юм
2юю.
2юя.
2яю.
2яя.
3в2лия
3европ
3з2вуч
3зис
3и2мено
3и2мену
3к6ниж
3ная
3ник
3ную
3ны
3о2т1ряд
3п2сих
3план
3с2лав
3с2лов
3с2луж
3с2посо
3хор
3ч2мок
3чий
5би2о
5бот
5боц
5вая
5вуа
5двину
5деб
5до.
5дью
5жев
5зо.
5зью
5инж
5инсп
5к6то.
5коа
5коры
5л6жеш
5лиг
5лицо
5личи
5мий
5минг
5моти
5нап
5нац
5ниб
5откр
5посы
5прое6
5с2наб
5скоя
5смес
5смы
5сты
5течь
5тиге
5тиз.
5туды
5тушев
5хоз
5хом
5хоу
5ца.
5чан
5шло
5штр
6б1б
6б1г
6б1м
6б1с2
6б1щ
6бл.
6бь.
6в5рац
6вн.
6вск
6вь.
6г5лай
6гл.
6гн.
6гр.
6грек
6д1б
6д5роз
6дж.
6дз.
6дн.
6дотд
6др.
6дт.
6дь.
6евол
6евыд
6жд.
6з1ж
6з1м
6з1ру
6зная
6зь.
6ип
6й1
6к1ф
6кв.
6кеа
6кр.
6л1с2
6ль.
6льш
6м1б
6м1м
6м1п
6м1т
6м1че
6мс.
6мь.
6нр.
6нь.
6о5ба
6одар
6окл
6окол
6охор
6пл.
6пль.
6пр.
6прь.
6пт.
6пь.
6с1з
6с5чу
6скон
6сл.
6слям
6ср.
6сс.
6сст
6ст.
6стр.
6студы
6стьд
6стьс
6сь.
6т1б
6т1ред
6т1т
6твь.
6тинж
6тл.
6томс
6трв
6труп
6тч.
6тш.
6фр.
6фь.
6х1ч
6х5ви
6хв.
6хрь.
6хуем.
6хуй.
6хую.
6хуя.
6ценни
6ч1к
6ч5лег
6ч5леж
6чт.
6чь.
6ш1б
6шв.
6шл.
6шь.
6щь.
6ъ1
а1а
а1ба
а1бе
а1би
а1бо
а1бр
а1бу
а1бх
а1бы
а1бье
а1бьи
а1бью
а1бья
а1бя
а1ва
а1во
а1ву
а1вы
а1вье
а1вьи
а1вью
а1вья
а1вэ
а1вю
а1вя
а1га
а1ге
а1ги
а1гл
а1го
а1да
а1двор
а1де
а1ди
а1до
а1дра
а1ду
а1дцат
а1ды
а1дьи
а1дью
а1дю
а1дя
а1е
а1жа
а1же
а1жж
а1жи
а1жм
а1жо
а1жу
а1жье
а1жьи
а1жью
а1жья
а1за
а1зе
а1зи
а1зо
а1зы
а1зье
а1зью
а1зья
а1зю
а1зя
а1и
а1ка
а1ке
а1ки
а1ко
а1ку
а1кы
а1ла
а1ле
а1ло
а1лу
а1лы
а1лье
а1льи
а1лья
а1лю
а1ля
а1ме
а1ми
а1мо
а1му
а1мы
а1мье
а1мьи
а1мью
а1мья
а1мя
а1на
а1не
а1ни
а1но
а1ну
а1ны
а1нье
а1ньи
а1нью
а1нья
а1ню
а1ня
а1п
а1р6а
а1ре
а1ри
а1ро
а1ру
а1ры
а1рье
а1рьи
а1рью
а1рья
а1рю
а1ря
а1с2ше
а1са
а1се
а1си
а1со
а1ста
а1сте
а1сти
а1сту
а1сты
а1стье
а1стью
а1стья
а1стю
а1стя
а1су
а1сы
а1сье
а1сьи
а1сью
а1сья
а1сю
а1та
а1те
а1ти
а1то
а1тр
а1ту
а1ты
а1тье
а1тьи
а1тью
а1тья
а1тю
а1тя
а1у
а1фа
а1фе
а1фи
а1фо
а1фу
а1фья
а1фя
а1ха
а1хе
а1хи
а1хо
а1ху
а1ца
а1це
а1ци
а1цо
а1цу
а1ч2не
а1ча
а1че
а1чи
а1чу
а1чье
а1чьи
а1чью
а1чья
а1ша
а1ше
а1ши
а1шо
а1шу
а1шье
а1шьи
а1шью
а1шья
а1щ
а1э1
а1ю
а1я
а2в1ля
а2в1п
а2в1ра
а2вот
а2дын
а2зри
а2н1об
а2н5уз
а2п1с
а2п1т
а2с1тир
а2скоп
а2уле
а2ум
а2ун
а2ус
а2уэ
а2ш1лы
а2эр
а3гу
а3и2г1р
а5ве
а5ви
а5дви
а5з6у
а5ли
а5стры
а6нинс
а6томн
аа2п1
аг1ва
аг1д
ага5с6
ад1а2ген
ад1руга
ад5рез
ади2о
адь2
ае2ди
аз1ве
аз1ви
аз1во
аз1р
аи6з5
айм2а
ак1н
ак1с
акоп5л
аль1д
ам1но
ам1ч
ан1р
ан2кро
ан2скр
ан2сп
ан2сур
ан2сц
ана2с3н
анс1у
ао2ст
ао6к
ап1рел
ар2т1ор
арт2р
ас1к
ас1пу
ас1х
ас1ч
ас3по
ас5лет
ас5лям
ас5лях
ас5ми
асс2ме
асс6п
аст1ву
аста2п1
ат1л
ат5ви
атх1л
ау2чи
аут1р
ауэ1р
аф1ри
ач1т
аш1лив
аш1та
ая2з
б1ва
б1во
б1вя
б1ж
б1з6
б1лав
б1лег
б1лож
б1лом
б1раст
б1рыв
б1ф
б1х
б1ч
б5лиза
бас1м
бе2д1р
бе2з1у4с
бе2зы
бе2с1к
бе2ста
бег1л
бег1н
без1д2
без5в
безы2з1в
бес1х
бес1ч
бес3п
бесс2
би5стр
био5с
бис2к1в
бл1исп
бле2с1к
бо1д6р
бо1жж
бо1з
бо1рв
бо1с
бо2ес
бо2мч
бо2сс
бо3м2ле
боз2л
бра6сл
бст6
буг1л
в1б
в1в
в1г
в1д
в1к
в1лаг
в1ма
в1мо
в1н
в1с2
в1т
в1ф
в1х
в1ц
в1ч
в1ш
в1щ
в2нуш
в2хож
в2чер
в5рас
в6би
в6кус
в6сег
в6ход
ва1д
ва2дл
ва2дн
ван5с6
вах1
вдо1с
ве2д1р
ве2с1к
ве2ст1в
вез1до
верт1ля
вет3в2
вет4в3л
вз6р
взыс5
ви2ам
ви2б1р
ви2зн
ви5аф
ви5ол
виа1с
вк1н
во1дво
во1п
во2ж3ж
во2с1пе
во2с3ток
во2с3точ
во2стр
во3з2дан
воз1в
вои2с
вос1к
впо6л
вра2ж5д
вро5т
вто3к2
ву1з
ву1ст
ву5г
вче6т5
вы1ск
вы1сп
вы1тв
вы1х
вы1ш
вы5п
выпу2к1
г1г
г1з
г1ляе
г1лят
г1ляю
г1ч
г2нив
г2ном
г2раб
га1ст
га2у
ге2од
ге2оп
ге2ос
ге2оц
ге6об
ги1с
ги2б1л
ги2д1р
гко1в
го1з
го1п
го2зл
го2с1а
го2сб
гос3с
грив1к
гро2м1ч
гс2шиб
д1ва
д1ве
д1вид
д1вис
д1вод
д1г2
д1д
д1за
д1зв
д1зо
д1л
д1н
д1п
д1рас
д1реж
д1руб
д1рыв
д1ряд
д1т
д1х
д1ч
д2воя
д5зем
д5зи
да4о
дву1ш
дву2х1
дд2в
де1ст
де1х
де2ес
де2з1а2
де2з1о2
де2о
дес2к
ди2ад
ди2ам
ди2в1л
ди2о5с
ди2об
ди2с1е
ди5он
ди5х
дис1тр
дмо1с
дно5д
до1бр
до1д2
до1з
до1п
до1рв
до1с2п
до1сн
до1ш2
до2ру
до6бла
дох1л
дро2ж3ж
дря2б1
дс2н
дс3кн
ду1п
ду1ст
ду2о
ду2п3л
дым1н
дэ1г
е1а
е1ба
е1бе
е1би
е1бо
е1бр
е1бу
е1бы
е1бье
е1бью
е1бья
е1бю
е1бя
е1ва
е1ве
е1ви
е1во
е1ву
е1вы
е1вье
е1вью
е1вья
е1вю
е1вя
е1га
е1гд
е1ге
е1ги
е1глам
е1го
е1гу
е1д2лин
е1да
е1де
е1ди
е1до
е1ду
е1ды
е1дью
е1дю
е1дя
е1е
е1жа
е1же
е1жо
е1жу
е1жье
е1жьи
е1жью
е1жья
е1за
е1зе
е1зи
е1зо
е1зу
е1зы
е1зью
е1зья
е1зю
е1зя
е1и
е1ка
е1кв
е1ке
е1ки
е1ку
е1ла
е1ле
е1ли
е1ло
е1лу
е1лы
е1лье
е1льи
е1лья
е1лю
е1ля
е1ма
е1ме
е1мо
е1му
е1мы
е1мье
е1мьи
е1мью
е1мья
е1мя
е1на
е1не
е1ни
е1но
е1ну
е1ны
е1нье
е1ньи
е1нью
е1нья
е1нэ
е1ню
е1ня
е1о2кр
е1па
е1пе
е1пи
е1по
е1пу
е1пы
е1пье
е1пьи
е1пью
е1пья
е1пя
е1ра
е1ре
е1ри
е1ро
е1ру
е1ры
е1рье
е1рью
е1рья
е1рю
е1ря
е1с2г
е1с2клад
е1с2пот
е1са
е1сб
е1сд
е1се
е1си
е1ск
е1см
е1со
е1сок.
е1ста
е1ств
е1сте
е1сти
е1стр
е1сту
е1сты
е1стье
е1стью
е1стья
е1стю
е1стя
е1су
е1сы
е1сье
е1сьи
е1сью
е1сья
е1тье
е1тьи
е1тью
е1тья
е1тю
е1у2
е1фа
е1фе
е1фи
е1фо
е1фу
е1ха
е1хе
е1хи
е1хо
е1ху
е1ца
е1це
е1ци
е1цо
е1цу
е1ча
е1че
е1чи
е1чу
е1чье
е1чьи
е1чью
е1чья
е1ша
е1ше
е1ши
е1шл
е1шо
е1шта
е1шу
е1шью
е1ща
е1ще
е1щи
е1що
е1щу
е1щью
е1э
е1ю
е1я
е2в1мо
е2в1рит
е2д1о2щ
е2оди
е2она
е2оро
е2пси
е2р1у2п
е2с1би
е2с3пу
е2х1у2ч
е2хк
е3жи
е3звон
е3ола
е3он.
е3та
е3те
е3ти
е3то
е3ту
е3ты
е3тя
е5ми
е5ол.
е5олы
е5охл
е5ста.
е6стиг
еа2де
еа2з
еа2т1р
еа6да
ев2ним
ев2нят
ево2с
ег1ла.
ег1ло
ег1лы
еж1м
еж1р
ежа6т
ез1во
ез5ви
еи2г
еи2д
еи2м
ек1н
ек1сту
ем1не
ем1ного
ем1ч
ен1ри
ео1с
ео2б
ео2дет
ео2ж
ео2кон
ео2ру
ео2ч
ео2щ
ео6хв
еоб1л
еоу4
еп1ле
еп1ли.
еп1та
еп1то
еп5те
еп5тич
еп5тур
епи1т2р
ер1ват
ер1тя
ер6кл
ере1д2р
ере1дв
ере1зв
ере1п
ере1с2с
ере5гн
ереп2л
ери1ск
ерис2
еро6б
ес1п
ес2кле
ес2кош
ес2пас
ес5кур
ескрип1
ет1л
ет1р
ет2рд
еу3то
ех1о2к
ех5об
еш1то
ж1б
ж1ж
ж1з
ж1л
ж1ма
ж1н
ж1п
ж1с
ж1т
ж1ч
ж2же
жат1в
же1с2п
же5д2
жео2
жи2в1л
жи2л1от
жи2л1у2п
з1акт
з1вк
з1вя
з1г
з1дв
з1де
з1ди
з1ду
з1ды
з1дя
з1з
з1л
з1не
з1ни
з1но
з1ну
з1ню
з1общ
з1окс
з1орг
з1п
з1ра
з1род
з1ряд
з1т
з1ц
з1ч
з1ш
з1э
з2вук
з2вяк
з2г1ни
з2г1ну
з2рак
з2рач
з5вет
з5гна
з5дом
з5рез
з6вон
з6ть
за1вче
за1г2
за1др
за1з2
за1кв
за1р2д
за1р2ж
за1с
за1х
за1ш
за2шк
за3тм
за5тв
за5у
зае2
зан5с6
зас2н
зас4по
зат2
зач2т
зая6
зв2н
зве2т3в
зд2ва
зди2с
зз2л
зи6ни
зи6оно
зо1б
зо1д2р
зо1з2
зо1м2н
зо1рв
зо1с2
зо1щ
зо2бил
зо3м2л
зок2
и1а
и1ба
и1бе
и1би
и1бо
и1бр
и1бу
и1бы
и1бье
и1бью
и1бю
и1в2с
и1ва
и1ве
и1ви
и1во
и1ву
и1вье
и1вью
и1вья
и1вя
и1га
и1ге
и1ги
и1гл
и1го
и1гу
и1да
и1де
и1ди
и1до
и1др
и1ду
и1ды
и1дю
и1дя
и1е
и1жа
и1же
и1жж
и1жи
и1жо
и1жу
и1з2вез
и1за
и1зе
и1зи
и1зна
и1зо
и1зр
и1зу
и1зы
и1зью
и1зю
и1зя
и1и
и1ка
и1кв
и1ке
и1ки
и1ко
и1ку
и1кю
и1ла
и1ле
и1ли
и1ло
и1лу
и1лы
и1лье
и1льи
и1лья
и1лю
и1ля
и1ма
и1ме
и1мо
и1му
и1мы
и1мье
и1мьи
и1мью
и1мья
и1мя
и1на
и1не
и1ни
и1но
и1ну
и1ны
и1нье
и1ньи
и1нью
и1нья
и1ню1
и1ня
и1о
и1па
и1пи
и1пл
и1по
и1пу
и1пы
и1пью
и1пю
и1пя
и1ра
и1ре
и1ри
и1ро
и1ру
и1ры
и1рье
и1рьи
и1рью
и1рья
и1рю
и1ря
и1с2ни
и1са
и1се
и1си
и1со
и1ста
и1сте
и1сти
и1стра
и1сту
и1сты
и1стье
и1стью
и1стья
и1стю
и1стя
и1су
и1сы
и1сье
и1сьи
и1сью
и1сья
и1сю
и1т2раг
и1т2рес
и1т2рон
и1те
и1ти
и1то
и1ту
и1ты
и1тье
и1тью
и1тья
и1тю
и1тя
и1у
и1фа
и1фе
и1фи
и1фо
и1фу
и1ха
и1хе
и1хи
и1хо
и1ху
и1ца
и1це
и1ци
и1цо
и1цу
и1ча
и1че
и1чи
и1чу
и1чье
и1чьи
и1чью
и1чья
и1ш2п
и1ша
и1ше
и1ши
и1шл
и1шо
и1шу
и1шье
и1шью
и1шья
и1ща
и1ще
и1щи
и1що
и1щу
и1э
и1ю
и1я
и2а1г
и2ап
и2аф
и2евод
и2к1ч
и2л1а2ц
и2о1с2к
и2опр
и2ох
и2оц
и2пси
и2с1тин
и2т1л
и2ш1лы
и2юл
и2юн
и5гд
и5ми
и5оле
и5пе
и5та
и6п5тиз
и6тот
иа1ск
иас2
иг1н
ид1ц
иди3ом
иди5а
ие2ди
из1в
из1д
из1реч
из2ва
из2гн
изг1не
изо1т
изо2б1р
изо2о
изыс1
ик1н
икс1ту
иле1п
иле2п1л
иль1д
им1н
ино1д2ра
ино1с
инс2
иню2ш
ио2ста
ио5сп
иоб1ре
ип1та
ип1те
ип1то
ип1ту
ир5в
ис1б
ис1к
ис1м
ис1п
ис1тек
ис1ч
ис5тец
иск1н
ист1в
ит1ва
ит1ве
ит1р
ит5ву
иу2г
иу2ч
иу6р
ия2д
й2дв
й2ль
й2мс
й2нв
й2с1б
й2сн
й2сш
й5о
й6с5ф
йер1в
йко5п
йс2ко
йх2ск
к1д
к1на
к1но
к1п
к1ск
к1х
к1ч
к2вак
к2о1бес
к2св
к2сл
к2ст1ак
к5ж
к5лий
к5сте.
ка1д
ка1сп
ка1ст
ка2д1р
ка2дн
ка2ж1д
ка2п1л
ка2п1ре
ка3ус
каз1на
кам5н
каш3л
ква2д1р
ке1ст
ке5гли
ке5д
кеп1ти
ки3о2с3к
ки4с3л
ки5о
клю1ч
клю2чн
кно2п3л
ко1знан
ко1ск
ко2мин
ко2с3н
ко2св
ко2тл
ко5ств
ког2н
копу5
кор1в
кос1мо
кост1ля
кри2о5
кро2пл
кс1п
кс1тр
кт2рис
кус1к
л1ба
л1би
л1бо
л1в
л1г
л1д6
л1жа
л1же
л1жи
л1за
л1зе
л1зо
л1зы
л1к
л1л
л1м
л1п
л1т
л1ф
л1х6
л1ц
л1ча
л1че
л1чи
л1чу
л1чь
л1ш6
л1щ
л2вк
л2вн
л2вст
л2гат
л2ль
л2тк
л5бы
л6т5л
лау1
ле1т2р
ле2б1л
ле2о
ле2п1т
лег5л
лен2д1р
леп5ло
ли2б1р
ли2в1л
ли2к1в
ли2п1л
ли2т1уп
ли2тоб
ли5стр
ли6ос
ли6х5в
лк1н
ллю1
ло1д6р
ло1з
ло1пл
ло1ску
ло6бор
лос5ка
лох5л
лс2то
лу1д2
лу1с
лу2д3к
лу2д3л
лу2д3н
лу3б2р
лу5т
лф2т
ль2тот
люк1в
м1г
м1ж
м1з
м1к
м1на
м1нее.
м1ней.
м1ное
м1нос
м1с
м1ф
м1ц
м2м1н
м2мк
м2с1ор
м2сти
м5неп
м5ний
м5нов
м5нот
м5х
м5э
м6ат
м6ль
ма1сб
ма2вз
ма2с1л
ма2т1р
ма2у
ма6чт
маг1н
мад1ри
ман2д1арм
мат1в
ме2д1осм
ме2о
ме2с1к
ме2ч1т
межо2т1
мете2о
мз6д
ми2ок
ми6з5ан
миро3з2
много1
мо1м
мо1п
мо1ско
мо2ж3ж
мо2т3р
мо3о
моз2г1л
моск1в
мосо2м3н
мп2л
мпо2ч
мс2н
му1г
му5с6к
мы4с3л
н1б
н1в2
н1г
н1д
н1ж
н1з
н1к
н1л
н1м
н1н
н1п
н1т
н1ф
н1х
н1ч
н1щ
н2дв
н2дг
н2дл
н2дн
н2с1ля
н2с1м
н2сн
н2сф
н2тк
н2тл
н2тр1а2г
н2трок
н2тш
н2шн
н6дц
на1з2
на1кв
на1м2ного
на1мн
на1рв
на1х
на1шл
на1шп
на3ивн
на3из
на3ит
на5э
наи1с2к
нао2т
нау6ч
нгоу5
нд2сп
нд6з
нде2с1
не1в2д
не1гл
не1гн
не1др
не1зн
не1мн
не1п2
не1с2н
не1с2п
не1ст
не1сч
не1т2р
не2а3по
не2вра
не2рот
не3о2гр
не3о2дин
не3о6с
не5кст
не5рж
не5с6х
нев2п
недо1с
нее6
неи2
нео2п
нео2пр
нео2р
нео2х
нео2ц
нес2к
нет2л
неу5стр
нея6
ни1п
ни1стр
ни5кт
нила6
нк5ро
нко1п
но1з
но1п
но1тв
но2пт
но5е
но5о
но5ш
ном5н
ноп2л
нсу2р
нт2р
нтиа2
нтио2
ну1ск
ну1т2р
о1бе
о1би
о1бо
о1бу
о1бы
о1бье
о1бьи
о1бью
о1бья
о1в2в
о1в2се
о1в2т
о1ва
о1ве
о1ви
о1вм
о1во
о1ву
о1вы
о1вье
о1вьи
о1вью
о1вья
о1вя
о1га
о1ге
о1ги
о1го
о1гу
о1да
о1де
о1ди
о1до
о1дру
о1ду
о1ды
о1дью
о1дю
о1дя
о1е
о1жа
о1же
о1жже
о1жи
о1жм
о1жо
о1жу
о1жье
о1жьи
о1жью
о1жья
о1зе
о1зи
о1зо
о1зу
о1зы
о1зье
о1зьи
о1зью
о1зья
о1зя
о1ка
о1кв
о1ке
о1ки
о1ко
о1ку
о1ла
о1ле
о1ли
о1лу
о1лы
о1лье
о1льи
о1лья
о1лю
о1ля
о1ма
о1ме
о1ми
о1мо
о1му
о1мч
о1мы
о1мье
о1мья
о1мя
о1на
о1не
о1ни
о1но
о1ну
о1ны
о1нье
о1ньи
о1нью
о1нья
о1ню
о1ня
о1о2
о1па
о1пе
о1пи
о1по
о1пу
о1пы
о1пье
о1пьи
о1пью
о1пья
о1пя
о1ра
о1рват
о1ре
о1ри
о1ро
о1ру
о1рье
о1рью
о1рья
о1рю
о1ря
о1с2кла
о1с2пор
о1с2то
о1с2шив
о1са
о1сб
о1се
о1си
о1сне
о1сним
о1спе
о1ста
о1сте
о1сти
о1стр
о1сту
о1сты
о1стье
о1стьи
о1стью
о1стья
о1стю
о1стя
о1су
о1сче
о1сы
о1сье
о1сьи
о1сью
о1сья
о1сю
о1та
о1то
о1ту
о1ты
о1тье
о1тьи
о1тью
о1тья
о1тя
о1фа
о1фе
о1фи
о1фо
о1фу
о1фье
о1фьи
о1фью
о1фья
о1ха
о1хе
о1хо
о1ху
о1ца
о1це
о1ци
о1че
о1чи
о1чл
о1чу
о1чье
о1чьи
о1чью
о1чья
о1ш2л
о1ша
о1ше
о1ши
о1шо
о1шу
о1шье
о1шью
о1ща
о1ще
о1щи
о1щу
о1щью
о1ю
о1я
о2б1раж
о2б1раз
о2в1па
о2вры
о2д1о2бол
о2д1о2дея
о2д3раж
о2дотр
о2евр
о2з1вол
о2з1но
о2з1ну
о2з1об
о2зня
о2зым
о2зьт
о2к1а2у
о2нн
о2ф1ак
о2ф1ра
о2ш3лы
о3в2люб
о3ло
о3отр
о3с2бер
о3ти
о5двиг
о5ом
о5пте
о5ру.
о5спу
о5ть6м
о5х6т
о5ча
о6тва
о6шн
об1в
об1о2с3н
об1ращ
об2луди
об5лик
об5лич
об5рад
об5рам
ово5стр
овыс2п
од1ра
од1рос
од1э
од2лит
оди5ап
одо1с
одс2п
одь1яч
ое2д
ое2с
оз1до
оз1ро
оз2дор
оз5дю
озо2б1л
ои2г6
ои2з
ои2ме
ои2му
ои6о
ок1з
ок1ну
ок5не
олу3д4
олуо2
оль1д
ом1ного
ом1р
ом2ня
он2трат
он6тру
онс2
оп1та
оп1ти
ор1исп
ор2б1л
ор5ть
ор5тя
орас6пр
ос1ка.
ос1кам
ос1ках
ос1ке
ос1ки
ос1кой
ос1ку.
ос1мет
ос1мос
ос1пы
ос2н
ос2с1м
ос2св
ос3ного
ос3ною
ос5ба
ос5ми
ос5нит
ос6пле
от1в
от1л
от1раз
от1у2ж
от1у2т
от1у2ч
от2лев
ото1д2ра
ото2чь
оту2а
оту2че
офо2р
ох1рис
оэ5ти
оя2в
оя2д
оя2з
оя6р
п1д
п1ла.
п1лен
п1лютс
п1ля
п1ск
п1тр
п1туа
п1ты
п1тя
п1щ
п2леде
п2ляс
п2ляш
п3леть.
п5лова
п5тил
п6е
па1с2к
па2в
па2с1то
па2ск1в
па5во
па5др
пав1л
пах1л
пе2п1л
пе2тл
пе6с5к
пеп1т
пер1в
пер2м1ал
пере3о6с
пи2ск
пи5с2коп
пле2в1р
по1д2раг
по1з
по1мн
по1п
по1ск
по1см
по1сх
по1х
по2д1ж
по2д1о2к
по2д1о2си
по2д1руб
по2д1рул
по2д1рум
по2д1руч
по2д1у2ро
по2дь
по3вли
по5б
по5сс
пог6
пое2
поз2л
пос2
поэ1м
ппо1д
пре2до2т
пре2дох
прей2с1к
при1в2н
при1вк
при1л
при1с
при1т
при2тч
приль2
прис2п
приче2с1к
про1д2л
про1д2ра
про1р
про1ск
пт1в
пу2б1л
пуг1л
пуг3н
пх6н
р1б
р1ва.
р1вар
р1вац
р1веж
р1вей
р1вен
р1ви
р1во
р1г
р1д
р1ж
р1за
р1зе
р1зи
р1зо
р1зя
р1к
р1л
р1м
р1н
р1п
р1р
р1с
р1та
р1те
р1ти
р1то
р1тр
р1ту
р1ты
р1тью
р1тю
р1ф
р1ха
р1хе
р1хло
р1хов
р1хуш
р1ц
р1ч
р1ш
р1щ
р2г1л
р2г1н
р2гв
р2гг
р2гот
р2д1ц
р2дл
р2дн
р2дч
р2жн
р2ль
р2м1н
р2м5ч
р2мк
р2мс
р2мф
р2сн
р2т1акт
р2т1л
р2т1об
р2узл
р2хв
р2ш1р
р2шк
р2шн
р2щ3в2
р5вя
р5хот
р6дв
р6мщ
р6хре
ра2зобл
ра2п1л
ра2с1та
ра2с1тер
ра2с1то
ра2с1ту
ра2с1тя
ра2так
ра3зорен
ра3зори
ра5ун
ра5ус
ра6сля
ра6стуш
раа6
раз1в
рас1пы
рас1т2л
рас1тра
рас1трог
рас3тян
расто2пл
рат1в
рах1л
раэ2
ре1г2н
ре1зр
ре1р2
ре1с2п
ре1сч
ре1т2р
ре2д1о2бе
ре2д1о2пе
ре2д1о2се
ре2д1у2г
ре2д3о2ли
ре2допр
ре2дос
ре2к1ват
ре2ос
ре2х1р
рег1ли
ред1р
рее2
рей2х
рем1н
рео2д
рео2ц
реп5ло
ри1дв
ри1жм
ри1зв
ри1мч
рис2м
риу2
рк1н
рк6ни
ро1дв
ро1зв
ро1зр
ро1пл
ро1с2кл
ро1см
ро1х
ро2г1не
ро2г1ну
ро2с1л
ро2х1н
ро5бр
ро5спа
ро5спл
ро5шт
рое6х
рои2с
рооп1р
рор2в
рпус1к
рро1
ррос6
рс6п
рт1в
рт1лю
руг1в
руг1л
руг1н
рх1оп
ры2г1н
рыт1в
рых1
рю5ква
рю5кве
с1вен
с1да
с1до
с1н
с1па
с1пил
с1пит
с1пл
с1с
с1хо
с1ц
с1чат
с1чл
с1ш6
с1щ
с2воя
с2гор
с2добн
с2катн
с2клер
с2пеш
с2раб
с2рез
с2сб
с2сн
с2сори
с2тяну
с2цена
с3с2не
с5ге
с5ди
с5на.
с5ное
с5ной
с5ном
с6как
са2б1л
само1
сва6е
свах2
све2т
све2т1л
свер2хи
сверх1
сг6
се1гн
се1з
сего1
сегод2
секс1т
сер1ве
сер5ва
си2п1л
си3ом
ск1ну
ск2вер
ско2б1л
смо2г1л
сму2г1
со1бр
со1д2ра
со1ж
со1з
со1л2г
со1м2
со1р2в
со1с2
со1тв
со2в1м
со2сь
со2тле
со3з2да
со5вл
со5о
со5щ
со6с5н
сп2люсь.
сс1во
ст1ли
ст5вер
ств2л
сто1пл
су1гл
су2б
су2ев
су2ни
суб1а
суб1л
супе2р1
сче2с1к
съ2е3ма
съе3д
съе3л
съе3мо
съе3х
сы2п3ле
сып1лю
т1вой
т1вою
т1д2
т1ж
т1з
т1к
т1лог
т1рез
т1рыв
т1ха
т1хо
т1ч
т1ш2
т2вл
т2рав
т2сд
т4рщ
та1ст
таме2н
тво1з
те1ст
те2к1л
те2ос
те2п1л
те2р1ак
те6хо
тег1н
тек1ста
теле3о
тем5н
тер1в
тере2о
тет1р2а
ти1стр
ти2в1л
ти2г1л
ти5а
ти5ок
тк2но
то1бр
то1д
то1з
то1с2
то2дн
то2ж1д
тооп1
трдо2
тре2х
тс2к
тс2н
ту2пр
туп1л
тыс5к
ть6му
у1а
у1ба
у1бе
у1би
у1бо
у1бу
у1бы
у1бье
у1бью
у1бья
у1бю
у1бя
у1ва
у1ве
у1ви
у1во
у1ву
у1вы
у1вье
у1вью
у1вя
у1га
у1ге
у1ги
у1го
у1гу
у1да
у1де
у1ди
у1до
у1ду
у1ды
у1дьи
у1дью
у1дю
у1дя
у1е
у1жа
у1же
у1жи
у1жо
у1жу
у1жье
у1жьи
у1жью
у1жья
у1за
у1зе
у1зи
у1зо
у1зу
у1зы
у1зья
у1зя
у1и
у1ка
у1ке
у1ки
у1ко
у1ку
у1кья
у1ла
у1ли
у1ло
у1лу
у1лы
у1лье
у1льи
у1лья
у1лю
у1ля
у1ма
у1ме
у1ми
у1мо
у1му
у1мы
у1мье
у1мью
у1мья
у1мя
у1на
у1не
у1ни
у1но
у1ну
у1ны
у1нье
у1ньи
у1нью
у1нья
у1ню
у1ня
у1о
у1па
у1пе
у1пи
у1по
у1пу
у1пы
у1пье
у1пью
у1пья
у1пю
у1пя
у1ра
у1ре
у1ри
у1ро
у1ру
у1ры
у1рье
у1рьи
у1рью
у1рья
у1рю
у1ря
у1са
у1се
у1си
у1см
у1со
у1ста
у1сте
у1сти
у1сту
у1сты
у1стье
у1стью
у1стья
у1стя
у1су
у1сф
у1сы
у1сье
у1сью
у1сья
у1сю
у1та
у1те
у1ти
у1тл
у1то
у1ту
у1ты
у1тье
у1тью
у1тья
у1тю
у1тя
у1у
у1фа
у1фе
у1фи
у1фо
у1фу
у1фье
у1фьи
у1фью
у1фья
у1ха
у1хе
у1хи
у1хо
у1ху
у1ца
у1це
у1ци
у1цу
у1ча
у1че
у1чи
у1чу
у1чье
у1чьи
у1чью
у1чья
у1ша
у1ше
у1ши
у1шо
у1шу
у1шье
у1шьи
у1шью
у1шья
у1ща
у1ще
у1щи
у1що
у1щу
у1ю
у1я
у2б1р
у2д1р
у2ес
у2х1р
у2хв
у2ш1лы
у4ныв
у5ле
у5мр
у5ол
у5шл
у5э
у6але
у6ас
у6зел
у6трь
уд2в
уд2рс
уе1р
уе2ди
уз5дю
ук1в
ук5н
укос6
уль1д
ум1ног
уо2к
ур1в
ус1ка
ус1ке
ус1ки
ус1ком
ус1ч
ус2кр
ус2по
ус5ков
ус5ку.
ут5ла
уть6м
уу2с
ух1л
ух1м
ух1о2к
уш3п
уэ5ла
уэ5ле
уя2з
ф1б
ф1г
ф1к
ф1м
ф1т
ф1ф
ф1ш
ф2узл
фа5у
фаг1н
фар5в
фе1д
фе2д1р
фе2с1к
фени6
фи1д
фи1с2к
фи2дн
фи3о
фи6нин
фото1
фра5с
фре2с1к
х1б
х1д6
х1з
х1к
х1ли
х1ло.
х1лу
х1лы
х1ля
х1ма
х1ми
х1н
х1осн
х1п
х1т
х1у2ро
х1ф6
х1х
х1ц
х1ш
х1э
х2лип
х2ляб
х4ны
х5ла.
х5мет
х5осм
хе6о5
хи2зы
хие2
хо1тв
хо2пе
хоз1ар
хри2п1л
хро2м1ч
ц1б
ц1д
ц1н
ц1р
ц1ц
ца2п1л
це1д
це2д1р
цей6т5
ци2к1л
ци2ф1р
ч1в
ч1н
ч1с
ч1ч
ч1ш
ча2т1л
чар3т
част1в
чет1вер
чех1л
чи2с1л
чу2ж1д
ш1к
ш1ля
ш1м
ш1н
ш1с
ш1ц
ш2кив
ш2лем
ш2лют.
ш2пр
ш5ч
ш6леш
шаг1н
ше1с
шео2
ши2в1л
ши2ф1р
ще1д
ще1с
ще2д1р
щи2п3л
ъ1я2
ъе2
ъе3х
ъем3н
ъю6с
ъю6т
ы1ба
ы1бе
ы1би
ы1бо
ы1бр
ы1бу
ы1бы
ы1бье
ы1бьи
ы1бью
ы1бья
ы1бя
ы1ва
ы1ве
ы1ви
ы1во
ы1ву
ы1вы
ы1вя
ы1г
ы1га
ы1ге
ы1ги
ы1го
ы1гу
ы1да
ы1дв
ы1де
ы1ди
ы1до
ы1ду
ы1ды
ы1дю
ы1дя
ы1е2
ы1жа
ы1же
ы1жж
ы1жи
ы1жм
ы1жо
ы1жр
ы1жу
ы1за
ы1зв
ы1зд
ы1зе
ы1зо
ы1зр
ы1зу
ы1зы
ы1зя
ы1и2
ы1ка
ы1ке
ы1ки
ы1ко
ы1ку
ы1ла
ы1ле
ы1ли
ы1ло
ы1лу
ы1лы
ы1лье
ы1льи
ы1лья
ы1лю
ы1ля
ы1ма
ы1ме
ы1ми
ы1мо
ы1му
ы1мы
ы1мя
ы1на
ы1не
ы1ни
ы1но
ы1ну
ы1ны
ы1нье
ы1ньи
ы1нью
ы1нья
ы1ню
ы1ня
ы1па
ы1пе
ы1пи
ы1по
ы1пу
ы1пы
ы1пье
ы1пью
ы1пя
ы1ра
ы1рв
ы1ре
ы1ри
ы1ро
ы1ру
ы1ры
ы1рье
ы1рью
ы1рья
ы1рю
ы1ря
ы1са
ы1се
ы1си
ы1со
ы1ст
ы1ста
ы1сте
ы1сти
ы1сту
ы1сты
ы1стью
ы1су
ы1сы
ы1сье
ы1сьи
ы1сью
ы1сья
ы1т6р
ы1та
ы1те
ы1ти
ы1то
ы1ту
ы1ты
ы1тье
ы1тьи
ы1тью
ы1тья
ы1тя
ы1у2
ы1ха
ы1хе
ы1хи
ы1хо
ы1ху
ы1ц
ы1ца
ы1це
ы1ча
ы1че
ы1чи
ы1чу
ы1чье
ы1чьи
ы1чью
ы1чья
ы1ша
ы1ше
ы1ши
ы1шо
ы1шу
ы1шью
ы1шья
ы1ща
ы1ще
ы1щи
ы1що
ы1щу
ы1я2
ы2з1вол
ы2с1ку
ы5см
ы6шн
ык1в
ык5н
ым1ч
ып1ле
ыре2х
ыс2мей
ыс5ки
ыс6па
ыс6пл
ыш1ле
ь1б
ь1ва
ь1ве
ь1ви
ь1г
ь1де
ь1ди
ь1ж
ь1з
ь1к
ь1м
ь1н
ь1п
ь1с
ь1т
ь1х
ь1ч
ь1ш
ь1щ
ь1э
ь2к1ло
ь2нул
ь2сн
ь2сти
ь2стя
ь2ф1ра
ь5дь
ь5дя
ь5фе
ь6зн
ь6зя.
ь6мс
ь6ща
ь6ще
ь6щу
ьдо1
ьк5н
ьти5с
ьхо2
э1ля
э1нь
э1о
э1я
э2д
э5зи
э5ка
э5ке
э5лы
э5ри
э5ш
э6в
э6ф
эд1р
эк1в
эк1з
эк1л
эк2ск
экс1
экс2и
эль5
эро1
эс1к
эс2па
эс5м
ю1а
ю1б
ю1ба
ю1бе
ю1би
ю1бо
ю1бу
ю1бы
ю1бя
ю1ва
ю1ве
ю1ви
ю1во
ю1ву
ю1вы
ю1га
ю1ге
ю1ги
ю1го
ю1гу
ю1да
ю1де
ю1ди
ю1до
ю1ду
ю1ды
ю1дью
ю1дя
ю1е
ю1жа
ю1же
ю1жи
ю1жо
ю1жу
ю1жье
ю1жьи
ю1жью
ю1жья
ю1за
ю1зе
ю1зи
ю1зо
ю1зу
ю1зы
ю1зю
ю1зя
ю1и
ю1ка
ю1ке
ю1ки
ю1ко
ю1ку
ю1ла
ю1ле
ю1ло
ю1лу
ю1лы
ю1лю
ю1ля
ю1ма
ю1ме
ю1ми
ю1мо
ю1му
ю1мы
ю1на
ю1не
ю1ни
ю1но
ю1ну
ю1ны
ю1ню
ю1ня
ю1о
ю1па
ю1пи
ю1по
ю1ра
ю1ре
ю1ри
ю1ро
ю1ру
ю1ры
ю1рю
ю1ря
ю1са
ю1се
ю1со
ю1ста
ю1сте
ю1сти
ю1стр
ю1сту
ю1сты
ю1стью
ю1стя
ю1су
ю1сы
ю1сю
ю1та
ю1те
ю1ти
ю1то
ю1ту
ю1ты
ю1тя
ю1фа
ю1фе
ю1фя
ю1ха
ю1хе
ю1хи
ю1хо
ю1ху
ю1це
ю1ци
ю1ша
ю1ше
ю1ши
ю1шо
ю1шу
ю1ща
ю1ще
ю1щи
ю1що
ю1щу
ю1ю
ю1я
ю2бч
ю2д1ж
ю2ли
ю2с1к
юй2д1
юйдо6
юк1з
юк1н
юм1н
юмини5
я1ба
я1бе
я1би
я1бо
я1бр
я1бу
я1бы
я1бью
я1бя
я1ва
я1ве
я1ви
я1во
я1ву
я1вы
я1вью
я1вя
я1га
я1ге
я1ги
я1го
я1гу
я1да
я1де
я1ди
я1до
я1ду
я1ды
я1дью
я1дю
я1дя
я1е
я1жа
я1же
я1жи
я1жо
я1жу
я1жье
я1жьи
я1жью
я1жья
я1за
я1зе
я1зи
я1зо
я1зу
я1зы
я1зью
я1зья
я1зю
я1зя
я1и
я1ка
я1ке
я1ки
я1ко
я1ку
я1ла
я1ле
я1ли
я1ло
я1лу
я1лы
я1лю
я1ля
я1ма
я1ме
я1ми
я1мо
я1му
я1мы
я1мя
я1на
я1не
я1ни
я1но
я1ну
я1ны
я1нье
я1ньи
я1нью
я1нья
я1ню
я1ня
я1па
я1пе
я1пи
я1по
я1пу
я1пы
я1пье
я1пью
я1пья
я1пя
я1ра
я1ре
я1ри
я1ро
я1ру
я1ры
я1рье
я1рью
я1рья
я1ря
я1са
я1се
я1си
я1со
я1ста
я1сти
я1сту
я1сты
я1стье
я1стью
я1стья
я1су
я1сы
я1та
я1те
я1то
я1ту
я1ты
я1тье
я1тью
я1тья
я1тю
я1тя
я1у
я1ха
я1хе
я1хи
я1хо
я1ху
я1ца
я1це
я1ци
я1цу
я1ча
я1че
я1чи
я1чу
я1чье
я1чьи
я1чью
я1чья
я1ша
я1ше
я1ши
я1шо
я1шу
я1ща
я1ще
я1щи
я1що
я1щу
я1ю
я1я
я2в1л
я5стр
я5ти
яг1л
яг5н
яз1в
як1н
яс1к
яс6т
ят1в
ях1ле

