## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Pt_BR.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Pt_BR.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Pt_BR;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Pt_BR> hyphenation pattern class

=head1 Copyright

The data for this library is copied from the OpenOffice.org project and
modified to be used as a Perl module by Roland van Ipenburg.

L<http://svn.services.openoffice.org/ooo/trunk/dictionaries/pt_BR/>

	Autor/Author: Raimundo Moura <raimundomoura@openoffice.org>

	pt-BR: Este dicionário está em desenvolvimento por Raimundo Moura e sua equipe. Ele está licenciado sob os termos da Licença Pública Geral Menor versão 2.1 (LGPLv2.1), como publicado pela Free Software Foundation. Os créditos estão disponíveis em http://www.broffice.org/creditos e você pode encontrar novas versões em http://www.broffice.org/verortografico.

	en-US: This dictionary is under development by Raimundo Moura and his team. It is licensed under the terms of the GNU Lesser General Public License version 2.1 (LGPLv2.1), as published by the Free Software Foundation. The credits are available at http://www.broffice.org/creditos and you can find new releases at http://www.broffice.org/verortografico.


	Copyright (C) 2006 - 2007 por/by Raimundo Santos Moura <raimundomoura@openoffice.org>

	=============
	APRESENTAÇÃO
	=============

	O Projeto Verificador Ortográfico do BrOffice.org é um projeto
	colaborativo desenvolvido pela comunidade Brasileira.
	A relação completa dos colaboradores deste projeto está em:
	http://www.broffice.org.br/creditos

	***********************************************************************
	* Este é um dicionário para correção ortográfica da língua Portuguesa *
	* para o Myspell.                                                     *
	* Este programa é livre e pode ser redistribuído e/ou modificado nos  *
	* termos da GNU Lesser General Public License (LGPL) versão 2.1.      *
	*                                                                     *
	***********************************************************************

	======================
	SOBRE ESTA ATUALIZAÇÃO
	======================
	. Inclusão das regras para a formação das Ênclises e Mesóclises;
	. Nesta atualização foram analisados 1.849 termos, em sua maioria 
	  parônimos. Foram encontradas palavras grafadas com mais de uma
	  forma, a exemplo de 'charreu' e charréu, e eliminadas as incorretas 
	  (Colaboração de Leonardo Fontenelle).
	. Revisão e exclusão de 1.113 nomes próprios duplicados; 
	. Exclusão de associações errôneas de termos à regras (colaboração de
	  Leonardo Fontenelle), exemplos: ação/K, ligeiro/M, duplex/B, etc;  
	. Inclusão de algumas letras como 'à' e 'é' para correção de falha na 
	  versão 2.3 do BrOffice.org;
	. Correção do apóstrofo em algumas palavras com d' como: 
	  açucenas-d'água e pai-d'égua, cuja grafia apresentava o d´
	  (asento agudo ao invés do apóstrofo). Leonardo Fontenelle;
	. Inclusão dos termos 'triangularização','dinamicidade', 'mestranda',
	  colaboração de Leo Barichello;
	. Inclusão do  termo 'cochilos', colaboração de Rafael da Fonseca 
	  Duarte;
	. Inclusão dos termos 'couché', 'pré-obliterado', 'pré-filatelia' e 
	  'regomado', colaboração de Carlos Dalmiro Silva Soares;
	. Criação do Temático Filatélico por Carlos Dalmiro Silva Soares;
	. Correção da conjugação de verbos terminados em ear com som aberto,
	  como: idear e estrear. Colaboração Hortência Maria Moura;
	. Inclusão do gênero feminino dos numerais ordinais como:
	  ducentésima, trecentésima, tricentésima, quadringentésima, 
	  qüingentésima, sexcentésima, seiscentésima, septingentésima,
	  octingentésima e nongentésima;
	. Inclusão ds siglas dos Estados de Alagoas (AL) e Amapá (AP);
	. Inclusão de algumas palavras no gênero feminino, tais como: 
	  oficiala, hipopótama, faquiresa, etc.
	. Exclusão da forma singular da palavra 'víveres';
	. Correção na regra de conjugação de verbos terminados em: aguar,
	  equar e inquar. Exemplos adequar(adéqüe,adéqüem), desaguar (deságüem),
	  minguar (míngüe);
	. Correção de 'argüeiro' e 'desmilingüir' (trema);
	. Correção da conjugação dos verbos haver e reaver
	  inclusão de 'hemos' e 'heis', e exlusão de 'reei',
	  'reás', reá e reão;
	. Exclusão de 'corma' e 'satividade', colaboração Leo Barichello;
	. Exclusão de 'indentar' verbo e derivados;
	. Inclusão de 'hidroplanagem','biodisponibilidade';
	. Correção de termos compostos com prefixos: Neo, Contra,
	  ultra, semi, proto, supra, pseudo, auto, intra, extra,
	  infra. Evitando-se erros como: semianalfabeto,
	  infraestrutura, semiárido, etc.
	. Criação do Temático Microbiologia por Gervásio Paulo da Silva;
	. Inclusão dos termos 'historicamente' e 'Finlândia', colaboração de 
	  Sérgio A. Elarrat Canto;
	. Exclusão de 1.309 termos terminados em 'icamente' derivados de
	  palavras acentuadas terminadas em 'ia'. Aplicação errônea da regra;  
	 
	=======================================================
	COMO INSTALAR O VERIFICADOR BRASILEIRO NO BROFFICE.ORG
	=======================================================

	Copie os arquivos pt_BR.dic e pt_BR.aff para o diretório <BrOffice.org>
	/share/dict/ooo, onde <BrOffice.org> é o diretório em que o programa 
	foi instalado.

	No Windows, normalmente, o caminho é este: 
	C:\Arquivos de programas\BrOffice.org 2.0\share\dict\ooo, e no  Linux
	/opt/BrOffice.org/share/dict/ooo/.

	No mesmo diretório, localize o arquivo dictionary.lst. Abra-o com um
	editor de textos e acrescente a seguinte linha ao final(se não
	existir):

	DICT pt BR pt_BR

	É necessário reiniciar o BrOffice, inclusive o início rápido da versão
	para Windows que fica na barra de tarefas, para que o corretor
	funcione.

	===================
	DÚVIDAS FREQUENTES
	===================

	Os arquivos foram copiados mas o Verificador não está funcionando.
	O Verificador Ortográfico não deve estar configurado corretamente,
	isto pode estar ocorrendo por um dos seguintes motivos:

	1- O dicionário provavelmente não está instalado.

	Para se certificar de que está utilizando o idioma correto confira como
	estão as informações em: Ferramentas >> Opções >>   Configurações de
	Idioma >> Idiomas. O item Ocidental deve apresentar o dicionário
	selecionado (deve aparecer um logo "Abc" do lado do idioma).

	Se não estiver Português (Brasil) mude para esse idioma. Após
	configurado clique em 'OK'.
	Feche o BrOffice, inclusive o Iniciador Rápido,  e em seguida reabra-o;


	2 - O verificador não está configurado para verificar texto ao digitar.
	Neste caso confira como estão as informações em: Ferramentas >> Opções
	>> Configurações de Idiomas >> Recursos de Verificação Ortográfica e, 
	no campo opções deste formulário marque a opção 'Verificar texto ao 
	digitar';


	Novas atualizações estarão disponíveis no site do BrOffice.Org, na
	página do Verificador Ortográfico.

	http://www.openoffice.org.br/?q=verortografico


	============
	INTRODUCTION
	============

	The BrOffice.org Orthography Checker is a colaborative project developed
	by the Brazilian community.
	The complete list of participants in this project is at
	http://www.broffice.org.br/creditos

	***********************************************************************
	* This is a dictionary for orthography correction for the Portuguese  *
	* language for Myspell.                                               *
	* This is a free program and it can be redistributed and/or           *
	* modified under the terms of the GNU Lesser General Public License   *
	* (LGPL) version 2.1.                                                 *
	*                                                                     *
	***********************************************************************

	=================
	ABOUT THIS UPDATE
	=================

	==============================================================
	HOW TO INSTALL THE BRAZILIAN ORTOGRAPH CHECKER IN BROFFICE.ORG
	==============================================================

	Copy the files pt_BR.dic and pt_BR.aff to the directory <BrOffice.org>
	/share/dict/ooo, where <BrOffice.org> is the directory where the software
	has been installed.

	In Windows, usually, the path is
	C:\Arquivos de programas\BrOffice.org 2.0\share\dict\ooo, and in GNU/Linux
	/opt/BrOffice.org/share/dict/ooo/.

	In the same directory, locate the file dictionary.lst. Open it with a
	text editor e add the following line to the end of the file (if it is
	not already there):

	DICT pt BR pt_BR

	It is necessary to restart BrOffice, including the fast start for the Windows version
	that resides on the task bar, in order to have the orthography checker to work.


	==========================
	FREQUENTLY ASKED QUESTIONS
	==========================

	The files have been copied but the checker is not working. The orthography checker may not be
	configured correctly, this may be due to one of the following reasons:

	1- The dictionary is probably not installed.

	To make sure that you are using the right language, check the information at
	Ferramentas >> Opções >>  Configurações de Idioma >> Idiomas.
	The item "Ocidental" must present the selected dictionary (a logo "Abc" should
	appear beside the language).
	If the language selected is not "Português (Brasil)" change to this language.
	After the configuration is correct, click on 'OK'.
	Close BrOffice and the fast start, and open it afterwards;

	2 - The checker is not configured to verify the orthography on typing. For this

	problem, check the information at
	"Ferramentas >> Opções >> Configurações de Idiomas >> Recursos de Verificação Ortográfica"
	and, in the field "Opções" of this form, check the option ''Verificar texto ao digitar';

	New updates will be available at the BrOffice.Org website, on the page of the
	Orthography Checker.

	http://www.broffice.org/verortografico

=cut

__DATA__
ISO8859-1
.a3p4o6i5a
.a3p4o6i5o
.csi1
.e1o2m5b4
.é3n2
.g6n4o
.hsi1
.hú1b
.hú2n3
.hú2s3
.hú3m
.p4s2a3
.p4s2á3
.p4s2â3
.p4s2e1
.p4s2é1
.p4s2i3
.p4s2o3
.p4s2ó3
.p6a1l4e3o2n5
.p6a5l4e3o1
.p6a5l4e3o1i2c3
.p6s2e4u3
.s2i3m2õ
.s2o4f6t3
.s2u4b3l2i5m2i3n2
.s2u4b3l2i5n4h2
.s2u4b3l2o5
.s2u4b3m2
.s2u4b3n2
.s2u4b3p2
.s2u4b3s2e1
.s2u4b3s2i1
.s2u4b3s2í1
.s2u4b3s4e6r1
.s2u4b3s4i6s1
.s2u4b4s3c2
.s2u4b4s3t2
.s2u4b5r2
.t2é3n4u2e
.thúr3
.x2é3n2
.yer1
13ú
1b2a
1b2á
1b2ã
1b2e
1b2é
1b2ê
1b2e4m.
1b2e4n6s.
1b2i
1b2í
1b2o
1b2ô
1b2u
1b2ú
1b4l2
1b4r2
1ba3ó
1bõe3z
1bões
1c2a
1c2á
1c2ã
1c2e
1c2é
1c2ê
1c2e4m.
1c2e4n6s.
1c2hú
1c2húm
1c2i
1c2í
1c2ó
1c2ô
1c2u
1c2ú
1c4h2
1c4l2
1c4r2
1ca3ó
1co3a
1co3á
1co3ã
1co3b
1có3b
1co3c
1có3c
1co3d
1có3d
1co3e
1co3é
1co3ê
1co3ê
1co3ê
1co3ê
1co3f
1có3f
1co3g
1có3g
1co3h
1co3í5
1co3i5b2
1co3i5g2
1co3i5n4h2
1co3ia
1co3im5
1co3in5c4h2
1co3in5ci
1co3in5d2
1co3in5q4
1co3in5t2
1co3ins5
1co3j
1co3l4h2
1co3la
1co3lá
1co3lâ
1co3lã
1có3la
1co3le
1co3lé
1co3lê
1có3le
1co3li
1co3lí
1có3li
1co3lo
1co3ló
1co3lô
1có3lo
1co3lõ2
1co3lu
1co3lú
1có3lu
1co3ma
1co3má
1co3mâ
1co3mã
1cô3ma
1co3me
1co3mé
1co3mê
1cô3me
1co3mi
1co3mí
1cô3mi
1co3mo
1co3mó
1co3mô
1cô3mo
1co3mu
1co3mú
1co3na
1co3ná
1cô3na
1co3nã2
1co3ne
1co3né
1co3nê
1cô3ne
1co3nh2
1co3ni
1co3ní
1cô3ni
1co3no
1co3nó
1co3nô
1cô3no
1co3nu
1co3nú
1cô3nu
1co3o
1co3ó5l
1co3óis.
1co3p2neu3
1co3pa
1co3pá
1có3pa
1co3pe
1co3pé
1co3pê
1có3pe
1co3pi
1co3pí
1có3pi
1co3pl2
1co3po
1co3pó
1co3põ
1có3po
1co3pr2
1có3pr2
1co3pu
1co3pú
1có3pu
1co3q4
1có3q4
1co3ra
1co3rá
1co3râ
1co3rã
1có3ra
1co3ré
1co3rê
1có3re
1co3ri
1co3rí
1có3ri
1co3ro
1co3ró
1co3rô
1có3ro
1co3ru
1co3sa
1co3sá
1co3sâ
1co3sã
1co3se
1co3sé
1co3sê
1có3se
1co3si
1co3sí
1có3si
1co3so
1co3só
1co3su
1co3sú
1co3ta
1co3tá
1co3tã
1có3ta
1co3te
1co3té
1co3tê
1có3te
1co3ti
1co3tí
1có3ti
1co3tl2
1co3to
1co3tó
1co3tô
1có3to
1co3tr2
1có3tr2
1co3tu
1co3tú
1có3tu
1co3v2
1có3v2
1co3w
1co3x2
1có3x2
1co3z2
1cõ4
1cões.
1cói
1coi3c2
1coi3d2
1coi3e
1coi3é
1coi3f2
1coi3l2
1coi3na
1coi3no
1coi3o
1coi3ó
1coi3p2
1coi3q4
1coi3r2
1coi3s2
1coi3t
1coi3v
1col3b
1cól3b2
1col3c
1cól3c2
1col3d2
1col3f2
1col3g2
1col3l
1col3m2
1col3n2
1cól3n2
1col3p2
1cól3p2
1col3q4
1cól3q4
1col3s2
1col3t2
1col3v2
1col3z2
1com3b2
1côm3b2
1com3p2
1côm3p2
1côn2so
1con3c2
1côn3c2
1con3d2
1côn3d2
1con3f2
1côn3f2
1con3g2
1côn3g2
1con3j2
1côn3j2
1con3l2
1con3n2
1con3q4
1côn3q4
1con3r2
1con3sa
1con3se
1con3si
1con3sí
1côn3si
1con3so
1con3su
1con3sú
1côn3su
1con3t2
1côn3t2
1con3v2
1côn3v2
1cons3c2
1côns3c2
1cons3p2
1cons3t2
1cop3s2
1cóp3s2
1cop3t2
1cóp3t2
1cor3b2
1cór3b2
1cor3c2
1cór3c2
1cor3d2
1cór3d2
1cor3f2
1cor3g2
1cor3j2
1cor3l2
1cor3m2
1cór3m2
1cor3n2
1cór3n2
1cor3p2
1cór3p2
1cor3q4
1cór3r2
1cor3s2
1cór3s2
1cor3t2
1cór3t2
1cór3v2
1cor3x2
1cor3z2
1cor5r2
1core
1cos3c2
1cós3c2
1cos3f2
1cos3l2
1cos3m2
1cós3m2
1cos3p2
1cós3p2
1cos3q4
1cós3q4
1cos3s2
1cós3s2
1cos3t2
1cós3t2
1cot3m2
1cot3p2
1cot3t2
1cou3
1d2a
1d2á
1d2ã
1d2e
1d2é
1d2ê
1d2e4m.
1d2e4n6s.
1d2i
1d2í
1d2o
1d2ó
1d2ô
1d2u
1d2ú
1d4r2
1da3ó
1dõe3z
1dões
1f2a
1f2á
1f2ã
1f2e
1f2é
1f2ê
1f2e4m.
1f2e4n6s.
1f2i
1f2í
1f2o
1f2ó
1f2ô
1f2u
1f2ú
1f4l2
1f4r2
1g2a
1g2á
1g2ã
1g2e
1g2é
1g2ê
1g2e4m.
1g2e4n6s.
1g2i
1g2í
1g2o
1g2ó
1g2ô
1g2õ4
1g2u
1g4l2
1g4r2
1j2a
1j2á
1j2ã
1j2e
1j2é
1j2ê
1j2i
1j2o
1j2ó
1j2u
1j4õ2
1jút3
1l2e
1l2ó
1l2ú
1l4h2
1lo3w
1lões.
1ly
1m2a
1m2á
1m2ã
1m2e
1m2é
1m2ê
1m2i
1m2í
1m2o
1m2ó
1m2ô
1m2u
1m2ú
1mõe3z
1mões
1n2a
1n2á
1n2e
1n2é
1n2ê
1n2i
1n2í
1n2o
1n2ó
1n2ô
1n2u
1n3ú
1n4h2
1nã
1no3w
1p2a
1p2á
1p2ã
1p2e
1p2é
1p2ê
1p2i
1p2í
1p2o
1p2ó
1p2ô
1p2u
1p2ú
1p4l2
1p4r2
1pa3ó
1pneu
1q4u2
1q4ú2
1r2á
1r2ó
1r2u
1ra3ó
1rais.
1s2á
1s2ã
1s2e
1s2e
1s2é
1s2ê
1s2i
1s2o
1s2ó
1s2ô
1s2u
1s2ú
1s2u4b4s3t2
1t2a
1t2á
1t2ã
1t2e
1t2é
1t2ê
1t2i
1t2í
1t2l4
1t2o
1t2ó
1t2ô
1t2õ4
1t2u
1t2ú
1t3n2
1t4h2
1t4r2
1to3w
1v2a
1v2á
1v2ã
1v2e
1v2é
1v2ê
1v2i
1v2í
1v2o
1v2ó
1v2ô
1v2u
1v4r2
1võe3z
1vões
1x2a
1x2á
1x2ã
1x2e
1x2é
1x2ê
1x2i
1x2í
1x2o
1x2ó
1x2ô
1x2u
1ye
1z2a
1z2á
1z2ã
1z2e
1z2é
1z2ê
1z2i
1z2o
1z2ó
1z2ô
1z2u
2a1yo3
2a3ya
2a4y1en3
2a4y1i3t
2a4y1n
2a4y3i
2a4y3i1
2a4y3l
2a4y3r
2a4ye3s
2a4yer
2a4yl3
2ãs.
2b1s2a
2b1s2ã
2b1s2e
2b1s2é
2b1s2ê
2b1s2i
2b1s2í
2b1s2o
2b1s2ô
2b1s2u
2b1s2ú
2b3c4
2b3d4
2b3j4
2b3m4
2b3n4
2b3p4
2b3t4
2b4s1b2
2b4s1c2
2b4s1s2
2b4s1t2
2c3c4
2c3f
2c3m4
2c3n4
2c3t4
2d3j4
2d3m4
2d3n4
2d3s4
2d3v4
2é3n3i
2é4n2s
2e4o.
2e4os.
2f3f4
2f3t4
2g3b4
2g3d4
2g3m4
2h1s
2i1é3n2o
2i3õ4
2l3b4
2l3c4
2l3d4
2l3f4
2l3g4
2l3l4
2l3m4
2l3n4
2l3p4
2l3q4
2l3r4
2l3s4
2l3t4
2l3v4
2l3z4
2m3n4
2m3p4
2m4s1
2m5b4
2n3b4
2n3f4
2n3g4
2n3j4
2n3l4
2n3n4
2n3q4
2n3r4
2n3v4
2n3x2
2n3z2a
2n3z2á
2n3z2â
2n3z2ã
2n3z2e
2n3z2é
2n3z2ê
2n3z2i
2n3z2í
2n3z2o
2n3z2ó
2n3z2ô
2n3z2u
2n4s.
2n4z3b2
2n4z3f2
2n4z3m
2n4z3n
2n4z3q4
2n4z3t
2o1i4z.
2ôs.
2p1na
2p1ná
2p1ne
2p1né
2p1nê
2p1ne3n
2p1nea
2p1nei
2p1neo
2p1neó
2p1neô
2p1nes
2p1ni
2p1ní
2p1no
2p1nó
2p1nô
2p3c4
2p3t4
2p4s.
2r3b4
2r3d4
2r3f4
2r3g4
2r3j4
2r3l4
2r3m4
2r3n4
2r3p4
2r3q4
2r3t4
2r3v4
2r3z4
2r5c4
2s3b4
2s3d4
2s3f4
2s3g4
2s3l4
2s3m4
2s3n4
2s3p4
2s3q4
2s3r4
2s5c4
2t3c4
2t3m4
2t3s4
2t3t4
2t3z
2u1ó3
2x3c4
2x3p4
2x3t4
3co.
3cos.
3n4h2é2n4s
4'4
4e1o2n3c
4e1o2n3d
4e1o2n3f
4e1o2n3t
4e1o2u.
4e1o2u3
4e1o3a2
4e1o3á2
4e1o3â2
4e1o3b2
4e1o3c2
4e1o3d2
4e1o3e
4e1o3f2
4e1o3g2
4e1o3i5a
4e1o3n2a
4e1o3n2á
4e1o3n2â
4e1o3n2e
4e1o3n2é
4e1o3n2ê
4e1o3n2i
4e1o3n2í
4e1o3n2o
4e1o3n2ó
4e1o3n2ô
4e1o3n2u
4e1o3r2a
4e1o3r2â
4e1o3r2é
4e1o3r2ê
4e1o3r2i
4e1o3r2í
4e1o3r2o
4e1o3r2ó
4e1o3r2ô
4e1o3s2a
4e1o3s2â
4e1o3s2e
4e1o3s2i
4e1o3s2í
4e1o3s2o
4e1o3s2ó
4e1o3t2
4e1o3v2
4e1o3x2
4e1o3z2
4e1oi3c2
4e3o2n2h
4h2ow
4l.
4m.
4n3s2a
4n3s2e
4n3s2i
4n3s2í
4n3s2o
4n3s2ô
4n3s2u
4o1i2u
4o2i.
4o2i1a
4o2i1á
4o2i1â
4o2i1ã
4o2i1e
4o2i1é
4o2i1ê
4o2i1i
4o2i1o
4o2i1ó
4o2i1ô
4o2i3ú
4p3s2
4r.
4r5r2
4s.
4s3s2
5ç2
6e1o2i3d4e
6e1o2i3d4i
6e1o2i3s4o
6e1o2i3s4ô
6e1o3í
6e1o3i2m5
6e1o3i2n5
6e1o3i3l2
6e1o3i5f2
6e1o3j2
6e1o3l2
6e1o3m2
6e1o3o2s5
6e1o3o5f2
6e1o3o5l2
6e1o3p2
6e1o3q4
6e1o4i3p2
6e1o4m.
6e1o4n.
6e1o4r3b2
6e1o4r3d2
6e1o4r3e2
6e1o4r3g2
6e1o4r3n2
6e1o4r3q2
6e1o4r3r2
6e1o4r3t2
6e1o4s3c2
6e1o4s3f2
6e1o4s3m2
6e1o4s3p2
6e1o4s3q2
6e1o4s3s2
6e1o4s3t2
6e1o5i3d4r2
6e3o1i4s3t
6n4s3b2
6n4s3c2
6n4s3d2
6n4s3f2
6n4s3g2
6n4s3j2
6n4s3l2
6n4s3m2
6n4s3n2
6n4s3p2
6n4s3r2
6n4s3s2
6n4s3t2
6n4s3v2
6o1i2n4s3
6o1i2r3r4
6o1i2s3m4
6o1i2s3q4
6o1i2s3s4
6o1i2s3t4
6o1i3n4h2
6o1i4m3b2
6o1i4m3p2
6o1i4n3c2
6o1i4n3d2
6o1i4n3f2
6o1i4n3g2
6o1i4n3j2
6o1i4n3q2
6o1i4n3t2
6o1i4n3v2
6o1i4r3m2
6o2i1p4
6o2i1q4
6o2i1r4a
6o2i1r4á
6o2i1r4ã
6o2i1r4e
6o2i1r4é
6o2i1r4i
6o2i1r4í
6o2i1r4o
6o2i1r4õ
6o2i1r4u
6o2i1s4a
6o2i1s4á
6o2i1s4ã
6o2i1s4e
6o2i1s4é
6o2i1s4i
6o2i1s4í
6o2i1s4o
6o2i1s4ó
6o2i1s4ô
6o2i1t4
6o2i1v4
6o2i1x4
6o2i1z4
6o4i1c2
6o4i1ç2
6o4i1d2
6o4i1f2
6o4i1g2
6o4i1j2
6o4i1l2
6o4i1m2a
6o4i1m2á
6o4i1m2e
6o4i1m2é
6o4i1m2ê
6o4i1m2i
6o4i1m2o
6o4i1m2u
6o4i1n2a
6o4i1n2e
6o4i1n2i
6o4i1n2í
6o4i1n2o
6o4i1n2ó
6o4i1n2ô
6o4i1n2u
6o4i3b2
a1c2a
a1c2á
a1c2â
a1c2ã
á1c2a
a1c2e
a1c2é
a1c2ê
á1c2e
a1c2i
a1c2í
á1c2i
a1c2o
a1c2ó
a1c2ô
á1c2o
a1c2õ4
a1c2u
a1c2ú
á1c2u
a1c2y
a1c4h2
á1c4h2
a1c4l2
á1c4l2
a1c4r2
á1c4r2
a1c4s2
a1d2a
a1d2á
a1d2â
a1d2ã
a1d2e
a1d2é
a1d2ê
a1d2i
a1d2í
a1d2o
a1d2ó
a1d2ô
a1d2u
a1d2ú
a1d2y
a1d4r2
a1é
a1e4m.
a1e4n6s.
a1í
a1l2a
a1l2á
a1l2â
a1l2ã
á1l2a
a1l2e
a1l2é
a1l2ê
á1l2e
a1l2i
a1l2í
á1l2i
a1l2o
a1l2ó
a1l2ô
á1l2o
a1l2õ2
a1l2u
a1l2ú
á1l2u
a1l2y
a1l4h2
á1l4h2
a1m2a
a1m2á
a1m2â
a1m2ã
a1m2e
a1m2é
a1m2ê
a1m2i
a1m2í
a1m2o
a1m2ó
a1m2ô
a1m2õ
a1m2u
a1m2ú
a1m2y
a1n2a
a1n2á
a1n2â
a1n2ã
a1n2e
a1n2é
a1n2ê
a1n2i
a1n2í
a1n2o
a1n2ó
a1n2ô
a1n2õ4
a1n2u
a1n2ú
a1n2y
a1n4h2
a1ó2r3t
a1ó2s3p
a1ó2s3s
a1ó3c
a1ó3d
a1ó3f
a1ó3l
a1ó3t
á1r2a
á1r2e
á1r2i
á1r2o
á1r2u
a1ra
a1rá
a1rã
a1re
a1ré
a1rê
a1ri
a1rí
a1ro
a1ró
a1rô
a1rô
a1rõ
a1ru
a1rú
a1s2a
a1s2á
a1s2â
a1s2ã
á1s2a
a1s2é
a1s2ê
á1s2e
a1s2h2
a1s2i
a1s2í
á1s2i
a1s2o
a1s2ó
a1s2ô
á1s2o
a1s2õ4
a1s2u
a1s2ú
á1s2u
a1ú
a1x2a
a1x2á
a1x2â
a1x2ã
á1x2a
a1x2e
a1x2é
a1x2ê
á1x2e
a1x2i
a1x2í
á1x2i
a1x2o
a1x2ó
a1x2ô
á1x2o
a1x2u
a1x2ú
ã1z
a1z2a
a1z2á
a1z2â
a1z2ã
á1z2a
a1z2e
a1z2é
a1z2ê
á1z2e
a1z2i
a1z2í
á1z2i
a1z2o
a1z2ó
a1z2ô
a1z2õ4
a1z2u
a1z2ú
á1z2u
a2c1b
a2c1c4
a2c1ç4
a2c1d4
a2c1f4
a2c1g4
a2c1k4
a2c1m2
á2c1m2
á2c1n2
a2c1n4
a2c1p2
a2c1q4
á2c1t2
a2c1t4
a2d1b2
a2d1c2
a2d1d2
a2d1f2
a2d1g2
a2d1h2
a2d1j2
a2d1l2
a2d1m2
a2d1n2
a2d1p2
a2d1q4
a2d1s2
a2d1t2
a2d1v2
a2d1z2
a2e
ã2e
a2i
á2i1
a2l1b2
á2l1b2
a2l1c2
a2l1ç2
á2l1c2
a2l1d2
á2l1d2
a2l1f2
á2l1f2
a2l1g2
á2l1g2
a2l1j2
a2l1l2
á2l1l2
a2l1m2
á2l1m2
a2l1n2
á2l1n2
a2l1p2
á2l1p2
a2l1q2
á2l1q4
a2l1r2
á2l1r2
a2l1s2
á2l1s2
a2l1t2
á2l1t2
a2l1v2
á2l1v2
a2l1x2
a2l1z2
a2m1b2
a2m1d2
a2m1h2
a2m1l2
a2m1m2
a2m1n2
a2m1p2
a2m1q4
a2m1r2
a2m1s2
a2m1t2
a2m1z2
a2n1b2
a2n1c2
a2n1ç2
a2n1d2
a2n1f2
a2n1g2
a2n1j2
a2n1k2
a2n1l2
a2n1m2
a2n1n2
a2n1p2
a2n1q4
a2n1r2
a2n1s2a
a2n1s2á
a2n1s2ã
a2n1s2e
a2n1s2é
a2n1s2i
a2n1s2í
a2n1s2o
a2n1s2ó
a2n1s2ô
a2n1s2u
a2n1t2
a2n1v2
a2n1x2
a2n1z2
a2n4s.
a2n4s1b2
a2n4s1c2
a2n4s1d2
a2n4s1f2
a2n4s1g2
a2n4s1j2
a2n4s1l2
a2n4s1m2
a2n4s1n2
a2n4s1p2
a2n4s1q4
a2n4s1r2
a2n4s1s2
a2n4s1t2
a2n4s1v2
a2o
a2r.
á2r1b2
á2r1c2
á2r1d2
á2r1f2
á2r1g2
á2r1j2
á2r1l2
á2r1m2
á2r1n2
á2r1p2
á2r1q4
á2r1r2
á2r1s2
á2r1t2
á2r1v2
á2r1x2
á2r1z2
a2s1b2
a2s1c2
á2s1c2
a2s1d2
a2s1e2
a2s1f2
á2s1f2
a2s1g2
á2s1g2
a2s1l
a2s1m2
á2s1m2
a2s1n2
á2s1n2
a2s1p2
á2s1p2
a2s1q4
á2s1q4
a2s1r2
á2s1r2
a2s1t2
á2s1t2
a2s1v2
a2s1z2
á2s1z2
a2s3s2
á2s3s2
a2u
á2u
a2x1c2
a2x1m2
a2x1t2
a2x1w
a2z1d2
a2z1l2
a2z1m2
a2z1q4
a2z1t2
a2z1z2
a3a
a3á
a3b2
á3b2
á3d2
a3f2
á3f2
a3g2
á3g2
a3h2
a3j2
a3k2
a3ôs.
a3p2
á3p2
a3q4
á3q4
a3r4é2n4s
a3t2
á3t2
a3v2
á3v2
a4m.
ã4o
a4s.
á4s.
a4x.
á4x.
a4z.
á4z.
a6l.
ar1b2
ar1c2
ar1d2
ar1f2
ar1g2
ar1j2
ar1l2
ar1m2
ar1n2
ar1p2
ar1q4
ar1r2
ar1s2
ar1t2
ar1v2
ar1x2
ar1z2
b1v
b2ó
b3d2é1n2
b4o5i6a
c1q
c1s
c4r2é3n2
d1d
d1g
d1t
d2l
e1á
e1ã
é1a
e1c2a
e1c2á
e1c2â
e1c2ã
é1c2a
e1c2e
e1c2é
e1c2ê
é1c2e
e1c2i
e1c2í
é1c2i
e1c2o
e1c2ó
e1c2ô
é1c2o
e1c2õ4
e1c2u
e1c2ú
é1c2u
e1c4h2
é1c4h2
e1c4l2
é1c4l2
e1c4r2
é1c4r2
e1e2m.
e1e2n6s.
e1í
e1l2a
e1l2á
e1l2â
e1l2ã
é1l2a
e1l2é
e1l2ê
é1l2e
e1l2i
e1l2í
é1l2i
e1l2o
e1l2ó
e1l2ô
e1l2õ
é1l2o
e1l2u
e1l2ú
é1l2u
e1l2y
e1l4h2
e1m2a
e1m2á
e1m2â
e1m2ã
é1m2a
ê1m2a
e1m2e
e1m2é
e1m2ê
é1m2e
ê1m2e
e1m2i
e1m2í
é1m2i
ê1m2i
e1m2o
e1m2ó
e1m2ô
é1m2o
ê1m2o
e1m2u
e1m2ú
é1m2u
ê1m2u
e1n2a
e1n2á
e1n2â
e1n2ã
ê1n2a
e1n2e
e1n2é
e1n2ê
ê1n2e
e1n2i
e1n2í
ê1n2i
e1n2o
e1n2ó
e1n2ô
ê1n2o
e1n2u
e1n2ú
ê1n2u
e1n2y
e1n4h2
e1ó
e1ô
e1õe3z
é1r2a
é1r2e
é1r2i
e1r2i2s3s
e1r2í3l4
e1r2í3m2
e1r2í3n2
e1r2í3s4i
e1r2í4s3c2
e1r2í4s3s2
e1r2i4s3t2
e1r2í4s3t2
é1r2o
é1r2u
e1r4i3t2
e1ú
é1z
e2a
e2c1b2
é2c1b2
e2c1c2
e2c1ç2
e2c1d2
é2c1d2
e2c1f2
é2c1f2
e2c1g2
e2c1m2
e2c1n2
é2c1n2
e2c1p2
e2c1q2
é2c1q4
e2c1s2
é2c1s2
e2c1t2
é2c1t2
e2c1z2
e2h
e2i
é2i
ê2i
e2l1b2
é2l1b2
e2l1c2
é2l1c2
e2l1d2
é2l1d2
e2l1f2
é2l1f2
e2l1g2
é2l1g2
e2l1j2
e2l1l2
é2l1l2
e2l1m2
é2l1m2
e2l1n2
e2l1p2
é2l1p2
e2l1q4
e2l1r2
é2l1r2
e2l1s2
é2l1s2
e2l1t2
é2l1t2
e2l1v2
é2l1v2
e2l1x2
e2l1z2
e2m1b2
ê2m1b2
e2m1f2
e2m1l2
e2m1m2
e2m1n2
ê2m1n2
e2m1p2
ê2m1p2
e2m1s2
e2m1t2
e2n1b2
e2n1c2
e2n1ç2
ê2n1c2
ê2n1ç2
e2n1d2
ê2n1d2
e2n1f2
ê2n1f2
e2n1g2
ê2n1g2
e2n1j2
e2n1l2
e2n1m2
e2n1n2
ê2n1n2
e2n1q4
ê2n1q4
e2n1r2
ê2n1r2
e2n1s2
ê2n1s2
e2n1t2
ê2n1t2
e2n1v2
ê2n1v2
e2n1w2
e2n1x2
ê2n1z2
e2n1z2a
e2n1z2á
e2n1z2â
e2n1z2e
e2n1z2é
e2n1z2ê
e2n1z2i
e2n1z2í
e2n1z2o
e2n1z2ó
e2n1z2ô
e2n1z2u
e2n4z.
ê2n4z.
e2n6z1b2
e2n6z1f2
e2n6z1m2
e2n6z1n2
e2n6z1q4
e2n6z1t2
é2o
é2r1b2
é2r1c2
é2r1d2
é2r1f2
é2r1g2
é2r1l2
é2r1m2
é2r1n2
é2r1p2
é2r1q4
é2r1s2
é2r1t2
é2r1v2
e2r3b4
e2r3c4
e2r3ç4
e2r3d4
e2r3f4
e2r3g4
e2r3h4
e2r3j4
e2r3k4
e2r3l4
e2r3m4
e2r3n4
e2r3p4
e2r3q4
é2r3r2
e2r3r4
e2r3s4a
e2r3s4á
e2r3s4ã
e2r3s4e
e2r3s4é
e2r3s4i
e2r3s4í
e2r3s4o
e2r3s4ó
e2r3s4ô
e2r3s4u
e2r3s4ú
e2r3t4
e2r3v4
e2r3x4
e2r3z4
e2r4s3b2
e2r4s3c2
e2r4s3d2
e2r4s3m2
e2r4s3p2
e2r4s3q2
e2r4s3t2
e2s1b2
é2s1b2
e2s1c2
e2s1ç2
é2s1c2
ê2s1c2
e2s1d2
e2s1f2
e2s1g2
é2s1g2
e2s1j2
e2s1l2
é2s1l2
e2s1m2
é2s1m2
ê2s1m2
e2s1n2
é2s1n2
e2s1p2
é2s1p2
ê2s1p2
e2s1q4
é2s1q4
e2s1r2
e2s1s2
e2s1t2
é2s1t2
e2s1v2
e2s1x2
e2s1z2
é2s3s2
ê2s3s2
e2u
é2u
ê2u
e2x1b2
e2x1c2
é2x1c2  
e2x1d2
e2x1f2
e2x1g2
e2x1j2
e2x1l2
e2x1m2
e2x1n2
e2x1p2
e2x1r2
e2x1s2
e2x1t2
é2x1t2
e2x1v2
é2x1v2
e2y1
e2z1b2
e2z1c2
e2z1l2
e2z1n2
e2z1r2
e2z1t2
e2z1z2
e3b2
é3b2
e3d2
é3d2
e3e
e3f2
é3f2
e3g2
é3g2
e3j2
e3l2e
e3n4é2n4s
e3ões
e3p2
é3p2
e3q4
é3q4
e3r2a
e3r2á
e3r2â
e3r2ã
e3r2a1b2
e3r2á1b2
e3r2a1c2
e3r2a1ç2
e3r2á1c2
e3r2a1d2
e3r2á1d2
e3r2a1f2
e3r2á1f2
e3r2a1g2
e3r2a1h2
e3r2a1í
e3r2a1j2
e3r2a1l2
e3r2á1l2
e3r2a1m2
e3r2â1m4e
e3r2â1m4i
e3r2a1n2
e3r2a1p2
e3r2á1p2
e3r2a1q4
e3r2á1r2
e3r2a1r2a
e3r2a1r2e
e3r2a1r2i
e3r2a1r2o
e3r2a1r2ó
e3r2a1s4e
e3r2a1s4i
e3r2a1s4í
e3r2a1s4o
e3r2á1t2
e3r2a1v2
e3r2á1v2
e3r2a1x2
e3r2a1z2
e3r2a2e
e3r2a2i
e3r2a2r1c2
e3r2a2r1d2
e3r2a2r1g2
e3r2a2r1m2
e3r2a2r1q2
e3r2a2r1t2
e3r2a2s1q4
e3r2â4m1b2
e3r2ã4o
e3r2a4s1c2
e3r2a4s1f2
e3r2a4s1m2
e3r2a4s1p2
e3r2a4s1t2
e3r2a4s3s2
e3r2e
e3r2é
e3r2ê
e3r2e1á
e3r2e1â
e3r2e1ã
e3r2e1b2
e3r2é1b2
e3r2e1c2
e3r2e1ç2
e3r2é1c2
e3r2e1d2
e3r2é1d2
e3r2e1e
e3r2e1f2
e3r2e1g2
e3r2e1í
e3r2e1j2
e3r2e1l2
e3r2é1l2
e3r2ê1m
e3r2e1m2
e3r2é1m2
e3r2ê1n
e3r2e1n2
e3r2é1n2
e3r2e1ó
e3r2e1ô
e3r2é1o
e3r2e1p2
e3r2e1q4
e3r2e1r2
e3r2é1r2
e3r2ê1s2
e3r2é1s2i
e3r2e1t
e3r2é1t2
e3r2e1v2
e3r2é1v2
e3r2e1x2
e3r2e1z2
e3r2é1z2
e3r2e2a
e3r2e2i
e3r2ê2i
e3r2e2o
e3r2é2s1c2
e3r2é2s1q4
e3r2e2u
e3r2é2u
e3r2i
e3r2í
e3r2i1ã
e3r2í1a
e3r2i1b2
e3r2í1b4
e3r2i1c2
e3r2i1ç2
e3r2í1c4
e3r2i1d2
e3r2í1d4
e3r2í1e
e3r2i1f2
e3r2í1f3
e3r2i1g2
e3r2í1g4
e3r2i1i
e3r2i1í
e3r2í1i
e3r2i1j2
e3r2í1j4
e3r2i1m
e3r2i1n
e3r2i1ó
e3r2i1ô
e3r2í1o
e3r2i1p2
e3r2í1p2
e3r2i1q2
e3r2i1r2
e3r2í1r2
e3r2i1s4a
e3r2i1s4ã
e3r2i1s4e
e3r2i1s4i
e3r2i1s4í
e3r2i1s4o
e3r2i1s4ó
e3r2i1s4ô
e3r2í1t2
e3r2í1v2
e3r2i1v4
e3r2i1x4
e3r2i1z4
e3r2i2a
e3r2i2e
e3r2i2é
e3r2i2ê
e3r2i2o
e3r2i2s1b2
e3r2i2s1c2
e3r2i2s1f2
e3r2i2s1m2
e3r2i2s1p2
e3r2i2s1q2
e3r2i3á
e3r2i3â
e3r2il
e3r2o
e3r2ó
e3r2ô
e3r2õ
e3r2o1á
e3r2o1ã
e3r2o1b2
e3r2ó1b2
e3r2o1c2
e3r2o1ç2
e3r2ó1c2
e3r2o1d2
e3r2ó1d2
e3r2ô1d2
e3r2o1é
e3r2o1ê
e3r2o1f2
e3r2ó1f2
e3r2o1g2
e3r2ó1g2
e3r2o1h2
e3r2o1í
e3r2ó1i
e3r2o1j2
e3r2ó1l2
e3r2ô1m2
e3r2o1m2a
e3r2o1m2a
e3r2o1m2á
e3r2o1m2á
e3r2o1m2â
e3r2o1m2â
e3r2o1m2e
e3r2o1m2e
e3r2o1m2é
e3r2o1m2é
e3r2o1m2i
e3r2o1m2i
e3r2o1m2í
e3r2o1m2í
e3r2o1m2o
e3r2o1m2o
e3r2o1m2ó
e3r2o1m2ó
e3r2o1m2ô
e3r2o1m2ô
e3r2o1m2u
e3r2o1m2u
e3r2o1n2a
e3r2o1n2á
e3r2o1n2e
e3r2o1n2é
e3r2o1n2ê
e3r2o1n2h
e3r2o1n2i
e3r2o1n2í
e3r2ô1n2i
e3r2o1n2o
e3r2o1n2ó
e3r2o1n2ô
e3r2o1n2u
e3r2o1o
e3r2ó1o
e3r2o1p2
e3r2ó1p2
e3r2o1q2
e3r2o1r2a
e3r2o1r2á
e3r2o1r2e
e3r2o1r2o
e3r2o1s2a
e3r2o1s2á
e3r2o1s2ã
e3r2o1s2e
e3r2o1s2i
e3r2o1s2í
e3r2ó1s2i
e3r2o1s2o
e3r2o1s2ó
e3r2o1t2
e3r2ó1t2
e3r2o1v2
e3r2o1x2
e3r2ó1x2
e3r2o1z2
e3r2o2m1n2
e3r2o2r1g2
e3r2o2r1m2
e3r2o2r1n2
e3r2o2r1r2
e3r2o2r1s2
e3r2o2r1t2
e3r2o2s1c2
e3r2o2s1f2
e3r2o2s1m2
e3r2o2s1p2
e3r2o2s1q4
e3r2o2s1s2
e3r2o2s1t2
e3r2õ4e
e3r2o4z.
e3r2u
e3r2ú
e3r4â1n2i
e3r4á1s2i
e3r4a1t2
e3r4a1ú
e3r4â2n1c2
e3r4â2n1d2
e3r4â2n1g2
e3r4â2n1t2
e3r4á2s1f2
e3r4á2s1m2
e3r4á2s1p2
e3r4á2s1t2
e3r4a2u
e3r4á2u
e3r4e1s2a
e3r4e1s2ã
e3r4e1s2e
e3r4e1s2i
e3r4e1s2í
e3r4e1s2o
e3r4e1s2ó
e3r4é2n5s2i
e3r4e2s3c2
e3r4e2s3m2
e3r4e2s3p2
e3r4e2s3q4
e3r4e2s3s2
e3r4e2s3t2
e3r4i1ú
e3r4i2u
e3r4o1l2a
e3r4o1l2á
e3r4o1l2â
e3r4o1l2e
e3r4o1l2é
e3r4o1l2ê
e3r4o1l2h2
e3r4o1l2i
e3r4o1l2í
e3r4o1l2o
e3r4o1l2ó
e3r4o2a
e3r4o2e
e3r4o2i
e3r4o2l1m2
e3r4o2m1n2
e3r4o2n1c
e3r4ô2n1c2
e3r4o2n1d
e3r4ô2n1f2
e3r4o2n1g
e3r4o2n1t
e3r4ô2n1t2
e3r4ô2n2o
e3r4o2n2s
e3r4ó2r1
e3r4ó2s1c2
e3r4ó2s1p2
e3r4ó2s1s2
e3r4ó2s1t2
e3r4o2u
e3s2a
e3s2á
e3s2â
e3s2ã
é3s2a
ê3s2a
e3s2e
e3s2é
e3s2ê
é3s2e
e3s2h2
e3s2i
e3s2í
é3s2i
ê3s2i
e3s2o
e3s2ó
e3s2ô
é3s2o
e3s2u
e3s2ú
é3s2u
e3t2
é3t2
e3v2
é3v2
e3x2a
e3x2á
e3x2â
e3x2ã
e3x2e
e3x2é
e3x2ê
e3x2i
e3x2í
é3x2i
e3x2o
e3x2ó
e3x2ô
é3x2o
e3x2u
e3x2ú
é3x2u
e3x2y
e3z2a
e3z2á
e3z2ã
e3z2e
e3z2é
e3z2ê
e3z2i
e3z2í
e3z2o
e3z2ó
e3z2ô
e3z2õ4
e3z2u
e4l.
é4l.
e4m.
é4m.
ê4m.
e4s.
é4s.
ê4s.
e4x.
é4x.
e4z.
e5é2n4s
f1n
g1g
g1t
g3s
g4u6á
g4u6ã
g4u6é
g4u6ê
g4u6í
g5n
gé3n2e
h1n
h1r
h1t
h2a
h2á
h2ã
h2e
h2é
h2ê
h2e4m.
h2e4n6s.
h2i
h2í
h2l
h2o
h2ó
h2õ4
h2u
h3m
h4m.
hô1
hô2u3
i1á
i1ã
í1b2
í1c2a
í1c2e
í1c2i
í1c2o
í1c2u
í1c4h2
í1c4l2
í1c4r2
i1é
i1ê
i1é3n2
i1e4m.
í1e4m.
i1e4n6s.
í1e4n6s.
i1l2a
i1l2á
i1l2â
i1l2ã
í1l2a
i1l2e
i1l2é
i1l2ê
í1l2e
i1l2i
i1l2í
í1l2i
i1l2o
i1l2ó
i1l2ô
í1l2o
i1l2õ4
i1l2u
i1l2ú
í1l2u
i1l4h2
í1l4h2
i1m2a
i1m2á
i1m2â
i1m2ã
í1m2a
í1m2ã
i1m2e
i1m2é
i1m2ê
í1m2e
i1m2i
i1m2í
í1m2i
i1m2o
i1m2ó
i1m2ô
í1m2o
i1m2õ4
i1m2u
i1m2ú
í1m2u
i1n2a
i1n2á
i1n2â
i1n2ã
í1n2a
i1n2e
i1n2é
i1n2ê
í1n2e
i1n2i
i1n2í
í1n2i
i1n2o
i1n2ó
i1n2ô
í1n2o
i1n2u
i1n2ú
í1n2u
i1n4h2
i1ó
i1ô
i1p
i1r2a
i1r2á
i1r2â
i1r2ã
í1r2a
i1r2e
i1r2é
i1r2ê
í1r2e
i1r2i
i1r2í
í1r2i
i1r2o
i1r2ó
i1r2ô
i1r2õ
í1r2o
i1r2u
i1r2ú
í1r2u
i1s2a
i1s2á
i1s2â
i1s2ã
í1s2a
i1s2e
i1s2é
i1s2ê
í1s2e
i1s2i
i1s2í
í1s2i
i1s2o
i1s2ó
i1s2ô
i1s2õ
í1s2o
i1s2u
i1s2ú
í1s2u
i1s2y
i1s4h2
i1x2a
i1x2á
i1x2â
i1x2ã
i1x2e
i1x2é
i1x2ê
i1x2i
i1x2í
i1x2o
i1x2ó
i1x2ô
i1x2õ4
i1x2u
i1x2ú
i1z2a
i1z2á
i1z2â
i1z2ã
í1z2a
i1z2e
i1z2é
i1z2ê
í1z2e
i1z2i
i1z2í
í1z2i
i1z2o
i1z2ó
i1z2ô
í1z2o
i1z2u
í1z2u
i2a
í2a
í2c1n2
í2c1q24
í2c1t2
i2c3b2
i2c3c2
i2c3ç2
i2c3m2
i2c3n2
i2c3p2
i2c3q4
i2c3s2
i2c3t2
i2c3v2
i2c3x2
í2e
i2l1b2
í2l1b2
i2l1c2
í2l1c2
i2l1d2
í2l1d2
i2l1f2
í2l1f2
i2l1g2
i2l1l2
í2l1l2
i2l1m2
í2l1m2
i2l1n2
i2l1p2
i2l1q4
í2l1q4
i2l1r2
i2l1s2
í2l1s2
i2l1t2
í2l1t2
i2l1v2
í2l1v2
i2l1x2
i2l1z2
i2m1b2
í2m1b2
i2m1m2
í2m1m2
i2m1n2
í2m1n2
i2m1p2
í2m1p2
i2m1r2
i2n1b2
i2n1c2
i2n1ç2
í2n1c2
i2n1d2
í2n1d2
i2n1f2
í2n1f2
i2n1g2
í2n1g2
i2n1j2
í2n1j2
i2n1k2
i2n1l2
i2n1m2
i2n1n2
i2n1p2
i2n1q4
í2n1q4
i2n1r2
i2n1s2a
i2n1s2â
i2n1s2ã
i2n1s2e
i2n1s2é
í2n1s2e
i2n1s2i
i2n1s2í
í2n1s2i
i2n1s2o
i2n1s2ô
í2n1s2o
i2n1s2u
i2n1s2ú
í2n1s2u
i2n1t2
í2n1t2
i2n1v2
í2n1v2
i2n1x2
i2n1z2
í2n1z2
i2n4s.
í2n4s.
i2n4s1c2
í2n4s1c2
i2n4s1d2
i2n4s1p2
i2n4s1q4
i2n4s1t2
í2n4s1t2
i2o
í2o
i2r1b2
í2r1b2
i2r1c2
i2r1ç2
í2r1c2
i2r1d2
i2r1f2
í2r1f2
i2r1g2
í2r1g2
i2r1h2
i2r1j2
i2r1l2
i2r1m2
í2r1m2
i2r1n2
í2r1n2
i2r1p2
í2r1p2
i2r1q4
i2r1s2
í2r1s2
i2r1t2
í2r1t2
i2r1v2
i2r1x2
i2r1z2
i2r3r2
í2r3r2
i2s1b2
í2s1b2
i2s1c2
i2s1ç2
í2s1c2
i2s1d2
í2s1d2
i2s1f2
í2s1f2
i2s1g2
i2s1j2
i2s1l2
i2s1m2
í2s1m2
i2s1n2
í2s1n2
i2s1p2
í2s1p2
i2s1q4
í2s1q4
i2s1r2
i2s1t2
í2s1t2
i2s1v2
i2s1z2
í2s1z2
i2s3s2
í2s3s2
i2u
i2x1b2
i2x1c2
i2x1l2
i2x1n2
i2x1p2
i2x1t2
i2z1c2
i2z1g2
i2z1n2
i2z1r2
i2z1z2
i3b2
i3c2a
i3c2á
i3c2â
i3c2ã
i3c2e
i3c2é
i3c2ê
i3c2i
i3c2í
i3c2o
i3c2ó
i3c2ô
i3c2õ
i3c2u
i3c2ú
i3c4h2
i3c4l2
i3c4r2
i3d2
í3d2
i3e
i3f2
í3f2
i3g2
í3g2
i3i
i3í
í3i
i3j2
i3ôs.
í3p2
i3q4
í3q4
i3t2
í3t2
i3v2
í3v2
í3x
i4l.
í4l.
i4r.
í4r.
i4s.
í4s.
j4o5i6a
jú3
l1j
l2a
l2á
l2ã
l2é
l2ê
l2é3n2
l2e4m.
l2é4m.
l2e4n6s.
l2é4n6s.
l2i
l2í
l2o
l2ô
l2ow1
l2u
m1m
m2é3n2a
m2e4m.
m2e4n6s.
n2a3ya
n2e4m.
n2e4n6s.
n3c42
n3d2
n3t2
n3t2é4n2s
o1á
o1ã
o1ay3s
o1b2a
o1b2á
o1b2â
o1b2ã
o1b2e
o1b2é
o1b2ê
o1b2i
o1b2í
o1b2o
o1b2ó
o1b2ô
o1b2u
o1b2ú
o1b4r2
o1é
o1ê2n3
o1ê3l
o1ê3m
o1ês.
o1í
o1l2a
o1l2á
o1l2â
o1l2ã
ó1l2a
o1l2e
o1l2é
o1l2ê
ó1l2e
o1l2i
o1l2í
ó1l2i
o1l2o
o1l2ó
o1l2ô
o1l2õ
ó1l2o
o1l2u
o1l2ú
ó1l2u
o1l2v
o1l2y
o1l4h2
o1m2a
o1m2á
o1m2â
o1m2ã
ó1m2a
ô1m2a
o1m2e
o1m2é
o1m2ê
ó1m2e
ô1m2e
o1m2i
o1m2í
ó1m2i
ô1m2i
o1m2l
o1m2o
o1m2ó
o1m2ô
ó1m2o
ô1m2o
o1m2u
o1m2ú
ô1m2u
o1m2y
o1n2a
o1n2á
o1n2â
o1n2ã
ô1n2a
o1n2e
o1n2é
o1n2ê
ô1n2e
o1n2i
o1n2í
ó1n2i
ô1n2i
o1n2j
o1n2l2
o1n2o
o1n2ó
o1n2ô
ô1n2o
o1n2õ4
o1n2u
o1n2ú
ô1n2u
o1n2y
o1n4h2
ô1n4h2
o1r2a
o1r2á
o1r2â
o1r2ã
o1r2e
o1r2é
o1r2ê
o1r2f
o1r2i
o1r2í
o1r2o
o1r2ó
o1r2ô
o1r2õ4
o1r2u
o1r2ú
o1s2a
o1s2á
o1s2â
o1s2ã
ó1s2a
o1s2e
o1s2é
o1s2ê
ó1s2e
o1s2i
o1s2í
ó1s2i
o1s2o
o1s2ó
o1s2ô
ó1s2o
o1s2u
o1s2ú
ó1s2u
o1s4h2
o1x2a
o1x2á
o1x2â
o1x2ã
o1x2e
o1x2é
o1x2ê
ó1x2e
o1x2i
o1x2í
ó1x2i
o1x2o
o1x2ó
o1x2ô
ó1x2o
o1x2u
o1x2ú
ó1x2u
o1z2a
o1z2á
o1z2â
o1z2ã
o1z2e
o1z2é
o1z2ê
o1z2i
o1z2í
o1z2o
o1z2ó
o1z2ô
o1z2u
o2a
o2b1b2
o2b1c2
o2b1d2
o2b1f2
o2b1g2
o2b1j2
o2b1l2
o2b1n2
o2b1p2
o2b1s2a
o2b1s2e
o2b1s2é
o2b1s2i
o2b1s2o
o2b1s2ô
o2b1s2u
o2b1s2ú
o2b1t2
o2b1v2
o2b4s.
o2b4s1c2
o2b4s1t2
o2e
õ2e
o2e4m.
õ2e4m.
o2e4n6s.
õ2e4n6s.
ó2i
o2l1b2
o2l1c2
o2l1ç2
ó2l1c2
o2l1d2
ó2l1d2
o2l1f2
ó2l1f2
o2l1g2
ó2l1g2
o2l1j2
o2l1k2
o2l1l2
ó2l1l2
o2l1m2
ó2l1m2
o2l1n2
ó2l1n2
o2l1p2
ó2l1p2
o2l1q4
ó2l1q4
o2l1r2
o2l1s2
o2l1t2
ó2l1t2
ó2l1v2
o2l1z2
ó2l1z2
o2m1b2
ô2m1b2
o2m1f2
o2m1m2
o2m1n2
ô2m1p2
o2m1p2a
o2m1p2á
o2m1p2ã
o2m1p2e
o2m1p2é
o2m1p2ê
o2m1p2i
o2m1p2í
o2m1p2o
o2m1p2ó
o2m1p2u
o2m1p4l2
o2m1p4r2
o2m1s2
o2m1t2
o2m4p1s
o2m4p1t2
o2n1b2
o2n1c2
o2n1ç2
ô2n1c2
o2n1d2
ô2n1d2
o2n1f2
ô2n1f2
o2n1g2
ô2n1g2
ô2n1j2
o2n1n2
o2n1q4
ô2n1q4
o2n1r2
o2n1s2a
o2n1s2á
o2n1s2ã
o2n1s2e
o2n1s2i
o2n1s2í
ô2n1s2i
o2n1s2o
o2n1s2ó
o2n1s2ô
ô2n1s2o
o2n1s2u
o2n1s2ú
ô2n1s2u
o2n1t2
ô2n1t2
o2n1v2
ô2n1v2
o2n1x2
o2n1z2
ô2n1z2
o2n4s.
ô2n4s.
o2n4s1c2
ô2n4s1c2
o2n4s1d2
o2n4s1f2
o2n4s1m2
o2n4s1p2
o2n4s1t2
ô2n4s1t2
o2r1b2
o2r1c2
o2r1ç2
o2r1d2
o2r1g2
o2r1h2
o2r1j2
o2r1l2
o2r1m2
o2r1n2
o2r1p2
o2r1q4
o2r1r2
o2r1s2
o2r1t2
o2r1v2
o2r1x2
o2r1z2
o2s1b2
ó2s1b2
o2s1c2
ó2s1c2
o2s1d2
o2s1f2
ó2s1f2
o2s1g2
ó2s1g2
o2s1l2
o2s1m2
ó2s1m2
o2s1n2
ó2s1n2
o2s1p2
ó2s1p2
o2s1q4
ó2s1q4
o2s1r2
o2s1t2
o2s1v2
o2s3s2
ó2s3s2
o2u
o2x1b2
o2x1c2
o2x1d2
o2x1f2
o2x1m2
o2x1n2
o2x1p2
o2x1s2
o2x1t2
o2x1v2
o2z1m2
o2z1n2
o2z1r2
o2z1z2
ó3b2
ó3c2
o3c2a
o3c2á
o3c2â
o3c2ã
o3c2e
o3c2é
o3c2ê
o3c2i
o3c2í
o3c2o
o3c2ó
o3c2ô
o3c2õ
o3c2u
o3c2ú
o3c2y
o3c4h2
o3c4l2
o3c4r2
o3d2
ó3d2
o3f2
ó3f2
o3g2
o3g2
ó3g2
o3h2
o3j2
o3o
o3ó
o3õ4
o3p2
ó3p2
ó3q4
ó3r2
ó3s1t3
o3t2
ó3t2
o3v2
ó3v2
o4c3c2
o4c3ç2
o4c3d2
o4c3f2
o4c3k2
o4c3m2
o4c3n2
o4c3q2
o4c3s2
o4c3t2
o4l.
ó4l.
o4r.
o4s.
ó4s.
o4x.
o4z.
p1p
p2é3n4
p2e4m.
p2e4n6s.
q4ú1e4m.
q4ú1e4n6s.
q4u2é2n4s
q4u2e4m.
q4u2e4n6s.
q4u6á
q4u6ã
q4u6é
q4u6ê
q4u6í
r1s2a
r1s2á
r1s2â
r1s2ã
r1s2e
r1s2é
r1s2ê
r1s2i
r1s2í
r1s2o
r1s2ó
r1s2ô
r1s2u
r1s2ú
r1s4h2
r1x
r2ã
r2a1i1n2o
r2a1i1n2ó
r2a1i2n3d2
r2a1i2n3f2
r2a1i2n3t2
r2a1i3n2a
r2a1i3n2i
r2a1i3n2ú
r2a1i3p2
r2a1i3q2
r2a1i3r2
r2a2i.
r2a2i3a
r2a2i3á
r2a2i3ã
r2a2i3b2
r2a2i3c2
r2a2i3d2
r2a2i3e
r2a2i3g2
r2a2i3í
r2a2i3le
r2a2i3lh2
r2a2i3li
r2a2i3lu
r2a2i3m2
r2a2i3ne
r2a2i3t2
r2a2i3v2
r2a2i3x2
r2a2i4l3g2
r2a2i4l3l2
r2a2i4l3m2
r2a2i4s.
r2a2i4s.
r2a2l3b2
r2a2l3c2
r2a2l3d2
r2a2l3f2
r2a2l3g
r2a2l3l
r2a2l3m2
r2a2l3n2
r2a2l3q4
r2a2l3s2
r2a2l3t2
r2a2l3v2
r2a2m3b2
r2a2m3m2
r2a2m3n2
r2a2m3p2
r2a2m3s
r2a2n3c2
r2a2n3d2
r2a2n3f2
r2a2n3g2
r2a2n3j2
r2a2n3k2
r2a2n3l2
r2a2n3n2
r2a2n3q4
r2a2n3s
r2a2n3t2
r2a2n3v2
r2a2n3x
r2a2n3z
r2a2n4s.
r2a2r.
r2a2s3b2
r2a2s3c2
r2a2s3d2
r2a2s3f2
r2a2s3g2
r2a2s3l2
r2a2s3m2
r2a2s3n2
r2a2s3p2
r2a2s3q4
r2a2s3s2
r2a2s3t2
r2a2s3v2
r2a2t3s2
r2a2t3t2
r2a2t3z2
r2a2u3a
r2a2u3á
r2a2u3b2
r2a2ú3b2
r2a2u3c2
r2a2u3d2
r2a2ú3d2
r2a2u3e
r2a2u3é
r2a2u3ê
r2a2u3g2
r2a2u3i
r2a2u3í
r2a2u3j2
r2a2ú3j2
r2a2u3l2
r2a2u3m2
r2a2u3n2
r2a2u3p2
r2a2u3q4
r2a2u3r
r2a2ú3r
r2a2u3s
r2a2ú3s
r2a2u3t2
r2a2u3v2
r2a2ú3v2
r2a2u3x2
r2a2u3z2
r2a2y3
r2a2y3b2
r2a3a
r2a3á
r2a3â
r2a3ã
r2a3b2
r2a3c2
r2a3d2
r2a3e
r2a3é
r2a3ê
r2a3f2
r2a3g2
r2a3h2
r2a3í1
r2a3i1n4h2
r2a3i2l.
r2a3i2o
r2a3i2ó
r2a3i2s.
r2a3i2u
r2a3i2ú
r2a3i2z
r2a3j2
r2a3l2a
r2a3l2á
r2a3l2â
r2a3l2ã
r2a3l2e
r2a3l2é
r2a3l2ê
r2a3l2i
r2a3l2í
r2a3l2o
r2a3l2ó
r2a3l2ô
r2a3l2u
r2a3l2ú
r2a3l4h2
r2a3m2á
r2a3m2â
r2a3m2ã
r2a3m2e
r2a3m2é
r2a3m2ê
r2a3m2i
r2a3m2í
r2a3m2o
r2a3m2ó
r2a3m2ô
r2a3m2õ
r2a3m2u
r2a3m2ú
r2a3n2a
r2a3n2á
r2a3n2ã
r2a3n2e
r2a3n2é
r2a3n2ê
r2a3n2i
r2a3n2í
r2a3n2o
r2a3n2ó
r2a3n2ô
r2a3n2u
r2a3n2ú
r2a3n4h2
r2a3o
r2a3ó
r2a3ô
r2a3p2
r2a3q42
r2a3r2a
r2a3r2á
r2a3r2ã
r2a3r2e
r2a3r2é
r2a3r2ê
r2a3r2i
r2a3r2í
r2a3r2o
r2a3r2ó
r2a3r2u
r2a3s2a
r2a3s2á
r2a3s2â
r2a3s2ã
r2a3s2e
r2a3s2é
r2a3s2ê
r2a3s2h2
r2a3s2i
r2a3s2í
r2a3s2o
r2a3s2ó
r2a3s2ô
r2a3s2õ
r2a3s2u
r2a3t2a
r2a3t2á
r2a3t2â
r2a3t2ã
r2a3t2e
r2a3t2é
r2a3t2ê
r2a3t2i
r2a3t2í
r2a3t2o
r2a3t2ó
r2a3t2ô
r2a3t2õ
r2a3t2u
r2a3t2ú
r2a3t2y
r2a3t4l2
r2a3t4r2
r2a3ú2l2
r2a3ú2n2
r2a3v2
r2a3va
r2a3x2
r2a3y
r2a3y2a
r2a3z
r2a4l.
r2a4m.
r2a4s.
r2ar3c2
r2ar3d2
r2ar3g2
r2ar3m2
r2ar3q4
r2ar3r2
r2ar3s2
r2ar3t2
r2e
r2é
r2ê
r2é3n4
r2e4m.
r2e4n6s.
r2i
r2í
r2o
r2ô
r2õ4
r2ow1
r2s1d2
r2ú
r3s2é1n
r4a
r4s1b2
r4s1c2
r4s1f2
r4s1j2
r4s1k2
r4s1m2
r4s1p2
r4s1q4
r4s1s2
r4s1t2
r4s1z2
s2e4m.
s2e4n6s.
s2h2
s2í
s3j
s3t2
s3t2é1n2
s3v2
t2é3n2u
t2e4m.
t2é4m.
t2e4n6s.
t2é4n6s.
t3g
u1á
u1ã
u1b2a
u1b2á
u1b2â
u1b2ã
u1b2e
u1b2é
u1b2i
u1b2í
u1b2o
u1b2ó
u1b2ô
u1b2u
u1b2ú
u1c2a
u1c2á
u1c2â
u1c2ã
u1c2e
u1c2é
u1c2ê
u1c2i
u1c2í
u1c2o
u1c2ó
u1c2ô
u1c2u
u1c2ú
u1c2y
u1c4h2
u1c4l2
u1c4r2
u1é
u1ê
u1e4m.
ú1e4m.
u1e4n6s.
ú1e4n6s.
ú1g
u1í
u1l2a
u1l2á
u1l2â
u1l2ã
ú1l2a
u1l2e
u1l2é
u1l2ê
ú1l2e
u1l2i
u1l2í
ú1l2i
u1l2o
u1l2ó
u1l2ô
ú1l2o
u1l2õ4
u1l2u
u1l2ú
ú1l2u
u1l4h2
ú1l4h2
u1m2a
u1m2á
u1m2â
u1m2ã
ú1m2a
u1m2e
u1m2é
u1m2ê
ú1m2e
u1m2i
u1m2í
ú1m2i
u1m2o
u1m2ó
u1m2ô
u1m2u
u1m2ú
ú1m2u
u1n2a
u1n2á
u1n2â
u1n2ã
ú1n2a
u1n2e
u1n2é
ú1n2e
u1n2i
u1n2í
ú1n2i
u1n2o
u1n2ó
u1n2ô
ú1n2o
u1n2u
u1n2ú
ú1n2u
u1n4h2
ú1n4h2
u1r2a
u1r2á
u1r2â
u1r2ã
u1r2e
u1r2é
u1r2ê
u1r2i
u1r2í
u1r2o
u1r2ó
u1r2ô
u1r2õ4
u1r2u
u1r2ú
u1r2y
u1s2a
u1s2á
u1s2â
u1s2ã
ú1s2a
u1s2e
u1s2é
u1s2ê
ú1s2e
u1s2i
u1s2í
ú1s2i
u1s2o
u1s2ó
u1s2ô
ú1s2o
u1s2u
u1s2ú
u1s4h2
u1z2a
u1z2á
u1z2â
u1z2ã
u1z2e
u1z2é
u1z2ê
u1z2i
u1z2í
u1z2o
u1z2ó
u1z2ô
u1z2u
u1z2ú
u2a
u2b1c2
u2b1d2
u2b1f2
u2b1g2
u2b1j2
u2b1m2
u2b1n2
u2b1p2
u2b1q4
u2b1s2
u2b1t2
u2b1v2
u2b1z2
u2bl
u2br
u2c1c2
u2c1ç2
u2c1m2
u2c1n2
u2c1s2
u2c1t2
u2c1z2
u2e
u2i
u2l1b2
ú2l1b2
u2l1c2
u2l1ç2
ú2l1c2
u2l1d2
ú2l1d2
u2l1f2
ú2l1f2
u2l1g2
ú2l1g2
u2l1l2
u2l1m2
ú2l1m2
u2l1n2
u2l1p2
ú2l1p2
u2l1q4
u2l1r2
u2l1s2
u2l1t2
ú2l1t2
u2l1v2
ú2l1v2
u2l1x2
u2l1z2
u2m1b2
ú2m1b2
u2m1h2
u2m1l2
u2m1m2
u2m1n2
ú2m1n2
u2m1p2
ú2m1p2
u2m1t2
u2m1z2
u2n1b2
u2n1c2
u2n1ç2
ú2n1c2
u2n1d2
ú2n1d2
u2n1f2
ú2n1f2
u2n1g2
ú2n1g2
u2n1j2
ú2n1j2
u2n1k2
u2n1l2
u2n1n2
u2n1q4
ú2n1q4
u2n1r2
u2n1s2e
u2n1s2é
u2n1s2i
ú2n1s2i
u2n1s2o
u2n1t2
u2n1v2
ú2n1v2
u2n1x2
u2n1z2
ú2n1z2
ú2n3s.
u2n4s.
u2n4s1c2
u2n4s1d2
u2n4s1f2
u2n4s1p2
u2n4s1t2
u2n4s1v2
u2o
u2r1b2
u2r1c2
u2r1ç2
u2r1d2
u2r1f2
u2r1g2
u2r1h2
u2r1j2
u2r1k2
u2r1l2
u2r1m2
u2r1n2
u2r1p2
u2r1q4
u2r1s2
u2r1t2
u2r1v2
u2r1z2
u2r3r2
u2s1b2
u2s1c2
ú2s1c2
u2s1d2
u2s1f2
u2s1g2
u2s1j2
u2s1l2
u2s1m2
ú2s1m2
u2s1n2
ú2s1n2
u2s1p2
ú2s1p2
u2s1q4
ú2s1q4
u2s1r2
u2s1t2
ú2s1t2
u2s1v2
u2s1z2
u2s3s2
ú2s3s2
u2z1b2
u2z1l2
u2z1m2
u2z1z2
ú3b2
ú3c2
u3d2
ú3d2
u3f2
u3g2
u3j2
u3p2
ú3p2
u3q4
ú3r2
u3t2
ú3t2
u3u
u3v2
ú3v2
u3x2
u5é2n4s
v2é3n4
v2e4m.
v2e4n6s.
w2a
x1s
x2e4m.
x2e4n6s.
y2a
z1z
z2e4m.
z2e4n6s.
z4í


