## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: No.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/No.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::No;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<No> hyphenation pattern class

=cut

__DATA__
% This file is part of hyph-utf8 package and resulted from
% semi-manual conversions of hyphenation patterns into UTF-8 in June 2008.
%
% Source: nohyphbx.tex (2007-02-07)
% Author:
%
% The above mentioned file should become obsolete,
% and the author of the original file should preferaby modify this file instead.
%
% Modificatios were needed in order to support native UTF-8 engines,
% but functionality (hopefully) didn't change in any way, at least not intentionally.
% This file is no longer stand-alone; at least for 8-bit engines
% you probably want to use loadhyph-foo.tex (which will load this file) instead.
%
% Modifications were done by Jonathan Kew, Mojca Miklavec & Arthur Reutenauer
% with help & support from:
% - Karl Berry, who gave us free hands and all resources
% - Taco Hoekwater, with useful macros
% - Hans Hagen, who did the unicodifisation of patterns already long before
%               and helped with testing, suggestions and bug reports
% - Norbert Preining, who tested & integrated patterns into TeX Live
%
% However, the "copyright/copyleft" owner of patterns remains the original author.
%
% The copyright statement of this file is thus:
%
%    Do with this file whatever needs to be done in future for the sake of
%    "a better world" as long as you respect the copyright of original file.
%    If you're the original author of patterns or taking over a new revolution,
%    plese remove all of the TUG comments & credits that we added here -
%    you are the Queen / the King, we are only the servants.
%
% If you want to change this file, rather than uploading directly to CTAN,
% we would be grateful if you could send it to us (http://tug.org/tex-hyphen)
% or ask for credentials for SVN repository and commit it yourself;
% we will then upload the whole "package" to CTAN.
%
% Before a new "pattern-revolution" starts,
% please try to follow some guidelines if possible:
%
% - \lccode is *forbidden*, and I really mean it
% - all the patterns should be in UTF-8
% - the only "allowed" TeX commands in this file are: \patterns, \hyphenation,
%   and if you really cannot do without, also \input and \message
% - in particular, please no \catcode or \lccode changes,
%   they belong to loadhyph-foo.tex,
%   and no \lefthyphenmin and \righthyphenmin,
%   they have no influence here and belong elsewhere
% - \begingroup and/or \endinput is not needed
% - feel free to do whatever you want inside comments
%
% We know that TeX is extremely powerful, but give a stupid parser
% at least a chance to read your patterns.
%
% For more unformation see
%
%    http://tug.org/tex-hyphen
%
%------------------------------------------------------------------------------
%
% TeX hyphenation patterns for Norwegian
% 
% version of 2007-02-07.
% Patterns of January 25, 2005, with later additions and changes
%
% Copyright (C) 2004, 2005 Rune Kleveland, Ole Michael Selberg.
% Copying and distribution of this file, with or without modification,
% are permitted in any medium without royalty provided the copyright
% notice and this notice are preserved.
% 
% Please send bugs or suggestions to tex-live (at) tug.org.
% 
% Originally generated by a script written by Rune Kleveland
% from dictionaries available from 
% http://folk.uio.no/runekl/dictionary.html.
%
% Adjusted manually by Ole Michael Selberg to prevent
% numerous wrong hyphenations, especially in compounds.
%
% Changes from the former version of 2005-06-29:
% 388 new patterns. Some old patterns have been deleted or changed.
%
% In Kleveland's nohyphb.tex there are 26017 patterns.
% This version of the revised nohyphbx.tex contains 27149 patterns 
% --- plus 45 exceptions in the \hyphenation-list
% (which you may change to suit your personal needs).
%
% To load these hyphenation patterns the parameters 
% of TeX must have the following minimum values:
%   trie_size = 33385 
%   trie_op_size = 815
% (The corresponding values for nohyphb.tex are
%   trie_size = 31900    trie_op_size = 636)
% If you want to load more than one set of hyphenation 
% patterns the parameters have to be set to a value 
% larger than or equal to the sum of all required values
% for each set.
%
% Notes on other Norwegian hyphenation pattern files, from Dag Langmyhr,
% tex-live mail of 29 Jun 2005 11:26:21 +0200.
% nohyph.tex -- manually created by Ivar Aavatsmark and others;
%   hyphenate according to pre-1973 rules; no longer recommended for use.
%   (Sometimes also known as nohyph1.tex.)
% nohyph2.tex -- created by Dag and a student; the present file,
%   nohyphbx.tex, is more extensive and is recommended.
% 
\patterns{
.a4
.aa4
.ab4ba
.ab7be
.ab6s5t
.ac6tin
.adel4s
.ad8la.
.ad6le.
.ad2r
.ad1s2
.af7f
.af5t4
.af5f6u
.ag6na.
.ag6ne.
.ag4r
.ai2
.a6k
.ak6ka.
.ak6ke.
.ak3kl
.ak3kr
.ak6ne.
.ak6r
.ak8sa.
.ak4se.
.ak6ta
.ak4te.
.akte4r
.akter5e
.ak5tr
.akva7
.a6l
.albu5en
.alfa3
.al4ge.
.al5gi
.al6ka.
.al4ke.
.al4kom
.al4la.
.al4le.
.al5leg
.al5lo
.all5s6
.al4ma.
.al8me.
.al5m6in
.al4na
.al6s7k
.als5o
.alt4a
.al4ta.
.al5tar
.al4te.
.alt3o
.al6ve.
.am7b
.a6me
.am6ma.
.am4me.
.am4s4
.am6ta
.a6n
.ana3b
.an4da.
.an4de.
.an5d4ra
.an4d5ø
.an3er
.anes5
.an4ga.
.an3ge
.an4ge.
.ange4s
.an4ja.
.an4ka.
.an4ke.
.an4la.
.an3n
.an4na.
.an7nal
.ann4e
.an4ne.
.an5s8
.an4sa.
.an4se.
.ant2
.an4ta.
.an4te.
.an5tem
.an5tep
.an4ti.
.an6tin
.an4tis
.an4tiv
.ap8lan
.ap1p6
.ap8t
.arbi5
.ar6de.
.are4o7
.ar4ge.
.ar5ges
.ari6a
.ari8e
.arie5ne
.ar5ka
.ar8ka.
.arlan9
.ar4me.
.ar7mea
.ar4na.
.ar3ne
.ar4ne.
.ar5nes
.ar6ra.
.ar6r7u
.ar6ta.
.ar4te.
.ar9ti
.ar6va.
.ar4ve.
.ar4ved
.ar4ver
.arvi6
.a6s
.as8ka
.as4ke.
.as5kese
.as4le.
.as6pa.
.as5s
.ast5ru
.at4h
.at4ki
.at4le.
.at4na.
.at2o4
.at3s
.atte4
.att6r
.a5ty
.au8de
.au6e
.au8ga
.au4ge
.au4ka.
.au8le.
.au4r
.au6sa.
.au6se.
.aus9k
.au4sp
.avi2
.av7i6d
.av7inde
.av4la.
.av4le.
.av7s6
.b6
.ba6by
.ba6la.
.ba4le.
.ba4ne.
.ban4k3l
.ba4re.
.ba4ri.
.ba8te.
.be4de.
.bede4n
.be6d5ene
.be4d5et
.be8di.
.be3e4d
.be6ke.
.be4la.
.be9nar
.be4ne.
.be6ra.
.be6re.
.be4res
.ber6ett
.be8ri.
.be7ska
.be6sten
.be4ta.
.be6te.
.be5t4v
.bi6de.
.bi6en
.bi4le.
.bilet5
.bi6t3r
.bl4
.bla4d
.ble4k3
.ble5k4e
.blek4k3f
.blekk3s4t6
.blekk9s8v4
.bling5
.bo8da
.bo8de.
.bogs8
.bok5
.bo4k4en.
.bo8la
.bon2
.bo4na.
.bor6t5
.bort6e
.bor8ti8
.bort9r
.brudd7s6
.bruddså7
.bu6da.
.bu3d6r
.bu4et
.bus6sy
.by6de.
.by8ta.
.bæ2
.bø6k5a
.bø8nen
.bø8ner
.c4
.ca4en.
.car4s5
.ca6se
.ce6b
.cos1
.co4st
.d6
.da4ge.
.da4le.
.dags6e
.da2m
.da4ne.
.da4ta
.dau3s
.deka9r
.deko7d
.de4le.
.de4l5ei
.del5s6
.de4mi.
.demo7e
.den5sl
.de4re.
.de4r5et
.de4ri. 
.de6r3i4
.de7r4i5v
.de4r5om
.de6s5m
.de4so
.de4sto
.de4u
.devi5s
.di2a
.di5e4l
.di6er
.di4et.
.di9f6t
.di4ne.
.dings7a
.di4sk
.di8s3t
.do4en
.do4er
.do8et
.dome5
.do4ra
.do6re.
.drau4m
.ds4
.du4a
.du4en.
.du4er
.duft3
.du4ge.
.duk3n
.du4se.
.du4st
.dy4re.
.dø6la.
.dø6r3
.dø7r4a
.dø7r4e
.dø4ve.
.då5ren
.då7ret
.e6
.eb4ba
.ecu6
.ed4da
.ed4le.
.efo7
.ef4ta
.efta5s
.ef6ter
.eg8de.
.ege2
.ege5l
.eg6ga.
.eg4ge.
.eg4gel
.eg8la.
.eg4le.
.eg6na.
.eg4ne.
.ego7t8
.egs4
.eg8se.
.eg5si
.ei2
.eid5a
.ei5den
.ei4ga.
.ei7ger
.eik5a
.ei4ke.
.ei3l
.ei3m
.ei8ma.
.ei8me.
.ein7as
.ei3ni
.ein5og5
.ein5s6ta
.ein8s7to
.ei9rar
.ei5res
.eir9u 
.ei5te
.eit9r
.ekk4o
.ek4le.
.ek3li
.ek6ne.
.ek4r
.ek8sa.
.ek3se
.ek8se.
.ek4sp
.eks6pi
.eks3t4
.ek5s4ta
.ek8ta
.ek4te.
.ek7to
.el8da.
.el4de.
.el4g5r
.eli5ne
.el3k
.el5l
.el6s
.els6a
.els4kl
.els6t
.el6ta.
.el6te.
.el6veg
.em3b2
.emfa9
.em4ma.
.em8me.
.em6na.
.em5p
.en5a
.en4da.
.en4de.
.end5r
.en4ga.
.en6gav
.en3ge
.en4ge.
.en6g5r
.engs6
.en6ka
.en4ke.
.en5og5
.en6sa
.en4se.
.en5so
.en3sp
.en5t
.en6te.
.ent4r
.en6t5ra
.ent8re
.en3ø4
.ep6t
.er8a
.er4e
.er4g5r
.er4ke
.er4la.
.er4le.
.er6ma.
.er4me.
.er4mek
.er4na.
.er6ta.
.er4te.
.es9ast
.es1k
.es3ka
.es8ka.
.es4ke.
.es5l
.es8la.
.es8le.
.es3p
.es6pa.
.es6r
.es8sa.
.es4se.
.es4so
.es5ta
.es3te
.es6te.
.es7tet
.es5ti
.est3r
.es7tu
.et8la.
.et8le.
.et4na
.et4ne.
.et4s
.et8sa.
.et5s4e
.et6se.
.ets4i
.et1te4
.et6ter
.et6ti
.ev8ja
.ev4je.
.ev4ne.
.ex4
.f4
.fa2e
.fag3s4
.fa4ne.
.fan3t4o
.fe4e
.feil5i
.fe2l
.fela9
.fel5l
.fel4ta
.fe4ma
.fe8me
.fem5o6g5
.fem5t
.fer8ro
.fer6s
.fe8sl
.fe8st5
.fes3t6e
.fi4b5
.fi6a
.fi4le.
.fire5o6g5
.fis6k
.fjel4
.fla4t5o
.fo4bi.
.fol2
.fo2r
.for3d6ri
.for7d6ra
.for5en.
.form5s
.for7s6o
.fre6e
.fri5e6re
.fug2
.fu6ge.
.ful2
.fu8se.
.fy8se
.fø8rel
.g6
.gaf7
.ga4le.
.ga8li.
.ga4me
.ga4ne.
.gang5s4
.gas4
.gas5ta
.ga2t
.ga4ve.
.ga9vee
.ge2a
.gel4e
.ge3ne
.ge6ni5
.gen5s
.ge4o
.ge4st
.ge5s6tap
.ge9sv
.gha5
.gift5s
.gi4n
.gi4s
.gis7p
.gi8v3a
.gl6
.glo6i
.glo9v
.gly5s
.glø9se
.gnå7la
.go5des
.gos7
.gra4v3end
.grei4e
.grunn5s
.grus5s
.gu4de.
.gud3v4
.gu4lat
.gus1
.gu4tu.
.gø2
.gås4e5
.gå4v
.h4
.hai5s6
.ha6ka.
.ha8ma.
.hand5s6l
.handsla9
.ha6v5ak
.ha6vi
.he4er.
.hei5e
.he2n
.hen3i2
.he6r5i6
.he6r5o6
.he9r6oe
.he7r6oi
.he7r6ol
.he9r8os
.hes4s5
.het6s5
.het7s6e
.he4t5
.he5t6e
.hil4l
.hi4n
.hi6re.
.ho2d
.ho2e
.ho4re.
.ho5ren
.ho7ret
.ho8ta.
.ho8va.
.hu4di
.hus6val
.hvit3
.hvi3t4e
.hy6ra.
.hy4re.
.høi5
.hø4re
.hø4va
.hø4ve.
.høy6st5æ
.hå8en.
.hå8er
.hånd5s6l
.i2
.i3a4
.i3bl
.i4da
.ifø5re
.ig8la.
.ig4le.
.i4her
.ik2
.ik6k
.ikke5
.i3k6l
.ik5t
.ik8te.
.i5kv
.i3la
.i4la.
.i8lande
.ilbo8da
.il6d3r
.il6de.
.i3leg
.i6les
.il4ja
.il6je.
.il6ke.
.il4le.
.il6sk
.il4te.
.i6me
.imø5te.
.in5ad
.in5de
.in8ga.
.in4ge.
.in3gr
.in6gri
.in5k6
.in6ka.
.in4n3
.in4ne.
.in5n6e
.in6n7eks
.in6n7ets
.in6n7ett
.in4n3i
.in5s
.in7tes
.io4na
.io4nom
.i4rer
.ir7k8
.ir8ra.
.ir6re.
.i6sa
.i3sc
.i6se
.is7k6
.isla8ga
.is6lam
.is4le.
.is4let
.is4me.
.is8na.
.is8ne.
.is5pa
.i5spe
.is3s4
.is6sa.
.is4se.
.is5sk
.ist6
.is8te.
.i5sted
.i5stem
.is7ti
.i6s7tj
.i6s7tr
.is8ut.
.i6s5ø
.i5ti
.i3va
.i4van
.i4var.
.i3ve
.i4vel
.i6ven
.i4ver.
.i4vere
.iv8ra.
.iv6re.
.i3ø
.j4
.ja4de.
.ja6e
.ja4ne
.ja8se.
.ja4va.
.je2a
.je2l
.je2m
.je5re
.jern5s4
.je4ta
.ji4
.jo8en.
.jo4se.
.ju6a
.ju6la
.jule3
.ju4li3
.jø4dep
.k6
.kaf2
.ka6la.
.ka6li.
.kalve5l8
.ka5me
.ka3na
.ka4ne.
.ka4p3r
.ka4ra.
.ka5r6a5v
.ka6re.
.ka5rin
.ka4te.
.ka5t6h
.kau9k
.ka6va.
.ka4ve.
.ke6e
.kel3
.kier3
.ki4na
.ki7ni
.kino3
.kir2
.ki4se.
.ki8va.
.ki6ve.
.kje3de5
.kje4k
.kjek7l
.kjønn4
.kle4s
.kli5ne
.klo9va
.kly7sa
.kna7se
.kne4p3r
.ko6da.
.ko7gr
.ko4la
.ko3le
.ko8le.
.kol5j
.ko3pe
.ko6pe.
.kor6s5ed
.ko4se.
.ko6ta.
.ko4te.
.ko6ve.
.kring5s
.ks6
.ku5f4l
.ku4le
.ku8ra.
.ku4re.
.ku8ta.
.ku8te.
.kva4r1a
.kve9ka
.kve5ke
.ky8la.
.ky4le.
.ky6te.
.kø3s
.kå6pa
.l6
.la4da.
.la4de.
.la4ga
.la4ge.
.la5ger
.la4ma.
.la6ta.
.la4te.
.la3tr
.la4va
.la3ve
.la4ve.
.le8ar
.le4da.
.le4de.
.le4er
.le6et
.le2f
.lef3l
.lega5ta
.le4ge.
.le4gel
.le8gi.
.lei5er.
.lei4ve
.le4ke.
.le4k5r
.lemu9
.le4ne.
.le6o7
.le7s6a
.le4se.
.le4sek
.le4ses
.le4s5p
.le2t
.le7ta
.let6tan
.le2u3
.le3va
.le4va.
.le4ve.
.le4ves
.li8a
.li4de.
.li4e4
.li5ene
.li2g
.liga3
.li2k
.lik5k6
.lik3o
.lik3s
.li4ma
.link6
.li6ra
.li4re.
.li4sa
.li4se.
.li4ta.
.li4te.
.li5ti
.li4ve.
.li4v5en
.liv8s7u6
.liv4s5v
.lo4e
.lo6ge.
.lo8gi.
.lo6g5r
.lo4i
.lo6na
.lo8o
.lo6ri
.lo8sa.
.lo4se.
.lo6te
.lo4va
.lo3ve
.lo4ve.
.lu4d
.lu2e
.lu4na
.lu6pa
.lu4pe.
.lu6ra.
.lu4re.
.lu6se.
.lu4ta.
.lu9tas
.ly4de.
.lyd3s
.ly8e
.ly8ge
.ly4se.
.ly4sk
.ly5s6e
.lys5s6
.ly8str
.ly4te.
.ly4ve.
.lø8de.
.lø6en.
.lø8ne.
.lø6pa.
.lø4pe.
.løv5i
.løye5ne
.lå8ma
.lå5re
.lå6re.
.lå4te.
.m8
.ma4ge.
.mag9r
.ma3ka
.ma4ke.
.mak6t5at
.makt5s
.ma4le.
.ma4li.
.ma4na.
.ma4ne.
.ma4ni.
.ma4ra.
.ma4re.
.ma4ri.
.ma4sa.
.ma4si
.ma6st
.ma8ta
.ma6t8h
.mat5t8o
.ma4v
.me4d3
.me6d5ei
.me6d4i
.me6d7in
.me6d5r
.mei5er.
.mei5et
.mek5l
.me6la.
.mel3l6o
.me4l5ø
.me4ne.
.me3ri
.me4sk
.me2t6a3
.me3ta4ll
.mes5ti
.me4tri
.mi6kj
.mi4le.
.mi4me.
.mi4ni.
.mi4nik
.min4k3
.min5k4e
.mi6s3t4
.mne6
.mo5de
.mo6er
.mo4na.
.mo8ne.
.mon4st
.mons6t5r 
.mor5d6e
.mo4re.
.mor3t6a5
.mo4se.
.mo4ta
.mo4tek
.mo4ter
.mo4tr
.mo5v
.mu8ga
.mu8ge.
.mu6le.
.mul5es
.mur7
.mu5r8e
.my8ka
.my4ke.
.mø4re.
.mø5res
.mø2t
.må6la.
.mål3o
.n8
.nabo3
.na6ge.
.nak2
.na8ke.
.nan5s
.na4r
.na4sa.
.nat2
.na3tr
.nat6tr
.ne4de.
.ne4den
.ne4d5i
.ne4d3r
.ned3s4
.nei5e
.ne8pa.
.ne6pe.
.ne2s
.ne4t
.ni8ar
.ni6er
.nig4l
.ni4na.
.ni5o6g5
.ni4pa.
.ni6pe.
.ni8sa
.ni6se.
.nita9
.ni4to
.ni4va
.no6de.
.no6e
.no8ka
.no4me.
.no8mi.
.no4r
.no8se
.no8si.
.no4va.
.nu4e
.ny5a
.ny8sa.
.ny6se.
.ny4te.
.nær9ast.
.næ4re.
.nød4d
.nø4re.
.nå4de.
.nå6le.
.o6
.obo5e
.od4da.
.od4de.
.od8la.
.od8le.
.offsi6
.of4te.
.of5teb
.og4
.ok1k
.ok8ka.
.ok8ke
.ok4se.
.old3s
.ol4ga.
.oli5
.ol8la
.ol8le.
.ol6m
.om1
.om4ar.
.om6bo.
.om4e6n
.om4gå.
.om4me
.om5s2
.on4de.
.on5des
.ond3s
.on6kl
.on6na
.on8ne.
.op5ar
.op4pa
.op4pe
.opp7el
.op4pi
.opp3l
.oppla8te.
.opp5s6
.op7r
.opt6
.or4da
.or4de.
.or4del
.or4dr
.ord5s4
.or5ga
.or6ka.
.or4ke.
.or6me.
.or4re.
.ort6
.or6va
.osa5
.os4k
.os4s
.os4te.
.ot5r
.ot7t8a
.ot4ta.
.ot4te.
.ot4tes
.ot3to
.ot4to.
.ove6
.over3
.overen6d
.over3i4
.over5k8
.ov8re
.ov5u
.p6
.pa8la.
.pa4le.
.pa5n6e
.pa6n7eu
.pa5n6i
.pa6re.
.pe3do
.pe4ke.
.pek5t
.pel4sj
.pe4ne.
.pe2p
.pep3r
.pe8sa.
.pese5t
.pe4st
.ph2
.pi6le.
.pi6p
.pi9ra
.pi2s
.plen5g6
.plus6s5 
.plus7s6e
.plø7se
.po4et
.po3la
.po8la.
.po4le.
.po4log
.po2p1
.po2p2e
.pop3p
.po3p2u
.po8ra
.po6re.
.po4res
.po6st
.po8ta.
.po6tek
.ps2
.pøn3
.pøn9s6
.på5d6
.r6
.ra6da.
.ra6et
.ra4ga.
.ra4ge.
.ra4ja.
.ra4ka
.raks7
.ra2m
.ra4na
.ra4ne.
.ran7s6a
.ra6pa.
.ra6pe.
.rap4s
.rap5s4e
.rap5s4o4
.ra4re.
.ra6sa.
.ra7ti
.ra6va.
.ra4ve.
.re4al
.re6da.
.re4de.
.ree6l
.rege4l
.re4gi.
.rei2
.rei7de
.rei5er.
.re4ins
.re6ka.
.re4ke.
.re8klar
.re8kle
.re4kli
.re6kn
.re8le.
.re4ma.
.re4na.
.re4ne.
.ren6sk
.ren4t
.rep5s
.res9s
.re5s6tan
.rett7s8kri
.re4ve.
.re4ves
.rev9n
.ri2d
.ri8e
.rie5ne
.ri6ka.
.ri6ma
.ri4me.
.ri4pa.
.ri4pe.
.ri4p5o
.ri4sa.
.ri4se.
.ris5ko
.ri4s3ø
.ri4ta.
.ri6te.
.ri6va.
.ri4ve.
.ro4an
.ro4de.
.ro8di
.ro4e
.ro8ke.
.ro4ma.
.ro4mi
.ro6pa
.ro9par
.ro3pe
.ro4pe.
.ro4sa
.ro9sar
.ro4se.
.ro4sed
.ro4ta.
.ro4te.
.ro4tek4
.ro8va
.ro3ve
.ro8ve.
.ru8ga.
.ru4ge.
.rug9le
.ru8ka
.ru4na.
.ru4ne.
.runes6
.run7g
.ru4se.
.ru4sk
.ru8va.
.ru4ve.
.ry2e
.rye7ne
.ry6ke.
.rød2
.rød7s4
.rø8le.
.rø4re.
.rø1v
.rø8va.
.rø4ve.
.røy7e
.rå8da.
.rå4de.
.rå4en
.rå8er.
.råg8
.rå6ka.
.rå4ke.
.rå3k4l
.rå6na.
.rå8sa.
.s6
.sa4ge.
.sag6n
.sa4la.
.sa4le.
.sa4me.
.sa4mer
.san6d7
.san7d8e
.san7d8i
.san8s7ku
.sau6e
.sch6
.se2b
.se2e
.se4i
.se4k5l
.sek4s5o6g5
.sel4v5
.sel4v5i6
.se6na.
.se4ne.
.sen7s
.se4ra.
.ser7vel
.se4te.
.sha9ke.
.si2d
.si6er
.si6ga.
.si4ge.
.sik5k6e
.si8la.
.si4le.
.si4ne.
.sinn6s5
.si4ra.
.si5str
.si4va
.si4ve.
.sje4i
.sju5o6g5
.sk4
.ska7ka
.ska5ke
.skat4
.skei5d
.ski6n
.skinns6
.sko7de.
.skog5u
.skritt9s8
.skudd5s6
.skuddså7
.sku6m5
.sky6f7la
.skå5ra
.slim5
.slotts5
.slu9ka
.slu5ke.
.slø5se
.sma4s
.smas5k
.smo9g
.små3
.små7k6
.små9l
.små5t4
.småt5t
.sn4
.sne3
.snitt5s6
.snø3k
.soa8
.so8de
.somma4
.son6a
.sop4pa
.sor4t5
.so4ta.
.s8p6
.spa5ra
.spe6e
.spi9la
.spri5s6
.st6
.sta9ka
.sta5li
.stat4s
.sted4s
.ste4i
.stein7a8
.stein7s8
.stem4m
.stev9na
.sti7me
.sto5ne
.sto6ra
.strek5s6
.stu8a
.stu9va
.stål5l6
.sund5s6
.su4ri
.su5te
.sv8
.sva5la
.sva5ra.
.sva5re
.svar5s
.sver8n
.syd5 
.sy5d6e
.sy6na.
.sy4ne.
.sy5ter
.sy3ti
.sy6v5
.sy6v5o6g5
.sz6
.sæ2
.sær1
.sær3e4g
.sø8ka
.sø4ke.
.søl6v5
.sør3a
.søye5
.søy6en
.så5pen
.så3re
.t8
.ta8ke.
.tak9r
.tak5sk
.tak9s8p
.ta4la.
.ta4le.
.ta4les
.tal4li
.tam5m
.tan5de
.ta4p5r
.ta4ra.
.ta4re.
.ta2s
.te4e
.te6i
.tei9er
.te8ke.
.te4ma.
.te6o
.te8ne.
.te4se.
.te7si
.te4sta
.te4str
.th2
.ti8a
.tid5r
.tid6s3
.ti4de.
.ti4e
.ti4g3r
.ti4ki
.ti4l5
.tili6
.ti4med
.ti4na.
.ti4ne.
.ti4p5l
.ti4s
.to5arm
.to6en.
.to4er.
.to6et.
.tokk8
.to6le.
.to6na.
.to5o6g5
.to4ra.
.to4re.
.to6reb
.to3ro
.torsk6e5
.tor4s5v
.to5rye
.to4str
.tota9la.
.to5t8
.to8te.
.to6va
.to4ve.
.tr6
.tra7c
.tre3b
.tre7p
.tre5o6g5
.tre6skja
.tre3s8ko
.tre3sp
.tre5s6t
.ts2
.tsj2
.tu4en.
.tu6na
.tu4ne.
.tu6ra.
.tu4re.
.tu8ve.
.tve6n
.tver6r5a6
.två7g
.ty6da.
.ty4de.
.ty8et
.ty8re.
.tyr8s9
.ty5ter
.ty5ti
.tæ4re.
.tøv9d
.tø6ve.
.tø9ver
.tø5vet
.tå5ker
.tå4le.
.tåp9n
.tå5ren
.tå7ret
.u5a6
.u1b2
.u6berg
.u3d2
.u7de
.u3e6
.u4er.
.u6era
.u4ere
.uf4f
.uf8sa
.u4ga
.u5gi
.ug6la.
.ug8n
.u1i
.ui6m
.u1k6
.u4ka.
.u6ke
.u7kn
.u3le
.u4le.
.ule8k
.ulen4d
.u6lende
.u8lene
.u6let
.u4lin
.ul6ka
.ul4ke.
.ul4la.
.ul8le.
.ul8ma.
.ul4me.
.ul4ne.
.ul5t
.ul6te
.u1lu
.ul4v5i
.u1ly
.u3lå
.u5ma
.umu7
.u2n
.unde6ri
.und5r
.une8
.u5nek
.u9net
.un4ge.
.un2n
.unn3s
.u3no
.un4se.
.un4t
.u5nu
.u1o
.u1p
.u4pi
.up2l
.u2ra
.u5raf
.ur6an
.u6rane
.ur4d
.ure4n
.u4ret.
.u6rets
.u2r2i
.ur4ke
.ur6na
.ur4ne.
.u1ro
.ur1s
.ur8ta
.ur4te.
.urte5m8
.ur6tet
.u5rut
.u3ry
.u5rå
.u1s2
.u4sa.
.u4sas
.u5se
.u3ska
.u5sn
.u7sp
.us3se
.us6t4
.u7stek
.u5stel
.usy5r
.u2t
.uta4g
.ut5age
.u3tak
.u4ten.
.ut5esk
.ut6e7sko
.u4ti.
.ut3kan6t5
.ut4ne.
.u5tol
.ut3o6v
.ut6rer
.ut6rov
.u3trø
.ut6se.
.ut4si.
.ut3t4
.u3tu
.v6
.va4da.
.va4de.
.vai4
.va4ke.
.va6les
.valg5s
.va4ne.
.van4n5
.vann5s4
.va6reta
.vari4e
.var5sk
.ve8en.
.ve4ga.
.ve6ge.
.ve4g3i
.veg3s4
.vei3g4
.vei3s
.vei4ta
.ve4l3
.ve5l4ar
.ve6l5art
.vel5d
.ve4l3e
.vel5l
.ve5l4os
.ve4l5ov
.ve4ly
.ve8læ
.ve4ne.
.ve4net
.ve4ra.
.ve4ras
.ve6re.
.vermo9
.vers4t
.ver5ste
.ve4sl
.ve4st
.vete5
.ve8te.
.ve4ve.
.vi4da.
.vide4
.vi6de.
.vi4d5å4
.vi2e
.vi4ka.
.vil5l6a5l  
.vil5l6a5t
.vi6ma.
.vi8me.
.ving7s
.vin5n
.vi4sa.
.vi4se.
.vi6seri
.vi4ta.
.vi4te.
.vi5tr
.vok4s3
.vok5s6e
.vo6r
.vo6ta.
.vy4
.vye5ne
.væ4ra
.væ4re.
.vå4d
.vå4r3
.vårs6
.wa4r
.wi6e
.xe2
.y6
.ye4
.yn8da.
.yn4de.
.yn6ge.
.yn8ka.
.yn6ke.
.yn4kv
.yns2
.yp8pa.
.yp4pe.
.yr8ja.
.yr8je.
.yr8ka
.yr4ke.
.yrkes5
.yr6t
.ys4
.ysterie8
.yt9ren
.yt5t
.yt6te.
.yv6
.z4
.zj8
.æ8
.ære4s5a
.ære4st
.æt4te.
.ø6
.øg8la
.øg4le.
.øi5
.øi6e
.øko5
.øk6ta
.øk4te.
.øl3ed
.øl3s6
.øl3v6
.øm4me.
.øres8t
.ør4je
.ør5k
.ør8na.
.ør4ne.
.ør6ski
.ør9sm
.ør3st
.ør8ta
.ørt9an
.ør8te.
.øs2
.øs4t
.øv4d
.øve4r5
.øve4r6s
.øv4re.
.øy6de.
.øy2e
.øyele8ge.
.øy5ene
.øy4n
.øy6na
.øy6ra
.øy4re
.øy8rer
.øy4str
.å2
.å6e
.å6f
.å6g
.å6k4
.å8l
.ål6t
.ål8ut.
.å8m
.ån8da.
.ån4de.
.ånd6s5
.åp6na
.års3k
.å6se
.ås3k
.ås7l
.ås3m
.å3ste
.ås5v
.å4t
.åt4te.
.åtte5o6g5
.å6v
a1ad
4aaf
a3aft
aa4g
a1aks
aak5v
aa3la
aa2m
a1a2n
a6an.
aans9t
a7antr
a1ap
aa4ri6
aarie9ne
aar5n
aa2s
3aase
aa5t6h
a1av
a6bab
ab7av
ab9b8l
ab4but
abe4lei
abel5t4
abe9na.
abes9ka
4abev
a5bh
abie6
abi9er
abi9la
a4bist
ab1l
ab9lara
ab4lok
abl7u
a5bo9a
abo3b
abo3e
a3boer
abo3kl
a3bord
5aborte
ab1r
ab8re
ab2sl
abu5e
a4buel
a4buf
a6busk
a4bute
a4by.
a4byb
a4byk
aby3r
8ac
aca5
a6ca.
ache3a
ack3
a1co
6ada
a5dal
ad5ant
a4dart
ad9da
a2deb
ade5i6s
a2dek
a4del
a4d5elv
a5dend
a3dene
a2deo
a2dep
a5der.
aderle7
a2des
a5de4ser
a3desl
a3det.
a3dets
3adfer
1adg
ad8ge
adi4ene
ad1j
1adju
2adl
1adm
ad5n
ado7a
a4dob
ad7opp
4ador
a7dora
ad5raf
ad7ran
a2dre
ad7rel
ad5rep
ad3ret
ad3rid
ad1ro
a7drø
ad4s5amt
ad4si
adsle6ge.
ad5s4let
ads5te
ad5s6tek
ad3str
ad5un
1adv
adva5re
2adve
a4dy.
a4d5øy
2a1e2
4aea
a4ed
ae3de
aed7r
aek5t
a4el.
ae5la
ae3li
ael5o
aen5t
a3ep
aes8ke.
aes4t
6afa
6afc
a4fe.
afei5
af4fan
af4fei
affe3s
af7fi.
affi3d
af5f4u
af4i
afia1
afi5an
a2fib
a6f5inn
afi7re
a4fiti
a5fjo
af9la.
af9lar
af3le
af5li
a4frik
6afo
afo7ra.
afo7r8e
afore5ne
afra5s
1afri
afs1l
aft5ei
af4t5e4l
af6t5o
aft1s4
af5yr
afø4r
afø5ri
4aga
a2gaa
a5gae
a4ganf
agang7s8
a4gart
a5gas.
aga6ve.
ag5de
a7gelen
a2gem
3a4gent
age4r3a
age6rek
age5risk
a7gers
a5geru
age5s2
a4geta
a4gé
ag5gar
ag4gas
ag5ge
agg1s2
agg7u
ag6gut
a4gi.
ag5id
agi6s
ag1la
ag4lem
ag6lesa
ag5lå
agmo8e
agn5om
4ago
ago5d8
ag1or
a5gos
a3got
ag5ov
ag7ras
ag1re
ag1ri
4a3gru
ag1rå
ag4samb
ags4ang
ag3s4ei
ag4sel
ag3sem
ag5s6ing
ag6sju
ag4ska
ags4kul
ag2sl
agsmå6la
ags3tr
ags3t2v
ag2sy
a6gu.
agu3ay
agå8va
agå8ve.
a1h
a5hi
ah4n5
ah4v
ai1a4
ai3e2
ai3er.
ai4is
ai5ke.
ai5ko
ai9kv
ai5ne
a3ing
a1inn
ai4n5o4
ai1ro
ais4e
ai4s3k
aisk2h
ai8sm
ais6om
ais5s
ai5s4v
ai5ve
ai5ø
a1j
aja9d
a7je
a8je.
ajes7
a4jé
a4ji
a6jl
6ak.
a1ka
4aka.
1a2kad
6akaf
ak3aks
6akan
aka4o5
4akar
ak6arb
aka4t5r
ak4au
2akd
2ake
a9kec
a2keh
a3kei5
a6kek
akel8e
akelei9er
ake5l4i
ake4rek
a4kerø
ake5sm
akes6p
a8kete
akhe6n
4a1ki
a6kid
a6kik
ak7ind
akis1
2a1kj
akk6and
ak5ke.
ak3ken
akk5erst
ak4kes
akki4
ak5kim
ak4k5is
ak6kj
ak1ko
akk3ol
ak6k5ri
ak1ku
ak4kul
ak4k5v
2ak1l
ak3lev
ak6lik
ak6lus
6akn
ak5ne
a5kno
2a1ko
ak5om.
a5kon
a7kos
ak1o2v
ak4pe6
akra8sa
ak5reg
akregi4
ak3res
ak3ro.
ak3roe
ak1ru
ak4s5and
ak4sek
akse3l4o
ak4s5elv
ak4ses
ak7s6id
3aksje
ak2s1k
ak7sku
ak6sl
4akso
4aksr
aks5ti
ak5stol
aks4tr
akst7ren
4aksu
ak4tab
ak4tai
ak4tak
akta6le.
akt5all
ak6tam
ak6tans
ak4tap
ak4tas
ak4tav
ak4teg
ak4tek
ak5teme
4akth
7aktig
ak5tit
aktle6ge.
ak2tr
ak6tre
akt3rå
akt5s4la
5aktue
akut2
2akv
ak3val
ak5øl
a5kå
8ala.
al7adr
ala4g
ala9ga
a5lagm
alag8ra
a5lah
a1lai
al3all
al3a4me
al3ana
a3land
a5lande.
a5lane
alan5gr
al3anl
al3anv
ala4o
ala5pr
a5lar.
a3lara
a5laren
al3ark
a7larl
3a4larm
al5arr
a5lars
al3art
a7larv
al3a4si
2alat
ala7tr
4alau
al5auk
al1av
ala4va
al4ba.
albo4g
albu7er.
5album
al3de
al7der
4aldo
ald3re
2ale
a2lef
a2leg
a9leg.
aleie6n
a9l8eik
a5leke
a4leks
a4leli
a2lem
al5e4mu
al8en.
a4l3enh
a4l5en5tr
ale4pos
a7lept
a4lered
alere6de.
a4le5ro
a4leru
ale1s2
ale7se
a4lesk
ale6s5kr
a4lesl
a6lesu
a4leta
a4le3te
a2leu
ale5v
a4leva
a4levi
3alfab
2alg.
al3geb
al2gu
al4går
al3ill
a2lim
a9lin.
ali5na.
a4l3ind
a4l3ins
al3int
al9ja.
al3je.
alj5end
al3jer
al1jo
al4jor
al2j1u
al1jø
alj5ø6v
al9kera
alk7s6
alla4ga
alla6ge.
al4lap
all5art
al5lea
alle6ge.
al4lek
al5len.
all5erst
alle3s4
al4lest
al5let
3allia
al4lid
5alli5e
alli9ne
al6list.
al4lo3m
all4sen
all4sti
al6lul
al6løs.
al4løse
al8løst
al6lå
al6mek
al4met
4aln
a5lo.
al1o4b
a5loi
al1om
a1lon
al3ope
al7ord
alori5
alo6rit
al3ove
alow7
alp2
al3ps
2als
al7sed
al9skap
al7skare
als1l
als5lø
al2sn
al6spu
als4te
als6ter
6alsu
alt6ak
alta8le.
al3ted
al7tema
5alterna
alte4t
al4t5eta
al4t5ete
al4t3op
a4l5u4k
alul8la
al5und
alu8re.
al5va.
alv5aks
alvak8se.
al4ved
al5v6er
al8v9er8m
alve5s
al9ves.
alvi8se
al1vo
alv3s
6a1ly
a2l5y4te
alø5se
al3øv
a1lå
al7å6t
a4mah
ama5is
a2mak
a5maki
am3aks
a2mal
am5ald
a3man
a3mar.
a5mara
a7mas.
amaso7
3a4matø
am4bar
3ambas
am4bat
am5be
a2mei
am3eie
a3meis
a2mek
am3eks
amen8de.
amen4s3
amen6t7arv
ame4ram
a4meret
3a4meri
4amerin
ame5u
amhu7
2ami
ami7na
ami7ne
amisk3
amis4ku
am4lese
am6lest
am4mad
6amn.
am4ned
a2mo
amo5e
am1op
am1or
amo6ve
am4pap
am4pare
amp5ei
am8peria
am6perie
ampes6
amp7inn
am2p3l
am5p4let
am4p4re
am4pun
am2på
amru4
am5rå
am1s
am7s6ku
ams4l
amst6
am4s3tr
ams9ut
ams2v
am4s5ve
am2sø
am3ti
amti5da
5amtm
am7tv
am6ul
am5yr
am5øy
6ana.
anak8te.
ana3la
anal4f
3analy
8anan
a3nane
a5nang
anant8
4anar
a6narb
an5art
ana3to
6an7au
anaus7
an9av.
3anbef
4and.
an4da5m6
anda5ta
an4dek
an5den
anderle7
an9det
6ando
an4dos
4ands
and4sel
and8send
and7slet
and5s6tre
a2ned
an5egg
a4n5elv
a2nem
2anen
2aner
ane3ru
a5nes.
a4nest
ane5sv
an5e6tika
a5netike
an5e6tikk
an5e4tis
a2nev
3anfal
anfø5re.
ang4e
an4ged
an4g5enh
ang5erme
an8geste
an4gi.
5angiv
ang5of
an5gos
an4g9ra
an4gre.
an6gres
an4gret
an4g3ry
ang4sm
angs6tro
angs8t9rå
angst5y
ang5sva
ang6søy
ang4t5re
ang5t6ve
an4gun
an4gå.
ania7
a6nib
a4nisj
4aniv
an4kana
4anki
4ankj
an4kob
an4kop
an4kos
an2k1r
ankra8na.
ank3re
ank3ut
8an2kv
an4kø
an6k5å6
2anla
anland6
anlø9pa
ann5ans
an6neme
an5nen
an5ner
an5nid
an4ninn
an4nom
5annon
an4nov
ann4sei
ann4sid
ann6s7kå
ann6sl
ann3st
ann5sta
ann4s3u
an4ny
an2nø
a3no.
a9noa.
ano6deb
2anog
a7norm
a6not
a2no4v
ano5va
an3ove
anri7ke
ans5aft
ansa7ka
4ansan
3ansat
an4sek
an4sent
anseri8e9ne
an4ses
3ansik
ans5ind
ans5ins
an4ski
an3skj
ans4k3l
ans6kun
an5skø
an6slø
an4sn
ans5or
an4s3pi
ansport7s6
an1st6
6anstar
ans4te4
6ans6ti	
2ansu
an9s6und
5ansunda
1an1sv
4ansve
6ansy
an4så
anta8la
an5t6and
an4tans
an3ted
ant5emi
5antenn
an4tesl
anti7kl
an4tim
an5toi
ant5ord
ant5rab
ant7rom
ant5ryg
ant5s6
an4tul
antus4t
2anu
anus7a
an5ut
3anven
6anvin
6any
a4nya
a2n1æ2
anær8
2anø
a2nøk
an7å
a1o
ao9a
aog9
a2oi
ao6k6
aon8de.
ao2p
ao4r
a5pea
a7pé
a1pi
a2pia
ap1id
a6pik
a6pins
a2pio
api6r5
api7r6e
api7se
ap1j
a1pla
a5p6las
ap3li
ap9lo
ap2ly
4apol
a4pon
a4poo
apo3p
apo5s4ti
a2pot
3ap3par
4appar.
6appare
app7esk
ap5plas
ap4ple
ap5pli
ap6pri
ap3ra
ap5ren
ap5ret
ap3rin
ap2s1
apsa4
ap3sel
apse4s
ap8s9l
a3psy
ap4s5ø
8apu
a6p5ut
a1py
ap7ø
a3p8øls
a5på.
a1ra
ara9bi
ar5aks
arak5t
ar3alt
a4rami
2aran
a4ranor
a4rans
a4ranv
2arar
a4r5ass
ara5te.
ar5aug
ar7auk
arau9ken
ar7avh
1arb
2arba
arba8ne.
6arbeh
4arben
6arbet
2arbi
4arbj
6arbl
2arbo
arbo8da
2arbr
2arbu
2arby
2arbø
4arbå
ar7deb
ar6deli
ardfø5re
ard3re
ard5sta
a1re
1a2rea
4arear
a4reb
areba4r
a2red
a2ref
a2rei
are3in
a2rek
a6r5ekt
a4rela
ar7elek
a4r6eli
ar7emn
a5remo.
3arena
a6r5eng
a4reni
aren5tes
a2reo
a2rep
a6rerel
a4r5erfa
a6rerk
a4rero
a6rerø
a5res.
ares8ka
ar4et
a7reta.
a4rev
ar7e6va
ar3evn
arev6ne.
8a1ré
6arf
ar7g6h
ar5g6i
6argj
arg4l
ar7go
arg5stj
2a1ri
aria7ne
a3rib
ariba9
ar5idr
a4rim
ar3inn
ar3ins
arins9k
ar3int
ari3se
arise4a
a4risto
a2riv
ar4kau
ar3ke
ar4ke5s
ar5kha
3arkit
3arkiv
ar4kle
ar4k5løf
ar6kod
ark6ste
ark4str
ark7veg
ar4køy
arla4ga
ar4map
5armbå
ar4medi
arme7t
ar6metr
ar4minf
armle6ne.
armå6la
2ar2n
ar4nad
ar4nal
arneva7la
ar3ni
ar3no
ar3nu
ar3nå
a1ro.
aro8de.
a5rok
a1ron
ar1op
aro6pa
a4r1o4r
a1ros
ar7ost
a1rot
ar3ove
ar6ped
ar9po
arp5ret
1arra
ar5ree
ar7resk
arri8e7
arrå6da
2ars
arsa6ka
ars5ans
ar3sel
ar6s5ers
ar4sin
ars5kam
ar5skar
ars5kes
ars7kre
ar4spr
ars6tr
ars4vei
ars7æ
arta4la
arta6le.
ar3te
ar7tele
8artets
art4ha.
art4has
ar4tika
6ar4tim
4artn
4arto
ar4top
6artr
art9ra
ar6trin
art6s5t
arts5ø
6artu
8arty
ar4tyv
ar1ul
ar1un
ar5u6r
a1rus
ar5utb
ar5utn
arve3s
ar6vete
arvi8sa
arvi8se.
a1ry
ar7æ6
arø8ve.
ar1øy
a1rå
arå8de.
ar7åp
a6r5åt
6as.
4a1sa
asab4
asak4
a4salo
as6an
as7aug
asbe2
a1sc
a2se.
asea4
a2sed
a2seg
a2sek
as4el
ase5le
a2sem
a6senet
a4senk
a7seol
a2se5s
a6sest
a4sete
a2se3u
as2h
as5hu
a4sib
a2sip
a2sir
a7sis.
asis5t
a2siv
as4ja
a6sjett
as5jor
as3kar
ask6et
as5keti
ask2i
as5kis
a5skj
as5ko.
as5koe
a4s5kopi
as3kor
as3kot
a1skr
as7kra
as3kul
a5s6kula
as6kule
ask9u8t
as4kv
ask5øy
as1l
a5s4lag
asla8ga
as4lev
as4lit
a1so
a4so.
a2s5om
as5ov
as4pan
as3pe
as7pis
as5pl
as9sa.
as4sab
as4sal
ass5ald
ass5alt
as4sam
as5se.
as4sed
as4sek
asseri7e6
as4serv
as4ses
as6sifr
as5sing
assi3s
as4sit
as2sj
as6s1k
assku6le.
as2s3n
as5so.
asso9a
as7sos.
as6s1p
as2s3t
as4stan
as4str
ass5tru
as2s1v
as4sys
as4søk
as2s5å
as1ta
as6tab
a6stande
a4statu
as5te.
as3ted
as4teg
as4tek
as4t5enh
a1stj
a9stof
a5stok
ast5ov
ast5ren
as4tro
as9tua
astu8ve.
ast5ø4v
a1su
asu3n
asu9sa
as1va
a6sym
asyn7d
as7øye
as5å
4at.
4ata1
a5taene
at6af
ata8ka.
ata8la.
a4tang
ata9rar
a6t7arv
atas4
a5tas.
atat8
a2tau
at5avh
atch5
a2tea
a2tec
at7edd
a2tee
a4tei
at5eid
at3eig
ate3in
a4teka
ate5k8e
ateke7ta
a6t5ekte
ate7le
at3emb
4aten
a5tene.
a4teni
a4tenu
a2teo
4ater
a5ter.
a6terat
a8terek
a4teril
a2tes
a4t3ett
at6e5u
a4té
3atfer
at4ha.
at8has
4ati
atik6ka
atili5
ati5nea
ati4rep
ati8sta
at3jo
5atlant
atl9øy
3atmos
at4nel
ato5a
ato5gr
at1oi
a2tom
a6t5oppr
a1tor
a5tose
a3to1v
a1tra
at5reg
at3ren
at3rer
a4trif
at3rin
at5rot
a9tru
at5røs
at5røy
2ats
at3ser
at7sje
at7s6kat
at7skj
ats6kul
at2s3ø
4att.
at6tat
4at5te.
at5tens
attfø7re
at4tid
atti4s
att5ise
at3tit
att1o
att7o6p
atto6v
at1tr
at4traf
at4t3re
at6trin
att3s6k
att5s8l
att3sp
att3sv
at6tys
at2t3ø2
a1tu
atu5e4
a2tut
at5v
atvi5er.
a3t3w
a1ty
atyr8ke.
a5t6yv
a1tø
atør3s
atø9se
a4t5øy
a3tå.
a7tåa
a1tåe
at5år
at5å4se
at7åt8
4au.
8a8ua
au9ar.
4au5b
auba6ne.
au3c
au5da.
au9det
au4di.
4a6ue
au7en
au7er
aue5re
au3est
au6e5ta
au5e6te.
au4gal
au4gas
au4gel
augele8ge.
5aug2n
3augu
au5i
au5keli
au5ket
auk5la
1auk7s6
au5kve
au6las
au4lat
aul5l
aul8la
au5lu
au9men
au6mo
aum5s6k
aum7s4t
a5und
au5rae
aure5s
au5ret
au5ri
aur5s6
au1ru
auru4e
au1sa
aus9kj
au6skr
au1so
aus5s
au6s8tas
aus8tett
austi6s
aus6t7ise
aus6ton
au5str
au6stri
au1su
au4sun
au2s5ø4
aut6a
au3ta.
au7tar
au5te
1auto
auto5v
au3t4re
au4ty
2aux
a1va
av5ab
a5vae
ava7g
6aval
av3alv
a4v3and
av3ang
a4v5anl
3a4van5s
a9var.
av3art
avar6ta.
4avas
5avbi
1avd
3avdel
2a1ve
a2ve3d2
a5vede.
a7veil
ave3in
a2vek
a4vela
a4vele
a5veleg
avens4
a5ver.
ave7ras
aver5d
a6verei
a2ves
a2vev
1avfa
1avg
avi4ar
4a5vig
a1vik
avi9ke
a1vin
a4v5int
2avir
5avisa
avi5sa.
3a6vise
av5ising
avis3t
a5vit
avlu9t
avlø5se
6avn
av7na
av4nes
a1vo
a4vok
avo3r
avo4v
av1r
av4res
av5ri
av1sa
av5seg
avs2i
avsko7g
3avsni
av1s2p
avspe9g4
avs4te
av5su
av1s2v
1avt
avta9ka
2avu
1avvi
av3øl
4a1vå
a6v7å6l
a1wa
awat4
a5we
awe9ne
a1wi
ay2a
ay7ane.
ay5ar
ay9s8t
a5y4t
a5zu
azz3o
a1ø
a7å6
1b4a
ba3a
baby5
ba4bys
ba5cl
ba2d
ba4da.
ba7dan
b5add
ba8de.
ba4deb
ba5den.
ba7dens
ba3di
bad1s
4baf
ba2k
ba5kan7
ba3kar
bakars9
ba3ken
ba4k5end
baken6de.
ba3ker
bake3s
ba9ket.
bak9ett
ba3ki
ba8ki.
bak6kers
bak6ko
bak5kr
4bakr
bak4re
ba5kri
bak3ro
bak3sm
bak5sp
bak5s6ti
bak5str
bak7t6
bak1v
ba3la
bal7ak
ba4les
ba4li.
bal3j
bal4lag
bal4lan
bal4led
bal4leg
bal4lei
bal4lev
bal4lig
bal6lov
ball5s6
bal6læ
ba1lo
bal5t
ba1lu
ban4a
ba4na.
ba5nan
ba5nar
ban9da
ba4nel
ba4nes
ban6kap
ban4kor
ban2k3u
bantu5
ba3re
baret5t
ba3ri
bari6e7n
bark5s
bar5skr
bar5tr
ba5ru
ba5sen
ba4seru
ba4set
ba3si
ba2s1k
bas6sak
bas4san
bassi4
bassis5
bas4so
bas4st
bass6tr
ba2st
ba7s8u
ba1ta
2ba1tr
bat6ti
bau9la
6bav
ba5z
2b1b
b3ba
b6bak
b4b5arb
b6base
b3be.
b4beb
b4beda
b2bef
b4beg
b6beh
b2bei
bb3eie
bb5eig
b2bek
b6belo
bbel6t3
bbelte4
b4bem
b9bene.
b2beo
b3ber
b4b5erf
b4bes6
b7beska
b6beta
b6beten
b4beti
b6beto
b6betr
b2bev
b8b1h
b3bi
bbi9e8
b4b5inn
b2b1l
bb7len
bb5op
bb5rek
bbu9ra
bb5ut.
bb5ute
b2by5
bby3e
bby1k
b4bø
b6bå
2bc
2b1d
b2dek
b7den
b4dep
1be
be2au
be4bo.
bebo5er.
bebo9k
be4da.
be9dar
be3der
bedi9e8
be4dre
bed5red
bed2s1
bedy9ra
be1då3
2bee
be5ed
be6ef
b4ef
befa5re
be3g
bega9
be4ga.
be4gi.
be4gn
be5go
be4g5re.
be4g5rene.
be4gå.
be6ha.
beha7g
behers7
4behu
behå4r
be6i
be5ke
be2k3i
bek6kel
bekke5r
bek4kes
bek6l
4beks
be4l3ab
bela9ga
bel5eie
bel5eig
bel5ein
be4lek
beli9na
beli9v
belle5sa
bel5let
bel5læ
be2l1o
bel5s4p
bel7s4t
bel4tag
bel4te5s
bel4t3ø
bel3u
bel5v
belæ5re
belå7ne
be4na
be5nat
be3ne
4bened
be4nest
ben5gu
be5ni
ben5s4i
ben5skj
ben5sp
ben5te
2bep
b4er
4berai
be7ras
ber5d
be4rep
8berest
bere5te
ber4ga
ber4g5ende
ber5ges
berg3j
berg3l
berg3o
ber4g3å
be5rib
beri5ke
be7ris
ber6kl
ber5na
ber5ne
be1ro
be4ro.
bero9a
berri6
ber5te
ber5ti
be1ru
beru9sa
berø5v
b4e1s2
5bes.
be4se.
be5s4i
4besik
6besj
bes5ke
bes6k5n
be3sn
bes7ne
4be3so
beso9v
be5sp
bes3s
bes6s7a6
bes6sel
bes7si
bes7tens
bes6tes
be5stes.
be6så
3b4et
5bet.
be4tab
be3te
4betei
be7tes
beto5ne
be6trar
be6tre.
be4t3ri
4betu
be4ty.
beva5re
be6ve.
bevi5se.
be9vo
bev9r
6beå
beån9
7bé
2b5f
6bg
2bh
bhu1
1b4i
bi5ak
bi6bla
bi5ce
bi1d
bi5dee
bi8dé
bid6r
bidu8
bi5el
bi6ele
bi5erv
4bifa
bi5g
bi3ka
bik1k
bik6ki
bi5k4l
4bi7kr
bi6la.
bi4las
bi4lau
bi3let
bilet5r
bi4lin
bil3j
bil5la
billa8ga
bil5leg
bil5m6
bil1o
6bi5m
bi4nans
bingo5
bin4gol
bi7no
4b5int
bio7
bi3o8m3s4
4bip
bi4ri5
bi7ris.
bir4ken
bi1ro
bis2a
bi3se
b5ish
bis6hi
bis7ke
bi5s4la
8bisn
bi4sp
bis4p5i
bis5se
bi1st
bi5s6ta
bis4til
bis5tru
bi3s4v
bi6ta.
bi4te.
bi5tes
bi8ti.
bi4tre
bi6tri
bjar3
bjek4t5o
bjø6r
2b1k4
b5kh
bl2
1b2lad
blad3a
bla6f3
bla8ga
blak5r
bla5me
blan9da
b4lank
blan5ke
b4lant
b1lar
b8larar
b3lat
bla4u
b4lef
bleie5
blei5er
b4lek
ble4k3a
ble5kes
ble4mo
b3ler
ble7r6a
b6lesa
blesse9ne
b4lest
2blet
bli9ke
bli5ma
bli5me
blings6i
blis3s
b5lj
blja4
blo6dr
1blok
blom5m
b6lu
blues3
blu9sa
bly7gl
blæ5re.
blå5n
blå3r
blå7sa
blå5se.
2b1m
6bn
b3ne.
b3ner
b7nes.
b7ni
b2o
boa5s4
bobba6ne.
bob5by.
bob9bye
bo2bl
bob7la
bobs4
bo3de
bo6din
bo6d7r
bo2dø
4boef
1boen
bo2er
bo4et.
2bo3f6
bo4gel
bogn7
bog1s
2boh
2boj
3bok.
bo2ka
bo6kel
bo4k3et
bok1i
bok1k
bo6kop
bo6k5ri
5bok1s
boksi8da
boks4p
bo2ku
bok3ve
b4ol
bol5eie
bo7li
boli7n
bo7lo.
bo5loi
bo4l5o4r
bol5s4p
bolst6
1bomb
bom4bel
bom5m
bo6mo
bom1s4
bo5nap
bon5ato
4bonn
bon5ne
bons4
bo5nus
boo6
boom1
bo1p4
bo1ra
bo4ra.
bo6re.
bo7rel
bo3ren
bo3ret
bo4rete
bo6ri.
bo3ro
bor6t7ef
bor6tei
bor4tes
bor6t7et
bor4ti
bort5s6
b4o1s
bose8te.
3boska
bo2sl
bos5se
bo4sto
1bot
bo4ta.
bo4tak
bo4tal
bo6te.
2bo7to
4bot6r
4bot4v
bou3c
4bo1v
bow4e
bo6y
4bp
b7pl
br8
1b4ra
bra5ka
brak5s
bra5se
bred5sp
brei5e
brei3s
bret7te
b6rev
brevi9er.
bre4vin
bri5a
b4rio
b2ro
bro9ar
bro1s4
3b4ru
bru5ke
bruk4s3
bru4na
bru7na.
bru5nes
bru5pl
bru7ren
bru5sa
brus4l
1bry
bryn4s
b4rø
brø5de
bråe6
brå9ne
brå5te.
6b1s
bs4e
b5s6e6a5m4
b4s5el
b5s6i
bsk4
b4sli
b2sm
b2s1of
bs2t6
b6st7f
b7s6v
bså5
6b5t
b7t6s
1b2u
bu4ar
4bub
bu3da
bud5d6h
bu3de
4bu3em
bu4en.
bu9ene
bu4er.
bue5s
bu1i
bu6is
6buki
buk3l
bu5la
bu4le.
bul3le
bun7de
bund4s3
bun8ge.
bunk3r
bunnla8ga
bunn3s
2bu3o
bu1p
bu6ra.
bu4re.
4bu3ro
bu3ru
bus6e
bu4se.
bus4h5e
busk7ø
bus6sek
bus4sel
bus6sent
bus6set
busse6te.
bus6sj
bus4sn
bus4sp
bus4st
buss3v
bu1st
4bustr
4busy
bu1ta
bu4tal
bu7tem
b5utg
4butst
bu2tu
bu1tø
4buv
6buø
2b1v
4b5w
1by
bya2
by5al
by9are
by7dep
by4en.
by7ene
by5ens
by2er
by3ers
by4ge.
byg3l
3byi
by1lo
4bylø
by5n
by1re
by6re.
by1s
5bys.
4byse
6bysi
6bysp
byst4
by4ste
4bysv
by5tar
by4te.
by1tr
2byv
bæ5rar
bæ6rar.
bæ4re.
bæ5ren
bæ5rer.
bæ5rere
bæ5res.
bæ5ret.
bæ3ri
bæ4r5is
bæ3ru
1b4ø
bø4e
bø7ens
bøf3
bø4kes
bø6la.
bø6le.
bø2n
bøne5
bøn6nes
bøn7o
bø6re.
bør4s5k
bør4sp
børs3t
børs8ta.
børs3v
bø5ta
bø1v
bøy7ar
bøye5
bøy4ene
bøy4es
bøy4et
1b4å
bå4de
bå9des
bå6e
bå7ene
bå4la
bå1re
bå6reg
bå4rep
bå4s3te
bå6s7ti
bå6t5j
bå6to
båt5r
1c4a
cab4
ca4e
ca5le
ca5me
ca5mo
ca4pe.
cap1r
ca6pris
ca3ra
car5n
ca5ro
car4te.
ca2sa3
ca6set
cash5
ca5s4til
cas5to
ca1t
cath5
ca4to.
6cb
4cc
c1ci
c2d
cde6
cebo9
ce3d
ce1i
1cel
ce5le
cel4les
cel4lev
3cen.
ce4ned
ce4nee
ce4nem
ce4ne5s4
ce5nes.
ce4net
ce4nev
5cens
cen4ti9m
cen6to
ce5o4
1cer
cerba6ne.
ce3re
ce1ro5
cer3t
6ceru
cest3o
2ch.
cha5le
3cham4
cha7ne
cha5t
2chb
4chei
chel5s
che7te
chi4li
4ch3h
2chm
4chn
ch5ne
chom4
cho5s6
2chp
8chs
6cht
ch1v
ci1c
3cid
ci2e
cie8n
cie2s5
cil5l
ci3ne
ci5ta
2c6k
ck5ar.
ck5art
ck1en
ck3er.
ck4ere
ck5e4t3
ck5et.
cke8y5
ck1i
ck1k
ck1o2
ck7r
ck5s2
cku6
ckup3
ck9ut
c2l
clai4r5
cly4
c1m
cmini4
coa6
coat5
co6bid
1co4c
2cod
6cof
6cog
co4la.
co4lab
co4lak
co4la5r
co2m
co5ma
com5t
co6n5os
con5s
con7t
co2o
co7pa
2cor
co3r6a
co1re
co4so
4cost
co4ver
c1pr
cr8
cras4h
crack4
cre2e
creen7
cros2
5cru
4c4s
4c1t
c6ta
cty5
1cu
4cu.
cu5la
cu5le
cu5lu
cup1l
cu6po
cup1r
cup7s
cu4på
2cur
cures4
cu6t
cy2a
cy6p7
cys3
c6z
cæ5
1da
4daa
4daber
8dabo
d5abs
6d5adel
d4adg
dadø4
dadør5
4daef
2daf
5dagb
da4gev
4dagj
dag7l
da6go.
da4g1r
da6gun
4dagå
4dahe
5dahl
da1i
2daka
4dako
4dakr
dak4se.
4daktig
da5kv
7d6al5j
da1la
da8la.
da4las
6dalau
dalbu8er
4d5ald
da4les
dal6so
da1lu
da4ma.
da4man
da3mas
da4me.
da3men
6d5ameri
dame3s
dame5t6
da3mo
dam7pe
5dan.
6danal
d8ane
9dani
2d1anl
3dann
dan5neb
4danno
7dano
d4ans.
dan3sa
dan4sel
dan9s8kan
4dansv
9dant.
9danti
8dany
2da3o
2dap
da3pe
d3app
3dar.
5dara
2darb
dard3s4
4darea
da4res
d5arn
da2ro
dar5os.
dar5s6
dar4ta.
dar6va.
dar8ve.
4dasei
2dash
6dasi
4dasjef
da4sk
da9sko
6dastr
6dasu
data5
4da4tal
data6le.
datali8na
da4tek
7d6ato
da3toa
4da5tr
dats6j
d6aud
daud7s8
dau5go
2daut
2dav
d5avb
d1avl
d3av5s
4daø
2d1b2
dba8le.
dba4ne.
dbe8ta.
dbe6te.
dbling7
dbo6en.
d6byf
4d1c
6d1d
d2dad
ddag4
d4dak
d4d5arm
dd3eie
d2dek
dde4lap
dde4l5o
ddel5sv
d4demi
dder5s
d4desu
ddie8
d7dom
d4d1re
dd5run
ddsa4
dd4sala
dd4skap
dds5tab
dd3s4te
dds5tr
d2dyb
ddø2
ddør3
d4d5øy
dd1år
1de
2dea
deak3
de2al
de7b
6debar
4debas
3debat
2debe
4debl
2debo
5debon.
2debr
3debut
2deby
4debø
de1c
5ded.
2deda
6d7edd
7dede.
4dedek
4dedel
4dedia
2ded4r
2dedy
2dee
5dee.
de7er
2def
d5eff
d5eft
2deg
6d6e5ge
5degg
de3gl
2deh
5dehavs
2dei
dei4d
dei4ene
3deig.
dei8ge.
5deigen
dei4g5r
5deik
d2e1in
3deir
de5is.
de3ist
7de7it
2dej
8deka
2deke
2deki
2dekj
5dekk
dekk3a
dek4kan
dek4kel
de6k6kv
dek2l
6dekly
5dekni
de5ko
4dekod
4dekon
4dekos
2de5k6r
dek6st
deks7ti
deks6tr
5dekt
2deku
4dekv
4dekø
4dekå
d4el.
6delad
6delage
de6lans
4delau
4deled
de4lef
4delei
del5ei4d
del5eie
4de4lek
de5lele
4d5elem
de4lest
6d3e4lev
4delid
6delinj
del5int
4delis
4deliv
del4lap
del6lei
del4lek
del6lerf
del6lig
d4els
del4s5at
del3se
delses7
del4si
del4spo
d4elt
del6tala
del3te
del7tr
6deluk
del5ve
4dely
4delæ
2delø
delø6pa.
6deløy
2delå
2de5ma
d3emb
2deme
demie4
4demj
dem8na.
de4mo.
de4mog
5demok
4demol
demo5no
5demos
dem5pe
3demr
5dems
4demu
2demø
2demå
d2en.
4dena
de7nak
6d5en6den.
de5neb
4dened
6denel
4denem
4denet
4denev
6d5engen.
4deni
4deno
de4nom
d2ens
den4sin
den4s3t8
den6t5ant
4dentif
4dentit
dent3o
den4tr
dent5s8
den6t5u6
den6tå
4denu
2denæ
2denø
de2ob
de4og
2deol
4deopp
4de3or
de4ove
4depak
4depap
2depe
4depi
4depl
6depu
d2er
der8am
de6rant
de4rare
de4rark
5de7rast
dera5te
der3av
der5d
4derea
4dered
de4r5edd
de4ref
4dereg
4derep
6deresi
der5est
8derest.
6dereste
4derett
de4rif
de4ril
5derin
de4rinæ
der5k
der5ne
de5rob
4derog
4deros
de5rose
dero8se.
6de7rot
dero4v
der5s6n
der4sp
der3t
der5un
de5rup
6derus
der3v
4derør
2derå
de1s
3d6es.
2desa
4desc
2dese
de5seg
des5ers
4desho
de8s9hop
desi4s5t
2desj
2desk
9desk.
5deske
4des4le
2deso
2desp
7despl
6de5s6pr
d4es2t
5dest.
5deste.
des6tem
de5sti
4destj
4desto
4destrå
4destu
6desty
de4s3tå
6desup
des6v
2desy
deså7
d2et.
2deta
deta8ka.
de3te
4detea
6deteg
6detekk
4detel
4deten
4detep
detes7
2deti
2detj
4deto
4det6r
2detu
4dety
4detø
6detå
2deu
d1eur
5deus
2dev
deva8ne.
devi9er.
3devik
d7ev8n
de5vu
2dey
4deø
2deå
2d1f
dfø6rarar
2d1g4
d4gel
d5gi
dgi6n
dgjø6re7n6h
d3go
2d1h
dhav4s
dheim2s5
dhu9ga
dhø4r
1di
di6ak
di5alg
dia5li
di1ar
dia3re
dia1s
dia7sp
dias6t
diats4
2diav
2dib
did5ri
di7ell
di5en.
4di5end
di1er
dies4
3diff
diffe5
3diful
4difø
di8g9and
di4gat
di3ge4s5
dig7g
2digj
dig8la.
dig6le.
4digren
dig5ret
4digru
di2gu
4dih
4dii
2dij
di5ka
di8ka.
di5kem
2dikj
6dikn
2diko
2di1kr
dik7v
2dili
dil4les
di5ma
6dimed
6d5i6mel
4dimes
4dimet
2dimo
4d5imp
4dimå
di5na
2d1ind
di7nen
4d5ingk
din3gr
ding8s5en
ding6s5er
din8g9å
dini4
di4ni.
4d1inn
2dino
2dinv
4dinø
3diog
7diol
dio3na
dio4no
di3ori
dio5tr
2dip
3dipl
4dired
4direg
4d5irs
5dis.
di6sc
di6sed
dis4i
disie5ne
d6isk
dis6kam
di4skj
dis6k7l
di4sk6o
dis5ko.
dis7koe
dis7ku
dis5s
dis1t
dis7tik
di5sv
dis4vi
2disy
di4tal
di7te
4ditek
dit4tet
ditt3r
di9us.
di4va.
4dival
di7van
4divek
div6i
2divu
2diøk
d1ja
d1je.
d1jen
djer5ve
d7jes.
dje9ve
d6jingan
d6jingar
d1jo
dju8la.
5djup
6djupar
d4jø.
2d5k2
dka8ra.
dki6
d5kj
dko2r
dku4le.
4d1l4
d3la
dla4ga
dland7as
dla6te.
dla4v
d4ledi
d2lef
d4lega
d7legar
dle3ge
dlei7er.
d5leka
d2lel
dlem4st
d4lenet
d4leru
dleva8ne.
d5li
dli4f
dli5ke
d5lo
dly8se.
dlø8pa.
d5lå
dlå9re
2d1m
dme6la.
dmo4e
dmors6
dmo8s
dmø4re.
dmå6la.
8d1n
dn6a
dno8de.
1do
2doav
do2b3
4doba
do3be
8do9b8lan
2dobå
do4da
dodø4
dodør5
4doeu
2dof
d3off
d5ofr
dog6med
dog4me5s
2dogr
6do5i
do3ki
4dokine
dok6kan
4dokn
do5le
4doled
doli8ne.
4dolinj
6dolis
4dolj
dol5l4
4domes
do5mis
4doml
do4mo
dom7p
2domr
dom8sa
dom8s5e6
dom6s5i
dom4s3k
doms3l
domsla6ga
dom4so
do4mu
do4na.
don5g
4donke
6d7on6kl
don5st
don5t4
2dop
do4pa.
do4pe.
3dopi
d6o1ra
do5ran
2d1ord
dor4da
do1re
dor6gest
d5orie
dorm8
do3ro
5dorp
3dorr
dors6
dors7ke
do1ru
do7rye
5dos.
do4se.
do4set
do1sk
6do7s6l
2doso
4dosp
2dost
do3str
4dotr
2dov
do5va
do5ven
do4ver
dov9n
4doø
2d7p8
5dq
dr4
d1ra.
d5raa
d9rad.
d5rade
1d6rag
dra5gen
dra6kes
3drakt
1dram
5d6rang
3drap.
5drapa
3drape
d3rapp
d1rar
d6rarar
d3rarb
dra6ret
d5rarm
d5rarr
d9ra8sa
9dratt
drau7ma
2dre.
5dreass
2dred
d5rede.
d5reder
dre7d6r
d5reds
9dreg.
9drege.
d3regj
3dreie
drei5en
drei5er.
drei7ern
d5rej
d6reka
d7rekk
3drekt
4drel
d7relig
4drem
d1ren
4drer
d3ret.
d3retn
d6retr
d3rets
drett4
dretts5
5drevet
3drevn
4dria
3d2rif
2d1rig
d2rik
d3rik.
dri8ka.
d3rike
3drikk
drik7s6
d9rikt
5d4ril
2d1rin
dring6
drit7tr
drit5u
dritun8ge.
1d2riv
3dronn
dro6pa.
drop5s
2d1ror
3d4ros
dro8ta.
2d1rov
dro5va
dro3ve
2dru
3druk
d1rul
d1rum
d3rup
6d5rut
2dryk
drykk4
d2rys
d4røm
drø6re.
d7røt
drø3ve
d1råd
drå4de.
3dråp
8ds
d5sa.
d3sabl
ds1ad
ds3a6del
d1sag
dsa9ga
dsak6se.
d1sal
dsa8la.
d4s3alf
d6sall
d9same
ds1a6n
ds5ane
ds1a2r
d2sas
d4satf
dsbø6n
d5se.
dse4d
ds1ef
d2s1ei
ds7eks
ds3ela
dsel4s5a
dse2m
ds3emi
d6s7enda
dsen8de.
d4s3eng
d5sens
ds3e2p
d7ser.
d6serf
ds5erk
d4s5e4sk
ds5e4st
ds3eta
dse4te.
d5setj
ds1ev
d2s1i
d3s2id
d7sida
ds5ident
ds3idr
d7sil
ds5ind
d3sir
ds3i4s
dsi4ve
d4s3jen
d2sjo
ds7jor
ds6ju
ds5kab
d4s3kan
ds3kar
d4skat
d1skj
ds5kjen
d6s5kjøt
ds1ko
d5skot
ds3kro
ds1kv
ds1l
ds5la.
ds5lan
ds6lem
dsli6k
ds6lo.
d9slott.
ds4luk
ds3ma
d6smo
dsmå6la
ds3ne
ds5no
ds1o2
d7somst
d4s5os
d7sot
ds1p
d3spek
d3spel
ds2pi
d9s8py
ds5s4
dst4
ds3tak
d4s3tal
d3s8tar
d5s4tat
ds6tau
dss8t
d8s9te.
ds9teik
dste6ma.
d6s5temp
ds5teo
d3s4tig
d3s4tik
d5stilli
ds1tj
d3stor
d3stri
dstu8na
d5stund
ds3tv
dsty8e
ds3tyv
ds1u2
dsure6
d5s6us
d6s7usk
ds1v
dsva8ne.
d3s4vet
dsvi6ka.
d5syk
d3syn
dsy6na
ds1yt
d2s1ø
d6sør
ds1å6
4d1t
d3t4a
dta6la.
dta4le.
dta4s
d3tem
dte4ma.
dt4eng
dterle7
dte4se.
d5t4et
d3ti
dt6j
d7to
d5t4rag
d6troc
d5t4rø
d6t1s2
d3t2va
dtø8
dt6øk
dtørs3
dtå4
1du
dub5b
dub5l
du1c
du9ene
du9ens
due5s
4dufo
3dug
4dugu
duit6
du6ka.
dul5l
4duly
dums2
du4na.
dun7de
4d5uni
dun5s6
dun7sta
7duo
d3upk
3dur
du6ra.
du6re.
du6rei
dur8ta
du1s
du5s4a
du9sem
du5s2i
du2sk
du2sl
du2sp
duss4
dust4
du2sv
2d1ut
du6va.
du4ve.
2d1v
dva6la.
dva6lel
dva4ne.
dve6s
dve6va
dve8ve.
d7vo
dvo8r
2d1w
1dy
dy9a
2dyba
2dyf
dy5ke.
4dykl
4dykø
2dyl
dy4na.
dy4ne.
4dynk
dynk6s5
dy3pes
dy2p3r
dy4ra.
dy5reba
dyrle8ge.
dyr5s4
dy2r5u
dyr5ø
7dys.
dy8sa
4dyse
dy6se.
dys7s
dyst7r
dy2t
d5z
8dz.
1dæ
dærs4
1dø
4dø.
død2s1
dø3gr
2døk
d5økn
dø4ma
dø4pe.
dø4pen
d2ør
dør3i
2døs
d6øs.
dø2st3
døt3
dø9va
dø3vel
dø1vi
6døvl
døv8le.
2døy.
døya8
døy8g
4d9øys
1dåd
dåd6s5
då8na.
1dåp
då8ra.
då5ri
d3ås.
då8sa.
då7sem
d7åt.
2ea
e1a2b
e1ad
ea2d1i
eadli5
e1af
ea2gu
e1a2k
e4akr
6eakt
eak6se.
e1al.
e5alle
eal8le.
ea4lov
e3alte
ea2lø
ea4m1
e3aman
e5amn
e1an
e2an.
ea4ne.
e6a5net
e4ani
ean7n
ea4nor
e6ans.
ean3sl
e1ap
ea4pe
e1ar
ea2re
ea5rer
ea5ret
ea5r4i
ear6ka.
ear8ma.
ear4ta.
ea2s1i
e3asp
e1ass
ea7ta
e5a4tel
eate6ren
ea4t3et
eat8h
eat6le
e8ato
ea5tri
e1att
e1au
eau6ga
eau6ge.
eau8ra.
eau6re
eau5s
eau8sa
eau8se.
e1av
eav8la
eav8le.
2e1b2
eba3d
eba4ne.
eb3be
eb4be.
ebe4d3e6
ebei7er.
eben6s5k
ebers6
ebesku5
ebet5s
eb3h
e5b6lo
eblæ5
ebob3
ebo4da
ebo5ers.
ebo6kr
ebo6la
eb5s
ebu4e5re
ebu5ern
ebu6et
eby4ta
ebø6n
2ec
e4ca
ec4c
e1ce
e5cha
e3com
e2dad
ed5ad.
e5d4ag
edag4s5
e2dar
ed3ark
ed3arv
ed7dela
ed4dyr
e3de.
ed5e6ge
ed5eg4n
ed3eie
e4deks
ede8le.
e4denf
e8d5eng
eden5t
e6depr
ede4ra
e4derø
e4desk
ede4sl
ede4sm
e4desn
ede4s5p
ede4ta
e6d5ett
e8dé
e5d6ia
edi6a5ne
edi4ene
edi6gj
ed4is
edi3si
edi4s5k
e7div
edle6ge.
ed8ob
edok8se.
e4dol
ed1op
ed1ov
e1dr
ed2ra
ed3reg
e5drev.
ed3rom
e6d5ryg
ed7ski
ed3skr
ed3s4la
ed2sm
ed5ta
ed3te
edt6r
edu8a
ed7va
edvi6s
e3dyk
ed5ynk
edyr6ke.
edæ4
e3d6ø1r
e3e2
eea7
ee3b
e2ed
ee3di
eeg4ga
eeg6n
ee5gå
eei4d
eei7ni
eek1e
eek4te
ee3la
e5e4li
eem6na
ee4n
e5enb
een3in
een6k
een5t
e3epl
ee8ra
eer3en
ee3ri
e4er3l
eer4me.
e6e5sh
ees8ka
ees6ke.
e3e6t
eev4ne.
e1f
4efa
efal6s7
e4fana
ef3ank
e4fark
efar6s5
ef7ea
ef5ef
ef3fe
3effek
ef3fo
4efi
e4f3id
e5fig
e5f4ilm
efi7ren
efisken8
4e3fj
2efl
efle6ge.
eflå3
e2fn
efo8bi.
efo4no
8efr
ef2sj
ef2sk
ef2sp
ef6str
e8ft
ef2ta
efta5r
eft5ei
ef5ter
eftle8ge.
eft1s4
6efu
efyrs5
e3fæ
4efø
efø5le
eføy9
2ega
e3gaf
e6gala
e7gam
ega4ve.
egde8l
eg7des
e5gedo
egei9e
ege4let
e2gem
e3geme
egen5s
3e4gensk
e7geom
e2ges2
ege5sp
eg9gen
egg3l
eg8g9ut
egi3an
egie2
e4giko
egis4p
e3g6lad
e3g4led
eg7lesa
e5g4lit
eg7ly
e5g6lø
6egm
e9g8nag
eg4nem
eg6no
e7gnå
4ego
e4go.
7egoi
eg2r
egrans5
e7g8rø
egs4am
egs4ki
egs4ta
e1gø
egøy6e5ne
4egå
egå4va
egå4ve.
e1h
ehea4
ehei9e
eh5er.
e4h5ere
eh7ern
eher4s
ehog5
ehov2
ehy6re.
ehø8va
e6hå.
2e8ia
e9iakt
ei9a4n
ei7ar.
ei4c
e8id.
ei3d8ar
e3idea
e3ideo
ei9der
ei5det
5eidf
5eidg
e6i2do
e1idr
ei3d4u
ei7e
eie5d
ei8eg
eie2n
ei9en.
eier3a
ei4ert
ei6es
ei1fl
8eig.
ei3ga
eig6e
ei6gev
ei5gi
ei6gra
ei6gu
4eii
ei5kaa
ei3ke.
ei6kee
ei6keh
ei4kel
ei6keri
ei4ket
ei1kr
eiks3a
eik6se
eik4so
4eil
ei9led
eil5egg
e3illu
ei3lo.
ei9loa
eil5op
ei5los
eil5s6
4eim
ei7ma.
e5imag
ei4m5a6l
ei4med
ei6mei
ei7men
ei4me5s
ei4met
eim9ett
ei6mo
8e1imp
ei4n3al
ei4nans
ein5ant
ei7nare
ein1d
4e3indu
ei5ned
ei7nel
ein9f
einga6
ein3gr
e4ini
6ei6nit
ein3k4
e5inkar
4e1inn
ei4nom
ei4nov
einsi9d
ein4s3l
eins6o
e4inspi
ein7sto
ei2n1u4
ei3num
6einv
ei2n3ø
ei5or
e4ip
ei9pa
ei3pe
eip5s
2eir
eir9ak
ei7ren
ei3ri
eir5s
2eis
ei5sar
e4ise
ei3se.
eise5i
ei3sen
eiseri9e8
ei3s4ha
ei4sil
e3isk.
e3iske
ei6s3kj
eis3ko
ei3s4pe
ei4spi
ei4tek
ei4tera
ei4tere
ei2to
eit7ta
ei6t7ut
ei3tve
ei6t7ø
ei4vak
eiva9r
ei9ven
ei3vi
eiv5s4
e1j
ejo8en.
eju6la
4e1ka
ekali7
ekalie6
ekam6s5
eka6ra.
e5kavr
ek3eie
e4kero
e4kes
ek5e4ta
e6key
e5k6hov
e1ki
e4ki.
4e1kj
2ekk
ekke7le
ekk9ist
ek1kj
ek4kjø
ekk3l
ek5kok
ekko5v
ek6ku
ek4ky
e1kl
e8klane
ek6leg
e6klen
ek5let
e3klu
e5klæ
ek2lø
4ekn
ek9na.
e3knek
ekne7s
ekni7p
ek3no
e3k4nok
e1knu
e5knø
e1k2o
e4ko.
eko7le
ekords8
eko6te.
e4kov
2e1kr
e3k2ra
e3k4red
e7kref
e3kren
e4k5ret.
e5krets
e5k4rev
e3k2ri
e3kro
ek4ry
e3k4rå
ek5råd
ek3s4ak
ek4sal
3eksam
ek3sel
3eksem
ek4sig
eks1k
ek4ska
1eksp
eks5pe
ek4sta
ek7s6tel
ek3sti
ek4stil
ekst5o
ekst3å
ek4sæ
ek6t7arm
ekt3av
ek3tef
5ek3tep
ek5tes
ek6test
ek4tid
ekti5m
ek5tiv
4ekto
ektori6a
ek4t3ra
e1ku
eku4le.
e1k2v
ek4val
ek6var.
6ekve
e4k5ve4d
e4k5vik
ek4vin
ek6vis
3ekviv
6e5kw
e5ky
eky6te.
e3kæ
e1kø
e1kå
ekå6pa
2e1la
ela4ga
el3agg
e2l1ak
e5lake
elak8se.
el7akt
el1al
e8lame
el3anl
e6l5arg
e4larr
el7arti
e5las.
e5lase
ela4te.
el5ato
el5avl
el3avs
elbo8da
el4ch
el5do
eld4rer
eld5sle
4eled
e4ledi
e4ledr
e3lee
eleg5d
ele7ger
eleg8na
e7leir
e7leis
e5leke
e2lel
e2lem
e5lem.
e5lemat
5elemen
e5lemet
e3lemm
e3lemp
4elen
ele9na
e4l5enh
elens3
e4lentu
e5lepa
2e3ler
ele8ra.
e7leret
e6l7erg
ele3sk
e6lesku
e4leta
e4lete
5e8lev.
ele4vak
6e5levn
el5fi
el9ga.
el5gele
el5gi
elg3s8
2eli
e9lie
eli5e6rer
e4lif
e4li5g4r
e4l3ind
elin5es
e4linsp
eli6o5s
eli8ta.
eli4tet
6e5litt
eli6v7en
el1j
elk2
el6k5al
el4ke5s
el4kete
el3kn
el5la.
el5l6ar
el4led
el4leg
ell5eie
el5ler
el3le4s
el6lete
elli7ga.
el4lisj
ell7sa
ell5sk
ell5s4l
ell5sp
ell5sv
el5l4ur
el4læ
el5m4o
el5mu
el5n
2e1lo
elo6ka.
e2lom
e3lomm
el3omn
el3oms
el1op
e2l1or
e3lort
el3ost
el4ot
elo7vers.
e4l5ovn
el4pet
el5ph
elro4s
el4sei
els5eie
el3sen
el3se6s3
el3si
el4sje
el4skal
7elskand
els5kare
els1l
el6sno
el4spe
el3spr
els4ten
el4sti
el4stj
el2sø
els5øk
el5s6åpe
elta8le.
el5te.
el6teg
el4tero
el4t5ett
el4t3op
el4tro
elt5rop
el2tu
e3lua
e1lu2e
e4lu4he
e3luk
e7lum
el3ung
elun6ge.
e7lup
elu8pe.
e1lur
e7lus
el3utr
elv3an
el4ve3d
el4vei
el6vere
elv1r
5elvs.
elvæ6re.
4e1ly
ely8et.
el5ynd
2elæ
elæ5res
el9ærv
e6l5æt
2elø
e4l3ø4r
el3øy.
el5øya
el5øyd
e6l3øyn
2e1lå
el1år
e5låt
4em.
e2mad
emafo5
ema4ge.
e4magr
e2mah
ema4ke.
e4mako
em5akti
e4maku
ema6le.
5e4malj
e4mam
e4mana
ema4ni.
e6manu
e4mare
em7ar8m
e4masi
e6masku
e4mata
ema3uk
ema5ve
5emball
3embed
embe6r5
3embet
6emd
8eme
emei9e
eme4li
e4mend
eme5tri
eme6trisk
em5e4v
e4mib
emi5ert
e4mig
4emin
emi5ni
emini6st
e4minor
e6mir
emi9sa
em7je
e5mju
em5le
emle6s
em5me.
em5men
em8mi.
8emnd
em4ne.
em4ned
em4nem
6emni
emo5nol
em1op
e2m3o4v
em4ped
em6peri
em2p3l
emp9lane.
em6pli
empo3
em4pol
em4pos
em4ses
emse8te.
em4s5ju
em4s1l
em2sn
em4sor
em1st8
ems4te
ems3u
emta8la
em4til
e3mug
e2muk
e5my
emy4k
6emø
emø8r
e5møy
emå4la
emå9lan
emål4s
em1å8r
2ena
en1ak
en3ald
ena5li
en3all
en5and
e5nane
e6n7ang
e4n3ant
e5nar.
en8are
e4narr
en3ass
enat6s5p
ena2v
en3avi
4enb
enbe9na
en4d5and
en4dek
en3del
endelø7se
en5demi
en3der
en4desl
end5l
1endr
en4d3ro
end3st
en7dø
endø4r
endør5e
en5egg
eneg8ga
en3eie
en5eks
e3nekt
4enem
2enen
en5eng
3energ
e4nesk
4enev
ene7ven
eng6a
en7gar
en4gem
en4geri
enge6r5u
en4gle
eng4les
eng4r
eng3s4e
eng5so
eng5sp
engs4ti
en4gut
en4g5å
4enhj
e4ni.
e4nierk
e2nif
e5nir
en4kera
en4keri
2enna
en9nal
2enne
en4nem
ennes6t
enne4s5v
enn2i
enn2o
enn4sj
enn5sta
enn7ø
2eno
en3ok
en3og
en3om.
en1op
e6n5ord
2enp
en4pås
en4rem
en5sab
ens5af
en6s7a6ker
en4sek
en4seli
5ensemb
en4ses4
ense3u
en3si
ensi8de.
ensi5ert
en4sim
ensle7g
ens6lev
en7s6opt
%en7so9v
en1st
en6s7tal
ens4ter
ens4ti
ens7und
ens4ve
ensvi6
en2sø
ens3øk
ens7å
en5ta.
en4tap
en5te.
en4tec
en4teg
en4tel
en3ti
en5tie
en5tig
en5tik
en9tima
en7timen
en4to4r
ent5ori
ent5rab
en4tre
ent5ren
en4t5rol
entropi5
en4t3rå
en6tul
entun6ge.
3entus
2enu
e2n7ul
e4n5ur
2en3v
4enw
e4ny.
e2nyb
e6nyr
e2nys
e4nyta
4e7næ
enæ8m
enø4k
e2n3øv
en5øyd
4enå
en1ås
en6ås.
e3o6
eo3a
e6obe
eo2bl
eo5d
eod8de.
e1og1
eo7gr
e2o1i
e2ok
e3oks
e2ol
e4o7lo
eom1s4
eon8de.
eo5ne
e7onk
eon4kl
e3ont
eo2p
eo3pa
eo5pl
eopo3
eopp5r
eo3pr
eor4da
eo9re
e2ori
eo4rid
eori5e6
eo4rik
eo4ris
eo1ro
eo1s
eos6l
e2o1u
2e1p
epa3t
e6peno
epe6p
eper5r
e3pes
epe4st
e4peta
e6peu
3epid
epi6ka.
epi7kr
3episo
ep2l
e8plen
ep5lene
ep5ler
eple9s6
3eplet
epo6et
3epoke
epp2s
ep6sem
ep4ses4
ep6s5lu
eps1t
ep2su
e3p2sy
ep6tin
ept6r
2e1ra
e4r3abb
era8da.
e4rael
e2raf
er3aft
e4ra4g
e2r1ak
e3rake
era5kl
eral3u
e4rama
era6na.
e5rande.
e5ra7ne
er7anli
era4no
er5ape.
er5aper
er5a4pin
er3apo
er5appe
e5rar.
e4rarg
e5rasane
e5rasar
e4rasje
e4rask
e6raso
e4r3ass
er6ast
e4ratek
era7tor
e4ratr
er5att
e2rau
er5auk
erau9ken
erau8s
er3av.
er3avh
er5avl
e3ravn
er3avr
er3avs
4erb
erbi9ti
erbo8da
erbo8de.
er8byl
erd2e
er4ded
erden8s
er4dis
er1dr
erd4ra
erd8re
erd4skj
erds3t
erd4sto
erdsto8ga
er3d4v
e1re
er3eff
er3eft
er5e4gen
er3eid
er3eie
ere6ka
ere6ke.
e4r3eks
e6r5ekte
e4r3e4le
ere4lit
e6relli
e4r3els
e9rem.
e5remm
er3emn
er5enden
e4r3eng
e4r5enh
e3re4o7
er8er.
e4r3erf
e5reri
er3ess
ere4t
e5ret.
e4r3eta
eret6h
ere5to
e7rets
6erett
eretts5
e4r3e4va
e4r5e4ve
e4r3evn
erev6ne.
e8ré
5erfari
6erfi
4erfr
2erg
erg5elv
ergi3f
er6gli
er4go.
erg5ret
erg5sko
erg5sp
2erh
erhø6re.
e1ri
e4riad
e4riak
erib3b
eri3bl
e4rice
e2rid
e5rid.
e5ridn
eri4kat
e6rikn
4eril
e7ri6ma.
er3ind
e3ring
6eringar
ering6si
er3inn
er3ins
er3int
e5riori
e5ris.
e4risa
eri3se
e4riso
e6risp
e5rist.
e7rista
e5riste
eri5stil
e4ri5s6to
eri5sø
e4rite
e4rito
er7ivo
er7jes.
4erka
8erke
erkeri6e
er4kesa
er4kese
er4kete
er6k5ett
3erklæ
6erkn
4er5k4o
4erkr
erland7as
erle6ge.
erle7s8t
er3me
ermo8de.
erm1s
ermå6la.
2ern
er4nad
er4ned
er5nede
er6nee
er4nero
er4nest
er2no
er3nob
2ero
e3roa
er3obl
5ero4b7r
e1roe
er3off
e1rog
er5oks
e1rol
er3oly
e1rom
er5omk
ero5mo
e1ron
er5ond
erono5
er1op
e5rop.
e7ro6pa
e5ropen
er1o2r
e5ror.
e3rore
e7ro4sa
3erosj
er3osl
ero4ta
er1ov
2erp
2err
er3ra
er4rae
er4rel
errie9n
6ersa
ersa8ka
ers6al
er3sep
6ersj
er1sk
er3ska
ers4ka.
er8skaran
er9s6karar
ers5kor
er1sl
ers4la
ers6led
ers4mi
er5sne
6ersp
ers5tens
ers5ter
er7stev
er1su
4ersv
er4sva
ers4ve
er1så
er4s5år
2erta
er4tare
er4te3s4
er5tia
er3tib
erti4e
er5til
erti4mo
er4top
ert5rol
4erts
ert3sa
erty6e
ertå7ren
2eru
e1rua
e5rud3
e1rui
er1u2k
e3rum
e4r3ung
er3uni
e3rup.
er1u8r
erure8
e1rus
er5ut.
e5ruta
e3rute
er5utn
er9uto
e4ruts
er7u6v
ervele8
6ervi
ervs3
ervæ6re.
e1ry4
e2r3ya
erye7ne
er1yr
erys3
e1ræ
e9r4ære
2e1rø
er5økn
e4røko
er1ø4l
e4r5øn
e5r6ønn
erø8ra
e6r5ør6s
er3øya
e4r5øy7e
erøy4n
e4r5øys.
er7øysk
2e1rå
e9rå.
erå4da
erå8de.
erå6e
erå4k
er5åke
er3å4l
e2r1ån
er3å4p
er3å4se
erå6t
er7åta9
e6råv
2es.
e1sa
es5aa
e2sad
esag6
es4al
esa6la.
esa9met
e4s3ant
es5arab
es5arv
esbi9e
2ese
es5ege
es3ei4d
es5eie.
es3eig
esei8ge.
e3sek
e4seku
esel5s4
e3s2en
e5ser.
e5sere
e5seri
e4s3erk
ese5s2
e3sest
e4sesv
ese5tas
ese4te.
e5setj
e9sets
e4seu
e4sha
es6har
esh9ar.
es4h5er
e4shi
e1sho
e7s8hop
esi6ar
esi5ert
e4sil
e5sili
es3ill
e4s3ins
esi6v
esi3st
es3jor
e5skab
es6ked
es4kee
es4ker
8eskil
e4sking
eskinns5
e1skj
e8s9kjer.
es4kjæ
e6skjøn
es5k4n
e5sko.
es7koa
e3skot
e1skr
e1sku
esku5et
es3kvi
e5sky
e6skyr
e1skø
e7skå
eskå7r
e1sla
es4lek
es4let
es7let.
es7lets
es4lit
e4s5lok
es4løk
es4løv
es4make
e7s4mett
es9na.
es4ner
es2no
es4nu
es2ny
esnæ5re
4e1so
eso4b
e2s3od
e2s1of
es3oks
e2som
e3somm
e4s3ori
e1s2p
espa9ra
es3pas
es5pe.
e4s4ped
es5perm
es3pl
es4p5le
es3pol
e3spor
es3pun
es4sed
es4see
es4seg
esse7i
es6sendi
es4s5enk
es4ses
es4sete
ess5e4va
es4s3ja
es4sje
es4skr
ess4let
ess3om
es4sos
es4spa
ess5tilt
es4stol
ess5tor
ess9tua
ess5tue
esstu8en.
4essu
es2s1v
es7så
e7stad
es5tae
es7takt
es9tala
e8stane
e5stans
es5tant
es3tap
e5start
e3stat
es5tato
e4s3tau
e7stav.
est5avs
e6s5te.
es4teg
est5eie
est5eig
es4tek
es4tel
e5stell
es5tels
e4stema
e6steme
e4stemo
es5temp
6esten
e7steng
es5tenk
e8s7ter.
e5s6terk
esterne8
este3s4
es4test
es4tien
e3stif
es4tig
e3stik
es4tikk
5e6s5tima
es4tis
e4stiv
e1stj
es3t6on
e4stog
e3stok
e3s4tol
es6tone
est5ord
est5ori
es5trak
est5rene
est5rer
est9ré
es5trib
e5stryk
e3strå
e1stu
e5stud
es5tus
8estå
estå5ren
estå6s
est7åse
e1su
es5ut
esva5re
e5s4vek
es5vig
e5svikt
es3vis
2e3sy
esy4na
e4s5yt
es5øvi
es7øye
e1ta
4eta.
e4tae
e2taf
etafo7
e3tak
e6tako
e3tal
eta3la
eta4la.
et5ald
eta5le
4e5tall
etal6list
etall5s6
etal4s7
et3amb
e6tand
eta4nen
et4ap
e9tapa
e5tape
3etappe
et8ar.
et8are
et5art
5e6tasjes
1e2tat
4e5tati
e5tato
e3tatt
et5aun
e8tax
et1c
2ete
e4teie
e4teka
ete4ma.
e5teran
ete5ru
etes5i
e4tesl
et8et
e5tet.
e7tets
4eté
4eth
2eti
e3tit
2e1tj
e7tjer
et3jø
6etl
et5m
2etn
et6nev
etning4
etnings7
2e1to
eto4er
et5oppd
et3ord
e4tot
2e1tr
e5t4rad
e7t6rak
8etre
e5tree
e5tref
e4t3ris
e9tru.
et5rum
ets1
et9sar.
et4sku
etsku8le.
ets7l
etsla8ga
etsnæ4
et2sø
et4tak
et4tal
etta6le.
ett5alt
et4tank
et8tap
et5te.
et6tei
et6telt
et4tenk
et4tenn
ettera4
etter5at
et5t6erf
5etterk
5etterr
ett5esk
2etti
et6tia
ettian8
et4til
et2tj
etto5a
et4tr
ett3re
ett4ski
ett4sti
et3tug
et4tur
ettvi5se
et2ty
2e1tu
5e6tui
etu6na
et3uni
2e3t2v
e4t3va
e5t6vang
2e1ty
4etz
4etæ
etæ3ra
e1tø
e1tå
etå5re
e1u
eu4a
e8uf
eug8la
eu4h
eu4ka.
eu2ke
eu5kem
eu7kr
eu2l
eum2
e3u2n
eun4ge.
eu5nu
e4up5a
e6upk
e2ur
eu6rat
eure4
2euri
e3urn
eur8na
eur6ne.
euro1
3europ
e3urt
e2us
eu4si
eu1ta
e3uts
eut7t
e4u3z
e1v
evad6r
ev5akti
eva4la
evann4s
e4v5anta
e4varar
e4varb
e4v5ark
e6vatf
6eved
eve5d6a
eve5del
6eveg
e5vegg
evei6s5
6evenn
even5s
5eventy
e4veny
e9ver.
e5ves.
e5veta
e5vev.
evi4e
evi5ere
evi5ert
evin4s
evi4se.
evis3t
e2vj
ev2na
evn5a4k
ev7nu
ev7oms
e4vre
e7vri.
ev9rå
ev1s
evs8v
evta8la
evti4
e2v3un
e5vyrk
e2vø
ew3a
ey1
eybal4
e1y2d
ey5k
e1yng
e1yr
eyr6ka
eyr4ke.
e1y2t
e7yti
ey3tr
e3zi
e1zu
e1æ2
eær3
e1ø4
eør6na.
eøy4
eøy9an
eøy7en
e1å6
eåk4
eån8da
eåt8t
é1a
é1b
é1d
édø4r5
é5e8
é1f
é1g
é1h
é1i
é1k
é1l
é1m
é4n5e
é5n6et
é5o
é1p
é1r
é2rj
é1s
ése2
é1t
é1v
éva8la
évo8re.
é5å
è1r
è2red
è2ref
è2rek4
è4rener
è2rep
ère3s2
è4rest
è2rev
è6ves
ê8lan
ê6ra
ê1re
êr7o
êr9sl
1fa
4fabo
fac8
fa1ci
fa3de
fa6de.
6fadm
fa4f
fa2g1a
fa5ger
fage4t
fag5eti
fa2gi
fa2go
fa2gr
6f5agro
fag3sk
fa2g1u
fai5
2fakr
fakse9t
fakta3
fa1ku
5fal
fa1la
fal6kes
fal4k3l
fal6lers
fal5m
fa4lo
fal4sk
4fa5mo
fa4na.
7fan5d
5fane
fanfa5
fang4s
fangst7ev
4fank
2f3anl
fan5s6
fan7tesk
fan5ti
fan3to
fan4try
6fanu
2fap
3far
9f8ar.
fa3ra
fa4ra.
fa4re.
fa4res
far4gel
far4ges
fa4rit
far5n
far6skj
fart2
far4vel
4fary
fa7sa
fa4sel
fa4seru
2fasl
fast3r
fa3tal
fa4te.
fa6t7ers
fa1to
fat2r
fa3t6re
fav5ne
fa1vø
2f1b
fba4ne.
2f1d
1fe
3fe.
2fe1a4
5fea.
fe5a6l
2fec
fe4da
3fede
fe2dr
fe3dra
fe3d4ri
fe7ene
2fef
2fe3g
2fehj
fei5en
fei5er.
feig4de
fei5ge
feil5es
fei4li
9fein.
7feine
fei7ter
8fej
2fek4a
4fekl
2feko
4fekr
fek6tes
fekt5ev
fe5lag
fe5len
fe5li
feli7e6
6felik
felles5
fel7læ
2felo
fel5ok
fel9ta.
fel4tek
fel4ti
fel4tra
fem5ak
fem9b
fem9ne
fe4mo
fem5s
fem4tid
fe2m1ø
5fen.
4fena
fend9r
4feni
5fens
fentleg5
2feo
2fe3p2
5fer.
fe6ral
4feram
fe5ras
fer6at
fer4dam
fer5de
4ferea
4fereg
fe4rek
fer6en
fe7rer.
fer5ers
feri6e
feri8e5ne
7fern
fer2r
fers9kar
fers7ke
2fe1ru
3fes.
2fesi
2fe1sk
fe2st
fes9t6i
fes8t3r
fes9tum
fe6st9ø
4fesy
fe6ta.
4fetap
fe4te.
4fetea
fe5ti
4fetil
2fet6r
fett5j
fett7s6
4fe4ty
2feu
2fev
fe4ven
2feø
fe6øy.
2feå
1fér
2ff
f7fa.
f4fab
f2f3a2g
f4f3ak
ffa7l
f6fann
f4farb
ffar6d
ffa7re
f9fas
f6fat
f8f9au
f2f3av
f2feb
f2fe3d
f2fee
f6feh
f2fem
f6ferdi
ffe4rer
f2fes
f4feti
f4feto
ff5eve
f2fib
f4fice
f2fid
f9fien
f4finn
ff5int
f2fip
ffi5s4
f2fj
ff3la
ffla8ga
ff9leg
ff3li
f2fo
ff4ol
f2f3re
ff1ro
ff5sl
ff5t4
ffu6r
ff5ut
f3fæ
f4fø
2f3g2
2f1h
1fi
fia7l
fia4n
4fiap
fi4as1
fibi6en
fi9cen
fici7
fi7di
fie2
fi1er
fi7e6re
fi4f
fi5fi
fi5fo
fi7fl
f6ig
figh9t
fi7g6r
4fih
fi9ka
fikali7
fikalie6
fi7ken
fik6ka
fik6k5n
fi5ko
fik7sa
4fiku
fi4la.
fi3li
fil6lel
fil6leri
fil4les
fil7leti
fil8m7at
fi1lo
filt6re
fil7tres
fil4tri
4filæ
fin5art
fin5d
fi4ne.
fi5ner
fing3r
6finj
finn5ei
6finnsa
fi4n3o
fi9nor
2fins
fin6sleg
fin6te5s
fi2nu
7fio5
fi2r
fi3ra
fi6ra.
fi9rene
fi5res.
fi3ri
fi5s4a
4fisc
fi6se.
fiser6s
fi8si.
fi2sk
fi6ska
fisk5a6d
fis7kal
fisk5and
fis6kart
fis6k5end
fis4k3l
6fiskol
6fisku
fis5ti
6fistu
fiti6me.
4fitr
fitt5s
fi7ty
fi4ve.
1fj
f1jeg
fjel6lend
f5jen
fjer5ne
fje4sk
fje2t3
f5ju
fjære5
fjæ4res8
2f5k6
f2l2
f5lag.
f6lagg
fla7ke
f4las
2fleg
fle6i
f4lek
f6lel
fle4sl
f4lett
f3lev
fli7ne
flis7t
flit9t8
1flo
flo9ga
flok9s
flo2m3
flo6r5o
flos6kl
f6lu
flue3s
flus8
fl5ut
3fly
fly3s4
f3løn
flø5s
1flå
flå9sa
flå7se
2f1m
fn6
1fo
2fo.
fo9ar
6fobs
2foe
4fof
foi7la
fo8ke.
fo6la.
fol4dr
fo4le.
fo5led
fol6k5v
fol9ler
fol5lese
folke5s6
fol5li
fo4lu
3fon
fo4na
fond2
fo5ne
fo3n4id
fo4nin
fon1s2
f1op
for1a
for9drev
for7dro
for5d6u
fo6re.
for9ei
for7e6n
for5ent
for5ess
for4et
for9e8te.
for9e8ten
for9g6
forh6
fo4r9in
fork8
forlo7v
forlø9pa
forlø9se
formo9r
for3n
foro6
for5p
for3se
forsi9da
forsi7de.
for3s4m
fors8t
for9ste
fors4v
forta8le.
for5t6e
fortei9e
for7t6i
forti5da
for3t4v
for3u4l
for7v6
forva9re
for5æ4
for5ø4
for9å
fo9se
fosfo5re
4fosj
fo4ta
fo6te.
foto5
fo4tok
fo4tom
fo6top
fo4tor
fot3s
fots6v
fot3t
4f1ov
3fô
2f3p2
fpo6e
fr2
1fra
fra5l
fra4m5e
fra6mi
framma8ne.
franko5
fran7se
fra7r8
fra1s
fra5se.
fra7sep
frasi8e
fra7sk
fras6p
fra7v
fra7v6r
f2re.
fred8sel
freds5t
fre4e3
8freg
f4rek
fre4m5
fremma8ne.
frems4
fre7ne
fre6sk
fres7ko.
fres5koe
fre8s9v
fri5a6re
6f5ridi
fri4erf
f1rin
fris6ka
fri5s4p
fri5s6til
frite8re.
friti8me.
6froc
fro7f
fronta9le
fro8st
frus1
fruta6le.
f1ryt
frø5b
frø7ko
frå9r
fråve4
2f1s
fs2h
fsho6
fsi2
f5sjuk
f2sl
fsle6ge.
f4sm
f2sn
fs7ne8
fs5ov
fs2t
f2s3tab
f6s5tan
f4s9v
2ft
f1ta
f3ta.
fta7f
ft1ak
fta8la.
ft3alg
f2t1am
f4tana
f7tane
ft3anl
f5tar.
ft8as4
f6t1av
f2tea
f3ted
f4tee
f2teg
f2tei
f2tek
f6tem
fte4na
ften3d
f4t3enh
ften5s6v
f2teo
fte4r5a4
f4terin
fter5s
f4test
f4teta
f4t5ett
ft3ind
f2t5i4s
ft5l
ft7n
f2t1o2
f5tog
3fton
ft3r
fts5alt
fts3ei
fts5ers
fts5erv
ft2s1i
fts1k
ft2skaf
ftsla6ga
ft5s4lan
ftsle6ge.
ft3sto
ft6s5top
ft5s6tri
ft5stø
fts1u
ft2s1ø4
ft5t4
ftta8ka
ft1u
1fu
fu8ga.
fug9le.
fug6l7eg
fu6le
full3
ful9lar
fulle6
ful9le.
ful4len
fullen8de.
ful4ler
ful7les
fullfø7re
funn2
funns3
funnsla8ga
fu6ra.
fu6re.
fu9ret
fu7ro
furu1
fu7sel
fu6sk
fus6o7
fu4s5t
fut4h
futu1
4f1v
fva8la
1fy
fy5la
fyr2
fy8ra.
fy4r5a4b
fy1re
fy4re.
fyr7k
fyr8ke.
fyr5t
fy3s
fysa7
fy8sa.
2fæ1
1fø
fø4da.
fø4dek
fø5den
fø4des
fø5des.
fø1f
2føk
fø4le.
f8ør
før6a
fø5rar
fø4re.
fø4res
fø7resv
fø8rete
før6tin
4få
få7ren
få7ret
få5ri
får7u
få7va
1ga
4gaba
ga1bo
6gabø
ga3da
ga4ded
4gadg
2gadm
4g5adr
ga4e5k
6gaflo
g3aft
6gah
6gak
g1aks
gak8ta.
gak8te
ga3kv
ga1la
ga4la.
galei5
ga7len
gal4les
4galli
5ga7lo
ga4ma.
4gamb
ga5mer
gamme6l5
6gand.
6ganden
9gane
gan5g6en
gan4g5j
4gan5k
2g1anl
4gann
4gansa
4gansv
4g5antre
ga6pa.
ga4pe.
ga4p5l
gap3s2
ga6p7u
9gar.
ga6raf
ga6r5ak
2garb
5garbr
5garby
gar4dek
7gare.
4garea
gar5es
gares6ke.
gar2i
4garki
gar3ne
gar6ta.
g5arte
gar8te.
g3arti
gart5s6la
gar4un
ga4ryl
ga4sc
ga5s2i
gas8ka.
gas8ke.
ga6ski
4gasp
gas6sel
gas5sen
gas7ser
gass5ett
gass3l
5gast
gas5te
ga5sto
gas7t6ra
gas9tri
g2at
ga4te.
ga5tens
gate5s
ga3ti
ga1to
ga3tr
gat6tap
gau5la.
9gav.
2gavd
6ga4vei
ga4veri
4gavg
g5avk
2g1avs
2gavt
4gavv
2gaw
4gaø
2g1b
gba4ne.
g6byk
2g1c
8g1d
gd5alt
g6d5au
gde3a
g2deb
g3deba
g4dedi
gde5lo
g2dem
g4dend
g2de5o
g4dera
g4de5re
g6dero
g2des
g2det
g3det.
gdevi8sa
gd5op
gd1or
gdy4d
g6d1øy
1ge
2ge1a
geak8ta
geak6te.
gea7ren
ge4ark
2geb
6geba
4ge5be
3gebri
4gebrå
3gebyr
ged4
4gedan
6gedel
gedia5
9gedom.
7gedoma
9gedome
7gedomme
6gedoms
4gedos
2gedr
2gedy
2gedø
2gee
geen8de.
2gef
g5eft
3gefæ
2ge1g2
g5egg
g3e2gn
2geh
gehø8ve.
2gei
g1eie
g4e1in
gei4r3
gei9re
gei8s7p
gei6st5
3geit
geit3a
geit3o
gei4t3r
2gej
2gek2
ge9kl
ge3kn
g1eks
6gekt
5gel.
ge4lar
4gelau
ge6le.
ge7lea
4geled
4gelei
gelei5er
4gelek
4g3elem
ge5len.
ge5lens
5gelet
gel5ett
3geli
4gelid
6geligg
4gelit
6geliv
2gelo
ge5lov
7gels4
gel3se
gel5si
gelsk7l
gel5t4
4gelu
ge5lun
gel7ve
4gely
2gelæ
2gelø
2gelå
5gem.
2gema
9gema.
2gemi
3geml
4g5emn
gem6na
2gemo
9gemr
3gems
3gem4s5t
ge3mu
2gemy
2gemø
2gemå
g2en
3gen.
ge2n1a
ge7n6am
gends6t
ge3nea
4genem
gen5erf
ge5nes
gene4t
gen5eti
4genev
gene5ve.
gen8ga.
gen5gr
ge4ni6n
6geniv
gen5k
genle6ge.
gen3n
gens5l
gen6sun
gen5tr
4genum
4geny
4genæ
4genø
2geo
5geog
3geol
geome5
geomet4
ge5on
6geop
ge9ope
2gep
g2er
3ger.
ge5ra.
ge6ral
ge4r5ant
ge9ras
ger5di
4gered
4geref
4gereg
4gerek
ge6rene
4gerep
6gerese
4gerett
ger4i5d
4gerik
geri8ka
6gerike
ge4rim
ge4ris
ge4rit
ge4riv
gerle9g
g9er8ma.
ger3n
gerne6
4geroa
4gerom.
4geromm
6gerop.
4gerope
ger5p
ger4s5af
5gerud
ge5rup
ger5v
gerø6re.
ge4r3ø4v
4gerå
g6es
5ges.
2gesa
2gese
5gesen.
5gesens
4gesi
4ge5sja
4gesje
2ge1sk
ge1sl
geslu7
ges4lø
4geso
4gespe
ge4spr
ge5spra
2ge1st
3gest.
gesta7b6l
5geste.
ges6tekk
ges8ti.
gest5rid
gestri8de.
6gestå
2gesu
ges5vik.
2gesy
6gesæ
2gesø
2ge1så
geså5re
5get.
ge5tak
geta6le.
6getat.
6getate
4ge3te
5gete.
2geti
2getj
2geto
2getr
5get5s
2getu
2gety
gety8e
2getø
2geu
g2ev
2ge7v8a
2geve
4gevir
gevi6sa
4g5evn
gev6ne.
4ge5vo
5gevå
2gey
4geæ
2geø
2geå
1gé
2g1f
gfe2l
4g1g
g6g5al
gg5ask
g2g1av
g4gedi
gg1ei
g4gela
g4gele
g2gem
g4genu
g6gerei
gge4rin
g4gerø
gges6b
gges5l
g4gesm
g6geso
g4gesp
g6ges6tio
g6ge5sv
g2gev
ggie6
g4gif
g4g5i4m
gg4je
ggje5s
g2gl
g7glu
g4gn
g2g1o2
g3go.
g5gos
gg3rad
ggra6da
gg5rat
gg8re.
gg3red
gg7rek
gg5s4par
gg3sto
gg4sy
gg3sø
g7g8ud
g4g5u4r
2g1h
ghe8n
ght5ene
gh4to
ghæ8
1gi
3gi.
4giak
gi1ar
4giarb
6giav
2gib
gi8c
2gid
gi3de
gi1e
4giek
3gien
gi9end
5gier
4gifa
2gifo
4gifr
4gifu
gi6ga.
2gigr
2gih
2gii
5gika
3gike
4giki
3gikk
gi5k4r
4giku
gi5le
4gimess
gi4metr
4gimi
4gimø
2g1ind
6gingeni
gi4nin
2g1inn
gin5nu
4gino
4g1ins
4g1int
2ginv
4gi5om
2gi1op
gio4r
2gip
gip5si
6gira
gi3re
gi4re.
giro3
gi6rob
5gis.
2gisa
gi3se
4gisel
4gisen
5gisk
6giska
gis8lu
gis4lø
4giso
4gisp
gi3s4pa
gi5s4pr
giste6ru
gis5ti
gist5ra
gi5stré
gi6st5rer
4gistu
6gisty
gi5ta
4gi5te
gite4s
gi2t9r
git5te
2giu
gi7va
4gival
4givo
4givu
1gj
2g1jak
g5jarn
2gjaz
gje5f
4g3jeg
gjels4
gje2n
gjen1opp3s4
gjen5s8
6gjent
3gjer
gje7sk
gje4s3p
gje8v9ak
2gjob
2g1ju
7g6jut
gjø9de
2g3k2
gkly9
gl2a
6gla.
gla3de
4glag
gla4ga
gla8ge.
g3land
g1lar
gl5art
glar7v
1g2las
7glase
g6lass
6glast
g5last.
3glat
g5lau
gl6e
gle6dero
g2lef
gle3ge
gleg8ga
6glei
glei7er.
g2lek
g7lek.
g5leke
g2lel
3glemt
4glen
g9len.
g9lene.
g9lenes
g9lens
gle9pl
4gler
gle4ra
glere8de.
g9les.
gle6se.
g4le5sk
g6le7sm
4glet
g2lev
1g2lid
gli4del
gli7e6n
gli8er
glig1
3g2lim
gli9me
4glio
glitt4
6g7liv
4glj
gl7ja
gl5l
g4lo.
g2loa
5glob
5g6lome
1g4lor
gloria7
glori6an
glorie7ne
g4los
glo5ste
6glov
gls4
5glug
g5luk
6glun
gl5ung
glun8ge.
gl5ut
g5lyd
3glyf
gly4se.
g2løg
glø8pa
2gløs
gl7øy.
5gløym
2g1m
g4mete
g4metr
g5mé
gmini6
gmo4e
g3mu
gmu8le.
gmå6la
g1n
gn1ak
gna5lem
gna4lo
g2nav
gn1d
gndø6
gndør5
gn4e
g2nee
g4nelo
g6nero
g6nerø
gne1s4
gne8se.
g4nesk
g4nest
g5net
g6netr
g2nev
g4nib
g4nid
g6nik
gning4
gnings5
gni4s
g6ni5sk
gni6st
gnist9r
gn5k4
g2nom
gn5o6p
gn7o6v
gn5r
gn1s
gn4skr
gn6sm
gn4som
gns4pr
gn4sti
gn2s1v
gn5t4
gnu5re
gnæ6re
g2nå
1go
7goan
go1ar
7goar.
2gob
gobe5
go4da
go5dal
god5ar
2godd
go4de.
gods9t
2gof
go9ga
go5ge.
go9g8r
6goi
2gok
gok4se.
go3le
gol6fa
go5lo
gol4va
gol6var
go4lå
2gom
g7o6ma
6gometris
7gomm
go4n5and
go9ne.
go7ni
go5nok
gon9s
2g1op
3g6or4a5
go5ra.
go7rae
go7ras
2gord
gor6da
go1re
gore8a7
2gorg
g4ori
gori5e6
g5orv
gor8va
go5rø
gos3p
4gost
6goto
got6r
4gov
go8ve.
go8vi.
2g3p6
1gr4
8gr.
4grab
6grac
gra5ce
9grads
graf5f
graf5t6
gra4m5
grand3s4
gran5to
grant4r
gra9se.
gra9set
gra6sk
gras3t
gra5t
gra8te.
grati4s
gra4u
gra4v3ak
gra7vis
gravta8
2grea
4g5reds
gre4en
2gref
g7refe
g4rega
greie5n
grei6ene
6g3reis
4grek
2g5rel
g5rent
4grepi
grep4s3
g7rese
gres6sak
gres6sent
6g5rest
4grett
4g5ri.
grib3
4grid
4grif
4g1rig
gri5sete
4grit
gro9ar
g4ro7i
grom5m
g4ron
gro5sk
gro3ve
4g5rui
4g3rul
grun7g
5g4rup
gru7sa
grus5t
2g1rut
2gryd
4g5ryg
6g5rytm
grø5de.
6g5rør
4g5røv
grø5ve
4grøy
gr7øy.
6gråd
grå6da
gråk4
grå7n
grå5te.
8gs1
gsa2
gs5akers
g7sal.
g7sale
g5salg.
g5salge
gsam3
gs3amb
gs7amn
g3s6ank
g5sard
g2sas
g7sast
gsbø6n
gs2ce
gs5ef
g2seg
g2sei
g2sek
g5sekr
g7sekv
gse9la.
gsel4s5a
gsel4st
g2sem
gs6ende.
gsen6ke.
g5sens
g3sent
g2ser
g5ser.
g3seri
gse4st
gse4t
g3sete
gs3eti
g9sets
gs4ett
gse2v
gsfø2
g2si
g5sider
gs5is
gsi2v
gs4jar
g3sjef
g5sji
g2sjo
g5sjå
gs4ka.
g5skad
gs4kal
g5skall
g6skam
g4skan
g4skapa
g5skape
g4skapi
gs7kav
g5skilt
g7s4kj
g7s6kjæ
g3skot
g5skren
g7skug
g6skv
gsla6ga
gsle6ge.
gs6leri
g4sluk
gs4lun
gsl9ut.
g5slyn
gs5med
g9s6mert
g7snel
g5sog
gs9ope
g5spal
g3spel
gs2pi
gs5pik
g3spil
gs5pile
g6s5pors
g3spur
gs3s4
gsse4e
gs5tak
g9s8tand
g5stang
gs4tasj
g7s4tat
gstatsrå7
gst6e
gs5te.
g5ste4e
gs4tell
gs5tema
gste6ma.
g7stemt
gs4tere
g5s4terf
g5s4terk
g5s4tern
g5s4ters
g5s4terv
gst7evnen
g5s4ti.
g3s4tie
g3stif
g3s4tig
gs5tiå
g5sto.
gs4tol
g5stol.
g7stola
g5stole
gs5toll
gs4trap
g5strau
gst5rea
g5strede
gst5rei
g5streke
gs6tret
gstri8de.
g5s4trof
g3strø
g5s6trå
g5stue
gst5ut
gstyr8ka
gs4tør
g5s4tå
gsu2
gsu5g
gs4vane
gs5vik
gs7væ
gsy2d
g7sym
gsy6na
gsy6t
g2sø
gsø6ki
gs6øt
gså4
2g1t
g3ta
gta8ka.
gta8ke.
gta6la.
gta4le.
g9t6e
gte6ke.
gte6ma.
g3ti
gti8de.
g4t5if
gt6re.
gtråd5s6
gt7sv
gt5t
gtu8en.
gtvek8
gty8e
gt9yt
1gu
4g5u4bå
gu2di
guds3t
gu4el
6gug
g5ug6l
gui4d
guid5ar
gu4le.
4g5ulk
gul8ke.
gul4la
gul5o
gul7ø
7gum
gun4g
gur2g
gu4ri
gur8na
gur6ne.
gu5rua
gu3rue
gu4st
gu1ta
2gutb
4gutd
g5ute.
6gutg
g7utl
4gutn
2guts
gut4tak
gut4tes
4guttr
2g1v
gva4ke.
gva8la
gvedli6
gvi8ta
6g1w
1gy
g9y8a
gy4da.
7gym
gy3ne
gyr6
gy8sa.
gy6se.
gy4te.
gy4ve.
g5æt
4g5øk
gør3s
2g3øv
gøy9a
gøye6r
gøy5n
1gå
gå6as
gå6en.
gå4er.
4g5å4k
4gåm
4g3ån
gån8da
2g1å4p
2g3åre
gå2s
gå3st
gå9ven
gå4vet
h2a
ha4a
haba9
4hae
ha2el
4hafi
ha2g
ha3ga
ha4ga.
ha3gen
hai1
ha7ism
ha5ka
ha4ke.
ha5ken
ha7kera
ha4ke5s
ha1la
ha6la.
hald4s7
ha4le.
ha4lev
hal6lei
hal6lø
hal4s3k
hal4so
hal4s3t
ha5lu
hal4v5
ha5ma
ha8me.
ham6nest
ha5mo
ham4st
hams4t7r
ha5na
han6d5r
hand7skr
hand5ø
ha4ne.
hani1
hanis4
han2n3
han4ne
han6nel
han5nen
han5n4o5
han3se
han4sk
ha4pe
ha4re.
ha5rei
ha4rel
ha3rem
ha4res
har5k
ha5rov
har7se
har5tre
har4tri
ha4sj
hasj5e
ha2sl
has6p7l
has5v
ha3tar
ha4te.
hat6le
h4au
hau5ke.
hau6st
hau4t5r
hav4a
ha4va.
ha5van5
ha4ve.
ha4veg
ha4vei
have3s
ha1vi
ha4vo
hav4sl
ha6vu6
hav1ø
4havå
2h1b
hba4ne.
4hc
2he.
he2a
he7ans
heat4r
heb5n
he4de.
heder6s5
he2d9r
hef9ta
hef7tes
he3ge
he4ge.
he2g3r
he2i
heia3
hei5en
3heim
he3ins
hei4sk
heit4s
he2k
hek4sek
hek6serin
hel1a
he4la.
he4le.
he4l5ei4
hel6lesu
hel3o
hel2s2
hel3sa
hel4se7
helses4
hel3sk
hel5sp
hel5ste
hel3sv
hel4tes
hel9ve
he4mak
hem5ne
hem3s8k
henfø5re
hen5o6
hen1s2
hen5se
hera9da
he5ret
he4ri.
her5j
herle9ge
herli9ga
4her5n
he1ro
he4ro.
hero9a
her7p
her6rei
her6resi
her6ret
her6ska.
her8s7kare
her6sv
her5un4
he2r3ø
he4se.
he2sp
hes7pa
hes5pel
hes5pen
hes9per
heste5ri
hes4tes
he6stø
het2
he4te.
he5t6i
het4s3a4
het4s5p
het3t
he6va.
he6v7arm
he4ve.
hev9na.
2hf
2hh
h5hu
hi5ao
hi4bak
hie4n
hi2et
hi4f1
hiff2
hif9r
hi6ge.
hik7e
himme6l5o
hi6n7an
hin4nes
hins4
hins9ke
hi4pl
hip3p
hi1ro
hi2s1
hi9se.
hi3sen
hi5s4i
4hisk
hit7o
hi4t5r
hit5ti
hi8va.
hi4ve.
hiv1s
hjar4
hje4
hjem7e
hjorte5
hju6l7
hju7l8e
2hl
h5lan
2h1m
hma8n
2hn
h2na
hne6n
hn1s
h4o
ho5ar.
hob6
ho6da
ho4de.
ho5den
hode3r
ho5der.
ho5dy
hof4f3
hof4f3a4
hof4f3e4
hof5f6er
hof4fi
hogs6
hog6str
hog7stra
hoi5
ho2la
ho5lag
ho5lan
ho4le.
ho4lin
hol5l
ho4lom
hols4
ho4lu
hol7ut
ho4me.
ho4mo.
ho4mod
ho4mos
ho5n6o
ho4o
ho8pa.
ho4pe.
ho8pi.
ho5ra
ho6ra.
hor2e1
ho1ro
2hort
ho4s
hos5a
ho5sen
ho5ser
ho5si5
hou2
ho1v
hove5re
ho4vé
2how
h1p
2hr
h1ra
h1re
hri5ne
hri2s3
6h1s
h5s4e
4ht
h5ter
htere4
h1tr
ht5t
hu4da
hu4d3
hud5s6
hudså9re
hu4er
hu6et.
hu4ga
hu4ge.
hu8ja.
hu6ka.
huk8ra
hu4la
hu4le.
hu4leg
hu5les
hu4lev
hu5ma
hun6des
hun2n3
hu1ru4
hus1a
hu8sa.
hu5s6a6r
hu6s7arr
husa7r8e
hu4se.
hu4s3ed
hu2s1i
hu2s5j
hu2s1k
hus7m
hus5s4
hus1t
hu8str
hust9ran
hus4tre
hu6sty
hu6s5u6
hu2sø
hu4va
hu4ve.
hu4ves
hv4
hva5le
hvas5
hve2r
hver3a
hvi5l6i
h4v4ir
hvits4
hvo2
hvor5
hvor5i6
h6y
hya3
hy2bl
hyd4
hy2e
hye5ne.
hye9nes
hyg5gel
hy6la.
hyldes7
hy4le.
hyr4des
hys3
hy8sa
hy4se.
hy2s1j
hys5t
hæ5g
hærfø9
hær3s6
hø4e
høf5
hø2g
høg3ri
høg7rø
høk6
hø6le.
hø4na
hø4ne.
hø5rar
hø5ren
hø5rer
hø4res
hør6sp
hø2s
høst7a
høst5ø
hø1va
hø1ve
hø1vi
høy5a6
høy5k
høy7n
høy7rar
høys4
høyse6te.
h6å
hå7a
hå8le
hå6na.
hånd5skr
hå5nel
hå6pa.
hå4pe.
hå4p5l
hå1re
hå1ri
hår3s
hår7u
hå8va.
hå4ve.
ia9al
i1abl
ia1bo
i2a3de
i1adj
ia5d8r
ia1g2
ia2ge
ia1in
ia1kr
i1aks
iak8se.
ia5ku
i1al.
ial1a
ial5ein
iale4t
ial5eti
ia4l5ett
i2alf
ial3g
ia4lin
i4alk
ial3op
ia6lov
i5als.
ials4t
i3alt.
ial1u
ia2lø
i1an.
i2ana
ia4nal
ian5ald
ia5nar
i7andr
i5a4ne.
ia8nes
ia7net
i5ank
i1anm
ia2no1
i1ans
ian3sa
ian3sl
i1ant
ia7nø
ia2pa
i3app
i1ar.
iar4do
iard5s4
iar4du
i2are
i5area
ia5r6e8l
i5arn.
i9arns
i7arska
i6asi
i1asm
ia4sp
ias3s6
i3assi
i1ast
i7ast.
ia1t
ia5te
iat6r
iaty6ra
i1att
i7auk
i1av
i1b2
iba4ne.
ib5bo
ib3bu
i3bere
ibe4ro
ibi5er.
ib7lar
i2b3le
ib4leg
ib4le5s
i5bo
ibo4e
ibo7n
ib4r
ib3st
ib8t
ibya7
iby9ar.
8icanarar
ice5ne
i1ci
ick1
ick7ete
i1co
i5cy
2ida
i5dal
i3das
id1av
id3del
iddel5u
id6dep
2ide.
3ideal
i2deb
i6def
id5e4ge
i7deki
i9del.
id3elv
2iden
i5dend
iden5sv
5identif
5identit
ideo3v
i6derap
i9de5re.
i7deren
i9deres
iderla8ga
iderle7g
i7dern
i5ders
i6desm
id6gem
id4ges
idi4en
1i2dio
i8dj
id7jer
id9na
1i4dol
id9ran
id5reg
4i3drev
2idri
id2s1
id5sam
idse4
id6sel
id5sim
ids5l
idsla6ga
ids3t
id4s5tu
id2t1
i2d1un
i2dy
3idyl
i3dyr
i3dø
i6d7øy
id7å
2ie
ie1a2
i2ed
i1eff
ie4ge
iego4
ie1i
iei6d
i1eie
i3eig
i5eini
iek8l
i1eks
ie5l6a
i2ele
i5elem
ie4lev
i7e6lim
i1els
i9elt
ielø8pa
i8e9ma
iem7b8
ie3me
i1en
ie7na
i2end
ien6dela
ie8né
i2e5ni
ien7n
ie5no
i5ens
ien4sk
ien4s5v
ien4t3r
ie5nu
i6eny
ie4ran
i4erd
ie6re.
ie5reg
ie4r5eng
i6eret
i2eri
ie4ril
ie4ris
ie4riv
i2erl
i6ero
ie7ro.
ier4ra
ier4sp
iers3v
ier5t
ie3run
ier5v
i2e1s
i6es.
ies4c
ie3se
ies5s
ies4ti
i8es6v
i1et
i2eta
i5e4tabl
i3etat
ie9te
ie5té
iet4re
ieu2
ie7ved
2if
ife4s1
if2fa
ifi6e
ifjø8
if3le
if4les
iform4
if1re
i8ft
if4tal
if4tere
ifte5s
ift2s
i3fø
2ig
i2gae
ig3ann
i7gark
ig4art
iga3ru
iga7te
ig3att
i2gav
ig3d
i6geb
i6gedi
i6gedomm
igedoms5
i2gem
i3gen
ige6no
i5gers
i4gerø
i4gesp
ig3e4ta
ig5ett
ig4ged
igges4
ig4gra
igg9s2
i6gh
i2g1ia
i5gib
i4gim
igion4
igje9va
ig1l
igl6d
igli6se.
ig5loa
ig5neu
ig5no
igof6
igo5fr 
ig1om
igo4no
ig2ra
ig2re
i2g1rø
ig3råd
igrå5t
igs4al
ig5sel
igs2j
ig5s4ka
ig3s4kr
igs4mu
ig3s4pa
igst4
igs4ta
ig4ste
ig5stek
ig7stel
ig5stem
igs4tra
ig5s4va
ig1un
ig9ut
i3h
ihen3
iho7le.
i4huk
ihu9la
ihu5le.
i1i
i5in
i7is.
i6ita
i1j
2ik
i1k2a
i2kab
i5kabel
i2kaf
i2kak
ikan9d
i2kao
i4kapo
i5kar.
i5kara
ika5re
i4karei
i6kasa
ika3sp
i2ke.
i2ked
ik9ei
i9keleg
i5keli
ike5lu
i5ken.
i4kena
i5kene
i9kens
i3ker.
i4kera
i5kere.
ike5ri
ike4r5o
i2ke1s2
ike3si
i6kesk
i5keso
ike5su
i5ket.
i5kets
i1ki
iki9ne
ik5inn
iki5st
i1kj
ik4kaf
ik6kana
ik4kap
ikk5arv
ik4kas
ik4kat
ikk5att
ik6k7ent
ik4keru
ik8kesk
ik4kest
ik3kjø
ik4kjøp
ik4kl
ikk5lag
ik2ko
ikk5ord
ik4kr
ikk3re
ikk5sv
4ik2ku2
ikk5und
ik2kv
ik6ky
ik1l
i5klæ
i1ko
i2koa
i9koar
i2kob
i4kod
iko5de
i2ko3f
i4kog
i4koh
i2kok
iko5na.
i2koo
i5k6ord
i4kore
i2kov
ik1r
ik4rak
ik5rem
ik5robe
ik3ros
ik2ry
ik2sa
ik4sek
iksmå8la
ik7sot
ik5spel
iks5ti
iks5to
ik8stu
ik4tav
ik4teg
ik2t1r
iktsla8ga
i1ku
iku6le.
i6k7u6t
ik1v
ik4vin
i1ky
i3kø
i3kå
ikå8pa
i1la
il5adr
il7af
i2l3ak
il3al
i4lana
il6and
i4lark
il3art
il5ass
ilas5t6
ila5t
il5av
il4dak
il4deko
il4dete
il7dj
ild3re
ildsfa9re
ild3s4t
ilea9r
ile8are
i3le7e
i2lef
ile4ge.
i4l3egn
i2l1ei
i6leig
i2lek
i2lel
i4leno
i4lero
ile1s
i4lese
i4le5sk
i4lest
ile6tri
ilet5te
ile4tu
i1lé
ilfø5re
il5ge
il1gl
i4lid
ili5ers
ili9ga
i5lik
i2l1im
i4l3ind
i7line
i4lins
i4l3i4r
ili5s6tik
il3ja.
il1je
il5jese
il1jo
il1ju
ilke3
il5ker
il4kes
ilk4o6s
il5ku
il4lab
il6lam
illan8da
il6lap
il9lau
il4lee
illei9e
il6l7ender
il6lesk
il4lev
illi9ga
il4lo5m
ill3s2
ills5kå
illæ4
illæ9re.
il4m5est
ilm5e4v
il4mi
ilm5s
i1loe
i9lolo
i4lom
il5omv
i5lon
il3opp
i4l1o4r
i5loso
ilot3u
i4love
ilo1w
ilret4
ilset8je
il3sl
ilsla7
ilsle7ge
ils4mu
ils2p
ils2t
il5str
il7su
il3s2v
ilsva9ra
ilsva5re
ilta9la
ilt5rett
il6t7å
ilu4h
i5luk
il7ul8
il3un
i5lur
i9lus
il1ut
il5v6
ilve8d
ilve4r
i1ly
il1å8
ilår6
8im.
4ima
i2mad
i4maen
i2mag
i6m5akk
i4mako
imal8n
i2mam
i9man
i2map
i5mar.
ima5s
i4matr
i8mb2
i4mee
i2me1g
i2mek
i6melu
im5enh
im8et
i9met.
i4meta
i4meti
i6mey
i8mé
imi9la
imini6
i7mj
im4lev
im8l9u
im5m
i6mog
imo9l
im5ord
imor8da
im7o6v
imp2
5imperi
imp4l
1impo
imp9s
impse8
1impu
im4ref
im4rek
im4res
im9se
ims4k5l
ims3kr
im5s4me
im1s4t
im6sti
imta8la
4imu
i3mø2
2in.
6ina
i4nag
in5agg
i5nakk
ina4let
i4na2m
in3ame
in2an
i9nane
in5ann
i2nap
in5app
i5nar.
i5nars
i4nask
i4nasp
i4n5ass
ina4t5ak
i6nau
in7auk
in5avl
in5avr
ince2
in7der
6indig
in4dog
ind9ra
in3dru
indr5ø
ind5sk
ind3sp
ind5s4t
5industr
ind7å
4ine
ine8are
i2ned
inedy6
in5egg
in5eid
in3eie
i6nele
ine4li
in7eng
ine8pa
ine8pe.
i7nere.
i5neren
i9neres
ine4rik
i7nern
i5nert
i5nes.
i4nesk
ines8ka
ines8ke.
ines4st
ine5s4ti
i4nesø
i2nev
8iné
3infek
in4fos
in4fot
infu9
4infy
in4g5ald
in4gav
in5gebj
in6gem
5ingeni
in5geri
in4geru
in3gev
ing5jen
in4goa
in4gos
in2gr
ing5rep
ing7ris
ing2s
ings5om
ingst8
ings5v
6ingu
in2g5ø
i7nia
ini9ar.
i2nib
i5nie
i4nif
i2nig
i4nil
ini7m
i4ninn
i2nip
i4nisa
ini3se
i4nises
5initia
i4nito
5injek
2ink
in5kel
in4kero
in4k3la
in4kok
in5l
inla8ga
2inn.
in4nal
in4nem
in4nerø
in4nesi
innes6t
4innet
in6n7ette
innfa9s
1inng
5innhal
3innho
2inni4
in4ni.
in4n5om
in5n6ova
inn1s4
6inns.
3innsa
inn5se
inn9sen
inn9ste
inn7sve
1innt
in4n5u4
4innæ
in2nø4
2ino
ino5a
i5noar
i4nod
inok6
in7oks
in1s
4ins.
8insa
in9sa.
in7sal
in5sar
in5se.
in4sek
in3sen
inseri8e9ne
in3si
insis5
6insj
in4sja
in3sje
4insk
in9s8kas
in5skat
inske4t
ins4ki
in3skj
ins5kjøt
ins6kor
ins4k3v
ins6kø
insle7g
ins8lega
in3slo
in3s2lø
in5s4ma
in3sop
1insp
in4spa
in5s4pl
ins4po
5instal
in8s5te.
ins5ten.
ins9tens
3in3s4ti
in4stin
4in3s6to
in5stra
inst5rel
5instru
in6stå
in7sul
in2sv
6in3sy
8int.
2in3ta
inta8la
4inte.
5in7teg
in8t7ege
in5ter
int5ess
in5te4t5
4in5ti
inti5me
int2r
intran4
int4rer
in5tres
6inu
inu6i
i8n9ul8
in7ut.
in9u8te
1inv
6invev
iny4i
iny4t
6inø
in7øk
i7nøt
in3øv
4io
io1a4
i2ob
io4dere
i1off
io5gn
io1i
i1oks
iol4
io3le
iol7jen
io3mu
io4nans
io4narr
io6n5erst
ion3g4
io4nin
io4nu
io1pl
i1opp
io5ra.
ior8da
io1re
io4rie
io4r5in
iorla8ga
iosk3v
io1st
iota6le.
io3t4e
io4tra
i5pap
ipa4ti.
i4pee
ipela9
i7pe6p
i1pi
ipi1e
ipi9ne
i4p5ings
i1pl
i2ple
ip4peli
ippel7s6
ipp6lan
ipplæ8re.
ip2pr
ipp4s3t
ippsy8na
ipp4sø
ip7pun
i1pr
i6pra
ip5ru
ipru8te.
ips1a
ipse4l
ipsfø5
ip2si
ip2s1k
ipsle6ge.
ips1t
ip6tar
i5py7
i3pø
2ir
i1ra
i9r6and
ir5ark
i9rast
ira6tr
ir5de
ird5s
i1re
ir3eie
ir6ek
i3repo
i3rer
ire6r5a
ire7st
i3ret
i8reto
ir7g
i1ri
iri4a
iri8ka.
ir3ind
ir3inn
ir5inst
iri9t
ir5ka.
ir4kat
ir5ker.
irke3s6
ir4kest
ir4kle
ir5kv
irk5ø
ir4mag
ir4mal
ir4mast
ir9mé
i5roa
i1roe
i4roi
i1rol
ir5opp
iro1s
ir3re
ir7sko
irs2p
ir3s4t
irt6
ir3ta
irti6g5r
i1ru
ir5u4k
iru8m
iru7sa.
i1rø
i1rå
ir7å6l
i1sa
i4saks
i4sanb
i4s3ang
is3ann
i4s3ans
is3ant
i7sas
is5aud
3isbry
is6cen
isch5
is3co
i5scr
i2sed
i4seel
i4seen
ise5ern
i2s2e3g4
i2sei
is3eie
is5eig
ise5is
i2sek
i3sekt
i4sekte
i6s7eld
is4e5li
i2sem
ise5ne
i4seno
isensi6
i5ser.
i5sers
i2ses
is5ess
i4sete
iset8je
i2seu
8isé
isha7ne
3ishav
is4h5in
ishø9ve
isi6ene
is5ild
i4s3ind
isis5t
is7jun
is9ka.
is3kal
is3kar
isk9art.
isk5arte
i8ske
is5ke.
is8kee
is4kel
isk5els
iske5s4
is3kje
i3skjo
iskla8ga
is6k5le
isk3lo
isko5g
is7kogr
is3kop
is3kot
is1kr
is6k5rin
is1ku
is4kul
i5skula
is1kv
is4kvi
is1l
i6slu
isl7ut
isl9øy.
i5smak
is4med
ismo5e
i6smus
is5ne
is5nu
1isol
6isold
5isomo
is5omr
iso3pa
iso5pe
iso7pr
3isot
is1ov
is1p
is4pan
is5pane.
is6pis
is7pru
is4ses
is5si
issis5
is6s7kj
is4sko
is7skr
is5sky
is4skå
is5sok
is7sto
is6sve
is5svo
is9s4ær
is4søk
i5stab
ista9le
is5tane
is5tap
i4s5tar
ist5avb
ist7avi
i2ste
is5te.
is4tek
ist5ekt
istel5l
iste6ma.
ist6en
is5ten.
is5tene
is5ter.
is5tern
is6terø
is6té
is4tik
is5tilb
is5tis
is3tok
is3tol
i2str
i8s8tre.
i4st5ren
i5strer
i6strer.
i4stres
i6stret
is3try
is3tus
6isu
is5uf
is5ul
is1un
is1v
is4vak
is7w
isy8na
isy5r
is5yt
i2s1øk
i4søy
is7åk
is3år
i1ta
ita4l3a
ita6l5ers
ita4lo
ita4ly
i6tang
itan7s6v
itau4
i4tav
i4tec
i2teg
ite8ke.
i7teky
i6t7elg
i4teni
i2teo
ite3re
i4tero
iter6s5
i4te5ru
i2te1s
ite6se.
itet6s5
i1té
it2i
iti6er.
i4ties
i2tif
i4tikam
i4ti3kv
iti5me
i2tio
i2tip
iti3r
i4tisa
i4tisen
i4tisi
i4tisj
i4tisko
i4ti3sp
i4tist
iti5str
i2tiu
itiv4
itivs5
it7jaran
it7jer
it7ji
itma6le.
itnes4s
i1to
ito9a
i4tom
it5ord
ito4s
itostra6
ito8v
i1tr
i4tra.
i6trae
it3rel
it3ren
it5rim
itri8ma
it3rin
i5tris
it7ro6s
it1sa
it4s3ei
it3ser
it6ses
it5sku
itsla8ga
it1sn
it6sti
it3sun
it4tag
it6tak
it4tal
itta9la
it6tann
it6tap
it4t5at
it5ted
itte4l5o
it4tenk
itte5s4
itt5ett
it4tid
it4til
it4tj
itt1o
it6tof
it7ton
it4tr
itt5skr
itt4sø
it4ty
it7tys
i1tu
itu5e
itær1
i1tø
i5tå9
i1u
iu6a
iu2b
i5u6l
i5um.
ium4f5ar
iu2m1i
ium5m
iu4mo
i6umse
i4um5s4t
i4umsu
iu2n
iu8p
i2ur
iu5se
4i1va
i4vad
i6vaj
i4v3aks
i5val
iva6la.
i4vana
i4v5ank
i4varb
ivar5s6
i4v5ass
ivat3t
i1ve
i2veg
ive6ge
iv5eg6n
i4vei
iv7eig
i2vek
ive4ra
ive5ras
iver5d
i6veret
i4vesk
i4vesti
i6vesv
i6vetø
i2vev
i1vé
i1vi
iv5ins
iv5is.
iv5isb
ivle6ge.
iv3n
i1vo
iv7om
iv3r
iv4sal
iv2si
iv2sk
iv2sl
iv2sn
iv4so
ivs5v
i2v3un
iv7y
ivyr8ke.
i9væ
iv7åpn
i1wa
iwi5
i5wie6
i5y
iyr8ke.
i5za.
i7zas
i4ze
i1zo
i1ø
i1ø4k
i1ør.
iør5i
iør5s
i4øs
iø3se
i1øy
i1å4
iårs7l
iåt4te.
ja1ak
ja9ar
ja4da
1jae
ja7en
5jag.
ja4ga.
ja7gar
ja4ge.
jag6r
ja4ha
ja4hv
ja4j
jak4kel
jak7kele
jak4ko
jakk5s4
ja1k8r
ja8kre
jaktel
ja7ku
ja3lo
ja1lu
jam7b
6jambi
jamhø8ve.
5jamm
jams2
jan4gr
j5anl
ja6ra.
ja6r5ap
ja9rek
jarn3s4
jar5ta
jar5te.
jar5tet.
jar7ti
6jarø
ja6rå
ja7se
ja8ski
ja5sti
ja5ta
jau4ere
ja9vi
1jaz
j1b
2jd
j2e
2je1a2
je5ak
2jeb
jeb9b
je4deb
6je4dek
4jedr
jeep1
6jeev
2jef
je4f3et
je2fj
jef5lag
je4f3re
jef4sa
jef6s5i
jef3t4r
je5ge
jeg5ge
6jegl
jeg6les
4jego
4jegr
4jegy
2jeh
je1i
je5i8s
4jej
2jeka
jek6keru
4jekl
je4kli
2jeko
jekt3a
jek4tan
jek6tes
jekt5ev
jek4t5in
jek4t3r
jekts4t
4jekø
2jel
je6legr
jelei7er
je7lele
je4les
jel7ge
jel6lag
jell5ang
jel5len
jel4lo
jelt3
jel4tr
jel9ut
jel7va.
2jem
je4mia
je4mit
jemp6
jem5pl
jem5se
jem4sti
2je7na
jen1d
4jendr
je3ne.
je7ne8s
4jenet
jen5ged
jeng5s4
2jeni
jen3k
4jenl
4jeno
4jenu
je2n1y4
4jenæ
2je5o4
2jep
je3raf
je4r5ant
jer4dep
jerd6s
je3r6e
4jered
6jereg
6jerei
6jerenn
je5rik
je6rim
je6rinæ
jer4kes
jer6k5l
jer4kv
jerle7
jer6mu
jer6n5as
jern5sl
je6ron
jer4sp
jert5s
4je1ru
6jerå
5jesf
5jesh
jes4kil
2je3sp
jes4tea
je6stim
je3str
5jesut
je5sve
je4t3ag
jeta6ka
je9tar.
je7tara
je9tare
je4t3ru
jets2
jet4t5an
jet6term
jett3o
jett5s6
je4t3v
jety8e
2jeu6
4jev6a
je7vark
je6vas
4jeve
jevi4s
jev7na.
jev7ne
6jeø
j1f
4jg
j1h
4ji.
jib5b
ji7e6
6jik
2j3inf
ji7ro
ji6sj
4jiø
2j1k
j4kap
6j1l
6j1m
6j1n
6jn.
j5ni
j2o
1job
5joc
jo4da.
jo6dat
jo6dis
jo4fl
jok9ker
jokk9o8
jol5t6
j3omr
jon2
jo5ne
jon7n
jons1
jons5a
jonse4
jons3p
jons5t
jon6sti
jon4str
jonsu4
4jop
jo5ra
jor6dek
jor6d7erv
jor6d7is.
jor4d3o
jord3r
jord5s
jords4l
jor6du
jo1re
jo4rie
jort6a
jor5tet
jo3r4u
2jos
jo3se
jo4ses
jo5stei
1jou
jour5
j1p
4j1r
2j3s2
j1t
ju8are
1jub
jubi3
ju9bo
ju3de
ju2do
ju7doe
jue7ni
ju4e5re
jue9s
jug9le
5jugo
4ju2k
ju3ka
ju3ke.
ju3ken
juk9sar
ju2l
ju3la.
ju5lar
ju5las
ju8l9ei
ju4li.
ju6lid
ju4lik
jul7inn
jull6
1jung
jun7ge
j6u6ni
8jup
jup7s
ju6p5å6
ju4ra
ju7ras
3juris
ju9ro
ju3ru
5jury
1jus
ju5so5
ju1ta
jut5o
ju6va.
ju6vak
ju1å
j5v
jy1
jy8de.
jy2p3
jæ5le.
jæ3ra.
jæ9ran
jæ9res.
jæ7te.
j2ø
1jø.
1jøa.
jø5b4
1jøe
2jøef
4jøeg
6jøei
2jøek
4jøend
4jøeng
4jøeta
jø1f
jø3gr
jø9kj
4jøl
jø4les
jøl6ver
jø5me
jøn5ne
jø5pa
jør4kel
jør4sp
jørs5v
jør4tel
jø3ru
jør7ut
jø1rø
jø4ses
jøst2
jø5ta
jø6t7av
jø3te.
jøte4t
jøt5eta
jø1tr
jøtte4
4jø1v
jø4vel
2jå
jå5ar.
jå9ge.
jå6la.
jå4le.
jå7les
jå5let
1ka.
2kaa
5kaa.
5ka4an4
k3aas
ka3at
6kabes
ka7bo
4ka1br
4kaby
ka3da
6kadale
ka5del
ka6del.
ka4deri
4kadg
kadi7e
2kadr
5kadu
4kady
3kaen
ka3fe
kaf5fere
2kafo
ka9fr
2kaft
kaf5ta
6kafø
2kag
k5a4gi
kag2r
2kah
ka5isk
ka5ism
6kajo
ka4ka.
ka4ke.
ka4ked
ka4kel
ka4kes
ka4ki.
ka4kis
6k5aksj
4kakt
ka3ku
ka3lam
ka3lan
ka6lant
ka3las
kald5s
5kaldt
kal2e
3kalen
ka5lev
5kalis
k6alk
5kalky
kal7la
kal6lero
kall4s
ka1lo
kal3p
kal7s6v
kal4ves
1kam
ka6ma.
ka8me.
4kameri
4kammel
kam4p3i
kam4pr
7kamu
1kana
ka8na.
4kanda
kan6da.
5k6ande.
1kane
ka5ner
kan4i
ka5nin
2k1anl
4k1anm
k3anno
5kano
ka4no.
ka8nom
4kansa
6kansi
3kansl
1kant
kan6t7end
kan6t9r
2kap.
5kapad
ka4pak
3kapas
ka5pe
5kapell
4kapen
3kapit
1kapp
kap3re
kap4s3t
1kar.
1kara
4karab
4karam
karan5
ka3rav
1karb
4karbei
4karea
ka6rek
ka5rel
1karf
5karg
ka4ri.
ka6rid
6k3arki
6k5arkt
1karm
kar3n
ka3rol
kar3om
kar5pes
karp3s
3karri
7karsj
kars4t
1kart
kar5ti
5karu
4karå
1kas
7kas.
ka5se4i
ka3sek
kas5ev
kas2ju
6kasjø
ka4sk
kas3ka
kasko5
6kasp
ka4spi
kass6
kas6sad
kas4sak
4k3assi
kas4so
ka4st
8kas5to
kas2t3r
1ka7t6a
ka3ted
3kateg
ka3tet
ka1to
ka4t5op
4ka1t4r
kat7s
kat5ta
kat4tel
kat6term
katte5s
kat4til
kat4tri
ka4t5y
k7au4r
2kav
ka7ves
k9avis
kav8l9u
9kay
6k1b4
2kc
k5ce
kcen4
2k1d
k5d6v
1ke
2ke1a8
ke9al
2keb
4kebr
4kebuk
4kec
ked4
ke5da
4kedag
4kedal
5kedan.
9kedant
ke5de
6kedei
4kedem
4kedes
7kedes.
2kedi
2ke5dr
ked8sk
kedu6
4kedy
2kedø
2keeg
2keek
2keel
ke4ep
ke7ern
2keev
4kef
k3eff
k5eft
2ke1g
k3egg
keg8ga
5kegladh
ke5h
3kehet
4kehj
2kei
k3ei2d
k1eig
ke5il
ke1im
k6e1in
keis2
2kej
2kek
kek2l
ke3kn
k1eks
k5ek4t
k6el.
2kela
ke3l4ak
5kelal
ke6lans
ke6lat
kel5eier
kel5eig
kel7eik
kelei8ke.
6keleis
kel3e4l
4k5elem
4keleng
4ke5lep
4keles
7k6elet
4kelev
keli8e8
keli9en
3kelig
4kelign
4kelinj
kel5int
4kelis
ke4lise
5kelit
4keliv
kel5l
4kelof
6kelov.
4kelove
kels4
kels7kar
kel5sl
kel5sp
kel5st
kel3sv
kelsva9
kel2t
kelt3e
6kelua
4kelue
kel9uka
kel5uke
ke4l3ur
6keluv
kel5v
2kely
2kelæ
2kelø
kelø8pa.
6ke5l4å
kelå7re
2kem
ke4mit
5kena.
6kenam
ken6ap
ke4nas
5kenatts
ken5de
6k5en6den
6k5en4der
4kend5r
ke3ne
4keneb
4kenek
4kenel
4kenem
6kenett
4kenev
3kenf
ke4ni
5k6enh
4ke5niv
ken3k
ken7n
kenne4l3
ke4nom
ken1s2
4k5ense
kens6t
ken7te
ken5t6r
4k3entu
6ke3ny
6kenø
2keo
ke3on
4kep
5kepi.
9kepia
7kepie
6kepl
kera7l
4keram
ke4ran
ker5ant
6kerau
4kered
4kereg
kerei4d
4kereir
6kereis
4kerek
4ke5rem
kere6n
6kerene
ke6r5eng
4kerenn
4kerep
ke4r5ert
ke3res
4keress
4kerest
4keresu
4keret
5keret.
5kereta
7kerets
3keri
ke4rif
6kerik.
4kerike
6kerikt
ke4rim
ke4rine
6keringi
6keringj
ke4rinæ
ke4ris
8kerist.
8kerista
6keriste
3kerm
7kerop
5keror
4ke3ros
kero6se.
ke3rot
k4ert
ker5to
ker3t4v
ker3un
4kerus
keru6se.
kerø6re.
8ker8øya
6ker6øye
2kerå
5kes.
4kesam
9kesam.
7kesdale
5kese.
k5esel
ke5sil
4kesit
2kesj
k9es8ka.
4k5eske
kes8ke.
4keski
4keskj
6keskå
kesle6ge.
kes5ped
5kespot
5ke4spu
5kest.
4ke3sta
5keste.
4ke5sted
4ke5stei
kes6tem
4ke5s4ten
ke3sto
4kestri
4ke5stru
4kestu
4kestø
ke4s5un
kes1v
2kesy
kes1å
2keta
keta6ka
keta6le.
5ketals
k6etar
ke3te
5kete.
4ketek
7keth
2keti
2ketj
2keto
2ket2r
kets2
ket6t7enh
ket8tes
2ketu
2kety
kety6e
4ketæ
ketøy6s5
2ketå
2keu2
ke5ur
2kev
kev2a
keva8ne.
5kevas
3kevel
kevi6sa.
k1evj
kev6ja
kev4je.
k3evn
kev6ne.
ke3vr
kevæ8ra
ke2yt
6keæ
2keø
2keå
1ké4
két5
2k1f
k5fi
4k5g2
k3ge
k5gh
kgu4
4k1h
kh5ak
k4har
khe4o
khjul8s
kh6m
ki3a2r
k3ideo
4kidol
ki3dr
k4ie2
kie5re
ki6el
ki3er.
2kif
ki5g4
ki6ka.
kikk8s9
ki1k8l
ki3k2r
kik4s
ki8la.
3kilde
ki4le.
ki5li
4kilj
kil9ja
kil6le5st
ki7loa
ki4log
ki3los
ki4lov
2kilt
ki7lå
ki8ma.
ki4me.
5kimo5
ki4mol
2k1imp
kin9and
ki4nark
ki5nas.
6kind
ki5ne
ki6ne.
2kinf
1king
king5and
kin3ge
kin5ing
2kinn
kinnsi8da
kinnsi8de.
kinn4sp
ki2no
2kins
kinsi6de.
2kint
kinti8me.
ki6nu
2kinv
kio4
4kiol
7kios
2kip
ki5pe
ki4p5l
kip5pe
kip2s3
1kir
ki5re
ki5ri
4kirs
ki3se
ki5sko
ki3smu
ki1s2p
ki5stav
ki5str
ki6ten
ki7ti
5kito
ki4ton
4kiu
k6iv
ki4vek
ki4v5enh
ki6vi.
kiv3s
kj2
3k8jan
kjap5pe
6k7jarn
kje7fj
kje7f6r
4kjegg
3kjeld
kjel7leg
5kjemas
3kjemp
6kjenk
kje9ny
kje1s
kje6t5r
kjet5t
6kjor
kju5le.
kju5len
kju9r
3kjærl
k5jødi
1kjøp
3kjøri
kjø4tr
2kk
k1ka
k2kab
kk3aft
k2k1ak
k2k3al
k2kam
k4kanb
kk5and
k8kand.
k6kanden
k4k5ang
k4kann
k4kao
k4karb
k6karg
k4k7art
kkar6ta.
k5kast
k6kasu
k6katt
k2k1au
kk1av
k6kedo
k4kedu
k2kee
k2keh
kk1ei
k5kel.
kke6lei
kk5e4lev
kkel3t4
kkelu4
kke4luk
kkel5un
kke6nan
k5ker.
k4kerei
k4kerel
k6kerent
k4kerig
k4kerit
kke5r6und
k4kesa
k5kesau
k4kese
k4kesi
kke3s4l
k4kesp
k6kestad
k4kete
k5ketet
k4ketø
k4k9g2
k1ki
kk3ind
kk3inf
kk9inn
kk3ins
kk3int
k2kir
k1kja
kkjek8
kk5jent
k4k5jern
kkje7t
kk5ju
kk5k
kkla4g
kk3lan
kk8lar
kk7lau
kk1lo
kk1ly
kk3læ
k4kn
kk5ne
kk5ny
kk6s5v
k1kod
k1koe
k4k1of
kko6lig
kk5oml
kk7oms
kk9omt
k6koo
kk1op
kko7s
k4kosi
k6kosk
k4kost
kk3ove
k4kra
kk5ram
kk3rap
kk3rea
kk5rei
kk3ren
kk3res
kkri6k
kk3ro
kkro8e
kkro4s
kk3ru
kk4rus
kk7rø
kk7rå
kk7s
kks6al
kk4sar
kk5sed
kk3s4ei
kk4sin
kk1sk
kks4kj
kks4l
kk3sla
kk7sle
kk5sli
kk3spe
kk1s2t
kks5tak
kks7tep
kkst4r
kk8s7va
kk5s4å7
kk3t2
kk5uk
k4kuni
k2k1u6t
kk1v
k2kvo
k1ky6
kkyl4
kk5yr
kk7yt
k2k1ø
k8køl
kkø6r
kkøy6
kk1å2
kl4
6kl.
4kla.
4k5lagt
2klak
kla9ke.
kla4mel
3k2las
k7lati
kla4tr
kleby7t
3k4ledd
kle4deb
kle4des
2kleg
klei9e
k7leik
k4leiv
k2lem
5k6lem.
7k4leno
k6lerik
kles7j
kle5sno
kle4sp
kle5sti
kles7s8
2klet
8klia
4klie.
4klig
1k2lim2
3k4lini
k5linj
1klip
4klit
klon7a8l
1klos
2klov
k3lukt
4klun
klun5t
k5lyd
6k7lyf
3k4lyng
klyse7te
k2læ
klæ5res
klø7na
k6lør
6kløs
klø9va
klø5ve
6k1lån
klå5re
2k3m
kmann6
kmål2
2k1n2
3k2nap
kna5t4re
kne4b3l
k4nedi
5k2nee
kne8se.
k4nest
kn5f
3k4nip
knippe6
kni2t3
3k2niv
kno7g
kno6kl
5knop
kno9ta
kno5te
3k2nu
4k3num
3k2ny
kny4s
k2nø
knø9le
kn3øy
9koa.
4ko1ak
9koane
ko7ar
ko2b3
ko3bo
4ko3br
ko5da
4kodd
ko4de.
3kodek
5koden
2kodø
ko3e
3koef
4koek
4koel
4koes
4koev
ko4g5eng
kog9ger
kog3l
ko4gre
kogst6
ko4gu
ko6gå
2koi
koi4e5ne
ko7i6k
ko1in
2koj
ko8ja.
ko4ka.
ko4kab
ko4ke.
ko6kel
ko1ki
kokk6o
k3okku
4kok4l
4koko
2koku
kolba5
2kole
ko4leg
ko4lei
ko6lel
ko4let
ko4leu
3kolle
ko5lo.
kol5p
4koly
2kolå
1kom
ko4ma.
4komaf
ko4me.
6komg
ko4mi.
4komil
4komisb
ko4mise
2komr
4komse
kom3sl
kom5so
kom4st
4kom5t
4komu
4komå
k6on
ko4na.
kon3d
kon6dr
kone5l6å
4koniv
kon3s2
kon6s7v
kon6ton
ko4nu
1ko1o
4koom
ko5pa
ko5pers
4kopet
ko4pi.
ko4pip
ko4p9l
4kopo
kop5per
2kopr
ko1ra
ko4ra.
kor6da.
kor4d3o
kord5s4ø
kor4du
ko1r6e
6koref
4ko7rei9
ko5rem
ko7ret
ko3ri
ko6rik
4korm
ko5rol
6korpa
6korpe
1kor3r
kor4sal
kor6s5inn
kor4s5l
kor6str
kor4sv
kor5tes
kor6top
kor4t5r
kort5s4
ko5ru
ko6rume
1kos
2kosa
ko6sa.
ko4sed
ko4sek
5kosele
ko5sen
ko4ses
ko9si
kosi9d
ko2sk
ko1sl
4kosmu
2koso
2ko1s2p
ko6sta
kost7as
kos6t5ers
kost5j
4kosø
kotes7
ko5t4i
4kotil
4kotr
ko6tre
kot2s
kots5tr
kot4ti
kott4s
kotts5t
4koty
2kou4
kout3
kou7ta
ko1va
kover7e
4kovr
1kov4s3
4koø
4koå
6k1p
kr6
k3rad
1k4raf
5krag
3krakk
krani6e7n
6krank
3krans
4krap
kra9se
7k8ra4sj
kras5s
kra4to
kra4u
1krav
4kred.
3kredi
4k1reg
kregi3
4krei
krei9e
krei5s
6krek
kre4kli
2krel
k5rela
4k3renn
4krent
6kreo
k5repr
5kreps
5kresj
4k3ress
kreta9
6k7retn
k4rets
k3rett
2krib
4krif
7k6rig
krig6s5
kri9ga
4krik
kri5ke
kri4kj
krik6ka
1krim
kri4me
3k6rins
krin6s7t
kri2p
1k2ris
7krisene
k2rit
3krite
6kriv
k2ro
kro5b4
kro5de
k3rofo
k4rofor
krok7k
k6roni
k5ronl
kro4nom
k4rop
krop9n
kropp4
k4rost
kro9t8e
kroten9
kro3v
kru3i4
krum3
kru5sa
krutt5i
kru3tr
2k5ryg
kry7pa
kry5pe
kry4pi
3krys
krø5ke
6k5rør
krø3v
4kråd
krå8da
kråe6
5kråk
krå5le
krå9m
krå7ne
k1sa
k3sa.
k2s3ad
ks3alt
ksa5me
k3sane
k4sans
k4s3ant
k3sar.
k7sara
k6s3ark
k7sas
k1sc
k2sed
k2see
kse6ge
k2s1ei
k5sekt
k5sela
kse5lev
ksen5to
k4serf
ks3erk
k5serol
k4sesa
k4ses6k
k4se3sm
k5seso
kses4p
k5sess
kses6sel
kses8serie
kses4sp
kses4st
kse6te.
ksfø4
k5sia
k2sif
ksi5ko
ks3ind
k3sing
ksi7ni
ks3inn
k4s3ins
k7sio
ksi3st
k4siti
ks9kab
k6s3kal
k6skio
ks1kj
ks5kl
ksko7na
ksko5ne
ks1kr
ksk8u
ks9ku.
ks7kua
ks8kut
ks1k6v
ks1l
ksla8ga.
ks5lo
k7s6lu
k8s7lug
ks5løs
kslø8va
kslø8ve.
k5s4mak
ks4mel
ksmå
k5s4no
k7s8nø
k1so
k6s7oa
k6sod
k4sog
k4somb
k2s1or
k2sot
ks1ov
k3spal
ks3pek
ks5pio
ks3pir
kspor6t5r
6k6s5pors
ks1pr
k8sr
k3spy
kss6
ks3sm
k5stad
k4stak
ks3tal
ks5tant
k7s8vak
ks6tav
kste4da
ks4teg
k3stei
k4stek
kst3ev
kstev6ne.
ks4til
k4stin
ks1tj
ks1tr
kst6ran
ks4t5rek
k6stren
k6strer
ks4tri
ks4tro
ks9tum
k5stus
ks3tyv
k2stå
k1su
k6sun
ks1v
k9s8vake
ksva8ne.
ks5veg
k7s6vert
k5s4vin
ks5w
ksy8na
ksy8s7m
ks5ær
ksø4ke.
k6s3øl
ks1å
k3så.
k4såp
ksår4
ksåt4
6k1t
k5ta.
kta7f6
k4tag
kta6ka
k4t3aks
k4takt
kta6la.
k4t3ana
kta9na.
kt3anl
k4t3ann
k4tanv
kt3app
k9tar.
k4t3arr
k4t3art
k6tass
k5tast
k6t7atl
kt5avh
kt5avk
k6t3avl
k3ted
k4teda
k6tee
k4tefø
kt5e4ge
k2te5i
k6teka
kte5le
k6t5elsk
kt5e4lit
ktem8
kt7emn
k4t3enh
k9ter.
kterie5n
kterie7ns
kter5s6
k7tes.
k6tesa
k6tese
kt5eske
ktes6ke.
kt5esti
k4t5e4ta
k4tete
kt5evn
ktev6ne.
k5tib
k3til
k4t3ins
k5tir
ktis5t
kt7i6te
kti6v7end
k2tja
kt7ju
kto9a
kt5off
k6togram
k4toli
k2tom
kt5omf
k2t1op
k9tor.
k7tora
kt5ord.
k5tore
ktori9e8
ktor7s
kt1ov
kt3ral
k2t1re
kt2ro
ktro5s
k2t1ru
kt4s5amb
kts5ar
kt5sek
kt7sem
kt4s5er
kt6sin
kts5kra
kt5sku
kts4kv
ktsle6ge.
kt6sok
kt4spa
kt5spre
kt4sta
kts6ton
kts5top
kt4stå
kt3t8
ktu9er.
k4tuk
kt7und
k2t1ut
kt7yrk
ktyr8ke.
ktør7
ktør8e
k6t5øs
kt1øv
k2t3år
ku2a
ku9an
ku4be.
ku3bj
2kud
ku4dal
ku4er.
kue4r5a
ku4et
6kuf
ku4f3l
6kug
k5u4gr
ku7is
kuit6
6kuldi
kuld3r
ku4led
ku4leg
ku6lei
ku4lem
ku5len
ku4let
ku4lev
ku5li
ku6li.
3kull
1kult
ku4man
kumen6tal
ku6mi
kum2s
3kumu
1kun
kund5s6l
2k1ung
kun4ge.
k6unn
ku4o
1kup
ku4pe.
kup4pl
ku7ra
ku4rek
ku8r7o
ku7r6op
kuro8pa
1kurs
kur6sk
kur4sp
kur4s3t
kurs3v
kur3t
ku5ru6
kuru9ken
kuru7ker
1kurv
kur4v3i
1kus
5kus.
ku7sa.
kus5a6k
kus5ar
5kuse
ku4s5el
ku4ska
ku7s6pe
kus3t
6k1ut.
ku1ta
4ku5te.
ku5to
ku6t7r
2kuts
1kuu8
kuøy6
kv2
kva8ke
k4vali
k6vard
kvari6e5n
5k6vart
kva9se
kve3d2
kve7e
k6veil
kvei9se
1k4vel
kve5la
4k3verd
5kvern
kverns8
2kves
kves5t
7k6via
4kvid
3k4vie
kvi4ene
kvi5er
kvi7la
3kvinn
kvi5se
7kvist
2kviv
1kvo
k1vog
6kvok
k4vot
k2vu
4k3væ
k1vå
k7we
k5wu
ky5a
ky6el
4kyf
kyf5le
2kyg
ky4leg
2k3yns
kyn6skjer
ky2p1
ky4p5r
1kyr
kyrie5ne
kyr8ke.
ky8sa
4kyse
ky6se.
kyse8te.
ky3skr
kys6sk
1ky4st
kyst3a
kys4tel
2kyt
ky6ta.
kyte3s
k1æt3
1kø.
kø2ar
1køe
kø4en.
kø2er
6k1øk
kø4le
k1øn
køn6skjer
k3ørr
køs4
kø5se
køy7ar.
k7øyd
køy4e5ne
1k6øyr
4kåke
kå3le
kån8da
kå5ne
kå4pe.
kå7pen
kå9ras
kå1re
kå1ri
kå2t5
k5åt6t
1la.
2laa
la1b
4laba
la6bl
1labo
2l3abon
4laby
4lad.
l6ade
la4dem
4ladg
ladi9e8
2ladm
2ladr
lad3s4
1lae
2laei
4laent
4laep
2laf
la3fl
4lagg
lagi4
6lagne
la2go8
lag5om
la2g1r
lag5san
lag4sj
2laha
2la1in
la5ka
la4ke.
4lakj
l2akk
la2kr
l7aksj
l5aksl
4lakt
lakterie6
la5kø
2lal
l1alk
la5mab
4lamb
la4mes
la4met
la3mo
l8a8mu
4l3anal
lan2c
lan6das
lan6deb
land3r
l6a3ne
3lane.
4lanet
lan6gel
lan4gem
lan6germ
lan4gr
lang3s4
lang4s5e
lan6g5ø6
4lanl
4lann
l3anno
la4nor
6l5ansi
lan5ti
4lanv
l3anvi
2lao
la6pal
la7pi
la8pl
lap5sa
lap5sen
lap5s4i
1l8ar.
6l7arab
2larb
l8are.
4l7area
la9red
la5rem
l6aren.
4larena
lare6t
la6r7eta
5larf
la7ria
lariar
lari6e7n
4l3arki
l2arm
lar3n
6l7arr
4lart
lar6ta.
lar7vet
la6sc
la5se
lasi9e
la2sk
7laskj
4lasm
la5smi
4la4sp
las6sak
las6sam
las6sat
las6sel
l6ast
4lastr
las3v
la1ta
lat5ang
6latau
la4teg
lat6ek
la4teno
late5s4
la5ti
la6ti.
4latm
la1to
lat7ra.
lat9ran
lat5rar
lat4t5is
lat4tra
latt6u
lau7a
2laud
laue6
4laun
4laur
lau7se
lau6st
2laut
2lav
la4v5al
la4vel
l5avh
lav5inn
6lavs
7lavå
1law
la6y5
2l1b2
lba3de
lba4k
lba5ke.
lba4ne.
l5be
lbe9na
lbe8re.
l4boa
l6buh
lby4e
l5bå
2l1c
l4ce.
6ld
l7da.
ld5aks
ld5akt
l9dand
lda6t5o
lda6t5y
l2deb
l5den
l2de5o
l2dep
l3der
l7der.
lder7a
l4derek
l6derik
l6derklæ
lderle9g
lder5s6te
lder6s5ti
l4desh
l6destr
l9dé
ldis7k
ldo9a
l8d5oks
l2dol
l4dore
ld5ovn
l3drak
ld3ran
ld5ras
l6dre.
ld7regn
ld5rer.
l8dres.
ld1ri
l7dry
ld1rø
ldse8
ld4sek
ld4sel
ld4ses
lds1k
ld4ska
lds4kj
ldsla8ga
lds6leg
lds4let
ld4s9m
ld5s4om
lds3tr
ld6tus
ldø2
ldø5d
ldø5l
ld7øy
1le
2lea
le7ag
le3ak
le1al
lea5la
3leas
le5at
2leb
le4bem
le6bosta
5lebæk
lec4
2leda
5ledar
led4dø
4ledeb
le4dem
6ledep
le5der
le3des
2ledo
3ledop
5ledov
le4dro
le5dry
led1s2
6ledu
4ledy
2ledø
4le3då
2lee
6leei
6lefa
lefa6ne.
4l1eff
2lefi
4lefl
4lefor
4lefot
2lefr
l1eft
6lefy
4lefø
6legap
5legas
3lege
le4ged
le9gen
le4gera
le9geran
le9geras
le4gero
le4geta
le4gev
7leggi
le3gi
6legif
4legj
2le1g2l
le4gol
4legre
leg3s4
2legu
2legå
2leh
6lehal
6lehamr
6lehan
6lehau
6lehave
le3ido
l6eie.
lei5ende
lei4e5ne
l6ei8et
leig6d
lei4ger
lei7ger.
lei4get
leig4h5
leig6na
leig8ne
2lein
le3int
lei6r7u
leis7t
l6eit
2lej
2leka
le4ka.
6lekan
lek6e
le3ki
2lekj
lekk7s
2lek2l
2lekn
lek4na
2leko
2lekr
4l3ekso
4leksp
lekt5ord
lekt4s5t
2leku
2lekv
4lekø
4lekå
2le3la
8l9eld
2lele
l3elem
4l5elg
5lelig
2lelo
3lels
4l3elsk
le1lu
4leluk
l5elv
2lely
4lelæ
2lelø
lelø6pa
4lema
le3me
le8me.
4lemet
8lemetrisk
8l9emn
lem8na
2lemo
lem9ped
lem5pes
3lemr
lem4si
lem4s5ø
2lemt
lem5ti
2lemu
6lemy
4lemø
2lemå
le4na.
le4nal
4lenav
lend8a
len9dan
6lenden
l6endre
4lendri
4lened
4lenem
4lenev
l4engd
len4g5r
leng9u
le5ni
4leniv
lensa4
len4s5ak
4lensem
len5ses
len4sta
len4tam
len4tr
len8t9ra
2lenø
4lenå
2leo
5leol
2lep
le5pa
le4pel
le8p9enden
le2p3j
le8pla.
le4ple
4lepo
4leraba
4leram
le2r3amb
ler5d
l8ere
le9re.
6lerea
4leref
4lereg
4le9r8ei
4lerek
le5res
4lereso
4leresu
4leret
4lerev
9leri.
7lerie
le6riei
le7rina
le4riv
4l5ernæ
le5ro.
4lerom
6lerope
le3ros
4le3rot
7lers.
lers4p
ler7te
le1ru
4lerus
leru8se.
2lery
5leryr
2lerø
2lerå
5l6es.
le4sab
4lesam
7lesar
4lesau
2lesc
le5sed
le4seg
4lesek
le5sen
le3ser
4leset
4lesho
le6si.
4lesig
le7sing
les5inn
4lesit
4lesju
le7skap
le4s3kj
6leskol
le6sk9u8t
4lesla
2lesp
6lespal
les3s6
lesse6ne.
4lesta
9lesta.
7lestal
le5sted
le5steg
le5stel
le4stim
le3sto
4lestrø
4lestyr
4lestø
4lestå
4lesug
les1v
le5s6vi
4le5sy
4lesø
5lesøy
3let.
le4tab
6letak
leta8ka
leta8le.
l5e4tas
5lete.
6letea
4leteg
4letek
le5ten
6letenk
6le7tep
le5ter.
4letes
2le3ti
l5e4tik
2letj
2leto
2let2r
le7tre
le5t4ri
3lets
let6sj
lets8k
let6tea
let6tr
lett3s4
2letu
le4tv
2lety
lety8e
4letø
8letå
4leul
2leun
l1eur
2leut
le4ute
2lev.
le6vad
le6valu
le4ved
4leveg
4levei
4levek
6levern
4le4vev
levi6d
lev5n
2levo
lev1r
4levs
4levæ
lex1
4leø
2leå
5lée
1lér
7lét.
7lè
5lê
4l1f
l4fa.
lf5ant
l5far
l5fe
lf3f
l5fig
l5f6in
lf5ja
l7fje
l6f3nul
l4fom
l4fut
2lg
l6gaf
lga8le.
l4g5alt
l4g3ana
lga5t
lga4ve.
l2ged
l4gela
l4gele
l2gem
lge3na
lge4r5an
lge4rap
lge5ri
lger5un
l4gery
l4gesl
l6ge7sp
lg5g
lgie8n
lg1lo
lg5ly
lg5n
lg3ob
lgo2d
lg1ok
lg1om
lg5ov
lg3ref
lgr9øy
lg3s2e
lg2sk
lg5s4kre
lgsle9g
lg5s4tr
lgu4l
lg3un
lg3ur
l1gæ
lg5ø
l6gå.
lg5år.
lgå8va
lgå8ve.
8l1h
lha8ka.
lhav6s5
l5hj
1li
li1a
li4ala
li2am
li5ans
li4as
liba5
libe5ro
libi5
libie6
liby5e
li4dak
li4ded
li4do.
2l1idr
lid3t
li4ene
li3er.
li5ers.
lie5s
3lif
4lifat
lif5f
3lig
li4ga.
li4g3an
li4gar
lig9art
li8gas.
li4g5enh
li4get
5lign
li4g3re
lig3se
lig3s4i
lig3sl
lig3s4p
lig5s4ti
lig5str
li2gu
4lih
li5kan
li9kar
li7kas
li5kee
li3ken
li5keså
li9ki
likk3o
li1k2l
9likn
liks4t
li5ku
6lila
8l5ild
li3le
lil5lebe
lil5let
li4mar
li4mas
li6mate
l6ime
li4me.
4limh
limp3r
lim7r
lim9u
li4na.
4lina6l
lin6c
linch5
5l4indr
4lindu
lind3s4
l5indus
li4ne.
li3ne6a
li6nem
2l1inf
lin4g3j
ling5l
ling7sen.
5lingv
4l5inju
lin5kes
lin5kle
lin4kv
2l1inn
lin5net
3linni
6linns
6l5inntr
li4nor
l4inse
5linsk
4l3inst
4lint
2linv
li6n5ø6
lio4no
lion5sp
lion5sv
li5o6s
2lip
lipes4
lipp4s3
li9rar
li4rek
4lisak
li5set
lis4kl
2liso
4lisp
lis6sp
lis7tan
lis6terk
lis5ti
4lis6til
list3o
li6s8tr
list7rø
lis4t3u4
li4st5y
listyr8ke.
li4tee
li4tek
li4ti3a
li4tid
li4tig
li4til
li4tim
liti5st
li4tiv
lit5j
6litn
li5to
li2t1r
lit5rer
lit6tele
lit6terk
lit6term
litt5s6
li5ty
7liu
li6va.
li4v3ak
liv5eg
livi5e
liv2s3
2lj
l1jan
l1jar
l4jarb
ljar5s6
ljas4
l4jed
l6jee
l2jei
l2jek
lje3l
lj9elv
l1jen
l3jer.
l4je1s
l5jes.
ljes4t
l5jet.
l4jete
l5jete.
l6je5t6r
l2jev
l5jé
l1ji
3l2jod
ljo8e
l4jom
lj5ori
3ljos
lj5un
l7jur
lj7ut
ljø3
l5jøs.
6l1k
l3ka
l5ka6l
lkali9e8
lk4an
l6k5b
lk4e
l3ke.
l2ked
l5kedal
l3kede
lkeei4
l6keh
l5keleg
l3ken
l7ker.
l4kera
l4keri
l4k5ers
l4ke3ru
l5kestad
l5ket.
l5kets
lk2l
lk4li
l5k4lu
l6k5nin
l6ko.
lko9ma
lko9sa
l2kot
lkras5
lk5ri6k
lk4ser
l4k3s2h
lk1s4t
lku4le.
lku8t
lk9ute
l6kveg
lkå1
2l1l
l5la6a
ll6a5f
l2lak
ll1al
l4lami
l5lane
ll3anl
l4l5ano
llans4
ll5ansk
ll7apa
llap3s
ll4as
ll5asp
ll5aur
llau6re
ll7avl
ll5avr
ll3d2
lle5a
l5leak
lle8da.
lle4d3r
l3lee
l2lef
lle5gev
lle5gr
l5leha
l5leho
l5lehå
l4l5eig
l4leki
l6l5ekst
l4leli
l2lem
llen6da.
ll5enden
l4lendr
l6lendt
l4lenk
l5l8ens
l4lentu
l4lenu
ll5eple
l6l5e6rik
l4lerob
ll6es
lle4so
lles5pr
lle5stø
l5let.
l4leta
l5lets
llet6tele
l8letæ
l2leu
ll5even
lle7vev
l5levå
lle6y
l2lé.
ll7g2
lli1e
lli5e4n
l9lig
l2lim
l4l3ind
l4lins
ll3int
l9lint.
l3lip
l4lir
lli6sen
l4liv
ll1j
ll7k2
ll5m
llmue9ne
llmu7ens
llmu9er
l5lo.
llob5
l2lod
l4l3off
llo5id
ll5oks
llo2m1
llom5s6
ll3op
ll5opp
l2l1or
l4loso
l6lote
ll5p
llra7n
ll4sak
llsa6me.
ll4sem
lls5end
llsk4
lls6kar
lls5kv
ll5skå
lls5lag
ll3smy
lls4no
lls4te
lls6tig
lls7øk
ll3t4
llto4e
l8lua
l4lu4e
l4luf
ll7ug
llu4k
l8l7uka
l4l3uke
l6luks
l5lum
l4l1un
llun6ge.
llu4pi
l2l1ur
l3lus
l2l1ut
ll1v4
llva8n
lly4se.
l4løk
ll5øks
llø6pa.
l4løve
ll7øy.
ll5øya
ll3øye
lløy6er
ll5øy6n
ll1å8r
ll3å2s
2l1m
l5ma.
lm3anm
l4map
l4marki
lm3av
lm7b
l4m3els
l4melu
lm5e4po
l4m5erf
lme7ri
lme7sti
lme5t4r
l5mil
lmi8le.
lm3ind
l5ming
lmini6
lmin7ne
lm3ins
lm5int
l7mis
lm5l
lm5m
lm1op
lm1s
lms6j
lm5s2p
lm3t
lmu4le.
lm3ut
lmyr8ke.
l4mø.
l6m5øs
lm5øy6
lmøya9
lmå6la.
lm5å4r
l4m5ås
2l1n
l2nab
l3ne
lni4u
l7ny
lo1al
7loane
lo1a4r
5loar.
2lob
lob5by.
lob9byan
lob9byar.
lob5bye
lo2bl
lo2d3a
lo3de
lo4d3ri
lod3s4m
lod7ste
lod7s6v
lo6d5u
6loeng
6lofj
3loft
1log
lo5ge
lo6g5e8v
lo4gir
log2o
lo3gop
log8res
lo6g5ro
log5sa
4loh
lo5id.
lo3ide
lo1in
3loja
lo1ki
lok4ko
lok6kul
2lo1k4l
4lokon
2lok7s4
lok8se.
lo1k4v
lole6ge.
2lolj
lolo9
l5omdr
lo4m5in
lom4mel
lomst9r
lo4nal
6lond
lo5ne
lon4g3r
lo4nit
lon7skj
2lop
lo3pa
lo4pea
lop5pa
5l4opt
lo1ra
2lord
lor6da.
lo1re
4l1org
lor4g5l
lorie6
lo1ro
lo7rød
lo7sa
lo6sek
lo4ses
lo5sev
los4kle
lo1sl
lo7sp
2lost
lo9tes
lo8ti.
lo3to
4lottet
lo1un
1lov
lov7ald
lo3van
lo9vand
lo7vane
lo3var
lo3ve7d6
l6over.
love5re
l5overn
6l5overs
6l5overt
7lovo
lov3sa
2l1p
l7pa
lpa5re
lpas5
l4pedo
l4pee
l2pei
l2pel
l5peleg
l3peli
l4pelin
l3pesm
l4peti
l2peu
lp2h
lp2i
lpin3e
lpi5ne.
lp2l
lpo6et
l4put
l5q
2l5r4
lra8da
lradi4u
lra6ne.
lre4de
lre4i
lre8ka
lre8ke.
lre8va
lri8ma
lri4ve.
lro8de.
lro6pa.
lro8sa.
lro4se.
lrot5s
lrø6re.
lrø5v
lrå8da.
lrå4de.
8l1s
l2sad
lsag6
ls5ald
ls4am
l7sana
lsan6ke.
l4s5ano
l4s3ans
ls5ark
l4sat.
l4scu
l3se.
l2sed
l2see
ls3eid
ls5eig
l4s3ele
l4s3elv
l2sem
ls5emb
l4seno
l7ser.
lse2s
lses5ku
lses3l
lses5pa
lses5s
lse8s5tr
lse4te.
l2seu
l6sev
l4sf
l2sh
l5sig
l5sik
l6s5ill
l4sim
l5simu
l4s3inn
ls5jakk
l5sjef
ls3jeg
ls3jen
8lsk.
ls5kabi
l4s5kan
ls5kari
lsk5art
l6s5ke
lskif5
l2s3kild
lskinn6
lskinns5
ls1kjed
ls3kjo
l6skl
lsk3læ
ls3koa
ls5kor
ls3kov
l4skra
ls8ks
lsk5un
ls7kva
ls3kvi
l4skå
ls3kåp
lskå6pa
l2sl
lsla4ga
l7slagn
lsle6ge.
ls5lo
l5s4luk
l6s5løs
l2sm
l5smør
lsmå6la
l2snu
lsok3
ls5ond
lson6de.
l2s1or
ls7o6se
l5sot
ls1ov
l2spa
l9speg
l5spei
l9spel
l5spi
l4spr
l5spred
ls3pri
l8s7s
l4s3tak
l4s3tal
l6stank
l6ste.
ls4ted
l4steg
l3ste4i
ls4tel
ls5terr
ls6ti.
ls4tie
ls6ton
ls5tren
l9stri
l2su
l5sub
l3suk
ls1un
l2s1v
ls7vea
ls5vee
lsve8en.
l6s5vek
lsve7re
l4svik
ls6vind
l4sør
l2s1øy
l2s1å
2l1t
l4taa
l4taf
lt3akt
l3tal
lta4la.
l4t3alb
lta6lev
lt3anl
lta6no
lt3art
lta4st
lta8tes
lta4t3o
ltat3r
lt3avk
l5tavæ
lt9b
l3tede
l4teka
lte6ma.
lt4en.
l4t5enh
lt3epi
l4teras
l4t5erst
ltesa8me.
ltid6s
l4tiet
l2tif
lti6g5
l2tik
l4tina
lt3ind
lt9inn
lt3ins
l4tivi
l2t1ja
ltle8ge.
lt9n
lto9ar
l3tog
lto4s
lt3ost
lt2r
l3tra
lt3reg
lt3rei
l6treko
l6t5rel
l6t7rem
l4trens
lt3res
l5t4rest
l5trev
l4t5rit
lt3rol
lt3rom
ltro8pa
l5tros
l4t5rød
l5trå
lt1s2
ltsa8me.
lt5s4i
lt7s6t
lt2s3v
lts4vi
lt7t8
lt3und
ltu4ra
ltur5e6
ltu5r6en
ltu5r6er
ltur5s6
ltur5å6
l2tut
l5tv.
ltva8la
l3tvs
l4t5w
l3ty
lty8d
lt7øl
lt3øv
lua8r
2lub
lub6band
lu6bri
lu5c
lu7ere
1luf
3lugar
lu7go
lui6
luid6er
1luj
4luk.
lu4ka.
4luket
luk6keri
lu3kr
5l6ukt
4luly
l4um
lu6mel
lu2mo
lum6sk
lu4mø
lun5d4r
lu4ne.
lun4gel
l7u2ni
lun5ne
3lunsj
4lunt
lu6o
lup4s
lu2p3u
lur2e
6lurei
lu5ren
lu5ri
6l5urn
lur8na
lur8ne.
lur8ta
1lus.
lusa5
lu7sak
lu6sel
lush7e
lu2s5k
lus4o5
lus4sid
lus4s3t
lus1t
lus2t3r
luta3
lu3ta.
lu7tet
6lutf
4lutg
luth
3lu5t6he
lutla9
lut6m
lu1to
lu4t5r
2luts
lut4tal
lut4tap
lut4t5at
6lutv
1luv
lu4va
lu4ve.
lu9ven
lu9ver
8lv
l1va
l4va.
lva6k
l4vakti
lva6la
l4va4m
l4vana
lv8and
l7var.
lv7asa
l4v5ass
lve3d4a
lve5i6s
l4vela
l4vele
lv4en
lve9ne
l9ver.
lve9rau
l4veru
l4vesk
lve5sl
l7v6et.
lve5str
l9vé
l1vi
lvi8ene
lvi9er
lvi6ka.
lv9im
lvin5g6r
lv3iro
lv1j
lvly8se.
l6v3n
lv1of
lv9op
lvo8re.
lvor4s
lv5o4v
l6v5p
lvra8r
lv9ri
lv1s2
lv5se
lv7s6k
lvs6l
lv9ta
l5vøe
lv1å
l3våg
lvå4p4
lvå6r
l5w
ly1a
2lyb
ly4d7r
ly5e
lyes3
ly4gel
ly5g6l
ly8is
2lykj
lyk6keri
ly5ku
ly7kv
6lykø
ly5l
ly5me
2lymp
ly2n3a
ly4ne.
ly4n5il
lyn3s2
2lyo
ly5ok
ly3pe
ly1r8
ly8ra.
ly6re.
6l7yrk
ly4sa.
ly4s5a4k
lyse6te.
lysk4
lys3kj
lys9kl
ly2s1l
4lysp
lyst9ra
6lysy
ly8ta.
4lytek
ly4teri
lyte5s
l5y4tin
ly1tr
ly3ve
l3z
l6z5b
1læ1
6læd
læ6ra.
læ5rar
lær4arm
læ4re.
lære3i
læ3rer
læ4re3s
læ5res.
lær6sv
læ6ta
1lø
lø3de.
lø4del
lø5dem
lø4er
løk5kj
4l1økn
2løko
lø4k5r
l5ø6l
lø9me
lø2na
løns5t
løp6s5
5l4ørd
lør5k6
lør5n
4l5ørr
5løs.
lø2sa
lø5san
lø5ser
løs3k
løs3s
2løt
lø9ta.
lø3te.
lø4teg
løva9r
6l7øv8d
lø4ve.
lø3ver
lø5ves
6løy.
4løya
2løyd
4løye
løy8ed
løy5el
2løyf
løy4g
løyg5e
4løym
6l5øys.
løy5ter
lå6gal
lå6gre
lågs4
lå4gå
2låi
lå1k4
lå6ke.
lå9me
lå2m5o
lå2n
6l5ånd
lån2s1
2låp
l1åp9n
2lår
lå8ra.
lå9rar
lå5ras
lå3rin
lå1ru
lå6sa.
lå1sk
lå6sko
lå4s5l
lå4ste
lås7ten
lås5ter
lå5su
lå3te.
lå4teg
lå4tek
lå8ti.
4lått
lå4ve.
1ma
2maa
3maa.
ma3ar
2mab
ma5br
ma3che
mada5me
ma4del
ma3dra
m6ad9s
4maef
4maek
7maene
2ma1f
3mafia
3mafr
6mafrå
ma8ga.
ma4ged
ma4gel
ma4ges
3magn
ma2gr
2mahe
ma4is
ma4ja
2mak.
ma5kab
4makad
ma4kes
mak7ke
4makl
mak6le
ma4kot
mak2r
ma3kre
mak5ron
mak4tal
4m3akti
mak4to
makts4t
ma1ku
2ma1kv
ma1la
ma7leb
ma6leng
ma4let
mali9e8n
mal5l
ma4lov
mals4
mal4t5ek
mal3u
mal3å
4mamer
ma3mo
m4an.
ma3nak
m3anal
6manam
4manav
man8ce
man4dom
man4don
ma3ne
m4anf
man5g4a
m6ange
4mangr
mania8
2manl
m3anle
4manm
5m4ann
man4nem
manns5l
ma4no
2mao
4mapa
2mapr
4marb
mar5d6
7mare.
6mareg
ma3rei
ma7rel
5ma9ren
ma5res
3mar4i
mari8e9ne
ma3rin
m4arka
4markit
mar4kv
mar5m
marmo9ra.
mar7n
ma1ro
ma4ro6p
mar3s4h
mar7sl
mar5te
ma4ry.
ma6rå
4masel
ma5set
mash3
ma4sia
ma4sik
ma4sis
6masju
mas4ki
4masko
4masp
mas4see
mas6set
massø9
7mast.
ma5stem
4masto
4ma5str
2masy
m6at
ma1ta
ma5tad
ma3te
ma4te.
ma6ted
ma4tel
7maten
7mater.
6matera
7matet
6m7atfe
4matil
7matil.
ma1to
ma1tr
4matra
ma4t5ras
ma4t3re
ma6t7rom
mat3s2
mats8l
mat5ta
m8at7t8r
2mau
mau4k
mau7l
ma1un
5maur
mau7su
2mav
ma6ve.
ma5ven
m7avh
m5avk
ma4ze
ma3zo
2m1b
m4bao
mbar3d
m2bea
m4beb
mbe9da
m4bedø
m2bef
m2bek
m4beli
m2bem
m4bena
m4beo
m4bereg
m4bero
mbet2
mbi6ar
m2bib
m3b4l
mboe2
mbo4end
mbo5er.
mbo5ere
mbo5id
mbo5n
m4bop
mbo5re
mbo9t
mbu7ar.
mbu4e
mbue7re
mbus5
m1c
m6co
2m1d2
m3de
md7om
1me
2mea2
me5al
mea5m
2meb
2mec
meck4
4medat
2medb
5mede.
me4ded
med5ei
me7den
me7det
4medf
me3di
4medik
4medir
2medm
me6dok
4medom
2medr
me6dret
med1s4
4medu
me6dun
me5d4us
med5v
7medve
2medy
4medå
me7e
2meef
6meek
2meel
4mees
4meev
2mef
m3eff
6me2ga
me7gal
2megr
2megu
4meh
mei2e
meie5n
m1eig
me3ild
me3ind
mei5ni
me7isk
4meiso
2mej
4meki
4mekj
2mekk
me2k1l
me3kn
4meko
2me5k8r
4meks
mek5t
6mekte
m2el
4mela
me5l4aks
5melane
5melar
me3le
me4le.
4meled
4melei
4melek
6m5e6lem
me4l5eng
4melik
4melis
4melit
4meliv
mel5le
mello6m3
4melok
4melov
mel4si
mel2s3j
melsk4
mel5s4t
mel7tr
me1lu
mel5v
melvi6
2mely
2melæ
4melø
4me5l4å5
2mem
me6mo.
4m5enga
men5k
menle6ge.
m6enn
men4ny
me4nom
me4nor
men4si
men3sm
men5spl
men5te
men6tek
men4tom
men5tr
me4nyt
2me3o
me6os
2mep
5mer.
me6rab
4merad
me4ra5l
me4r5ant
mer5di
4mered
4mereg
4merei
4merek
4merel
me6rense
me3res
4meress
mere6t
m4eri
4me5rib
meri5ke
5merin
merle7g
mer9n
mer5os
5mers
mer5sk
me3run
mer5und
4merus
2mery
me2r3ø
2merå
me4råk
5mes.
2me5sa
4me5s4h
2mesj
2me1sk
mes5ke
2me1sl
mes6le
4me3so
2mesp
5mess
7mest.
4mesta
5meste.
mes4ti
6me7sto
mest3r
me5stro
6mestrø
4mestrå
4mestu
4mesu
2mesy
2mesø
4metab
4me9tap
me4tar
me3te
4meteg
4metei
4metek
4metel
4metep
4metil
2metj
4meton
me4t3ra
me4tre
met5ren
met7rer
met5res
met5rik
me4tru
4metræ
2metu
4metv
2mety
2metø
4metå
2meu4
7m4eu3s
2mev
meva8n
2meø
2meå
2mé
2m1f
mfa9ra
mfar8ta
mfav5
m2fek
m6f3ess
m4fi.
m4fibr
m2fit
m5fru5s6
m5funn8s5
mfu6se.
2m5g6
m4ga.
m4gi.
mgå8va
mgå8ve.
2m1h
mhea4
m4hu.
1mi
mi1a
5mi6al
mia2n
9miane
7miar.
2miav
mi6c
miche6l
8m9idé
2midi
mid5j
mid3s4
mid4t
4mi3ele
mi3er.
mie9s8
2mi5f
5migraf
2mih
2mii
4mij
mik6h
4mikj
2miko
mik5ro.
mik5ron
mik5sa
6miku
mi4la.
mile6t
mil7eti
mi4lev
mi7li
4milin
mil6s5v
4milæ
2mim
mi8ma.
5mimo
m7imp
mi4na.
mi5nar
mi4ne.
mi4n5ers
4m3innh
4m3inns
6minnt
min2s
min3sp
mins4t
mi3nu
m4inv
mi4n5y
mi7ov
2mip
4misa
mi4san
mi3se
4misek
4misel
9misé
misha9ge
4mi7si
mi2sk
mis4ko
mi3s4la
mis9le
7mism
mis4s5k
mis4s7p
mista9k
5mis7te
mis4tra
4mistu
2misy
4miså
6mita
mi3te
4mitj
4mito
2mit6r
mitt3s
mi5ur
2miv
mi5vå
m6ja.
m6jan
m5jar.
m7jarn
2mje
m7je.
m1ji
m8jingan
m8jingar
8mjo
mju7ke
1mjø
mjøs5t
2m3k2
m4ko.
mkro5
mku6le.
mkå8pa
4m3l
m7la
mla6ga
m2lef
mlei5er.
m2lek
m2lel
m2lem
m4lera
mle6se.
m4lesk
m6le5s8v
m4leta
mle4ve.
ml6i
ml5ja
mly6se.
mlø6pe.
mløy3
2m1m4
m6mai
mma5kl
mmal5
mma8le.
m4mam
mmando5
mman6dol
m5mar
mmar7in
mmar7o
mmatik7ka
m4medø
m2meg
m2mei
m2me3k2
m4melu
m6meni
m4menu
mmer5t
mme4run
m2me1s
mmest6
m5met.
m4meta
m4meti
m4metra
mme5t6re
mme3u
m3mé
m4mia
m7mian
m2mib
m4mid
mmie6n
m2mik
mmi5sk
mmi5so
mmi3st
mm5n
m3mu
mmø2
mmå8la.
2m1n
m2nee
mn7eid
m2ne9l
mne4ra
m5nese
m4nesk
m4nesta
mnes9tie
m9net.
m4nete
m2nev
m6nip
mn7sk
1mo
3moa
mo2ar
4moba
5mode
mo3dem
mo5di
mo6di.
2mody
3moe
mo4en.
m1off
mofo6bi.
mo6gi
5mogl
mo5go
m5ogs
4moh
2moka
mo8ka.
mo8ke
mo1ki
mo6la.
mo3le
mo4le.
mo7le6s
4molt
mo3ly
m5om.
4momf
2momr
mom4s5ø
mo5ne
mo4nisa
mo2no
mon1s
mon4ste
mon5t6
2mop
5mo1ra
mo4ra.
mo4rar
mo7rar.
mor5d6e
4mordl
mor6d5r
mo3re
mores7
m2ori
mo4ri.
mo6rid
4m3o4rie
mor4kl
morla8ga
mo5rok
mo4rom
mor4si
mor4skj
mor7sky
mor4sp
mo1rø
mo9sen
mo2s7k
mos4o
6mostab
4motap
mo4te.
mo6te6g6e
mo4tei
mote7kl
mo5ter.
mo4tes
mo5to
4motr
mot7re
mot1s2
6motsagd
motsva5
mot7t
mour5
3mo3va
mo5w
8m1p
m4pana
m4p5anta
m4pee
m4pelot
m6pena
m6pep
mpera8te.
mpe5res
m6peress
m4p5erfa
mperi6e7n
mpes2
mpes6te
mpe4sti
m5pett
m2pe5u
mp3id
m4pinje
m8pla.
m3p4lan
mp5le.
m6p5lin
m6p5n
m6p5ob
mpoe4
m4poeta
m4pog
m6pok
m2pop
mp3opp
mp1p8
mp3rad
mp5ret
mp3rop
mpro8pa
mp1s
mp3sek
mps4p
mp5s6t
mpun6ge.
m9pur
mp5ut.
mp5ys
mpø5
m9på.
m3q
2m1r6
mro8sa.
mro6se.
mru7te.
mrø9de
m9rår
6ms
m5sa.
ms1ak
ms5ant
m1sc
mse5lu
m9s6ei
m4sem
m4s3eng
ms5e4pl
m4serv
mse5s
m5s6etn
mse6t7jare
mse8t9jas
msi6e
ms4ing
ms3inn
m4s5ja
ms5kab
mska9k
ms6kin
msk5ing
ms3kor
msk8u
ms3lan
ms6lega
ms9lua
ms3lue
ms4ly
m2sm
m1s2n
ms9ne
ms5no
ms3næ
m1so
m4soms
ms3ori
ms1ov
ms3s2
m4s3tal
m8s7te.
ms7tea
ms2ti
ms5tilb
ms3tim
m1sto
m4s5top
m5s6topp
mst5ord
m8strand
m5strane
mst5red
ms5tref
mst5ren
ms5trik
ms4tru
ms3unn
msu9ta
msu7ten
ms1v
msva9ra
msva5re
m3s4vet
ms3ynd
msø4ke.
m4s5ør
ms1øy
ms1å
2m1t
m3ta
mt4b
mtbe6
m2tee
m2teg
mteks7
m6te7kv
m4tel
m6testu
mti9a
m9tida
mti5e
m6tien.
m6tif
m2tik
m6tini
m4tiø
mtiør6
m5to
mt4r
mt6ve
mt4vin
mtå5
1mu
mu6a
m1u2b
mu2e
mu3el
mue7r
mues1
2mug
mug5l
mu4he
mu2k
8m9uka
4m1uke
mu5la
mu4leg
mule6s
mull2
mull6s7
mul6tiv
4muly
7mum
mu3mi
mum2s
mun2c
munes6
4mung
mun6ge.
6m5univ
mun3k
munn5s6
mun4t3r
mu6ra.
mu4re.
2murn
murs4
6murt
m2us
mu4se.
mu4ses4
mu4sé
mu2s3k
muske6l5a
must4
mus5tan
2mut
3mu1ta
mu8ta.
mutsa8la
mut7t6r
2m1v
mvak5t
mva6la
mvari6
mveg5s4
mvi7e6
mvi6se.
2mw
1my
my5a
myg4ga
my3ke
myk4kes
myk3l
my8kr
my2ra
my9ran
my9rar
my1re
my4re.
4myrk
m5yrke
my4r5u
mys3
my6sa
my4se.
my4so
my4te.
mytt6s5
5mæ
mæ6la.
1mø
møb3l
mø7des
mø6e
mø9ens
møkk6a
m3økn
2møko
mø6na
mø4ne.
møne9s
mø8nest
6m5ønsk
mø2o
3mørke
mør4k5r
mør5sm
mør3ø
mø5se
7møt
mø9tas
mø4tere
møt9t
2møy
møy9ar
m5øys.
1må
2må.
må5a
6måenh
må7g2
må1k
må4ka.
må4ke.
må4kes
m6ål
må5lar
må4le.
må6led
måle3i
målø6pe.
må4ne5s6
må9nese
må8pa.
må4pe.
må7pl
2mår
måra6r
må1re
må1ro
må1ru
må1s4
må6tak
6måtf
må5tr
må3tø
1na
na6ans
2nabo
7na7bortr
na6bot
4naby
na4ded
na8dem
nadi4
n3adop
nad2s1
4nadv
8naf
n1aff
nafo7r
na3fr
naf7t
na8ga.
na3ge
4nagen
nag3s4
nagså5
na7gø
6nah
4nair
2nak
n6akk
nak7ka
nak6ko
5nakl
na1kr
n1aks
nak8sa
nak8se.
8n1akt
nak6ta.
na7kv
na9lag
na6lare
6nalarv
na7leg
na4l3ei
na4lek
nal5epo
na4les
na4l5ett
na4lev
nal5g
nal6ge.
na4lil
nal6lag
nal4løp
nal3op
nal5s2
nal3t
na3lur
2naly
na2l5ø
4nalå
na3lå5r
5nam.
na7mere
na5mes
na5mo9
5nams
2namø
9nan.
4nana
n3anal
n6ane
nanfø8
4n5angr
nan5k
nan6ke.
4n3anl
6n5anle
nan4ne
na4n5o
n4n5ans
nan4sin
nan4skj
nan4s5t
4nany
na7o
na5pe
nape4s
nap3s4
n4ar.
na4rap
2narb
nar5dr
4narea
nar7ei
4na5rek
nari4e5n
7nariksk
4narkiv
6n5armé
6n5arme
nar8ma.
nar5s
nar8ste
2nart
nar6ta.
nar5ti
nar7v
nar5ø
nasa3r
na4sas
nas7h
8nasik
na4ski
na2s5t4
nasta5
8nasu
na1ta
nate8k
na7tem
4natl
4natom
natori5e6
nat8ra
nat3sp
nat6tak
nat6tea
naty5
2nauk
naus6p
na6va.
4navd
6navf
2navg
2n3avh
na1vi
4n5avk
4navl
nav4les
3navn
6navo
4navr
n1avs
4navt
4n1b2
n5ba2
nba3d
nba9ser
nben4s
nbo5et
n6buf
n6butr
nbyr5
nbø9le
nbø6n
n1c
n5ca
ncel5
n3che
nch3ei
n6cot
n2cy1
6nd
n7daa.
n6dabi
n4dad
nda5f
n7dag4
ndags5
n4daks
n3dal
n4dalf
n4d5all
ndals3
n4dark
n6d3art
n8dask
nda5tal
nd5d4
n3de.
nde5a
n2deb
n2ded
n5defi
nd1ei
nd4ein
nd6ek
n4dekl
n4deko
n5d4e5l
nde4le.
n4delik
ndel4sk
ndel4st
n2dem
n5dem.
nde5mo
n5den.
n6dener
n5dens
n2de5o2
n2dep
n4derab
n4deras
n4derei
n4derim
nd6erk
nderla6ga
n4desi
n4dest
n4desu
n1dé
ndi4en
n4d3int
ndi6sk
nditori5
nditorie6
ndit4t5a
nd3jer
nd1ju
nd5k
nd4lem
nd4lese
nd4lest
nd4lev
ndo9a
n6dob
n6d5okk
nd4om4s3
n2doo
nd1op
n2dor
nd3org
nd5orm
n6dote
nd5rae
n4d3ram
nd3ran
nd6rek
ndre4ra
nd5resen
nd5rett
nd1ri
n1dro
nd4sag
nds3ak
nd4s5amb
nds5elv
nds5ende
nd4ser
nd4sje
nd4skj
nds7kul
ndsla6ga
nds6lett
nd7spu
nd3s4te
nds9teg
nds5trek
nd5stry
ndta6ka.
n6duf
ndu3is
n4dun
nd3ung
ndun6ge.
n2dup
ndu6si
ndus7k
nd7v
n2dyg
ndy1k
n2dys
ndy5sp
ndø5l
n2d1øy
1ne
2nea
5neae
nea4g
ne7a6le
ne5alp
ne5als
nea9m
ne9a8r9an
nea9ren
ne1as
6ne7av
2neb
3nebb
4nebe
ne4ble
neck5
2neda
3nedal
ned3d
6n5eddik
4nedeb
4nedeg
4nedel
5nedg
ne4di.
nedi4s
2nedo
ned5over7
ned1r
ne6dre
5neds
ned3st
6nedu
4nedø
ne5dår
4neeg
4neei
2neek
5ne4e4r5
2nef
n1eff
n5eft
2neg
5negati
ne3gla
neg5lesp
neg8r
6negru
6neh
2nei
n2eid
nei8dan
n5eig
n2e1in
n3eini
5neir
2nej
2nek
ne4ka.
6nek2l
ne3kn
nek2r
nek5rin
n7ekser
nek5t
4nela
nel3de
4neled
6nelegg
7neleggj
4nelei
nelei5er
4n3elem
6nelê
4nelid
4neliga
4nelis
4nelit
4neliv
nel4lov
nel7s
2ne1lu
4nely
2nelæ
2nelø
nelø8pa
4nelås
2nema
4n3emb
4nemel
4nemer
6nemes
2nemi
nemie8
6nemj
nem6k
5nemn
nem5ne.
nem7nel
2nemo
2nemu
2nemy
2nemø
2nemå
3nen
4nena
nen5at.
6n5en6den
6nendr
nene4
4nened
4nenem
ne3nes
4nenesl
4nenet
nen5eta
4nenev
nen4ga.
4n3enhe
6nenhet
4neni
nen5se
nent5ei
6n3en5tr
4nenu
4neny
4nenæ
2neo
5neo.
ne5o4r
7neos
2nep
ne5pe
3n4er.
4nerad
6nerap
3nerb
4nerea
4nered
nere6de.
4neref
4nereg
4nerek
4nerent
4nerep
ne5res
4neress
4neresu
4neret
4nerev
4nerfar
4ner2g
ner3ga
ner3ge
4ne3rib
4nerik
4nerit
ne4ri9v
5nerl
nerla8ga
n3erob
6neroc
ne7rof
ne5rok
4nerom
ne5rot
ne1r4ov
n6ers.
ner7se
ner5s4i
ners4p
ners8ten
4ne3rul
ner5un
2nery
3neryr
4nerør
2nerå
2nesa
ne4sa.
5nesar
4nesc
4nese
6nesek
nes6er
5nesets
nes5eva
ne3si
nes5ind
4nesit
2ne5sj
ne5skam
4ne5skar
nesk4e
4neski
5neskins
4neskj
4ne5sko
4neskr
6nesku
2nesl
ne3sli
ne7slø
nes6mi
6nesn
ne7snø
2neso
3nesot
2nesp
nes6sam
nes4stu
5nest.
4nestas
nes9tas.
nes9te.
4nesto
nes5tor
4ne3str
4nestu
4nestø
2nesu
2ne1sv
nes8va
6nesy
4nesæ
5nesøy
4ne5så
neså5re
3net.
2neta
4netaks
neta6le.
ne3te
5nete.
4ne3ti
6netid
2netj
2ne5to
6netom
2net4r
3nets
net5s4p
nett3a4
net6tel
2netu
ne4tv
4nety
4netå
netå5ker
2neu
neu1r
ne5us
ne6va.
ne4ve.
6ne8vent
5nevik
nevi8sa
3nevn
nev1r
ne4y5t
2neø
4neå
1né
4néb
4néd
2néf
6néh
2nél
4ném
6néo
2nép
5nér
4név
4néå
4n1f
nfall4
nfalls5
nfan5t
n6foa
n4fob
n4fole
n4fom
n4fora
nfor9en.
nfos4
nfø5des
nføy8ed
6ng
n8g8ad
n4gaf
n6gag
ng1ak
ng5and.
n8gan8da
ng3ank
n4g5arm
n4gart
ng5art.
n5garta
ngar5u
n2gat
ng5ato
nga4ve.
ng7avi
ngd4
ng4ded
ng4del
ng4dep
ng3dr
n4geda
n4gela
n3gen
n4gena
n7gene
n4g3eng
n6geno
n4genu
n3ger
n4geret
nge5run
n2ges
nge3sl
n4geta
n2ge7v
ngfø4
ng5g2
ng5id
ngjen5g
ng1l
n5glem
ng4lu
ng7n
ngo4d
ng5odd
n7goe
n3g4ok
n8g7o8m
ng9ome
ng5ond
ng7o6pe
n2gor
ng5ord
ng3ork
ngos6p
n2got
ng3ra.
n5grad.
ng5rand
ng7rea
ng3reg
ng3ren
n4grend
n4grer
ng5rest
ng3ret
ng3rev
ng3rid
ng3rin
ng7ro.
ng9roa
ng7roe
n5g6ros5
ng3råd
ng8sa.
ngs5elv
ng4sem
ng4ses
ng2sj
ng2sk
ng6skj
ngs7leg
ng5sløy
ngsmå6la.
ngs3ne
ngs7tep
ngst5rid
ngstyr8ke.
ngs9tør
ng3und
ngu5ru.
ngvi4s
ng5ye
n1gø
n2g1øy
ngå8va
ngå8ve.
4n1h2
nhat5
nhet4s
1ni
ni1ak
ni1a2n
nian5dep
ni2bl
4niby
4nibå
4nicr
n8ida
ni4del
ni7dele
n5idé
ni6do
nid7r
nids4
nid5st
4nieg
ni1el
7ni3e2n
ni3er.
nie5ri
ni7ers
ni5ert
4n3i4fr
ni5gla
ni9glo
2nih
8nij
ni3ke
2nikj
4ni5ko
2nikr
4nikv
ni5l4i
5nilu
4nimar
4nimas
4nimo
2nimp
ni6n7al
2n1ind
4ninf
ning3o
nin5gr
ning6s5
ningse4
nings5te
2n1inj
n1inn
4ninnb
4ninnh
4ninns
4ninnt
2n1ins
2n1int
2ninv
5nio.
nion2
nions3
4niop
7nios
4ni5ov
ni4pet
ni9pet.
ni9pets
ni2pl
nip3li
nip5si
4nir
nir7kel
4nisem
ni5set
nis5im
4ni3skj
nis4k3o
ni9sol
niso5ne
niss4
4nistas
6nistat
nis5tik
4nistil
ni3str
4nisty
4nistø
6nisu
6nisy
n4it
ni3ted
6nitj
ni4tog
ni4tos
nitt4r
nitt4s3
nitt6sk
4nitu
ni3ty
nit5z
nitær6e
2niub
ni4umf
2niut
4niva
2nive
niv5ei8
4n5ivo
niv3s2
6niå
4n1j
n6jah
njav9
n2jed
n5jede.
n4jee
n6jei
n2je1s
n3jes.
n2jet
n3jet.
njet6r
n5jett
2nk
n1ka
n2kak
nk3aks
nkal5l
n2kau
n4kedo
n4keer
n4keh
nk5eie
nkel5s
nkelt3
n4k5enh
n8keno
n4k5erfa
nker4st
n4ke1s4
n6ketø
n1ki
n4kid
n4kie
nk3ier
nk5ind
nk7inf
nk3inn
nk7int
n5kj
nk1k4
n1kla
n5k6lang
n7k4lis
nk3lok
n1klu
nk3ly
n3klæ
nk1lå
n1knu
n1kny
n3ko
n4kof
nkofi8
nk5oks
nko5le
nkol4la
n6kot
n6kov
n1kr
n3krav
nk1s2
nk4tak
nk6tal
nk4tin
nkt3sk
n1ku
nku4le.
nkuri9
nkurie8
n4ku6t
nk9ute
n1kv
nk3ve
n7kvit
n6kvo
n9ky
n1kø
n1kå
nkå6pa
4n1l
nland9a
nland6se
n5le
nlei7er.
nle8ma.
nli4en.
n3lj
nlu4e
nly6de.
nly6di
nly4se.
nlø6pa.
n7lå
4n3m
nma4le.
nmik3
nmi8l
nmini6
nmo6se.
nmusik7k
nmå6la.
4nn
n2nad
nn5ad.
nn9aft
nn5air
n6n1ak
n4nala
nn5alg
n4name
nn4an
nn5ana
n9nane
nna8ni
n4n5ank
n5nanl
n6n7anta
n9nar.
n4nari
n6nasi
n4nask
n2nat
n2nav
nn3avl
nnbo9e
nnbu9e
nn5d2
nndø4
nndør3
n5nea.
n5neap
n5nebar
nnebe8r
n5nebu
n4nedi
n2nee
n6nef
nn1ei
n3neke
n4nelo
n3n4en
nne6nat
nne4n3o
n9ner.
n4nerel
n4nero
n7nes.
n6nesj
n5nes4la
n4ne3st
n5n6et.
n4nesø
n4nete
n2nev
n2ney
nn3g2
nnhø8re.
n4nid
nn3ide
nni3e
n2nim
nn7inf
n5nis
nni4sj
nni4s3t6
nn7k2
nnle6ge.
nnlø6pe.
n4no.
nn5of
nno2m1
nn6oms
nnomsy8na
nn1op
n2n1o4r
nn7ord
n4n3o4ve
nn9r
nnsa9ka
nn4s5amb
nns5and
nns3ar
nn5seg
nnsei8g
nn4s3em
nn6s5enk
nn4s3es
nnse6te.
nnsi7da
nn4s3in
nn4s5i6s
nn6s5jak
nns5kan
nn5s4kli
nns5op
nns3or
nnst6
nn6s5tab
nns5tal
nns5telt
nns4ten
nns5tep
nns7tin
nns5top
nn6s5tre
nns5tro
nns3tv
nn4s5ul
nns3va
nn6s5vo
nnsy8na
nn2sø
nns3øk
nn3så5r
nn7t4
nnte6se.
nnto9ga
nnu1i
nn6ung
nn1ut
nnvi4s
nn1yn
nny4t
nn7øk
nn1øv
nn1å
1no
noa4g
no1ak
5noane
no7ar.
2nob
nobe4l
no4bl
nob5le
no3b4r
no5co
nodi4e5n
3noe
4noef
4noei
4noek
4noent
2nof
n1off
3no3ft
n6ogra
no5id
no3in
2nok
no1ki
nok8r
nok6se.
n3oksi
no9le
2nolj
no6mid
no6mik
no4mil
4nomj
nom9m
nom7s2
5nomy
non1s4
non5t
2noo
2nop
n1opp
no1r4a
no5ran
no5rar
no5ras
nor4da
nor6d5end
4nordn
nor4d5r
nord3s4
nor4dø
no9ree
no3rek
no3ren
no7ret
nor5g
3norge
norges5
n3o4rie
7norit
4nork
nor6kla
nor6kle
n4orm
normlø7se
nor2s
nors6ka.
no3ræ
no4sel
no4ses
nose8te.
4nosp
no3stj
nostra4
2nosy
no4ta.
no4te.
note5i
5notek
no4tel
no4tes
not3s
4noty
4nou
no1v
no3ve
4no5vi
4n5ovn
7nó
6n3p2
n5pe
npo8ta
n4påk
n3q
2n1r2
n9ra
nra8na
nra8sa
n3re
n4reb
nrei7e
n6renem
n6reo
n6ri.
nro6de.
nro6t
nry6
nrå8da
6ns
n1sa.
ns1a4d
n5sag
n5sakk
n5sa4kr
ns3aks
nsak6se.
6n5akti
ns5akv
n3sala
ns3ald
n6s5alp
n5sane
n4sanf
n5s6ann
n5sanse
ns5ansi
ns5ant
n5saren.
ns6arm
n6sart
n4sati
n1sch
n3sco
nse9a8l
n2sed
ns5edd
ns8ede
n2see
nse5ei
nse6er
n6sef
n2seg
ns5ege
nsei6d
ns5eie.
ns9eig
n4seks
n4s3elv
n2sem
n5sen.
n5sene.
n4sener
n9senes
n4senet
n4seni
n7sens
n3ser.
n4sera
nseri7e6
n4sesa
n4sesi
n4se3sk
nse3sl
n4ses4p
n4sest
n6sesu
n4se3s4v
n4sete
n9sets
n2seu
ns5fr
n2sh
ns3ha
ns7he
ns5hi
nsi5de.
nsi4ent
nsi6er.
nsin5d
n3s4ing
ns3inn
n4sinte
nsi8ra
nsis7k
ns3jak
n4sjav
n5sjef
n6s5jord
n4skan
n6s5kauk
ns7kele
ns4kete
n9skim
ns5kir
n5skis
n6skja
n6skjele
ns5kjen
n3skjæ
nskog6s
ns5kor
ns3kro
nsku9et
n4skug
ns5kuli
n5skum
ns1kv
n5s6ky.
n5s4kye
n5skyss
n5slang
n7slarar
ns5las
nsle6ge.
n3s4lekt
ns6leri
ns5lid
n5slyn
n1slå
ns3mi
n4smal
n4s5mo
n4smur
n4smus
nsmå6la.
n5s4nar
ns5nes
nso4d
ns1of
n3s2ok
n1sol
n4sond
nson6de.
nso5ris
ns1ov
n3sovn
nspa9ra
ns5pels
n5spet
ns1pr
n6spros
n7spur
ns7s6
nsse4e
nsså5
ns4ta.
n4stak
n4stag
ns5take
n3stam
n4stank
nst5art
nstar8ta.
ns4tau
n3s6ted
n3s4tei
ns4tel
nste6ma.
ns5tenk
n6step
n5s4tik
ns5tild
ns7tilf
n4s5tils
ns4tin
ns4t3i4s
ns1tj
n5sto.
n3stru
ns7trøy
n3stue
n6stuk
ns5tur
nst3ut
n1su
ns1uk
n4sung
ns5vang
nsva9ra
n2s3ve
ns9veg
ns5verd
ns5vern
ns1vi
n5s4vill
ns4vind
ns9vis
n4svu
n3s4væ
nsy4d
ns1yt
n5søn
n4s1øv
ns5øya
n5såpe
nså7pen
ns7ås.
6n1t
n5tab
n4tagr
nta4lan
ntall4
nta5na.
n4t5and
nt3anl
nt4anv
nt3app
n7tart
n6t5arvi
nt6as
nta5sia
nt4at
nt3avi
nt5avr
nt7avs
n2tea
n5teat
n2tee
n4tef
n4tege
n4tegi
n7tegn
n2tei
nt5eini
nte5ins
n5teis
n4teka
n7tekn
n4tekse
n9teleg
n5telig
n5tell
n4tels
n9telt
nte4ma.
nt3emb
nte4mis
n5ten.
n4te7na
n5tene.
n4t3enh
n5tens
n2teo
n5teori
n5tepp
nt4er
n5ter.
n7terek
n6terest
nte6risk
nteriø7ra.
n5ters
n7tes.
n4tesel
n4teta
n4tete
nt4e3u
nt5e4va
nt9g
nti1a
n4tiat
n4tid
n5tiem
n4tig
n4tikap
n5tiki
n4tikl
nti5kli
n5tile
nti3lo
n9time.
n7times
n4t3ind
nti6net
n6tini
n2tio
n2tip
n4tisa
n4ti5sti
nt5l
nt5n
nto3a
n2tob
nt5omf
nt5omn
nt3oms
n2t1op
n5tor.
n5to5re
n6torg
n2tou
nt1ov
nt6ran
n4trep
n5trer
nt5resi
ntres9kjare
n4t3rin
ntrol6li
n6trom
n6trul
ntrøy4
nt5skj
nt5s6la
nts2t
nt3t4
n6t7ub
ntu9e
ntu4l
n2t1u2n
n4t5uro
n2t1ut
ntva8la
nty6e
ntyr3s
nt7år.
1nu
4nu.
nu3an
nu4av
nuft4
nufts5
2nug
nug6la
4nu4h
nuit8e
nuk5
nul9t8
4nulu
6nuly
nu9me
2n1un
nun4ge.
nuo2
6nup
nu3pl
nu4re
nu5sa.
nu5sen
nu7ser
nus4k5l
nus7l
nuss4
nu6st
nus3ta
2nut
nu7ta
nu3te.
nute6r
nut5eri
n7utl
nu6ume
6n1v
nva6la
nvand5
nverle9
nves1
n5vi
nvi4et
nvi4ka.
nvi5ke
n3vu
nvæ8ra
n3w
1ny
ny5ar.
ny9ast
2nyd
ny4de.
4nyef
4nyg
ny5ge
5n6yhe
ny3ke
ny3k4le
4nyko
ny1lo
2nyn
nyn8da.
nyn4de.
4nyo
4nyp
ny8pa
ny6ra.
ny4re.
ny7rev
ny4ru
ny1s
ny5se
ny9s6k
nyst4
nystu4
ny3te
ny3tr
2nyv
ny8va.
ny5vak
ny8ve.
4nyø
n1z
1næ1
næ8ra.
nær9and
næ8rast.
1nø
nø2da
4nødd
nødde5
nød3sk
nød5sto
nø9dun
2nøe
4nøf
nø1fl
nø1fr
nø7gr
4nøko
4nøks
nø4le.
nø9mo
nø5mu
nø3p4
nø7ra
nø6red
nø1ry
nø3se
nø1sk
nøs4l
nø7te
nø7tr
n6øtt
nøtt6r
nøv4d
nø3ver
nøy1
2n1øy.
nøy8a9n
n7øyh
4nøys
n3øys.
nå6as
1nåd
nå5ded
nå8en
nå6et
nå8j
n1å2k4
1nål
nå2la
nå5lev
nå8ma
nån6de.
n1å4p
nåp8na
n1å6r
nå2s
nå5sa
nåse4
2oa
oa5c
o1af
oa4k
oak6kana
oak4ku
o1all
o3alt
o1a2m
o3a6n
o9and
o1a6p
oar6d7e
oar4d5in
oa4r5e4g
oa4r5enh
oa6ré
oa4r5i
oar5m
oa9té
o1au
o1a4v
2o3ba
obakk8s
obb4l
ob4bo
ob4b5r
ob4b3u
ob4e
o4bea
ober5et
ober4s
obers5ta
obers5te
o3bes
2o3bi
obi5e6
1ob1j
o1b2l
ob5la.
ob3le.
ob3len
o2b5li
3oblig
ob4lo
o1b4o
obo9a
2obr
ob5rar
ob1re
ob1ri
3obser
ob5st
2obu
2oby
obyl5
o5bø
o3bå
4oc
ock5ers
o5cy
2o1d
o6dab
oda4f
od7att
odd5ei
od4del
od4dest
od9do
od4e
o2deb
o6d5ei
o4deko
o5deku
o2dep
oderle7
o2des
o5det.
o5dets
odie4n
o4d3igl
o4dj
odko5
od3oml
od3ov
o2d5re
o4d3rø
od3sk
ods4ka
od3s4po
od5s4tol
ods8t
odu7s
o4dy.
o4dyb
od5øk
o5døs
od5øy
o2d1å6
6o1e
oe6f
o4ein
oek6s
oe2l
oe4mu
oe2n
oen5a
o7ene
oeng5d
oen2g7r
oeng3s
oeng3u
o5ens4
o7ens.
oen5t
o3e4re
o6erer
oer8ma
o3ersk
o2es
oe6sip
oe6sit
oes8ka
oes8ke.
o4etan
oet2h
oe5ti
oev6ne.
2ofa
o2fa.
ofag6a
o4fara
ofa4se
o2fav
o2feb
o4fei
o4fera
o4fe3st
o1fé
off9and
of4fek
of5fes
of6fia
off5id
of6fr
of2fu
of6fy
2ofi
o4fip
o1fl
of5le
2ofo
o6fra.
of9ras
of1re
6o5fri
of8sa
of8se.
6oft
of4tel
oft2s3
2ofy
2og
o2ga.
og7ank
o4gare
o2g7av
o2ge.
o4ged
og1ei
oge7na.
o3get
og4gera
og4g5j
ogg3s4
og6g7u
ogi3a4
ogie2
o4giev
o2gif
o6gig
o4giko
o2gil
o2gim
o2gin
o3ging
o2gi1o
o6gista
o6gi7str
o2giv
og5jer
og7la
ogly7
og4ned
5o4g5ni
og6nel
o5g6nos
o2go.
og6ra
og4re.
o4g3reg
o4g3rei
og4rer
og7rett
o4g3ri
og3ryd
o4g5rø
og5rå
ogs4a
ogs6an
og3s2e
og1sk
ogs4kj
og5sl
ogs4le
og1s4p
ogs5pa
og5ste
og3sti
og4s5tj
ogs4to
ogs4tr
ogs5t6ra
og5stre
og5sy
5og5s6y4v3
ogt6r
5o4g5åt
og1un
og5ø
og7ås
2o1h6
ohe5te
ohm9a
o4ho.
ohø4
oia4
o1i2d9i
o1idr
oid5t
oie4n
oi5er
oi6es
oi5k
oi4la
o1im
o3in.
o1ing
oi2n1o4
o4insp
oi6r
o1is
o2is.
o6isa
o2ise
o4isi
4o1j
o8je.
o4jo.
o1ka
ok7aft
ok1ak
oka4n5i6
ok2ar
ok5ark
o3kas
ok1ef
ok5els5
ok5elv
o5k6en
o4kesk
o6kev
o1kj
ok4kand
4okke
ok6kera
ok4ke5s
ok3kje
ok3ko.
ok5kol
ok4kun
4okl
ok8la.
okla5m
ok8le.
o1klu
ok7lut
oklå5
2okn
okna8sa
o3ko
o8ko.
ok8ol
o4k3oms
ok3omt
oko5pe
ok5opp
ok3orm
oko4s
oko9se
o6kov
o1kr
ok5reo
o6kret
o4k5ru
oks4al
oks4e
ok4sek
okse5kr
ok4sem
ok7sen
ok6serin
ok4ses
okse9te
ok5s4i
oksi7da
okst2
oks6ti
ok6s5vi
oks6tr
ok5ta
3oktan
ok3ti
ok5to
okto4r5i
okt6r
o1ku
ok5u4k
oku8le.
oku6t
ok7ute
o5kva
o3kvi
ok5øy
o3kå
8ol.
4o1la
ola6ded
ola8ga
ol5anl
ol3ant
o9lar.
o6larbe
ola5t
olber4
olbo7e
olbo7ge.
ol4bol
olbu7
2old
ol9dan
ol5de.
ol4dem
ol4dest
ol5det
ol3do
oldo7ve7
ol5drev
ol3dri
old3s4kr
2ole
o5leaks
o6leb
o2led
o2lef
ol5eig
ole5in
o2lek
o7leki
o2lel
olele6ge.
o2lem
o5lem.
o5lems
o7lene.
o9lenes
o4lenet
o4leni
o4leno
o6lered
o4leru
o2les
ole5sta
ole5str
o9let.
o2lev
o1lé
ol4f5i
ol4fj
ol3g4e
ol1g4l
2oli
o4liba
oli9e6n
oli7ert
oli5ne
3o6lj
olke3s4
ol4kese
ol4kesk
ol4kest
ol2k3l
ol9ko
ol6ku
ol5kv
ol5la.
oll3ak
ol4lam
ol7le.
ol4led
ol4lel
ol7len
ol4les
ol6linj
ol4log
ol4lom
ol5los
ol4lov
oll5over
olls4t
oll5sv
ol2lu
ol4løp
ol6løs
ol6løy
ol2lå
olme5s
ol4mest
ol4må
ol9n
2o1lo
o4lo.
o5loan
o3loe
o4lof
olo3i
ol5oks
ol3oms
ol3op
o6l7os.
o6l7o6se
o6l5osf
olo5ve
ol4ped
ol7so
ols8t
ol5sva
ols5vik
ol3ted
ol5tep
ol2tr
ol6t7ra
olt5re.
olt5rer
olt5ret
o1lu
olu5l
o4l3ung
olun8ge.
o4l5ur
ol5va
ol1vo
o1ly
oly7d
ol5ør
o1lå
2om.
2oma
om3ald
o2ma2m
om5ang
oma4nif
omann4
oman5t
om3ars
omar7ø8
om4as
om1av
omb6
om4bet
om4bis
om3bl
5ombod
1ombu
2ome
o2m1ek
o5meka
o7menes
omer6s
o6mese
o5met
ome4tak
ome7tar
om1eu
3omfan
3omgre
8omh
o2mia
o2mib
omi3e4
o4miek
o2mig
o7mikk
o7mine
om7inn
om3in5s
o4mio
o2mir
o4misj
o4mist
o2miu
om1j
2omm
om6mat
om4med
om4metr
3ommø
2omo
o4mofo
om1op
omo1v
omp2
ompa3t
1omr
2omre
2omro
2omru
6oms.
oms3al
om4sek
3omset
omsko9d
omsku9la
om4som
oms3un
oms4ø
omt2
3omtal
om4tes
om3ti
om3tv
o2m1u
o3mus
omvæ8re.
6omy
omyr8ke.
o2møk
omø4r
om5øy6
o5må
2on
on3abo
o4nac
o6nak
o4n3ang
o4nap
on3app
o6narb
o4n3arg
o4n3arv
onat5r
o2n1a4v
on5b
on4dar
onder6e
ond3re
on4d5ri
onds4i
o4ne.
on5eie
o4nele
o7nell
o2nem
o3ner
o4neru
onesi6
o4nesk
o4ne3s8t
o4nete
o2nev
on7f
on7ga.
ong3d
on5ge.
on6ged
onges4
on5gi
on5go.
ong2r
on8gro
ong9ros
ongs4j
on2gu
on4gy
on4g5ø
o9ni.
o2n3i2d
oni1e
o2nil
on5ild
o2nim
oni6mi
on3inf
o6n7inn
o2ni1o
o4ni5p
o6niso
on3j
on1k
on5k6a
3onkel
on5k6i
on4kle
on5ku
onle6g
on5nad
on3ni
on5ny
o4no.
o5nor.
o4no4v
on3ove
on4sh
ons1i
onsi3s
onsi4v
ons1k4
ons7ke
ons1l
onsla6ga
onstitue9ra
onstitue9re
onst5rum
ons5und
ons1v
on4sve
ons1å
ont6a
on3te
on4ted
on5ten
on5ti
on4tok
on5tor
ont2r
on7ul8
on5ur
onu4sk
o4n5ø4
on6øy.
on7å6
2oo
ood1s
o1off
oo2k1
oo5k8a
ook5es
ool7a
oo4m5i
oo6mo
o1o2p
oopa8
oop9an
oo4pe
oop5en
oop5et
o6opi
o1o4r
oor6da
oo5s
oo6sp
o1o4v
2op.
2opa
o4pab
o2pak
opan9d
o4pa3re
o7paren
o4pasj
o4pau
o3pea
ope1i
opel6lø
2open
o4pena
o9pend
o4penet
o7pent
o2per
6o3per.
3opera
ope6rar
o7pero
o5pert
2opet
o4peta
4oph
o1pi
o4piek
oping9s
o4pir
2opl
o1pla
o4p5land
op3li
op9lu
op4na.
op4ne
2o3po
2opp.
4oppa
op4p5art
op4pas
4oppe
1oppg
op4pi.
op6pia
op4pis
opp3li
3opply
op6poe
op6pr
opp5rop
opp5und
opp1å2
2o1pr
op6re
op7ru
op7rå
op6sa.
o8p8si
op2t1r
o4q
4or.
o6r7add
or3adr
o2rag
or1ak
2oral
or5ald
o4r5alg
oral4st
or6alt.
o3r4am
o4rana
o3rane
o4rang
o4rans
or6ap
or3att
o4rau
ora3uk
or1a4v
4orb
orbit5
or7by
4orc
orda9ta
or3dea
6ordel
ord7e6pl
or7dik
ordi4s
or4d5ise
ord3it
1ordn
ordre8gi.
ordsa6me.
ords6e
ord3st
ordy9ra
8ore
orear8a
orear8e
o5rebra
o8redi
or1ei
or1el
o4rela
o6reld
ore6na.
ore4ned
ore4net
or3enk
oren3s
ore6o5g6
o6rerf
o4rero
ore1s2
o5resc
ores6te
o4reta
or9et8n
o6retv
o2rev
2orf
orfa6re.
orfi7ne
orfø9re.
1or3g4a
4orga.
or3ge
or5ger
orge4s
orgi6e5ne
org4sk
orha9g
orha9le
o1ri
o3ria
ori5b4
ori4e5ne
5orient
o7riet
o2rig
ori7ka
o6rim
or3ind
or3ink
or3inn
or3ins
oriro8
6oris
oris4a
6orit
o4riti
oriti6me.
or5ka
3orkes
or5ko
orko6se.
ork7s2
6orl
orla7te
or5le
orm5ang
or6map
or5mel
or4m3un
ormæ9
or4nar
orned5
orne6dr
or5net
or4nol
orn3t
4oro
o3roa
o3roe
or3off
o5rog
oro5i
o1ron
or1op
o4r1or
oror9da
o5rosa
o5rot
or3ove
or5ovn
orpe6s
4orr
2ors
ors5alt
or5sen
or4serk
orse9ta
orse7te.
or3si
ors5kar
orsk5ei4
ors8k9l
ors4ku
or1s4l
orsmå8la
or1sn
or3s2o
orso9na
orso9ne
orso9v
ors4pa
ors4ten
or1su
orsva9re
or3sy
or9sø
2ort
or4t3ak
orta8la.
or4t5and
orta9pe
or4t5av
orte5i6g
or4tek
or3tem
or6t5erf
or4t5erm
or5tii
or7til
or5tis
3ortod
or6tok
orto9ne
orto4r
ort5ori
or4tou
ort5res
ort5råd
ortå4
or4t3år
or1u
oru8d
or9ude
oru4h
o5rum
oru4t5
oruta4
or4utf
orva9ra
or5veg
orv3s
4ory
o7rya
or1yn
o9r4ære
2orø
or9ø8k
orøk8t
or5ør
or3ø4v
orøv8d
or1øy
or5ås
2os
o1sa
o4sa5b
o6sad
o2saf
o4saku
6o5sau
osbi7
osefi5
o2seg
o5selei
o2sem
os2en
o6sena
ose5sl
ose5sm
oses4sk
oses6sp
oses4st
o4seu
osfa9ta
os2hi
os7his
osi6e7ne
osi5ere
osi5ert
o2s1ing
osk3ei
oskei6e
o4skil
osk9lar
osk5len
o1sko
osko5p
o3skri
os8k3v
os2l
os3le
oslo1
os3lod
os5lu
os5lø
os9ma
os5me
os3mo
o2sn
o3so
os7ove
os6pa.
os6pe.
os4pil
os4por
os4sek
os3sem
os5sens
osseri7e6
osse5v
ossis5te
os6ski
oss3kj
os4s5ko
oss9l
os6spa
oss7tro
os7sty
os8sv
ost5adr
os5tal
osta5le
o8ste.
os4teg
ost5egg
os4tek
ost6el
os5teo
o4sti.
o8stia
o4stie
o4stin
os5tis
ost1o
os6tons
ost5ran
ost3re
o3stro
ost5rup
ost7rå
o5stø
os1v
os5øy
os7år
2ot
o1ta
o5tad
ota4l5a
ot5ald
otal7ev
ota4lov
o9tane
o9tar.
ot3arg
o8t9arm
o5tas
ote7d
ot6ei
ote5int
otek5i
ote6k7la
otekla8ga
ote4kle
ot5elem
ote5lev
otel6lan
otel6lek
otel4li
otel8lø
o4tena
o4t5ende
oten8de.
o2teo
o4teram
o4teret
o6terev
o4tero
oter5s
ote5r8u
o4terå
otes6ter
ote5sté
otet5a
otet5o
otet3s6
otfø4
oti7ert
oti2k
otika3
ot7i6ko
o1tj
o6tja
ot5jer
ot6nero
otno7te.
ot6nå
o1to
o2to.
o4to3a
o5toa.
o2tob
oto6en.
o6tof
ot3off
o6toga
o6togram
o4toi
o2tol
oto5ne
oto4ral
otor5d
o2tot
o2tou
o1tr
ot7red
ot5rer
ot5rev
o6t7ri
o6t5rom
o6t5rø
ots5el
ot6sh
otshusvæ8
ot4s3ki
ots6op
otsopp6
ots5pr
ots5tab
ot7ste
ots6å
ot6tank
ot5tas
ot5tegn
ot6tenk
ot5tese
ot5tin
ot5toa
ott4s3k
otts5po
otts4ti
ot7tug
ot4typ
o1tu
o6t5ut
o1ty
oty8e
ot1yt
o1tø
ot7å
oub8
oul5l
oun6ge.
ou4r
ou7ri
ou5ro
ou9sa
out8a
ouve4
o5vae
o1vak
ovanfø8
ovan9o
ov3anv
o7var.
o6varb
ova9re
ov5art
ov7arv
oved3
o1vei
o1vel
ove4la
4oven
o4vend
o5vende
ove6nya
ove2r
over3a
ove7ra.
ove9ras
o6verdr
overe6
ove8r5es
3o6verf
3overg
o5verks
5overr
5oversik
overs4p
over9v
o1vet
6ovh
2o1vi
oviso3
2ovj
6ovna
ov4nes
2ovni
4ovo
o5vo.
o7vom
ov1or
o5vot
ov1o2v
ov5sal
ov4sek
ov4sen
ov9ske
ov4sle
ovs1p
ovs5te
ov4sti
ov7sun
ovsy5k
ovta6le.
ovveg7i
ow1
owa8
o7was
owat2
ow5h
ox3
oy9ar
oys5l
o1y2t
o1za
o3zy
o1ø
o1å
ô6ra
ô2re
ôr5ei
ô1ri
ô4t
ó9sa
ó7t
ó8v
ò9re
1pa
4paa
2pac
pa8cen
p5ad.
pa3deb
p4adg
pads4
2paj
6pak.
6paka
4pake
pak4kas
pakke4s
pakk7esl
4pakti
3pa1la
pa3le
pa7lim
pal5in
pal1j
pal5lø
5palm
4palø
2pam
pa5me
p3anal
pa4nap
pan9de
pa5ne
pang5s6
pan3ka
9panne.
pan5se
pan5sl
pant8r
4panv
pa4ny
2papa
pa8pa.
pa3pe
4papo
pap4pr
4papr
pap3ri
pa4ra.
5parad
2parb
4parek
4parena
par5ess
par5g
2pari
pa4ri.
pa3ris
4parki
par6k7l
par4kv
par3m8
pa1ro
4parr
par8ra.
par9s4
par6tid
par4tig
par4tin
par5u
par7v
parvi6
6parø
4parå
p6as
pasa5
pa9se
pase6r5
4pasp
3pass
pas5sab
pa4s3t
pas4tar
pas5ti
pas9v
pa1t
pa3te
pa4tist
pa6tre
p8atta
pat6tak
2patu
p8at6v
pau7k
2pav
pa4ve.
3pa1vi
2p1b6
pba4ne.
pbo6da
pce6
2p1d4
pde4le.
pdø2
pdø9d
1pe
2pea
peak3
pe4a3re
4peb
pec3
pe7d6a
5pedas
4pedd
pe3de
pedfø9
pedi9e8
pe6doa
pe6don
4pedr
pe4dro
4pedu
4pedy6
2pedø
pe7då
pee6
pe3er
2pef
p5eft
2peg
p5egg
peg8ge.
pego4
2peh
pe4il
pei4leg
2pe1in
pe6ism
2pej
2pek
pe8ka.
pek4l
pek4tro
pekt7ros
8peku
p6el
4pela
pe5l4aks
5pelal
pe5lar
pel9d
4peled
pe4lef
4pelei
pe6lep
4peler
pe6lev
6peliv
6pelj
pel4lo
4pelov
pel5s6e
pel5s4i
pel7st
4pelu
pe5lun
2pely
2pelø
6pelå
2pem
p1emb
pe4nan
pe4n3ar
pen3de
6p5enden.
4pener
pe3net
5peng8
pen4gel
pen7gl
peni4n
4peniv
penly4
pen7s8a
pensa7k
pensa8la
pen5sk
pen4s5l
pen3s6m
pen5s6o
pens4t
pen9sta
pen7ste
pen7tag
pen5tr
6peny
2penå
2peo
pe7o6s
2pep
pep5ar.
pep7p
pera3a
4pe4rab
4perad
pe4rai
pe4ral
4perap
pera5t
4perate
4pered
4perei
4perek
4peresp
4perest
4peresu
4peret
pe4rev
3peri
perie8ns
4pe5rik
peri3s4
4perit
per5k
per6les
per5mu
per5n
4pero
pe3ros
pero6se.
per6regj
per6rei
5perro
pers6m
per4tro
per4t5rå
pervi6k
2pery
6perø
4pe7rå
2pe1s
3pes.
pe3se
pe6se.
pe7si
pes8ka.
p3eske
pes4ke.
6pesl
pes4n
5pess
3pest.
5peste.
pes5til
4petab
peta6ka
4petal
4petas
4petau
pe3te
5pete.
4peted
6petei
6petek
4petel
4petem
pe3ti
4petid
4petil
pe4tim
2petj
2peto
2pet4r
pe4t5ru
pet1s6
4pett
2petu
4petø
4petå
pe2u
2pev
peva8ne.
pe5vi
p5evn
pev6ne.
4peø
4peå
3pér
2p1f
3p6fenn
p3fo
p5fr
pfri4
pfø5re
2p1g2
pgjer4
2p1h
phav2
pha9va
phavs5
phe9te
phe7va
phe5ve
phi5li
7pi3ane
7piar
pi4as
7piase
4piav
4pib
pi6ca.
2pid
pid3s2
pie2n
6piend
pi3er.
pi9ers
2pif
pi9fr
pig5ge
pig6g9u
p7i6gj
2pih
6pii
pi4keh
pi6kel
pike5r6o
pi4ké
8pikk
pik3ko
4pikl
piku5
pi5la
pi6la.
pi3lep
pil4lag
pillba6
pil6led
pil4leg
pillega6
pille6ra
pil4le5s6
pi1lo
2pim
pi4na.
pi4ne.
pi9ned
pi4nel
pine4v
3ping
pin6go
ping3r
ping5sk
6pinns
pin4sl
pi2nø
pio6n5an
pion5s
3pi2p
pi4pi
pip9la
pi4rar
pi4res
pi4rut
pisi9e
pi4ski
2piso
piss4l
pis4sp
pis4st
pis1t
pis4t5r
pis9t8ra.
1pit
pi9ta
pita7la.
pi5té
2piti
4pitj
4pitr
pit5t
2piu
2pi5v
4piø
4p5k4
pka5v
pka8va
pl6
8pl.
2plad
pla8de.
p4lak
p4lan.
plan7de
4plane.
plan5g
plan5s
plap3
4p1lar
p2las
pla4st
p2lat
platina5
2ple.
2pled
4pleis
p2lek
p6le5n4u
ple5n4a
ple6r5u
ple8se.
4plev
p2li
4plit
p3liv
pli7va
plo4gj
p4lo8i
p1lok
4p5lov
plu4e
p4luk
plun3
plun6d7ri
p1ly
ply5d8
plæ5re
plø6pa
p1lå
2p3m
2p1n4
p7ner
pne6se.
1po
po9a
pod8
po6da.
po4de.
po6em
2pof
po6f7r
pog6
4poh
po5id
2poke
po6lan
po3le
po4lek
6polj
pol5li
po6lom
pol6s4ka
po2lu
2pom
pom6p9u
pom5s
4pon.
pon5d
pon4gr
pongs6
2pon1s
pon5sa
pon4sv
po2p1a
po6pe.
p5opn
pop1s
2por.
po1ra
2p5ord
po1r4e
po4ref
po6reg
po8ré
2p1org
2pori
2pork
por6s7v
por4tor
por4t5ro
por4trå
2porv
po1ræ
po1rø
po4se.
po4ses
4posj
po2st
po4sta
pos5tas
po5stat
pos3te
4pos4v
5pot.
7pota
potak9
po3te
po4te.
potek5l
po5t6ha
3poti
4potr
4pou
2po4v
pove6
pover6n
pow4
2pp
p2pad
p2pak
pp3akt
p2p3a4l
p9pane
pp5angr
pp5ank
p4p3anl
p2pap
p9par.
pp5arr
p7past
p4p7at
p4pee
p2pe5i4
ppel5s6
p4pena
p8p9ender
p4pendr
ppe9nes
ppe5p8
p4penø
ppe5ra
p7pere.
p4perkl
pp7e6sen
pp9esn
ppes8ti
p4peta
pp5e4tas
p4pete
pp5ett
p2peu
p1pi
pp1id
p2p1il
pp5im
pp3inf
p4p5inn
pp7ir
ppir8re.
p4pist
pp1j
pp3k
pp1l
pp5last
pp3led
pp5lei
pp9lev
pp5n
pp1of
p2pol4
pp3old
pp5om
p2p1op
pp3ork
pp1ov
pp5p
pp1r
pp5rei
pp5rin
pp4ris
pp7riss
pp9riv
pp9ro.
ppropri6
pp7rot
pp1s
ppse6te.
pp3ska
ppska9k
pps2p
pp9spe
pp3spl
pps2t
pp7sto
pp7t2
p2pu
pp1uk
pp5ut
pp3ø4
ppøs8
p6på
pr6
4pr.
4prad
3praks
pra7li
2pran
pran3s
5prat.
5prate
pra5te.
4pray
5pref
prei7er.
4preii
pr5elem
1prem
pren4s
1pres
6pres.
pres6sak
p6restas
4prett
p3rif
pri5ke
pri4l3e
4pring
5prino
3pr6in6s5
3pr6in7s6e
3pr6in7s6i
1pris
pri6s5k
pris3t
2prit
pri9ve
1p2ro
8pro.
6p7roc
3prof
4prog.
4proge
4progl
4p3roi
p5rop.
3pros
7prose
6pru
prun7ge
pru5ta
pru5te
6prør
prørs5t
prø5s4
5prøv
prø5vels
2prøy
4prå
prå8da
pråk3i
prå4ko
pråk5k6
2ps
p1sa.
ps5a6n
p1sc
p3se.
psei8ge
p2sek
p2s1el
ps5e4ly
p3sen.
p5sens
p7ser.
p5sete
p5sets
p2sh
p6sib
ps5ins
p7sis
p3s4jo
p4s3kil
ps7kjen
p2s1ko
p7s6ko.
p3skod
p5s4koe
p2sle
p9s8lo.
pslø8va
pslø6ve.
p3s4lå
p2sm
psmå8la.
p2sn
ps4no
ps1o
p3sod
pspi9la
ps5ple
p3s4pre
p4s5pro
ps5pu
ps3s2
pst2
ps7tal
p4s5tem
ps3tv
p5s6tå
psu4r
p3s4us
ps1v
p2sva
p2sve
ps4ving
p4svæ
ps5w
psy3ke
3psyko
4psys
p2s1ø
p3s2øk
psø4ke.
psøy8
psøy9ene
ps1å
2p1t
pta8la.
pta4le.
pt7ark
p3te
pte6k
pte4ma.
pte7re
p5ti
pto7g
p4tou
ptus5t
p4tut
1pu
pu4br
5puc
6pu6dy
pu2k
pu7la
pu8le.
pull6
5pum
pu4ma.
punk4t5
punk5t6e
2punn
2pur
pu4re.
pu8rea
3puri
3purk
pur5u
pur3v
pu7sa
pus4h
pusl7u
pu1ta
pu4ta.
pu5tas
pu5ter
pu5tev
4putg
2puts
put6tr
put4tu
2putv
6putø
2p1v
pver7
pvi4se.
py4dr
py8o
3pyra
py1re
py1ro
6pys
py6sa.
py4se.
pys6t
4p5z
1pæ
pæ4re.
pø1kj
pør4ret
pø8sa.
pø9ta
pø9te
p1ø2v8
5påb
på4by.
på1k2
1pål
på4la.
på4le.
p5ån
på3pe
på1pl
p1åpn
på1r
1pås
på7sko
på5sm
på3t2
6påtå7
1påv
qa5
qu2
qu9ar.
1que
que7r
4raam
4raar
4rabis
ra1bo4
4rabr
2raby
ra3cet
ra3ch
5raci
ra3d2a
4radf
3radio3
4radir
4radj
2radm
2ra1dr
r3adre
rad2s3
radvi4
ra5ede
rael4
4raerk
raf4fer
ra4fiu
ra2fj
2rafo
ra5fo.
ra4fos
2rafr
ra5fre
6raft
ra4fu
ra6fy
ra7gea
ra5gee
2ragl
2rah6
7raid
ra5int
ra3isk
6r5akad
ra9kar
ra7kel
ra5k6ha
r2akk
rak4kel
r6akr
ra5kro
2raks
rak6sa
rak3s4e
rak6se.
rakst6
4rakti
rakt3r
r4a5ku
4rakv
ral5ans
6ralbum
5ralds
4raled
ra5leo
ral3g
4r5alge
4r5algo
rali5e6n
ra4lin
ral1j
ral5le
ral7m
ralo6i
ral3op
ra5ly
4ralø
4ra5l8å
ra4mag
ra4mas
ram3b
6r9ambi
rambu9ens
6ramed
4ra4mer
ram8et.
4ramil
ram1o
ramperi8
ram6p3u
ramse8te.
ramta8la.
ramta6le.
4ramu
6ramy
r4an.
ra4naa
6r3anal
ra5nar
ran9cs
r4an9de.
r5andel
rand3r
rand5s6a
r4ane
4ranfa
ran5ge
6rangi
rang5st
rania8
ra6nin
ran3kv
2r5anl
r6anli
2r1anm
r4ann
ran6n5ett
ran4n5in
rann3s4
rans7kar
4ransv
ran4tik
ra5nu
ran6ut
4ranø
2rao
4rapa
ra4pel
4rapin
ra4pir
ra4pis
ra6pit
ra1pl
4rapo
ra4pos
4rappa
4r5appl
3rappo
2ra1pr
4raps
4rapu
1r4ar.
2rarb
7rarbeh
4rarea
4rareg
rar5e6l
4ra3rep
rar7eta
r1arg
6rargu
8rarinna
6rarinne
rar8ka.
4r1arm
rar8ma.
6rarn
4rarr
rar3re
rar5s
2r1ar5t
rar6ta.
ra3rø
4rasa
2rasc
ra3sea
4rasel
ras3h
raska8ra
ras3ke
ra4ski
ra7s6ko
ra6sl
rass4l
ras7st
4rasti
ra5s4til
4rastj
rast5re
6rasty
ras7v
ra1ta
ratak9
r6ate
ra4te.
6ra5teg
8r7a6teli
4ratfe
ra1to
ra1t4r
ra4t5ro
ra4trø
ra5t6røy
rat5tel
ratte4s
4ratub
rat5ut
6raty
7raud
raud3s
6raug
rau6ga
rau6ge.
4rau4k
raus6s
2rav
6ravd
rave5s4
4ravg
ra1vi
r3a4vis
4ravl
rav8l9ut
ravlø8pa
ravlø8s
rav6r
4ravt
ra5vy
ra3vør
4raw
raz5z6
2raø
raøy4
2r1b8
rba3d
rbe2d
rbede4
rbed5en
rbed5et
rbed9ra
rbie8
rbi9er
r2big
r2bik
rbist6
rbis5tr
rbo8di.
rbo4ni
rbon7s
rbo5re
rbra5s
rbrei6
rbu5en
r5bø
r1c
4rd
r4dab
r5dag
rdag4s5
r5dah
r4d5ak
rdal4
r4dala
rda4le.
rdals5
rda4mes
rda8n9o
r4dant
rd5anta
r4d3arm
r4d3art
rd5atl
r4datm
r4d3au
rd3d2
r6dedi
rde4en
r3defi
rd5e4ge
rd1ei
r9deka
r4dekl
r4deks
r6delo
r6demi
r7dena
r6d7eng
r6d7enh
rden4s3
rdense4
rdenta8le.
r4deo
r6depo
r4derik
r4d5erst
rde6sm
rd3e4ta
r6d7ett
r8dé
rdfes5
rdi3an
r4diana
r4dians
r6diau
r4did
rdi3e2
r2dif
rdi6gres
rdig3s4
r4dika
r4dikl
r4diku
r2dil
r6dimi
r2dio
rdi3ov
r4dish
r2dit
r2diu
rd5je
r1dju
rd7m
rd3n
rdnæ4
r9dob
r4d5o4d
r4dol
rdon8na.
rd1op
r6dor
rd3ost
rd1o4v
rdover5
r9drad
r3drak
rd5ran
rd7rara
rd3ras
r3drei
rd3ret
r5drev.
rd1ri
rd3rot
rd3sei
rd8ske
rds4kv
rds5tan
rd3sto
rdsto5g
rds7tre
rds7tu
rdsva9r
rd5t
rdta8ka
rd5tr
rd7tø
rd3und
rd5ve
rdvi8ka.
r4dyg
rdy5pe
rdy3re
r6d7yt
r6d5æ
r7d6ær
r7d6æ5r6e
rd1øs6
rdø4ve.
rd3år
rd7å6s
1re.
2rean
re7a6r7an
rear5e
4reav
2reb
3redak
6redam
re3def
re5den
re3des
re3di
3redig
r1edl
2redo
2redr
re4d5ri
red5sku
red4sl
reds5la
red7s6led
3reduk
6redy
2redø
2ree
re4el.
re3er
8refa
4reff
4refi
2refj
6refos
6refr
4reft
2refø
4regar
rega7ta
re3ge
4regeb
re5gel
4regen
4reger
4regg
1regi
re4gia
re4gil
reg1l
2regr
4regub
4regud
2regå
2reh
2reid
2reie
2r1eig
rei8ga.
rei8ge.
4reik
rei9l
rei5na.
rei7nas
re5inde
rei5ne.
rei7nes
rein6skj
re4inva
rei9ra
rei5sa
rei3si
rei7ska
reis6led
re7ism
rei7va
rei5ve
2rej
6rek.
re5ka.
re5kav
re7ken
4rekj
rekk6an
rek4k5v
5reklam
rek4led
re5k6lir
re7ko
4rekob
4rekom
4rekon
6rekos
4rekra
3rekru
r3eksa
6reksp
rek4ter
4reku
r8el.
re9la
4relag
9relandsk.
9relandske
2r2ele
rele8ge.
r4e5lei
6relek
re7len
7relene
6relg
r3elit
4re3lj
r2ell
rel4lag
rel6land
rel5led
rel4lev
5r4elm
rel5ses
rel4sk
4re1lu
4relv
2re5ly
2relæ
2relø
4re7l6å
relå7r
2rem
remann6
r1emb
remi6ene
remi6l
re7mis
rem9ji
remmed5
6remn
rem8na
rem5p4
rem1s
remti9da
4remu
8remy
4remå
2re3na
ren4del
4rendr
8rened
re5neg
re7nei
4renek
r3e4nel
4renest
6renet
6rengd
reng5l
4rengn
reng5st
re5ni
2renk
ren6kl
r3enl
ren8ne8sl
rennes9la
re5no
ren5sa
r3enss
6r7entit
4r3en5tr
6rentu
4renu
5renz
6renæ
4renø
re5og
2reop
re3o2r
5reou
8repen
6r5e6pi
1repu
6repus
1rer
6rerad
6re9rang
4rer6at
re5re.
4rered
4reref
4rereg
4rerei
re4rek
4rerent
4rerep
4rerese
4reresu
4reret
6rerfa
4rerig
4rerik
4r3ernæ
4rerol
4rerom
re3ros
rero6se.
re5rot
3rers
rers4p
4rerute
re6r7øy
2rerå
1res.
2resa
re2s3c
re3se
4resel
re4sem
4reset
resi7ere
4resin
2resj
2resk
res5ke
re6s7kje.
res6kl
res7kod
re6sky
6re1sl
re4slu
1resm
re5smo
re3sov
re9spe
4respi
4respr
2ress
res4sal
res4sek
res4sit
res4sj
res6sk
res6sort
res4sp
res4st
res4sy
res9tane
5restau
res6t5erv
res4tes
res3té
4re3sti
res4til
re3str
4restre
7restv
4re5sty
4restå
1resu
6resuk
4resun
re3svi
2resy
2resø
4retaki
4retal
re4tap
4retea
8retek.
6reteke
4retekn
6retel
6re5tem
re5ten
4re5ti
4retj
4retoa
2re5t2r
rets4i
ret4st
ret7ted
ret5ter
rett8o
rett6set
4re5tu
2rety
2retø
5retøya.
7retøyets
4re7tå
2reu
reu6r
4revak
re5van
reva5re.
6reveg
4revei
4revel
re6v7enh
re5ver
reve5s
r3e4vig
re4v5inn
re7vom
1revy
re4v5åp
3rew
2reå
2r1f
rfa5re
rfat5
rfe8en.
rfe8er
rfe4et.
rfei5li
r4fik
rflå3
rfe5m6ø
rft2
rfu8se
rfyr4
r9fæ
rfø8rarar
2r1g
r5ga.
rga8le.
rga8li
rg5and
r7gann
r4g5anv
rga3ri
rg3art
rga4ve.
r6gedi
r4gef
r2gem
rgent4
r3geo
r4gerei
r4geret
r4ge3ru
r4gesj
r4gesl
r4gesta
rgi1a
rgie4n
r2gik
r2gil
r2gim
r2gio
r2gir
rg3i4ri
rgi7sl
r2giø
rg2le
rg5le.
rglem5
rg3len
rg3ler
r2gn
r4gog
r3gom
r2got
rg5rab
rg3rea
rg3rel
rg5reps
rg5rin
r3gru
rg5sc
rgs6kor
rg5s4le
rg1sn
rg5s6till
rg5sto
rg9stu
rg2sy
rgu7d
rg6ut
rgå9as
rgå6va
rgå6ve.
2r1h
rhav2
rhavs3
rhjul8s
rho3d
r7hu
rhø5re
rhånd6s9
rhå9ne
ri1an
4rianf
4rianl
6riansv
ri1ar
4riarb
4riarr
6riau
2riav
ri4ava
3ri6avo
2rib
ri2b3l
ri8ca.
ri4co.
ri5da
4ridale
ri5der
ri5di
2r1idr
rid3t
4rieie
4rieig
4rieks
ri1el
6rield
4rielem
6rielim
riel4la
rie4n
ri3end
4rienh
4rient
rien5t4r
ri1er
rie5ra
rie5ri
4rietat
ri5even
2rifa
riferi9e8
rif4fi
rifiserba8
6rifj
1rifl
rif5la
2rifo
2rifu
4rifø4
ri4ga.
rig4gr
ri3gi
4rigj
4rigre
rig2s
rig6s7t
2rih
2rii
2rij
5rij.
ri4kali
ri5kan
5rikd
ri3kes
ri7ki
rik7ken
rikk5j
4rikl
ri8k9la
2ri7ko
6rikon
2ri1k2r
rik4sk
rik4s5u
rikt6
rikts3
riku6m
ri3k4v
4rikå
2rila
6r5ilde
6riled
ri5lei
ril6lest
2ri5lo
ril4sn
2rilø
4rima
ri9mab
ri9mar
6rimes
ri5met
2rimi
ri4mi.
7rimis
rim7l
4rimm
4rimo
ri4mor
4r1imp
4rimu
rim9ut
4rimy
rina5l
ri5n6am
4rinas
4r5inc
4rind
r3indu
ri4nee
ri4nes
2r1inf
rin7gom
ring3r
ring4sa4
rings5ak
ring8spa
2r3inj
2rink
4rinn
rin9nes
4rinor
2rins
rins6k
rin6sm
2rint
rin4t5j
rin4tr
2rinv
ri6nø
2ri1of
6ri3om
2ri1op
2rior
rio5s4
riot3r
2rip
4ripe
ripo4s3
4ri1r
4risau
4rised
rise5i
6risek
4risel
ri4seli
4rish
5risiko
2risj
ri6sju
4riska
ri4ski
6risku
4risky
6ristad
4ri5sted
ris5tik
4ristil
ri4sto
ris5tof
ri5stun
6ristø
ri6stå
4risv
4risy
4risø
ri3te
6riteo
ri7ti
riti9da
4ritil
4ritj
ri5t6o
ri5tr
rit1s6
ritt8s7t
ri6tun
4rity
2riun
riu4r
2riut
4rivar
ri6ved
rive9ge
ri5vei
4riverk
2rivi
ri4vi4s
riv5ise
6rivo
4riøk
riø4r3a
8riøya
4riå
r1j
rj7ambi
r4jere
r2jes
r4jeti
r4jetr
r4jetu
rju6la
2r1k
rk3akt
r6kanf
r4kao
r4kapr
r6katr
r3ke.
r2keh
rk5eik
rkei8ka
r6kek
r4kelo
r4ke3lu
r3ken.
r4kenav
r3kene
r4keni
r5kens
rke5ri
r4keris
r4kero
r5kers
r4ke3ru
r4kerø
rke4se
rkeslø7se
r9ket.
rk4han
r3ki
rki3d
rki3e
rki4vi
rkjek8
rk5jor
rk1k2
r5k8led
rk2li
rk5lun
rk9lut
rklæ5re
rk2lø
rklå9ra
r3knek
r5knep
rk7nes
r3kno
r2kob
rko6b5r
r6kofo
r2koh
r4kola
r4koli
r4kope
r4kora
r4koru
r4kosel
rko6sele
r4kosj
r6k7ras
rk5rei
r5k6rem
r8ks
rk4sar
r6k6seg
rk2s1i
rk4ska
rk1st
rk6stal
rk4sten
rk4s5ti
rk4stj
rk4sto
rk6s5vi
rk5ti
rkti4s
rk5to
rku4le.
r6k7u6t
r4k5ve6d
rk9vei
r5kvel
r4kver
rk3ves
rk5vik
r4k5øl
r2k3øy
rk9øys
rkå4k
rk5åke
rkå6pa
rk5å4s
2r1l
rla4te.
rle4a
r2lef
r3lep
r4l5e4ri
r6le7sl
rle4st
r4lesu
r4leu
r3l4i
rli9ke
rling3s4
rli8ta
rli4te.
r3lj
rl6o
rlog2
rlo5ve
rl4sk
rlu4e
r3ly
rlys7k
r6l5z
rlø8pa.
r5løy9
2r1m
rma6ge.
rma5k4l
r4m5alte
rm3anl
rm4ans
r6manv
r4mare
r4marr
rm5av
rm3b
r2me7g
r2mek
rme6lap
rme5ne
r4menet
r6merev
r4mese
rme9tar
r4mey
r4m5ide
rmi6ene
rmini6
rmin5ski
r6m5inst
rm5i4v
rm1je
rmlø8pa
rmo4e
r2mof
rm1op
rmo7st
rm7p
rm5s6ko
rm1sl
rms6n
rm1st
rms5til
rm1su
rmta8la
rm3te
rmu7an
rmue4
rmue5ne
rmu8la.
rmu6le.
rm5øy.
r9må.
rmål4
r6m5åp
r9mår
r6m7åta
2rn
r3na
r4n1ak
r4n3ald
r6n5appar
r4narb
r4n3art
rnat7r
r4natv
r6n9a6vis
rn3avl
rn3d
rndø4
rndør5
r3ne.
rne5a2
r5neboe
r2nec
r4nef
r2nel
rnele6ge.
r3nell
r3nels
r4n3eng
r4nenh
r4nerei
r6neris
rne3ro
rne1s2
r5nes.
rne6se.
r8nesi
r4ne3sk
r4nesm
rne3so
rn5e4tab
r4nete
r2nev
rne5vr
r2nés
rn5g6
r4ninn
rn5k4
rn3n
r5no.
r4noa
rno5b
r4nod
r4noi
r6nok
r2nom
rn5omn
rn3oms
r4n1op
rn3ork
r2nos
r4n1o4v
rn7se
rn4s3in
rn5ske
rn3skr
rn5sla
rnsle7ge
rn7s6mi
rn6s3ovn
rn5spon
rn3s4pr
rn1st
rn4sti
rn3te
rn5ti
rn7tr
rntre4
rnt4v
rnu4
rn5ug
r6n3ut
r7nøt
r4n5øv
rnå8le.
rn3ås
ro1ak
roa4s
ro5asi
9roban
9robar
1robe
ro4bed
ro4bef
5roben
ro4bes
5robølgj
1roc
r3odds
7rodo
ro5end
ro7ens
ro7fa
ro4fel
ro4fem
roff5ri
ro7ga.
roga9ta
ro7ge.
rog5ret
ro6gry
rog1s4
ro2gu
1roi
ro4kel
ro5ki
rok6kat
rok6keri
rok5kl
rok4kom
ro7k6l
rok5n
rok7s
rok8se.
rok5v
roli7ga
4rolj
rol4lab
rol4lap
rol4leg
rolle8ge.
rolle8se.
rol4lis
rol6ly
rolo9v
2roly
ro6mak
ro4mal
3ro5m8an
ro4mate
2rom7b
4ro3me
rome5d
4romk
4r3omn
ro4mor
2romr
rom5sla
r7omsy
romsø3
rom3t
ro5ne.
ro7nim
6ronism
6ronista
8roniste
6ronisti
4ronn
ron4na
rono5s
ron1s4
ronta6le.
ro4pad
5ropet
ro4pia
ro8pla.
2ropp
ro9py
ror3a
ror6da.
ro3re
ro1ru
ro4sat
ro5sel
ro3sen
4rosl
ros3la
ro4sm
ro6sov
ro1s1p
ros4st
ros4sy
ros7tas
ro3sti
ro3str
rost7rø
rot5ekte
ro5tes
rote7ster
roti7ka
rot5ord
ro5tu
6roty
roun2
round3
ro5ut
ro5va.
ro9vare
ro7vas
ro5vek
ro7ven
rove5re
rov5sm
rovve6
rò6te.
2r1p
r5pa
r6parb
r5pefo
r4peno
r6penø
r5pesk
r5pet
rp6j
rp2l
rp3lad
rprø5ve
r3pu
rpun7g
r6p5ut.
r6p5øy
r2påk
2r1r
r8raa
r2rag
rra3r
r4raro
rr3d
rr6e
r4reb
r7rebart.
r2ref
rre7int
r4rekl
r5relat
r4reo
r4repl
r4re3ru
rre5sk
r4resm
r4reso
r4respe
r3ress
rre4st
rres5ta
rre7sti
rre5str
rret6s5
rre5u
r3ri
rri6ka.
r6rip
rri5v
rr3m4
rrmå8la
rro6e
r5rom
rro8sa
rro8se.
rro8ta
rr5s2
r2r3un
rr5v
rrå5de
4rs
6rs.
r1sa
rs3ab
r2s7ad
r3sak
rsa5ka
r6sakt
rsa6la.
r8s9ald
rs3all
r5sam
r4sarr
rs3arv
r1sc
5s6ch6l
r8sedi
rse6g7
r4seku
rs4ela
rs7eld
r4seli
r4s3elv
rs5e4rik
r3ses
r4sesi
r6sesu
rse4te.
rs6ett
rsett8o
r7sim6
rsimp7
rs1in
r5s4ing
r4sins
rsis5t
r7sja
r4sjh
rsj3or
r3skad
r6s7kaf
rs4kam
r3skap
r4skar.
r4skas
r4ski
r5skil
rsk7inns
r1skj
rs5kjens
r6skl
rskla8g
rsk5lar
rs4k5le
rs4k3læ
r5sko.
r5skoe
rsk3op
r4skor
r3skot
r1skr
r4s3kra
r5skriv
r4s3kro
r1sku
r5sku.
r5skue
rsku7et
rsk5und
rsk5var
rs5kys
rsk5ø
rs4lef
r4slei
rs4lek
rs4les
r5s6lit
rs3lok
r4slun
rs4make
rs4mo.
rsmål4
rs6nev
r1so
rso9a
rs5oml
rso6n5
rso7n6al
rso5n8e
rso5n6i
rsons4
r2s1or
rs5ord
rso7ris
rs1ov
r1sp
rs4pan
rs6pat
r5spel
r4sper
r7spes
r5spi
rs4por
r5spred
r4spå
rs3s6
r1s2t
r4s5tabb
rs5tank
rs3tap
r6st7b
rs4ted
rs4tem
rs5tend
rsten6s
rs5ter.
rstev9na
r3stil
r4s5tilf
r4s5tilh
r4s5tils
r4s5tilv
r5stis
r4stit
r6st5k
rst4r
rs9tre.
rs7tree
r4strin
r4s5tro
r5strø
rst7ut
rstu9va
rstyg7
r3st6ø
r7stå
rs5ukl
rsu9r
rsu7sa
rs5usi
r1sv
rs8vak
rsva9ra
rsvar4s5
rs1ve
r3s4vek
rs5vit
rsy4na
rsy3t
r1sz
rsøks3
rs9øye
6r1t
rt5ad
r4t5af
rta4ka.
r4tana
rt3anl
rta9pa
r4tarr
rt3art
rt3avs
r4tec
r4teda
r3tede
r2tee
r4tego
r4tegr
r4teie
r4te3in
r4teka
rte6ke.
r4teki
r4teku
rt5e4lit
rte6ma.
r3temp
rten4s5k
rtentle8
r2teo
r7t6er
r5terd
r5teres
r4teris
r5terk
r4terå
r4tese
r6tesk
r6testi
r4teta
r4tete
r4tev
r4th
rtian8d
r4tians
r4tiar
rti8ar.
rti5en
rti6gra
r4ti3kv
r4tila
r4tili
r4tilo
r4ti7na
r2tio
r2tip
rti7sa
r6tiska
r4tiski
rt6i9so
r4tisp
rtis3s
r4ti5str
r3titu
r2tiv
rtma6le.
r5to.
rt3off
r9tofo
r9tok.
rt3omk
r4t3opp
rt6opp.
rt3ord
r6t7o6s
rt1o4v
rt2r
rt8ra
r9tre.
rt6red
rt3reg
rt3rei
r4t5reko
rt5rel
rt5rep
r7trib
r4t3ris
r4t5ros
rt3rut
r5t6rål
rts3ar
rt4seg
rts5eng
rt2si
rt4s5ja
rt5ske
rt3skj
rt5s4no
rt3s4pe
rt4sti
rt7s6trek
rt4s5tøy
rts5unde
rt3t4
rtu6en.
r7tug
rt3und
r2t1ut
rtu8ve.
rty8da.
rty8de.
rtyr5s
rty6ra
rt5yt
rtæ9ra
rt5øl
r6t5ås3
ru3and
6ruav
ru6avh
ru8bl
ru5bo
ru4di.
rud4r
ruds4l
ru4ele
rue4r
rue3s4
ruga8l
ruga5t
rui3d6
4ruk
ruk4su
rukt3s
ru9la
4ruli
6r7ulk
rul8ke.
r2ull
r7ulv
r4um
rum3al
rum4p9l
5r2unde
run5del
6r3under
7r4under.
r5unders
rund3r
rund3s4
run6ge.
4ru2ni
run5kr
r7uly
ru4nøy
ru2r
ru5ra
ru8ran
ru8rar
ru9rer
rur8ta
r4us
rus2h3
6r7u6sik
rus5j
rus7lu
ru1s4o
rus5sel
rus4st
ru4s4t3r
r4uta
ru3tal
ruta8la.
r7utan.
r4utbe
4rutd
rut8e
rute3i
ru4tel
ru9tene.
ru9ter
2rutg
r1utk
rut9o
6rutr
rut4re
ru6trø
rutto5
2rutv
ru5va
ru4ved
ru4veg
ru4vei
ru4vel
ru4vere
ru4ves
ruvi8
ru6v7is
2r1v
rv4a
rva7ka
rva6la
rve3de
rve4den
r4ve5dr
r4vega
r4vegi
r4vegr
r4veim
rveis7e6
rve5kl
r4vela
rvel9le
r4v5eng
r5ver.
rve5re
r2ves
r2vev
rvil9l
rville9d
rv2j
r4vos
r4vov
r3vr
rv2s1
rv5ung
rvå7r
4r1w
rx1
ry1a4
ry2dr
ry7fe
ry5fl
ry5ke.
2ry1kl
ry7le
ryl4l5i8s
4r5yndl
ry4nes
ry5nes.
ry4pa.
2ryr
ry8re
r1yrk
ryr4ke.
ry9ro
ry5rø
rys6sal
ry5ta
ry4tek
1rytm
r3ytr
r4z
ræ7le
8r3æ4re
8r3æ4ren
rær5in
rær8t
ræ8v
2rø.
rø8ar
6røb
rø4be.
rø4dek
rød1s
4røep
røf5l
rø4ke.
rø4kero
røk3l
4røkn
røk5s4
røk7t
røk1v
2røl
rø6m
røm1a
røn5nes
rønn5s4a
rønn5sk
røn5sko
5r6øntg
rø4pe.
røp9l
1rør
rør5d6
r6ørende.
rø7ret
5rørl
rø2r3o
rør4sp
r8øs.
rø3se
rø5sla
røs5v
rø8ta
røt9as
rø1va
rø5vede
rø9vers
rø1vi
r4ø5væ
2r1øy.
4røya
røy9ar
røy6ed
røy6ene
røy5es
røy4et
5r6øyk
3røyr
røy5re
røy8senes
6røy4s3k
røy4st
2rå.
rå7a
4råag
4råb
3rådet
rådy9ra
rå9ene
2råf
4rå5g4
2råkj
råk3re
rå2k3u
råk1v
4rål
råle7s8
rå4let
rå5let.
rå5lu
r5ånd
rån6da
2råp
2r1år
rårs5k
rå5ru
rå1s
4råsb
2råse
rå5si
2råsj
rås4t
6råta
råta8ka.
rå5tr
rå5tu
2saa
5saa.
sa4ba.
s6abe
s8abl
sa5bok
s3abon
sa5by
sa3ce
sa4dag
4sadam
sa4dere
4sadm
sa4do
2sadv
sae5d
3saen
7saer
1safe
5saga
sa4ga.
sa4gas
sa4gat
6sagent
6s5agg
6s5a6gi
sag8na
sa6go.
sa4gog
2s1a2gr
sag3s4
sa3ik
sa5ir
sa1is
5sak.
sa2ka
3saka.
4sakad
sa5kai
3sakb
3sakd
3s4a3ke
5sakf
1sakh
sakh5e
1saki
sa4kj
sak5kr
s4akky
5sakl
5sakm
4sako
3sakp
sa1k2r
5s4aks.
sak4s3i
4s3aksj
sak4sp
5saksr
5saksu
2s1akt
sak6ta.
5s4akto
s4aku
4sa7kø
1s4al.
sa1la
4s5alarm
7sala.
5sa5lat
4salb
1sa3le
sa9let
1salg
s4alge
4s5algo
salg6s5
s6ali
sal4mes
sa5lo
5sal2s3
sals4a
4salter
sa1lu
3salv
sal5ved
2saly
1s2am
5sam.
sa2ma
sa5ma.
sam4an7
sa5mas
sam5ei
sa4mel
sa4met
5saml
sam4lev
5samm
sammen5
sa4my
4s1a2na
sa9na.
sa7nar
sa3nat
san6da.
san7d8al
5s6ande.
sand5r
sand5s6lo
sand5st
san4d5ø
1s2a5ne
4s3a6nek
5sang.
3sange
4s3angr
s7anken
2s1anl
s5anm
san5ne
6sanno
sa2no
s5anor
san5os
san1s
5s4ans.
4sansa
5s4ansen
san7s6k
4s5ans8l
6sansv
s8ant.
san9te
6santr
4santy
4s1anv
2s1ap
sa2po
1s2ar.
1sara
6sarab
2sarb
s4ard
9s8are.
4sareal
4sareg
sa5rev
3sari
sa4ri.
sar6ka.
4s3arki
2s1arm
sar5me
sar8me.
s1arr
2s1art
sar4ta.
sa4ru
4sarv
s4ary
1sas
8sasju
2s1a4sp
4s1ass
s6ast
4sasty
2sasu
4sasy
1sat
sa1ta
sa5ten
sa3ti
2s1atl
4s3atmos
sa1to
4sa5t6r
s5atsk
5satt.
4s3atta
6s5atten
satte4s
5sau.
sau4d
sau5di.
5saue
4saug
sau6ga
s3auge
sau6ge.
2s1auk
5saum
3saus
4saut
2s1av
s2ava
sa4ve.
5s6a5v6in
sav5n
3savu
8s9b4
sba4ne.
sbi6e
sbo4da
sbu6et
s6bug
sbul3
sby8ta
4sca
1sce
2scel
s4cene
s3cer
6sch.
8schl.
6s7cl
4sco.
6scoc
4scos
s4cus
8s9d6
sdag4s5
sdam9p
sde6le.
sdu8en.
sdu8er
sdø8v
1se
2se1a
3sea.
sea4g
se3an5d 
se7ansa
sea9re
5se4au3sk
2seb
4sec
4sedag
sed5d
se3de
5sede.
5sedl
4sedo
2sedr
2sedu
6sedvanle
2sedø
5see.
see3d
2seef
2seeg
se6e3i
se3e4l
se5en
seer1
5sees
2seev
2sef
s1eff
4s1eft
6sega
sega6l
se2ge
se6ges
se3gev
seg8ga.
9segl.
7seglet
3segm
4s2e7g8r
2seh
2seid
sei8dan
sei9den
sei8e9nes
s5ei4et
2seig
sei6ga.
sei5ge
sei5k
3se8il
6seim
2sein
se3ind
s3eini
se6ink
se3ins
se3int
sei5r
3seis
2sej
5sej.
2se5ka
3seke
4seki
2sekj
5sekk
sek4kes
2sek4l
4se3kn
2seko
se2k1r
4sekra
4sekri
4sekro
3s4eksj
4seksp
sek4st
sek2t3an
sek6te.
sekte9ra
3sek5to
4seky
4sekå
s2el
2sela
se6la.
3selak
5selane
5selar
sel5art
s3e4las
se6l5at
sel1d
se4le.
4se5led
6selega
4selei
4s3elem
4seleng
4seles
4s3e4lev
5s6elg
4selik
4selil
4selis
4s3e4lit
sel6løp
2selo
7selol
se3lom
3sels
sel4sin
8s5elske
sel9s8lag
sel4spo
sel5t6
2selu
se6l7u6r
sel4v5ak
sel4van
selv3e4
sel4ve.
selvei4
sel4ver
sel8vin
2sely
2selæ
2selø
selø8pa.
6selå
2se3ma
3semb
7semd
se5me
se4mi.
semini6
2s1emn
sem4na
9semnd
2semo
sem5pe
2semå
s2en.
6senau
sen9d8a
sen6dela
6senden
4sendr
s2ene
4sened
se3neg
4senem
8senesa
6senese
sene8se.
s5engas
2s1enh
se6nin
s3enkj
5sen3n
s2ens
4s5ensem
sen6s5end
sen4sj
sen3so
7s6ent
sen5ter
8s7en5trep
4senum
4seny
2senæ
6senø
2seo2
7seod
se3or
2sep
se3pe
seperso5
3sept
s2er.
se3ra
4seram
5seran
4serap
5seras
6serau
ser5d
s2e5r4e
5sere.
4serea
4sered
4seref
4sereg
4serei
4serek
4serel
4serenn
4serent
4serep
4sereso
4seress
4serest
4seresu
4seret
4serev
s1erf
s2eri
seri6e5ne
4serik
4serkje
5serkr
5sern
ser7nev
2se1ro
se4rop
se4ror
se4ros
9s6ert
ser4tak
ser6tat
ser4tr
se1ru
4serul
se4r3un
ser4ved
ser4vel
2sery
2se5r6ø
2serå
5ses.
ses5ald
5sesals
ses5alt
4sesc
2sese
se4sene
ses5in
se3sj
4sesje
4sesjuk
ses5kal
ses5kar
ses5kv
ses5lit
se3sna
5seso
ses3pr
ses4s5in
se1st
5sest.
5seste.
4sesto
ses5un
ses1v
2sesy
4sesø
ses3å
3s2et.
2se2t6a
3seta.
se5tae
seta8ka
se5tar
6setea
4seteg
4setei
4setek
se7tel
se4tera
se5tero
4setes
2se3ti
se8ti.
s3e4tik
s3e4tis
4setje
5setje.
7setl
5setn
2seto
2set6r
s4ets
s5etters
2setu
2setv
2sety
6setø
3seum
4seun
seure9ne
seu2t
2sev
seva6ne.
s8e5var
sev4d
sevi4sa
s1evn
sev4ne.
se3vr
3sevåg
2seyn
2seø
2seå
1sé
2séa
6séb
4sée
4séf
4séj
4sék
2sél
4séo
6sép
9sér
4sés
2sév
2s1f
sfa4ne.
6sfe
sfe6et.
sfes5
sfisken8
sflå3
s5fo
sfo8ra
sforlø9
sfra5s
sfri5e6re
sfyrs5
3sfæ
sfø9ren
sfø5rer
sfø5ri
6s9g6
sga4l
sga8va
sga4ve.
sgen9s
sge4st
sgå4va
sgå4ve.
s1h
4sh.
sha2k
s7hat
s3hau
6she
shea4
s5hei5
7sh6e4rif
s4hi.
s6hip
sh5isk
4shj
6s7hopp
3short
3show
6shs
2shu
4s5hy
s5hø
shø8l
shø6va
shø6ve.
s7hå
1si
sial5v6
4sia5m
si7ans
4siap
4siav
si2bl
3si2da
3si4de.
3si3den
si4deo
s4ider
si5der.
si4dete
2si2do
4s1idr
sid8ra
4sidy
4sieg
si1el
sie4n
si5er.
si6eren
sie4s
si3est
6sife
si3fl
2sifo
si4f3r
2sifu
4sifø
3sig
siger4s
4sigi
4s3iglo
si5gr
4sih
3sik
si3ka
si5ke.
sik2h7
sik4ka
sikk8artet
sik4k5el
sik4ko
siko3
si4kom
si4kop
si4kos
si4kot
sikt4s3
s2il
5sil.
3sild
sil4del
sil4der
sil4des
sil5j
sil2k
sil4les
2silø
si6mel
4simet
2simp
si3mu
4sinde
4s3indu
si3nek
2s1inf
sing4s5a4
7singu
si4ni
4sinj
2sinn
3s4inn.
7s4inna
s6inne.
5sinnet
s3innh
s5innk
s3innl
4sinnt
si5nob
sinsk5e
2s1int
4sinv
si6nø
4si5ov
si4pa.
si8pe.
si6re.
si7ren
si4ri.
sir8kl
s2is
si5sel
si4serf
sis5e4v
si6sin
6sisju
si4sk
sis5ke
si4sn
si4s5te
si4sti
sis3to
4sisy
3s2it
si5ta
sit8ji
si6t7ra
si4t5re
si4tri
sit3s4
sitsva9
sit6term
sit4tes
si4umf
4siut
5siva
si9van
si6vek
si8vi.
si9våt
1sj
2sj.
s2ja.
8s5ja9g
4sjam
s4jan
4sjanl
s7jarn
2sj3av
6s7jaz
2sjb
6sjd
5s4je.
sje4f3i
sje4fla
sjef5t
sje3g
sjek4t5o
3sjel
sje4lev
3s2jen.
5s2jene
4s3jent
5s4jer.
s2je5s4
5s4jet.
sjet4ti
2sjf
2sjg
s6jim
2sjk
2sjl
2sjm
2sjn
2sjob
5sjok
4sjom
9sjon
sjons7
2sjor
2sjou
2sjp
2sjr
2sjs
2s6jt
s6j3t6sj
sju1a
6sjub
6s7jug
sju8la
4sjun
4sjur
2s7jus
5s2jø
sjø3k6
sjø1p
sjø9rø
sjø1s2
sjø3t8
6sk.
1ska
2ska.
4skab
skabe3
s2kad
8skae
4s6kag
2skak
5s4kal8a
ska5lar
2skam
s4kaml
4s5kana
4skande
4skane
4skano
6skant
5s6kap.
9s8kapa.
4skapas
5skapen.
6skapit
4skapp
2sk2ar
sk5arab
sk7arbe
5skard
4s5kark
6skars
4skart
3s8karv
2skas
4skate
8skay
4skb
6skd
2ske
s4keda
s6kedo
s2keh
s6kei
skei5er.
s8k5e4lev
s6kelik
skel3t
s4kelu
s3ken.
s4kena
s6kenav
s4keno
s5kens
5skept
s5ker.
s4kero
s5kers
s2ke1s
ske3si
skes4m
ske5sn
s4ketet
s3ke4t3j
s6kev
s2key
2skf
2skh
1ski
5s6ki.
7skia
4skid
5skie
5skif
5s4kik
s6kill
5s4kilt
ski6net
ski4nin
5sk8inns5
skino6
5skiol
5skip
2skir
s4kire
6s5kirk
sk5irs
s6kis.
7skiss
4s5kist
5s2kiv
s6kje.
5skjema
6skjemas
5s6kjer4m3
3skjer5m4e
7skjers
3skjor
4s5kjærl
5skjøn
6skjøp
skjø5res
2sk1k4
2s1k2l
6skla
sk5lak
s6k5lan
s5klas
sk9leg
s6klei
sk3lek
sk5ling
sk5lit
s4k5luf
s2klyd
2skm
2skn
s1knu
4skoa
7skodd
4skof
3s2kog
2s3koi
1skol
7s4kola
3skole
4s3koll
4skom
s6koma
s5k6ome
6s1kon
4skoo
sk5ord
s6korpi
s7kors
4skort
2skos
s2kot
3skott
sk8ra
s4k9ra.
5s4kral
s4krat
s2k7re.
4s3kref
6skreg
5s8krek
4s3kret
5skrevn
3skrib
3skrif
4skrig
3skrik
3skrip
4skrite
3skriv
5s4krog
s3kron
4s3krop
sk6rud
skru3s6
6skryss
1s2krå
2sk1s2
2sk3t4
5skud
1s4kue
sku4end
sku4er
skue5re
1skuf
5skulan
5skular
3skule
6s5kulis
4skull
s4kulp
4skult
skum3s
2skun
s6k5underv
4skup
8s5kurs
8skurv
2skv
sk5va.
3skvad
sk3vas
s6kven
sk3ver
sk5vit
3skvu
1sky
s6kya
s6kye
4skyr
sky3re
4skys
6s6kyss
5s6kysk
3skyt
6skæ
6skø.
6s5køa
4skøe
1skå
skå5re
6skåt
sl4
sla8da
s3lade
sla5ge
sla8ge.
sla5ke
s5laks
3slakt
3slal
4s3land
slap5pe
s5laran
s5lare
4s5last
s1lat
sla4te.
4s1lau
s5laus
sla1v
3slave
sla4vin
2sle.
s8leda
7slegare
5s6legas
s4legi
s4legn
s6legr
6slei
slei5er.
s4leiv
8s5leke
s5lekk
s2lel
s4leme
4sle7ne
s6lener
s6len6t3
2sler
8s5les
s6lesj
s4leso
s6lest
s4leta
s5lev
s4leva
4sley
s5lia
2slid
sli4en.
6slig
sli5ke
s4likk
2slin
8s3linj
slin6t5
3slip
5s4lit.
3s4lite
4s5liv
slob5b
slott4
s6lott.
7slottet
1slu
8slu7a
2slu2e
slu5es
6sluf
4slug
sluk3s6
slum4p5
slum5p6e
s3lund
s5luns
s6lup
slu7sa
s4lut
s1ly
sly8et.
1s4lyn
4s5lys
sly8t
slæ6rari
2sløn
8s5løp
slø4pa.
s6lør
2sløs
slø8s5a
3s4løsi
slø5va
slø5ve
slø5vi
5sløyd
sløye7
9s4lå.
s4låe
s1lån
slå5ner
1slåt
s1m
sma6d
3smak.
5s4maken
sma9let
4sman
s4med.
s4mede
6s5medi
s4medk
smeg5
4smei
smek7l
s4mekt
8s5meld
3s4mell
5s4melt
2s5men
3s4mert
6smes
s6mesi
s6mia
s4mie
smi4ene
s4mig
s6mil.
smi7la
s6mile
smini6
s2mit
smo7a
smo8de.
s2mok
6smot
3smug
6s5mugg
smul2
s6mula
s4muld
s6mule
5smurt
1s2my4k
6smøn
1s2mør
smør3s
4smøt
5små.
små5r
s8mått
s1n
8sna.
s4nab
7snak
4s3nas
6s3nat
4snav
4sne.
4sneb
4sned
s6nee
s4neg
3snei
snei5er
sne4kri
s7nekt
s4nel
2snem
4sner
6snes
sne9sa
snes9v
4snet
s6nif
sni6gl
s2nik
snik5ko
3s2nil
6s3nin
3s2nip
snir4
5s2nit
2s3niv
s8no.
s6noe
s5nord
6s7not
5s6nud
s3num
s4nur
7snut
8snyh
2snæ
snæ4re.
5s6nø.
snø5d4r
5snøe
1s2nør
snø1s
snø5vi
so3al
so8ar
4soav
2s1ob
so2bl
1sod
so4da.
5soe
sofa1
so4fag
so4fas
6s5off
6s5ofre
soft1
so2ga
so8gi
so7gl
sog6nem
6soh
5s4oi4
so5id
5sokn
4soks
sok4se.
7sol.
so4la.
sol5av
1sold
so4le.
solei5er
so4lene
sol5f6
1so7li
2solj
so2lo
so8lo.
sol3s2
sol5t4
so4lum
so4lø
3som.
so6mend
4s3omfa
4s1omg
5somh
2s1omk
4soml
1som5m
sommar5a
3s6omme
somme6r5e6
2somr
7somren
5somrer
6s3områ
s1oms
som5sl
s4omst
som5sti
4somsy
1s2omt
5somt.
6somta
3son
so4na.
son7da
7s6one
so8nea
song3s4
so4n3o
sons4k
son5st
so2nu
so4ny.
2s1o2p
so7pak
so9par
so7pet
3sopp.
5soppa
3soppe
sop4pi
8sopple
so3pr
1sor.
7sora
so3ran
5sorb
4s1ord
sor4da
1so1re
so4rek
7sorga.
sor4gl
so2ri
4s3orie
7soris
so5riu
4sorke
sor5n
3sor5s
7s8ort
1sos
4s5osc
so8se.
6sosf
4sosj
so4sl
so5te
so8te.
so4tra
sots4
sot5te
sot4ti
4sou
2sov
so3va
so4ve.
so5ven
sover5e
sove3s4
5sovet
3sovj
sp2
4sp.
spa5g6h
7spak.
7spaka
5spake
8spakk
s2pal
s3pall
5spalt
3s4pann
3spari
4spas
5s6paser
4spe.
spe4a
8speda
spe9dé
s4pee
1s2pei
s2pel
spe4leg
spe4les
5spelet
3s4penn
s4pent
s5pep
spe4r5and
6speri
4sperl
s4perr
s3pers
3spesi
s4pest
s9pet.
1spi
6s5pilo
4sping
s2pio
2spip
spi7res
spi7ri
spi7ro
5s6piss
2s3piz
2s1pl
8s9plant
sp9lar
4sple
s4plin
3split
sp6o
2spoe
spo6et
2spol
5s6pole
6s7poli
s4pora
s4pore
5s4pors
sport6s5
3sporv
2s5pos
4spot
s3pote
spo5v
9sprag
5spran
6s3preg
5sprei
s4prek
spre5ke
s3prem
5s4pren
6s5pres
5s4pret
s6print
s5prio
8sprinsi
8s3pris
8s7pro
6s5prob
s3prod
4sprof
5sprog.
5sproge
5s6pross
1spru
s4pry
3sprøy
5språ
2s3ps
8spub
2spul
3s2pyd
5s2pø
6s3pøl
sp5øy
9spå.
5spåd
8s9r
sre8ka
sre8ke.
sri8e9
sri8ka
sri8ma
sri4ve.
s5ro
sro4e
sro6pa
sro6sa
sro6se.
sro2t
sro9te
srot5o
srø1v
srå4da.
sråde9r
srå6ders
srå8ma
4s1s
s7sabel
s7sabl
s6sae
s4saj
ssa8ke.
ssa6la.
ss5all
ssa4me.
ss5amp
s5sane
s7s8ar.
ssari8e9n
s7s6arm
s4sarr
ssar8ve.
ss6as
ssau8sa
ssau6se.
s6seet
s2seg
sse5ge
ss5egg
ss4el
sse5li
ssel5s
ss9elv.
ssel5v6å
s2sem
s5sen.
sse8na.
ss5enden
s5sene
s4seni
ssen6ke.
s4senu
s6senå
s5ser.
s6serab
s6serat
sse7sk
s4seski
s4sest
s7set.
s9sets
s2seu
s4sey
s2sh
ssi4a
ssi7e6rer
s4siff
s6silo
s8s9ime
s6s3ind
ss5init
ss3inj
ss3inn
s4s3ins
s5sis4
ssis5m
ssi6v7end
s5s6jarg
ss4kape
ss3kar
sska8ra
ss3kof
s7skog
s4skor
ss6ky.
ss4kye
ss4kå
ss5kål
s7skåp
s2sl
ss1lo
ss5ly
s2sm
ss6nar
ss2no
ss4nø
s4s5nød
ss5nøk
s2sof
s4sok6
sso5lo
s2som
ss4oma
sso3ra
s4sorga
ss3ove
ss6pil
ss4por
ss9ri
ss2t
s5stad
ss4ted
ss3tek
sstel6li
ss5tep
ss7tilp
s7stip
sst6r
ss5tren
ss4trå
ss3tus
ss3t4v
s2sul
s3sur
ssva7ra
ss1ve
ssy6na
ssy5r
ss7øye
s6så
6st.
2s1ta.
stabs3
3s6t2ad
stad3a
sta6d3o
s5tafa
3stafe
sta5fl
st3aft
sta7ge
4stah
sta6ka.
5stakk
4stakl
6stal.
6sta4la
sta5lak
st5ald
4stale
sta4le.
5s6tali
5stalt
s3tame
3stamm
sta5na.
3s4tand
6stande.
st8ane
s4tanf
s4tang
stang5s6
st3anl
sta8n9o
s6t5antr
st3anv
4stao
2stap
s7tapa
s4tapp
s8tapå
s3tari
1stas
3s8tasj
4s5tast
1stat
4stato
sta5top
sta3tu
3stave
2s4t5b
st7c
2std
2s3te.
2stea
2steb
3sted.
s4teda
5stedt
s2tee
2s4tef
3s6teg.
stega6l
s4tege
3stegh
4s5tegn
s4tegr
4stegsp
5stegspl
ste4her
s2t4ei
stei5er
4steikn
ste6in6s5
3s4tek.
4s4teka
s6teke
ste4ket
s4teki
4s5tekn
4steko
v4s5tekst
s4tekt
s8te5kv
4stela
ste5le.
s5teleg
ste5lev
s5telig
5stemd
3s4temm
5stemn
4stemø
sten5a
ste4nar
5s4tenen
s4tener
4ste5nes
3s6teng
s4teni
6stenk
4steno
stens5l
4steo
s5teol
2step
step7per
st8er.
8s5tera
s4teram
s6terest
s4terev
s7t6erf
s4terid
ste7ris
s6teri6v
4s3term
6sterr
ste5run
2stes
s4tese
ste7sle
4stet
s4teta
ste7t6r
s6tetø
4steve
4stevi
6stevl
5stevn
6steå
2s4t5f
2stg
stga6ve.
stgå8va
stgå8ve.
2s6t5h
st5he
2s3tia
4stib
s5tibe
s9tibl
3stic
6s5tid
s6tidel
sti5en
s2tif
3stift
s4tigen
7s6tigi
st9i8gj
3stign
s5tij
6s5tika
4s5tike
s4tikl
3s6til.
5s4tila
sti4lag
4stild
3stile
stile9ge
s6tilk
6stiln
s4tilo
6s5tils
5s4tilt.
6s5tilta
5stilte
4stime
sti7mer
6stimé
3s6timu
s6t3ind
s6tini
4s6tinn
s6tinst
s6tint
1s2tip
4s3tipp
6stips
5stir
2stis
6s7tisk
4stitt
4stiå
s4tja
5stjel
4s3tjen
s6t5jent
3stjer
4stju
2stk
2stl
2stm
2st5n2
s2to.
1stof
2s3tog
4stoks
6stokt
3stoli
4stolj
s5toll
4stom
s9tomm
st3oms
6s5tomt
4stoni
st3ope
st5oppl
6s8t5ord
sto4ret
s6torm
stor3o
4stors
st5o4s
s1tot
sto4t5r
5s6tore.
st5ou
5stova
2stp
8str.
st3ra.
4s5trad
s8traff
6strafi
6strail
st3ral
st4ran
stra8na.
5strand
4strane
6strans
4strap
4strar
st7ras.
st7rast.
5s4traum
s4tre3a
s4tred
7s6treik
st5reis
7strek.
st5rekl
6streni
st5rer.
6strers
6strh
9stria
9s8trid
5strie
st5rige
st3rin
3s4t6rip
5stri3s
6stroe
s5t4rog
5s4trok
st3rol
6s4t5rom
st3ron
st7rop.
st7ro6pa
s6trope
s6t7rug
9s6truk
st5rum.
2stry
6stryg
s7trykt
4s3træ
1s2trø
6s5trøb
st6røm
4strør
4strøs
st5røse
s5trøst
4strøy
6stråd
2st5s6
stsa6me.
stsy8na
4st7t6
stta6le.
st3t4r
s4tua
1s2tub
3s4tud
s2tue
stu4el
stu4er
stue5re
3s4tum
6s3tung
6stunn
3s8tunt
6stur
2s4tut
2stv
s3t4ved
1sty
2stya
2styd
3s4tyk
sty6l
2s5tyn
2s7typ
3s4tyr
styrs3
6stysk
4styv
sty5ve
1stø
2støk
5støl
6støm
5støp
6størk
5støt
stø7va.
stø5var
stø3ve
stø5vi
st8øy
1stå
5s4tåe
stå5k
4su.
1su4a
su7a8l
1su2b
sub7l
sub3o
5subs
s3ubå
1sue
su8er
su2f
5s2ug
su6ga.
su4ge.
sug3g
su2h
3sui6
su3is5
suit5a
su2k
4s1uke
3suk5k
suk3r
1suk5s
su4le.
3s4ulf
su4lik
sul4t5r
s1ulu
2suly
sulæ5
3s2um
4s3umid
su2mo
sums6
5sund.
8s5under
5sundet
5s4undi
sun6d7r
9sunds
sun4ge.
6s7u2ni
su4o
3s2up
su4pe.
super3
supi9
sup4r
su8pre
sur5d
su4re.
4s3u4rei
1surf
su4rie
su4riu
surs5k
sur4sp
sur4sti
1sus
su3san
su4se.
su6s5es
4susi
su4sik
sus3p
sus3s
su2sy
2s1u4t1
sut6ra.
sut8reg
7suv
8s5u6vi
sv2
6sv.
sva5a
svai5
5svak.
3svake
6svaks
sva4la
sva4les
6svalet
5s6vali
7s6vam
s4var.
s4varet
s3varm
3s4vart
6s1vas
6s1veg
sve6g7i
s5veie
3s4veis
s5veka
6s5veks
5s4vens
sverd5s4
sve4re
sve8res
3s4verg
5s4verj
s5verk
sver4ki
s4verm
6s7verv
7s4vev
s4vie
svi6e3l
4svig
svi5ke.
6svikg
4sviks.
3svikt
4s5vikti
4svil
s6vindel
svi4nes
sving5s4
ll6svint
4svir
2svis
svi4sa.
svi4se
svi5sen
svi5ser
s8viv
svi9ve
4svol
5s2vor
svor7t
s3vr
3svul
5s6vulm
s3vy4
svye7ne
1s2vø
4svæs
2s7vå
1sy
sy4c
sy4de.
sy5den
5sye
sy2er
sy8ka
sy4ker
sy5kere
2syko
sy6kog
s4ym
sy7me
s2yn
4s5yndl
synk4
syn6sk
syn3te
sy4ra
sy5rar
s6yre
sy4re.
2s1yrk
syr4ka
syr4ke.
3sy1s
sy4se
sy2sl
sy2s3t
sys4tr
2sy2t
sy5ten
sy5t6h
9sytt
sy2vå
s4z
sz3c4z
6szt.
1sæ
sæ2l
8s3æ4re
8s3æ4ren
sæ4r1i
særle9
sær5s8
7s6æ5te4
4sætt
1sø
4sø.
sø2d
s1øde
4søf
søg4
4søj
9søk.
3s6øke
5søkj
5søkk
søk7kj
3s6økna
2søko
søk4sk
søk6s3e6
5s6øksm
søk4ta
3s4øl
sø4la.
sø4le.
sø5let
3s2øm
sø6må
3sønn
s1øns
s4øp
sø4ras
sø4re.
sø4r5end
søren6de.
sø8ret
sør9ett
7sørl
sør3s
sør5ø
3s2øs
4søs.
sø8sa
7søt
sø7tast
sø7tel
sø5tes
2søv
s1øve
3søvn
2s5øy.
4s3øya
søy8de.
6s5øyd
8søye
3søyl
6s5øy4n
søy2r
2s7øys
5såg
s3å2ke
5s4ål
så4le.
6s1ån
sån4da
sån6de.
så2p
9såpa
så5pet
6s1åpn
såp9u
så2r
så6ra
sår9ast.
så4re.
sår3sk
sår7ø
så2s
s7åsa
s4åsb
s5åse
sås5k
sås5t
9såv
såva7
ta1a
4tabo
tab2r
tab2s
ta4bu.
4tabø
ta1c
4tad
ta2da
ta8d3ei
ta6d3e4t
tad5spa
tad7s6v
ta6du
t8ae
6taei
4taek
4tael
1taen
4taend
4taenh
ta6es
2ta5fe
taf7f6
5tafis
4tafl
1tage
4tagj
8tah
ta7is
1tak.
ta4ka.
4takau
ta7ken
ta5ker
tak7kel
tak5k4l
ta8k9la
2takr
tak4sal
tak6se.
tak4si
4t3aksj
5takst
tak4tal
4taktig
tak4to
t5aktø
ta1ku
tak3v
1tal.
ta9lam
ta3lan
tal5ang
ta7las
3tale
ta4lei
tal5eie
ta4lek
ta5ler.
tale7s6
1talg
tal6ge.
7talj
talj5es
tal4led
tal4leg
8t7allerg
tall7es
tal8lign
tall6s9a
tal4ly
tal3op
6talter
t5altern
ta6l9u
ta6lå
2tamb
tamba6ne.
t3ambi
t4ame
4tamet
tam4i
2ta3m4o
t6an.
ta2na
4t3anal
ta3nar
ta5nas
ta5nat
t5andak
5t6ande.
t7andel.
t5andele
tand5r
tandø4
tandør5e
1tane
ta4nel
ta5nem
4tanett
t3anfa
tanfø6
6tangf
6t3angr
1tank
2tanl
t3anle
2t1anm
3tannl
t5anno
tanns4
tan6sk
tans5ka
t5an5sl
4t5anstr
4tansv
8tantil
tan4tra
6t7antre
t3anve
2ta3o4
5tap.
ta4pa.
1tape
ta4pe.
3tapi
4tapl
4tappa
5tappi
1t4ar.
t6ara
ta4r3ak
4taram
ta6rare
2tarb
3tarbo
5tarbø
4t9arena
6t7ark.
tar8ka.
4t5arke
4t3arki
4tarra
tar9si
tar7sp
tars6v
4tart
tart7est
t5artik
tar7tit
tar4t3r
ta6r5å8k
4tasa
ta3se
6t9asf
t3a4sia
tasi3e
ta4sif
ta4sil
ta4si5s4
tas4p
tas5s4
6ta7sto
ta7str
4tasu
ta1ta
ta7tes
tate8se.
tat5e4v
tati1
tat3op
tat2s1
tat3te
t3attr
1tau
9tau.
7taue
4t5aug
2t1a4uk
4taun
tau4ne.
tau4sk
2taut
2tav
6tavin
3tavl
4tavli
ta9xy
6t1b2
tba3d
tba2n
t6be.
tbe6te.
tbe6t7r
tbe6t8ra
tbo6da
tbu8da
tby3k
tby4s
tby7te
2tc
t1ce
tcen4
tch5e
t5co
2t3d
tdy5pe
1te
4tead
4te3ag
2teak
2te9a8l
tea6m
2tea2n
2teap
2tear
te5arb
tea4s
3teatr
4teatt
2teau
2teav
4teb
t5ebb
tebu8da
4tecel
te1co
2ted
6t5eddi
3tede.
4tedeb
te7def
4tedek
4tedel
4tedem
te5den
4tedi
5tedil
4tedo
tedo6en.
tedo4er
tedo8et.
te4dor
ted4sk
ted4sl
6tedu
4tedy
tedyr9k
4tedø
te3e4
2tef
8tefa
4tefi
4tefl
4tefo
tefo8r
t3efte
3tefø
2tega
5tegat
4t3egd
te7gea
te9gee
4tegg
teg8ga.
2tegh
te4gim
2tegj
2tegl
te3gla
te9g8li
8tegs.
6tegspl
6tegsv
2tegu
tegvi8
2tegå
5tegås
4teh
5tei.
2tei4d
t3eie
t3eiga
tei6ga.
t7ei6ge.
6teigr
3teikn
tei5le
te1im
6teinf
te4inne
te5inte
te5i4s
6teiso
2tej
te7ken
te5ker
4tekil
2tekj
5tek1k
2tekl
te5k4la
tek6lede.
tek4li
4teknu
2teko
2tekr
te7kra
te6k5ru
9teks.
4t3eksa
t3ekse
4teksp
t4ek8st
tek8t9r
tekt4s
tek6ty
2teku
te2k3v
4teky
2tekø
4tekå
2te3la
tel6ak
5te4l5ar
3telav
8te4le.
4teled
4telei
4telek
4teleme
te4lene
6teler
te4les
te5lesk
4te4lev
te6leva
4telid
4telik
4telil
4telin
te4lir
4telis
4telit
4teliv
tel5lef
tel4lei
tel4lev
tel8lign
tel4lo
2telo
tel3se
telses5
t3elsk
tel7s6v
5teltet
2te1lu
7telut
2tely
6telæ
2telø
telø8pa.
2telå
2tem
3temae
6teman
te4mans
t5emba
6temenn
5temik
tem9ma
6temn
tem5ne.
tem5ord
tem5pe
tempe8l7
3tempo
tem3s
4temø
3ten.
te5nab
te4n5al
ten8am
te4nan
te4nat
ten5at.
6t7enc
6t5en6den
4tendr
4tened
te5neg
6tenem
6tenerg
5tenes
4tenet
2teng
7tengon
t5e4nig
7tenik
5tenis
4teniv
ten9no
te4nom
te5nor
6tenorm
4tenot
te6nov
6tenó
ten3sa
ten5sko
ten6slu
ten3so
tens5v
ten4t5in
tentle8ge.
4tenum
4teny
4tenæ
2tenø
ten5øks
2teom
5teon
4teop
te6ora
4teord
2teov
2tep
te3pa
4tepak
tepa9ra
4tepas
4te5pe
7tepee
9tepé
tep6pere
t5e6ple
4tepr
4terac
te7rakk
6teramm
ter7apa
4terapp
te4rare
6terasa
4terase
7terast
terba6ne.
t6er5d
4tered
4teref
4tereg
4tereis
te4rel
8terem.
6teremm
te4r5eng
teren6ga
6terenn
4terep
te4rerk
ter5esti
4terett
6terevo
3ter5g
3terh
te4rig
4terik
4terisi
te4riv
ter5j
4terk.
4terke
4terkh
7terkr
6terks4
4terkt
terla6ga
terle7ge
terle6ve.
ter8ma.
ter3no
tern5s
te5ro.
tero6e
te3rof
4teroll
4terom
5teromr
4te3ros
4te3rot
tero6v
ter5r
5ters.
5tersjøo
ters4kl
ter7s6ko
ters4l
ters4h
ter3s4m
ters6ne
ter5sv
tersø6ke.
3ter3t
ter9to
ter9ul
8terum
ter7v
tervi6se
2tery
ter5ør
4terøt
te4r3øv
4teråd
te4r3ås
t4es
5tes.
2tesa
5tesar
te7sen
2te1sh
4tesid
4tesik
6te3sin
4tesit
4tesj
6tesjef
4te1sk
t9es6ka.
6teski
te5sko
2te1s2m
7tesmåe
2te1sn
2te3so
6tesp
5tesr
3tess
5test.
4testaf
tes5tas
4testat
5tes7te.
4te5stei
te5s6tiv
5testid
tes4tik
4te5s4til
4te3sto
4te3str
4testy
4testø
2tesu
4te1sv
tes8væ
2tesy
2te3sø
te7så
te8sår
teså9re
3tet.
teta6ka
teta6le.
te4tap
te3te
5tete.
tete4e
4teteg
4tetei
4tetek
4tetem
2teti
3tetik
3tetis
2tetj
2teto
2t8et2r
3tet2s
tet5ti
tett3s
2tetu
5tetu.
2tetv
2tety
te2t3å
2teu
teu8k
t1eur
3teus
2tev
t6eva
te4valu
3tevl
tevo6r
te3vr
2tey6
2teø
2teå
4téa
2téb
2téf
2téh
2téi
4téle
2tém
2tése
4tést
6t1f
tfe6e
tfe4l
tflå3
t7fo
2t3g2
t4ga.
tge4a
tgei5
t4gi.
tgi5ros
tgrei9e
t4gå.
2t1h
t4hap
t4hea3
thei5m
tho7li
tho3re
3thr
thu5le
thu6s
thy5r
1ti
2tiad
ti3ag
2ti1ak
4ti3all
ti5als
2tia2m
2ti1ap
ti3asp
4tiau
2tiav
2tib
2tick
3tid
ti2da
4tidan
tid7d
6t3idee
4ti5dem
4t7idé
4tidis
4tido
4tidr
2tidu
tidvi4
6tidy
4tidø
ti1e2
2tief
2tiei
2tiem
4tienh
tie5ra
4tierf
4tierk
ti4ert
ties3
ti3esk
ti3et
4tieta
4tiett
2tifa
tifa8ne.
2tife
4tifl
2tifo
2ti5f6r
t8ifrå
4tift
tif5te
2tifu
4tifø
ti9ge.
4tigj
2tign
3tigno
ti6gun
2tih
2tii
2tij
ti3ka.
6tikarr
ti5ke
4tiket
4ti5ki
6tikj
tik4kj
2ti3ko
2ti1k2r
ti3ku
6tikular
6tikult
6tiky
4tikø
t4il
tila6ga
til1d4
3tilde
2tile
ti3lei
3tilfe
3tilg
til3id
4tilke
3tilkn
4tille.
4tillh
4tillin
tillø7
4tilm
7tilnæ
3tilst
til3t4
4tilte
2tilu
2tilø
ti7mab
5timat
ti4me.
5timedie
ti4mera
5timeri
2timl
4timo7
4tim6o8r
2t1imp
tim7s
2timu
2timy
2timø
ti6nab
tin5art
4tinaz
2tind
t3indu
ti4nem
4t1inf
tin5ge4s
6ti4nit
6t5inj
2tink
7tinks
4t1inn
6t5inne
ti5no
tinsk5
4tinsp
4t3inst
4t1int
2tinv
4tinva
4tiny
9tiol
6ti7om
tion9s6
4tiop
ti1or
ti1ov
ti3pa
ti6pla
4tipr
3tips
2tir
tira4t
ti4ref
ti1ro
6tisak
4tisam
ti5s6an
ti3se
4tis4ei
4tisek
4tisel
4tisem
4tisep
tise8ra.
4tisers
6tisig
4tisio
4tisje
4tisju
tis4ka
4tiskan
4tiskil
tis5kok
6tisku
tis5l
4tisn
4tiso
6tisprå
4tistat
tis4ti.
tis4til
ti5stre
4tisty
4tistø
ti8støy
2tisy
2tit
ti7ta
ti3te
ti1tj
3titl
tit4r
tit3s
3titt
4tiub
2tiut
ti4v5and
tiva9re
ti4v5art
tiv6is
2tivo
tiv5si
tiv5sk
4tiy
ti5ær.
ti7ære
ti9ært.
ti1ø8
2tiå
6t3jag
2t1jak
t5jarn
2t1je.
2t1jeg
2tjel
1tjen
tjen6st
6tjep
2tjer
t5jev
2t1ji
5t6jingan
5t6jingar
2tjo
t5jord
2tjub
tju4e
2tjun
6tjur
3t8juv
tjæ4res
2tjø
4tjå
4t3k2
t6kag
tka8ra.
tkly9
tku6le.
tkå8pa
6t3l6
tla4ga
tla8te.
tle6da.
t4ledr
t6lef
tlei5er.
tle8se.
tle5ti
tligh6
tlight5
tli6nes
tli4te.
tlu4e
t6l7ut
tlø4pa.
tl7øy.
tlå3ne
tlå7r
2t1m
tma3d
tma8ge.
t6maku
t2mam
t2meg4
tme3in
t2mek
tmini6
tmin5s6
t2mos
tmå4la.
8t1n
t3na
t6nee
t4neli
t7nelig
tne4rek
tne4r5ø
tne8se.
t4nesk
t4nest
t5ni
t8no.
tn5sk
tnæ6re
7toan
7toar.
toa6t
6toau
2toav
tobe6r
t3o2bl
6tobs
4toc
to5da
to9de.
to4dera
3todo
1toe
2toek
6toel
toe4t
2tof
6toff.
t3ofre
to5fri
to2g3at
to7gen
4togg
to6gl
6tograv
to4gre
tog3st
to2gu
2toh
toil3
2to1in
4toj
t6ok
1to3ke
to3ki
2tokj
2tokk
tokk5end
to3kl
5toksi
5tokt
2toku
to4l5arm
5tolat
to5lel
tolele7
5tolera
toli8ne.
2tolj
1to4l3k
7tolki
tol4lab
tol4lag
tol6leg
tol6lett
3tolo
tol5tr
4tolå
to9ma.
2tomb
to5mene.
2tomf
4tomg
to3mi
to5mise
to7mist
4tomk
tomlø8pa
t8omm
2tomr
4tom1s
5toms.
1ton
to5na
to4ned
to4nel
tong5s4
to8nib
2tono
ton3sa
ton5s4l
ton5sp
2tonu
to4ny.
2to3o
4to1pl
4toppd
6toppg
6t5opple
4t5opplæ
top4po
4toppt
4topr
to1ra
to4rak
tor5alt
tor5ang
to4r5ant
to4r3as
4tord
tor8da.
to1re
6toreg
to4rek
tor7eks
to7rem
6torent
5torer
tore4t
tor5ete
4torga
tor5int
tor7me
torm5s
tor5na
tors4i
tor5t8
torvei5
to4rø
4torå
to1s
4tosa
4to3se
to2sh
6tosj
tos5ke
to8sku
4tos2p
2tosy
4tota
to5te
to8ti.
to5to.
to4tor
6toty
2tov
to1va
to7veg
to5verd
tove7re
t5overs
5tow
4toø
6t3p2
t7pa
tpi7ne
tpi7pi
tpo4et
t4påk
tr4
8tr.
6t9rabat
3trafi
tra8ka.
trak7to
t5rane
3t6rans
tran7ske
5trap
tra3pe
tra5po
tra5r4
5trase
tra5se.
tra5ses
5trasé
t2rat
t5rate.
3trav
tre4al.
tre1c
4t3reds
t3refu
6t1reg
t5regi
4trei
tre5int
6trek.
4treke
4trekl
4t3rekor
4trela
3t6re7na
tre5ne
t6reng
3t6reni
4t3renn
tren6sk
t7repe
t5repres
t2rer
t4rero
t4re3ru
2tres
6tresi
tre5sko
tres4l
3tresn
t5resu
t1ret
t4reta
t6reto
t5retted
5t6rettel
4trev
tre9va
t6rib
4t1ric
4t4rid
tri7ei
t5rig.
t4rikk
t8rina
t4ri5ne
4t5ring
3trinn
7t6rio
t4rist
tri5to
t4riu
t2riv
tri7vi
5trix
3t4ro.
5troa
tro9ar
3troe
t4rof
tro5g
3t2roi
tro3in
t4rok
t2rol
4t3rom.
t6rond
5t4rong
tro5per
t2ros
5t6rosk
tros3l
tro1v
t8ru.
t8rua
7trua.
5trued
5truet
3trug
tru1i
5trukn
t3rull
2t1run9
t3rund
4trupe
tru5sa.
7t6rusk
2trut
t5ruta
t3rute
t3ruti
tru5v
try3dr
3t2ryg
tryg5ge
7trykk.
5trykke
try7pe.
t6ræ
trø8a
t5rød.
t5rødt
4trøk
4trøm
2trør
5trøt
5trøya
5trøye5
trøy9et
4trøyr
6trøys
5trøyt
trå8da.
4trådet
trå4dr
t6råkl
t3råst
4ts
6ts.
t5sa.
t5sab
tsa2g
tsak6se.
ts1an
ts4ang
tsau6r
t1sc
t6scha
t6sch5k
t5se.
tse6d
tse4er
ts5ege
tsei4d
ts3eig
ts2em
t3sen.
ts4ende
t5sendi
tsen8ka
tsen6ke.
t5sens
t4sentu
t5ser.
t3seri
t4s3erk
tser3o
t5s6ers.
ts4es
t4sesk
ts5e6st
ts3eta
tse4te.
ts1e4v
ts3f
ts4fæ
t7s8hop
ts7ill
ts3inn
t4s3ins
t5sir
ts5jeg
tsje5t6sj
ts5jor
5t6sjov.
t7sjuk
t4sjur
t5skad
t4skan
ts6kis
t4s5kjed
ts6kjø
t5skol
t6skoll
t7skot
ts5kren
tsk5ru
ts5krø
ts1k6v
ts9kvi
ts6ky.
t6s7kyn
ts1l
t7s6lo.
t3s4lot
ts2lu
ts5lø
t5smit
tsmå6la.
ts1o
t4s5o4d
t5sok
t5somst
t5spek
t3spel
ts2pi
t2s3pike
t3s4por
ts5s4
t1st4
t2s3tabb
t5stad
ts3tak
t4s3tal
t5stand
t5stang
t5star
t5stat
ts6tau
t3sted
t4steg
t4stek
ts6tig
ts4tik
t4stilk
t4stin
t4stit
t2s1tj
ts5ton
ts5tors
ts5tree
t4s5tren
t4s5tro
ts3try
ts6trål
t5stu
ts3tv
t4sua
tsu7ge
tsu4l
ts3uli
ts3u4r
ts5usi
ts1v
t3svik
ts1w
t5syk
ts5yt
tsø8ka
ts5økni
ts5øv
tsøy8er
ts1å
tsåt8
6tt
t1ta
t3ta.
t2tab
ttaba6ne.
tt9abo
tt5adr
t2taf
tta9fr
tt3aft
tta4la.
t6t3ald
tta7lel
ttall4
t4t3ana
t5t6ane
t4t3ang
t4tans
t4tanv
tt5appe
t7t8ar.
ttare6
t4tarr
tt5ar5t
tt6arta
t4tase
t4tasj
t4tav
tt3avi
tt5avk
tt5avr
t3te.
t2tea
t3ted
t4teda
t5tede.
t8tedr
t2tee
t4tef
tt3eff
t2teg
t2tei
tt7eid
tte3in
t2tek
tte7kv
tt7elev
tteli6te.
t4tem
tte4ma.
tt5emn
ttem8na
ttem6ne.
t3ten
t5ten.
t4tena
t5tene.
t4teni
tten5s
t9tens.
t4t5ense
t2teo
t5ter.
t4terei
tter5un
tte4r5ø
t4terå
t4tese
t4tesi
ttes6ke.
t4tesl
t5tet.
t4teta
t4tete
t1té
t4th
tt5he
tti5a
t4tidel
tti3e
t2tif
t5tig
tti4g5j
tt3ind
t5tine
t7tiné
t5ting
t4tini
t4t3ins
t4tisj
t6tisti
t7tite
ttle6de.
ttlin5
t1to.
t5tofr
tt5om.
t7tomr
t2ton
tton6na
tt3opp
t5tora
tt3ord
tto5re
tt5o4ri
tt3orm
tto5u
ttpar4
tt6pås
tt9raka
tt5rake
tt3ram
tt3rap
tt7rat
t4t3rep
tt3res
tt3rev
tt5rom
t5trop
t5try
t2t1rø
t6ts
tt7saf
tts3ar
tts5kan
tts5kj
ttsla6ga
tt3sok
tt5still
tts5top
tts5tra
tts5tøy
tt3ugl
t1tum
tt1un
ttun6ge.
tt1ut
tt8ute
ttva8la
tt5ve
tt6vun
t5tw
t5ty.
tty8e
tt1y6t
ttæ6
tt3ø4l
t1tør
tt3øv
tt7øy6r
tt1å4
5tual
4tu4av
tuba3
tu4be.
tu6bå
tu6dem
5tuel
tu4er.
tug8la
tu1in
tu2k
t5uka
t1uke
7tukt
3tula
1tule
tul5les
tum5m
tum4s
3tun.
4tund
3tune
tun5gesv
6tungd
tung9s
6t5uni
tu4nio
5t4un5n
9tuns
3t2ur
tur7ant
tu4ras
4tu4rei
tu4rek
turi4
tu4rin
tur1o
tur3p
tur5s4
tur3uk
tu5rus
tur1ø
1tus.
tu1sa
3tusb
3tusf
tu4sin
tu4sm
tus5o
tus7s6t
tust6r
tus5u
2tutg
t5utj
t5utk
t1utr
tut6tenk
tut5tor
tutt5ov
tu8va.
2t1v
tv4a
tva8k
tva6ne.
3tvang
t4v5anl
8t9var
tve5del
3tveit
4t7ver
tvert5
t2vet
3tvet.
7tvets
t5vik
tvi8ka.
t8viklas
5t4vil.
tvi5la
5t4vile
t4vi5l4i
t6ving
tvi4sa.
tvi4se.
6t7vo
3tvung
6twa2
1tyd
tyg9gel
tyg5ges
6tyh
tykk5s6
ty4med
1tyn
ty4ne.
6t5yo
1typ
5t6ype
ty4pere
ty4pet
ty4rak
5tyrann
6tyreg
ty4rep
tyre5st
ty4ri.
tyri9e
ty4ri5s
ty2s
3tysk
tys3t
2ty2t
ty8ta
t3ytel
ty5ten
ty4ve.
2tz
t5za
5t6zel
6t6z5l
1tæ
tæ5l
tær6ene
tæ4renh
tær4er
tær4et
tær5s4
tøf3l
2t1øk
tø9ket
tøk8ta
4tøl
t7ø4let
5t4øm5
tøn5nes
4tøp
tøp5se
t2ør
tø4r3as
tør3in
tørk4
7tørk.
9tørka
5tørke
tør5ne
tørs7ta.
tørs7ter
tørs5tin
tør3t
tøs4
tø8sa
4tøt
tøt5a
tø5ta.
tø3te
tøtt6
2tøv
tøv6d
tø7vele
t4øy
tøy5a
t9øyem
tøy5r
tøy5te
tå4en.
tå2k
tå5ket.
tå5ki
tåk6r
tå2l3a
tå9la.
tå4leg
tå7lel
tål5s4
tån8da
tån6de.
tå3ne
4tåp
tå6pe.
t1åpn
tå6re.
tå4rep
t3året
4t5åri
3t8årn
2t1års1
tå3s
tå2t
t3åtak
tå7ten
ua7g
u1ak
uak3s
u1al.
ua7la
ual5l
ual3o
ual3u
u3a4ne.
u5anl
u3ans
u1ar.
uar5d
u4arr
u5ars.
uash3
ua3t
u5au8
u1av
1uavh
u4ba.
ub7alt
ub7ant
ub5ark
ub4bo
ub2br
ub4bu
ubel5s
ub5h
ubi6s
ubis7t
ub1j
ub7lande.
uble3s4
u1b4r
ub5rin
2ubs
ubu8e
u4bå
uch5en
uch5er
u1ci
uck1
ucu5
2ud
u3da.
u7das.
ud4dag
ud2dr
udd4s5e
ud2då
udea9
ude8are
u2deb
udeie5
udei5er
u2dek
ude3lu
u2dep
u6dero
u2des
u3d2et
u6d5ett
u5devo
udia2
udi3an
udi4en
udio5
ud7ir
ud7ji
ud5leg
udle6ge.
u7dob
u6doe
u2dot
udover7
ud1r
udse4
ud3t
ud5v
3u4dy
udy9ra
ud5å4s
ue5a8
u5ei
u1el
uem8na
u1e2n
uend5r
u7ene
uensar4
ue7o
u1er
u5e6rast
ue4re.
ue5ren
ue4rer
ue4res
ue5ri
uerle7
u2erm
ue4se
ue2si
ue4skj
ues6n
u1et
uet8r
ueul8
u4fe.
u6feb
ufe6e
uf1f4
uf4f5erm
ufi9l
ufi5ne
u1fl
u6foa
ufor3s
u1fr
uft3a
uf4tan
uft5s4la
uft3sp
ufø6
u5gag
u5gar
u6g5av
ugby7
u2gem
u5gen
u3ger
u4gerø
u2ge5s4
u9get.
u8geta
u2gev
ugg3s4
u5gis
u4gl
ug1la
u5g4lad
ug9lar.
ug4le.
ug9ler.
ugle7s
ug5ly
ug7na
ug7ne.
ugo1
u4go.
ug4re
ugrei9er
u4grø
ug5s4i
ugs4k
ug7so
ug3s4pr
ug5s4va7
uguay7ans
ug5øyn
u1h
3uhel
ui8a
u4i6c
ui2d
uid5el
uid5en.
uid5ens
uid5er
uid5in
ui3e6
u4il
uil5l
u1im
ui3ne
u1ing
uinnsmi8
uinnsmig9
u1ism
uista7
uit3en
uit5er
u1itt
u1j
u4jas
u8je.
u7jå
4uk.
u1k2a
u7kar
ukare6
ukar5t4
u5kat
u2ke.
u4ked
uke5l4
4ukem
uker5an
uke4rek
uker5i
ukho7
u7ki
u1kj
4ukk
ukk6a
uk7kestal
uk8k9l
ukk7n
ukks6
u5klem
uk8lu
ukl7ut
u5k4no
u1ko
u4k5og
u2kra
uk3rus
2uks
uk2sa
uk4sek
uk4sel
ukse7te
uk2si
uk2s1k
uk7ski
uk2so
uks5t
uk4s3un
uk2sø
ukt5e4sk
ukteslø9se
uk4t3id
uk6tj
uk4t5ori
uk2t7r
ukts6l
ukt3sp
ukt9s6v
ukt4sti
uktu8e9ra
uktue5re
u1ku
uku6e
uku5le
uk5vik
ukys8
uk3ø4
uk5å4
6ul.
u1la
u4la.
ula7d
u6l1af
ul3aks
ul5art
ul4det
u4lef
u2lek
u2lel
ulele8ge.
ule5ma
u3len.
u6leni
u3lens
u5ler.
u5lere.
ule3ri
u2l3erl
u4lero
u2les
ule3st
u5lest.
u5leste.
u2leu
u1lé
ul4f5l
ul4fo
ul4fr
u3l4i
ulie8
uli9en
uli5ke.
3ulikh
uli9na.
uli5ne
u7linj
ul1j
ul5ka
ul4k3v
ul4lag
ul4lam
ull7arm
ul4leg
ull5egg
ulleg8ga
ul6leng
ul9lere
ul4le3s4
ul8li.
ul8lig
ulling7s
ull5i4v
ul4l3o6s
ul8lot
ullo3v
ull5sle
ull3s6m
ulls4t
ull3sv
ul2lu4
ul6ly
ul2lø
ulm4u
u1lo
ulo6i
ul5op
ulo7va
ul4sk
uls4po
ul8sn
ulss8
ul2st
ul8s3t6r
4ult
ul4teg
ul4tek
ul4tes
ul4til
ul4tim
ul4to
ul7tor
ul4t3re
ult3ri
u7lua
u3lue
1uluk
u5lup
u5lus
ul9ut.
u7luta
u9lute
ul7va.
ul5van
ul4var
ul4ve.
ul4veg
ul4vei
ul4ves
ulv3t
ul4v3u
1uly
ulyk5kes
ulæ6ra
ulæ5re
ulø3se
uløy6e
ul5å6l
2uma
uma8ge.
u6mare
um5au
umau7ken
um3av
2umb
um5be
4umc
4umd
2ume
u4mend
u4m3enh
umen4t5i
ume5ra
2umfo
2umh
2umi
u6midd
umie6n
umi9na
u4mint
um9ja
2umk
4uml
4umm
um3me
um4mil
um4mis
um3n
umna8
4umo
umo6g
um5ok
2ump
um7pan
um4ple
um4p7ut
4umr
ums1
um7se.
um4sku
umsku8le.
um2sn
um4sor
ums3t
6um7t
umta8l
um5ut
4umve
umør3s
um7øy
umå7
2un.
una6da
un5alg
u4n3ap
u9nar
u7nas
u3nat
2und.
6unda
6unde.
un4dek
un4del
6unden
5undersk
5underv
4undet
un6d7im
4unds
und5s4i
u2ned
u4nee
u9nei.
u2nel
unele6ge.
u4n5eng
u4neno
u2ne1s2
u3nes.
u2nev
unev5n
1ungd
ungele8ge.
un4gem
un2g1j
un4g5l
un4go
un2g1r
un9g8ru
ung3s4i
un6i
u4ni.
u2nid
1u2nif
u4nim
u3nin
3union
uni4st
4unk
un4k5l
un7ko
un4kr
un7nak
unn5erf
un4n5ers
un4n5erv
un5nes
un4niv
un2no
unn5ste
unnta8la
un4n3y
u4no.
u2n3os
uno7t
4uns
un6sj5i
un3skr
un5s4p
un3stek
unst5e6l
un7s6tenk
unst3o
un1s2v
un4tal
un4tam
un4tas
un3t2r
unt5rep
un4tri
untun8ge.
unu6
un5ut
u3ny
u3nø
un5øy6d
u7nøyg
u3nå
uo9a
u1ob
u1om
uom7s
u1op
uor8da
uo1re
uo5ro
u1ov
up3av
u3pea4
u5per
uper3a
upe6ren
u4peta
6upf
u3pi
u8pi.
up3ins
up3li
up6nev
upo9pe
up1p2
up4ped
up4pla
up6pre
upp5s
4upr
u3pra
6ups
up6sen
up2s3k
ups4ke
ups5pr
6upt
6upu
u1på
upåvi6
u1ra
u2rad
u2raf
ur3aft
u2r1ak
ura6ly
u4ram
u5rane
u3rans
uran6t5re
u5rar.
u6r7arl
ur3arv
u9ras.
ur5asp
ur3att
ur7au
urau9ken
ur1av
ur4bod
ur4c
urd4
ur3di
ur4d5o
u1re
ure8al
ureer6e
ur5egg
uregi6
uregist5
3urein
ure4l
ur3ele
u4reli
u7r8ell
u7r8elt
u4r3els
u4r5eng
u7reom
ure7o6s
u4resu
u4reta
u4rete
ur4e5v
2urf
ur4feb
ur6fed
ur3ge
u1ri
u4ri.
uri6a7ne
uri9en.
uri4e5ne
uri9er.
u3rik
u3rim
uri5ne
ur3inn
ur3ins
ur3int
uri6sp
ur4ke5s
ur7k6j
ur6k7ja
ur8kla
ur4kle
ur6k5n
urk5s
urla8ga
urle6ge.
urle8se.
urma7g
ur3nea
urn1s2
urnæ6re
u4ro.
u6roc
5uroe
urom5s
u2rop
uro7pi
ur3opp
ur1or
uro3s4
uro4sta
uro8ta
ur4pel
ur6p9ut
ur3re
ursa8ka
ur4sal
ur4s3el
ur4sin
ur4skr
ur4spe
ur5ste
urs5til
ur4stj
ur2sv
urs3va
ur2s1ø
ur3teo
ur5ti
ur4to
ur6t5ri
urts4t
urue7re
u6rug8
ur7ugl
uruk6
uru4ke
uru7kn
ur6ul
urumo7
urun4g
u7runk
uru7v
ur4vel
urv3s
u6rys
urø2
ur1ød
ur1øy
4usa
u9sane
us3ang
u9sar.
u7saren
u6s7ark
us7au
us1c
2use
u5seal
use4al.
us7edvanle
u2s1ei
u2sek
u4sele
u2sem
u6s5endi
us7erk
u4s5erm
u6sesi
uset8je
us3eva
4usg
u2sh
u2s3h4a
u2s3h4o
us4id
us3ind
us5inn
us7jag
u4sji
us5kaf
u4s3kan
uska8ra
us7kat
us5ken
u6s5kis
usk4l
us6k5le
us5klo
us1ko
u1skr
us7kru
usk7u6t
us4ky
us1l
usle6ge.
us5lin
u4slu
us7mø
u4sn
us1ok
uso5l
uso6l5d
us1or
u3sori
usove7r6e
us1p
u1s2pin
us5sar
us6sat
us4sjå
us4skj
uss5kor
us4skur
uss1l
us7smi
uss7mø
us4s5ti
us4str
us2sv
u6stande
u4stat
us3tav
u2ste
us3ted
u5stei
us7ten
ust9ette
us5ti
u5s6tig
us1tj
ust5of
uston8
ust7onn
us5tor
ust5o6v
us8tra.
us8tran
us8trar
u6stre
ust5ren
us4tri
us3tro
ust5rød
u6st5rå
ust7ut
u4stå
us3ung
u2sur
us1v
u5svale
u7s6valt
usva8n
usvi8ka.
6usæ
usæ9le
usø6m
us1øy
u1tae
u2tag
u7tagg
u9tal.
ut3alb
ut5ald
u3tall
u5tande
uta7no
ut6anv
ut3arm
ut3art
uta1s4
u5tas.
u6t5a6sa
u6t5a6se
u2ta1u4
1utb
ut4ba.
utbe8d
4utbi
ut6by.
utch5
1utd
4utdat
utda7ta.
u2te.
u2tea
u4tee
u4tei
u2tek
ut3eks
u5tekst
ute6ma.
u5temm
u9temt
ut2en
u6tena
u3tenk
u4tenu
u2teo
2uter
u6terø
u2te1s6
u4teta
u3tett
ut6eu
uteva9
1utf
utfa7s
utfø5re
1utg
8utgåe
6u3ti
u4t5if
utikk6u
utiku9
u4tili
u6tiven
ut1j
u5tjen
ut6ju
3utlei
utlø5se
utlå7na
utmå5le
u8tni
1utny
2uto
ut7oms
uto5s
uto4v
3utpr
ut4på
ut1r
u5t4radi
ut3re
u5treng
u3triv
u3trol
u3tros
5utru
u5t6rul
ut4rø
ut9rød
1ut1s4
4uts.
4utsei
utse8t9ja
2utsj
ut3sk
5utst
7uttak.
5uttake
ut4terk
utt5eva
ut4tid
ut4til
ut5torea
ut1tr
ut4tra
3uttry
utt1s2
u1tu
utu5e
u6t5un
utun8ge.
u2t5ut
1utv
u3t4vil
utvi5se
2u3ty
3u4t6yd
u8ty.
8utz
ut1ø
u5tør
ut4ø8s
utøs7t
1utø4v
ut5øya
ut7åk
u3tål
ut1ån
ut7år
u1u
u7uma
u5ume
u7ut
u1v
uve5di
uve3in
uve6ris
uve3s
u7ves.
uvet5ø
u6vev
u5vi
uvi6k
uv5ra
uv9sa
u5vu
uvø9re
u1w
4ux1
ux4a4
uy6a
u7yn
u1æ
uærle9ge
u1ø6
uøv5
u9åra
u7åre
va3am
va8an
4vab
6vadj
vad1r
vaf3
vaf6r
vai5r
vai5s
va6ka.
va7kan
va5ker
6vakh
va8ki.
4vako
vak3r
7v6aksi
4v3aksj
vak5s6t
1vakt
vakt5r
va1ku
vak3v
va3lan
va4led
val9eks
4valel
val4g3r
vali9e8
val3la
val6mes
va6l1o
va1lu
va4lun
4valv
va4løy
val7å
vam8pu
4v3anal
vand5s
v4ane
vane5s
va4net
2vang
van4gr
vang4s7
va8ni.
1v4ann
van4nan
van4niv
vann6sti
va4nom
v4ans
van5sem
5vansk
van5s6ki
van3sm
van3ti
van9tr
va4ny
2vap
va5po
va4ra.
va6rak
va4ral
va4ram
va4rap
va4re.
va4reg
va6rem
va4res
var8ka
var5ma
var4mee
var4sa
var4sk
var4s5ti
var4sv
varta9la
var6tem
var4t5i4s
4vasa
va4sa.
va9set
6vasid
va6sie
va4sif
va4sik
va4sil
va6sis
va2sk
vass5a
vas4sau
vas4sel
vas6s7ø
4vasta
vat5a
va3ta.
va6t7e8l
va2terf
vatle6ge.
5vatn
va1to
va6tr
vat7ra
vat1s
4vau
2v1av
va4z
2v1b2
vba4ne.
vber5g
vbo6da
6v1d
v7dev
vding5s4
v7doi
v7don
vd6r
vdu6en.
vdu6er
v7dø
1ve.
2ve1a2
ve6ag
ve6ar.
2veb
2vec
ve2d1
ve9dob
vedom5
veds2
ved5s4k
3ve8d5t
vedø4
vedå6
2vee
ve4er
2vef
ve6g5av
ve5ge
3vegg
veggs4
2vegj
4vegl
ve3gle
ve5g6lød
veg5n
2vego
6vegre
veg5rett
4vegru
ve4gut
ve4g5å
2veh
1vei1e
vei3en
4veill
6veit
2vej
4veka
5ve4ka.
ve4ke.
ve4ked
4vekee
2veki
4vekj
2vekl
vek8la
vek8le
ve4kli
2veko
2vekr
3veks
vek4st
veks4t5r
1vekt
vek4t5an
vek5to
vek4t5r
2vekå
5vel.
ve4l5as
5velat.
5velatp
6veld.
vel4del
8velds
4veled
6velei
7velet
4velis
4velit
6veliv
2velo
5veloc
vels2
vel3se
velses5
vel3sm
vel5sp
vel5st
4velug
vel5un
vel5v
2vely
2velæ
2velø
velø8pa
2vem
ve5ma
1ven
ve8na.
4venem
ve5net
ve6nete
4venev
ve4nin
ven6n5i
vennle7
ve2no
ven6sti
ven6str
vent6a
ven5t6r
vent4s
4venty
2venu
ve4nus
ve5ny.
4venya
ve4nym
2ve3o4
2vep
1v8er.
ver5ak
ver3al
8verau
ver6des
ver6din
ver6dir
verd7v
ve3re.
4vered
4vereg
5vereig
4verek
ve4rel
ve6r7eng
4verenn
4verep
ve5rer
ve5res.
4verett
4veretu
verfø5re
ve9ri.
veri3a
ve4rial
ve7rie
4verik
ver3il
5verkn
ver5m6
ver6nal
vern6s5
ve9ro.
ve3rom
ver8ska.
ver5ski
ver7spo
verta8la.
verta6le.
ve1ru
5verum.
6very
verø6
ver3øs4
4verå
v4es
3ves.
2ves4a
ve5san
4veset
4vesh
4vesi
4vesj
4veski
2vesl
ve9sli
ve1s2m
6ve3so
4vesp
ve6s3per
ve5sted
ves6t5end
vest5o4v
4vestr
4vestu
4vestø
vesva7
5vesynds
2vesø
ve1så
veså5re
v4et
1vet.
2veta
8vetaka
4veteg
4vetek
ve5te6s7
6vetev
2ve7ti
4vetj
2veto
ve4to.
veto7e
9vetoke
9vetoks.
ve4tor
2vetr
1vets
vett5sk
6vetv
4vety
vety8e
2veu
ve8um
2veva
ve6vak
ve5van
ve9var
2vevi
vevi8sa
vev4sm
vev4sp
2veø
2veå
1vê
2v1f
vfall4
vfø7re.
2v1g2
v4ga.
vga4le.
vga6li
vga8ve.
v9ge
v4gi.
vgjer6s7
vgo4
v4gå.
2v1h
vhø4re.
1via
vi1an
vi6bl
vice5s
1vid
vi5de
vide4o7
vi4d5o4
vid3r
vid3s4
vi1el
vi5end
vig4m
vi4gu
vi5gø
vi4kat
5vikb
vi5ked
7vikg
vik5ke
vik5n
vi2k3o6
3viks.
vik5sa
vik5s6l
4vikt
5vikti
vi4k5ø4
vi2l1a
vi5la.
vi4les4
vi4l3in
1vilj
vil4l5an
vil4led
ville6de.
vil4lei
vill9ep
6v5illu
vil5m
vil1o
vil4sti
vilt7o
vil6tret
vil4tri
vi2lø
4vim
vim7p
vim7u
4vindl
5vindu
vine5st
v6ing
4vingn
vin5gom.
ving3r
vin8g9u
vin3na
vin4ned
6vinnh
4v5innl
4v5inns
4vinnt
vi6n5o6ver
v2in2s
vin7sja
vin4tes
vin5tre
vi8pa.
vi6pe.
vip5s
1vir
4viro
7viru
vis3ab
vis3ak
vis5and
vi4see
vi3sen
vi6seng
vi2s1k
visk6re
vis5m
vi1so
vis3om
vi4sp
vis9pa
viss4p
vis5ti
vi4tak
vi5tese
5vi6t5j
vi4t3o
vi4tr
vit7ra
vit5re
vit5skr
vit6te6s7
vi4t5un
vitun6ge.
vi4t5øy4
vi4va.
vi6ves
vivi3
v1ja
v1je
vje4t5a
vje5t6e
vje4t5r
vjet3t
vje4tu
v1ji
4v5jo
vju3t
6v3k6
vk4le
vk4ler
vku4le.
6v1l2
v6lab
vla6ga
v9led
v9leg
vlei9e
vl6el
vle4se.
v5lesn
vle5str
v6lesv
vli7v
vls9
vlu9sa
2v1m
vma8le.
vmo8de.
vmord4
vmå8la
2v1n
v3nad
vna8ke.
vn5al
v9nar
vn5dy
vne7b
v2ned
vne7de
v4nele
v4neli
v4nelo
v2nem
vne5r6e
v4nero
vne1s
v4nesta
v6neste
v2nev
vnor9s8kas
vn4s5pa
vn1s4t
vn5t4
vnæ4re.
vn5ør
vo1al
vo2ar
6vob
2vof
vof8fan
vo4gu
voi1
1vok
4voko
voks3k
vok6s5
1vol
voli7
vo4litu
vol4tes
2vom
vo4na
vo9nal
vo9nar
von5de
vons6
von5sh
2v1o6p
2vord
vor8da.
vo1re
vo9ren
2v1org
4voro
vors7k
1vos
4vosj
vos4se
vo4teg
vo4tel
6votr
vo1v
vo4ve.
vo6vi.
2v1p4
2vr8
3v6rak
v7rar
v1re
vregi3
6vrenge
4vrengi
v6rengj
v6rengt
vrett4s
v6ri.
3vrid
7vrie
v6rigas
vri6ma.
vri8me.
v3ring
vrin5s
vri6ve.
v1ro
v4rob
v4rof
v4rok
v4rop
vro8te.
v1ru
v7ry
vrø3ve
v1rå
vrå8da.
8vs
v6sa.
v7sali
v6se.
v4seg
vs3egg
v3s4el
v4s5e4li
vse4n
v5sen.
v4s5eng
v5s4ens
v2ser
v6si.
vs1in
v1sk
vs8ke
v6s5kum
vs1kv
v1sl
vs3lan
vs6let
v6slik
vsmå8la
v1s2n
v6s7na
vs3ne
vs3ny
vs3næ
v4s3nø
vs5od
vsom5
vs5oms4
v7son
vs1or
vs2pe
vsre6de.
vs7s6t
vs4s5å
v1s2t2
vste6ma.
vs3til
vs1v
vsø6ke.
vsøl5
v2s5øy
vsøy4er
v8så.
vså7re
2v1t
vta1
v4ta.
vta8ka.
vta6led
vta9len
vta4lev
vta6s
v5tepp
v5t4i
vti8na
vti8ne.
v5t4r
v3t2v
vty8e
1vu
vu2d1
vud5d
vuden5t
vuds4
8vué
vu8k
2vul
2vung
vun4ge.
6vu6o
2v1ut
2v1v
vva8la
vve8g9ing.
vve6g7inga
vven7n6i
vvi5ke
vvi6k7l
vvi8s9an
vvi4se.
2vy1
vya4
vy7ens
1væ
væ1ra
væ9ret
væ8ta.
v3ø4d
vø4l
vø7li
vøm4met
3vøre
vø6re.
v3ørke
vør8na.
vø3se.
v5øv
4v1øy
vøy6e
vøy7ene.
vøy9enes
1våa
1våe
4våend
v4åk
vå8ka.
vå4ke.
vå4kene
vå9kene.
vå4le.
1vån
vå5ne
4vånu
vå3ren
vå8sa.
vå5tes
6våtf
våt7å
w2a
wa6l
5wald
wal4k
walk5o4
wal4l
2wap
war6d7er
wash3
1wat
wa3z
w1b
wboy5
we2
weate7
we7b
we3g
we5re
wes2
wes3s
wester6
western7
wet5
wett4
w4i2
wi9ar.
wich3
3wicz
wi3d
5wi6en
wi9er.
wi5f
wi3ni
wi5ra
wi3ren
wi5ta
wk3r
w1l
w1m
wn5s
wob5
wou6
wout7
ws5
ws6k
wurs6
wy2
w1yo
wyor2
wyork3
w1z
xan5t
x7b
x3f
xga6
x7h
x1ic
5x6id
xi5e4
x5k
x1l
x1p6
x3r
x1s2
x7t
x6u
xy2
ya7b
1yac
ya5f
ya4h
y1ak
yak6te.
ya2l
y7am
y1an
y6an.
y2ana
ya4ne.
yan7k
yan7sl
y1ark
y7arr
yas4
ya5si
ya5t
y1av
y1b
yba4ne.
yb4bed
ybde3
ybo2
ybu6er
ybue7re
ybu7ern
ybyg5
y1c
y8ce.
y8cé
y2co3
y6dab
yd5av
4ydd
yd6dela
yd4dep
y6d7enh
y4deo
y2dep
y4dero
y2d1is
yd6je
yd1ji
ydo4
yd3op
yd5ov
y1dr
y4d4r5au
yd1re
yd5rem
y4dro
y4d4r5oks
yd3si
yds4v
y2du
yd1un
ydø4
y4døm
ydør5
yd1øs
4y1e
yed8l
ye6dre
y2ek
y5eks
ye4len
ye6let
yel4s5j
yel4sk
yels3m
yel6s5t
y2em
ye2n
y7e6ne
y8ener
y2enh
ye5ni
y2enk
y2enl
yenle6ge.
yens4
y4ense
y3e6re
ye4rel
y3ern
yer8sk
y4erst
yes2
ye5sm
ye2t
ye9te
ye5ty
y2ev
y1f
yfan9
yfjell4
y4fle
yf5le.
y8ga.
yga8ve.
yg4dal
yg4dek
yg4del
yg4dep
yg2do
yg2d1r
yg2d1y
yg2dø
yge5i
ygen5s
y6geret
y2ges
y4gev
yg6gam
ygg7art
ygges4
yg5gj
ygg5l
yg6gr
ygg3s2
yg6gu
yg6g5å
ygi2
y5glo
yg7m
yg6r
y1h
yhes5
y1i
y9in.
yis7t
y1j
6yk
y1ka
ykap3
y6kara
y2ke
y7kel.
y5kelen
y3keli
y7kels
y3ken
y3ker
y4kerel
y4kero
y5ket.
y9kets
y1ki
y1kj
y4kjar
y5kjare
ykjeva8ne.
yk4kana
yk4k5enh
yk5kesj
ykke6s5ta
yk1kj
ykk5ni
ykk4s5k
yk8k5vi6
yk4ky
yk1la
yk6lest
y1klo
y3klub
yk3lus
y5klæ
y1ko
y2koa
y6koli
y4komo
y5kosa
y2kot
y5koti
y1kr
yk1s
yku6le.
yk3var
y1la
yla8ga
yl4dan
yl4derk
ylde4s
yld1r
yld5s6k
yle6ge.
y7les
y4lev
yligh9
yl5k8
ylke2
ylke4s3
ylkesla8ga
yl4lev
yll5is.
yl3s6
ylst7re
yl5tet
y8luse
3ylven
y1ly
ylæ7re
y6mei
y4mete
ym4fe5d6
ym5jara
y4mo.
ymo5e
ym3p2
ym1s
ym8sa.
ym4se
ym8sl
ym6ta.
ym6te.
ymå6la
y9n8and
yndes8
yn5det
y2nel
yn7eld
yner3g
yne5s4
ynesi8
y6nev
yn5gel
yn4gem
yn2gr
yn4g5ø
ynko3
yn6k5v
yn5na
yn5ne
ynn3s4
ynn4ø
y3no
y4no.
yns1
yns6are
yn4sem
yn9set
yn2si
yn2sk
yns9ket.
yns7ki
yn5skj
yns7kjele
yn8s9kjer.
yn4st
yn2su
yn4s5ver
yn4tap
yn8teg
ynt5ei
yn4tek
yn6tete
yo4gat
yo6gi.
y1om
yon4
yon5nen
yo6nu
y1o2p
y1o2r
yor6da
yo5re
you4
yout5
yp8e
y2pe.
y4pee
y4pena
y4penet
ype4rel
y6peta
y1pi
y4pi.
y7ping
yp5inn
ypin8na
y1p2l
y5po
yp7p6a
yp3pe
y1pr
yp5s8
yp4tok
y3pu
y1ra
yra8ka
y4r3a6l
y7rarb
y4r5au
yr5av
yr7da
yr5dø
y7real
yre3in
y5reis
yrek4
y7rek7k
y3rels
y5rems
y1ren
yre9ne
y4reo
y6rerel
y4rero
yre5sc
y5rest.
yre5ste
y5reste.
yres6ten
y1ret
y4reta
y4rete
y4reto
y7retø
yr7ga
y1ri
yrin5g6
yri6ene.
y4rif
yri8ka.
yr3inn
yris6p
yr4kee
yrke4s
yr5kj
yr3m
y7roe
y3romm
yr1op
y5rosk
yr5r8
yr4san
yr7set
yr5sk
yr6skj
yr6skr
yr2sp
yrs7tan
yrs5tar
yrs7tene
yrs5tens
yr3sti
yr4sv
yr3te
yr6tek
yr2t3r
yr3tra
yrty8
y1ru
yrul8la.
yr5ut5r
yr3v
y1ry
yr3øk
yrøy4
y1rå1
yråd2
yrå8da
yråde7r
yrå6ders
y4rådi
y2råm
y6råst
y4råt
y4råv
2ys
y1sa
ys6a7kers
ys4e
yse4bu
y4sed
y4see
yse5ei
y2seg
y2sek
ys7ekte
y2sem
y4sera
yse7rid
yseri7e6
y4sesj
y4sesk
y4se5s6l
y4sest
y5seste
y6sesu
y9set.
y4seu
ys6i
ysi8e
y5sjk
y7skag
ys6kara
ys7kare
ysk9au
ys2k3l
ysk5øs
ys4mi
ys4nø
y1so
y4s5or
ys2pe
ys5pis
y5s4po
ys6sak
ys6sam
ys4s3ei
ys4s3ek
ys4s5il
ys2sj
ys4sku
ys2so
ys2sp
yss5pe
ys4sta
yss5tab
ys4s5ti
ys4su
ys2s5v
ys2t
ys3ta
y8star.
ys4tat
ys3tel
ys3ten
y4s3ter
ysterie7n
ys7tesl
y2s3ti
yst3op
yst3r
ys5t6ry
ys6ty
y1su
ys1ve
ys5år
y1ta
y4t3ana
y2tee
y4tef
y2teg
yt5e4ge
yte3in
y4teka
y4teki
y4tena
y4teno
y2teo
y4teret
yte6ro
yters6
yter5ske
yte5r6ø
y2tes2
y2tet
y3t2hi
6y5til
y6tj
yt9ja
yt5jen
yt9jer
yt4mei
yt4mes
y3to
yt8ra
yt4re.
yt5rer
yt1ri
yt4rik
y5trå
yt4s3en
yt3sk
yt5sv
4ytt
yt5t6a
ytt4e
ytte8r9end
yttes6
yt4test
yt8tien.
yttsa6me.
2y3tu
y1ty
yt4ys
y7tå8
y1u
y6ua
y8ue
yu8g
yu4l
y1v
y4vak
yva8la
y2ved
yve4ria
yve4ris
y4vese
y6vesy
y6vev
yvi8sa
yvi6se.
yv1år
yvå5te
y1w
y5æ
y5ø
y1å2
za5b
3zae
4zaes
za4g5
za5k6h
zani4
zania5
5za5v
z1b4
zbu4
z1c
z1d
1ze
zea1
zebu9
zeli5
zen3s
4z3ense
4z3ent
z1f
z1g
5zha
z3hi
z5hu
5zie
1zifi
5zing
z5int
1zis
6zisty
4zi5s4v
2zisy
z1k
4z1l
z1m
5zo.
5zoe
zo1f2
zo4no
zo5re
6zos
z1p
z5r
z1s
4z1t
zu3e
z1un
z1v
z1za.
z2z3el
æ5by
æ2bø
æ5de
æ7di
æ1f
æg6
æ2k
æ3ke
æ5ki
æ8kj
æk1ja
æk7je.
æk9jer.
ække7
ækkel6
æk6l
æ1la
æ4le.
æ2le3d
æ4lena
æ4lev
æl5j
ælsle9
æ4r1ak
æ3rane
æ4rans
æ4rarb
æ6rarbe
ær4arte
æ4r1at
ærbu5e
ær1d4
æ1re
æ2rea
æ4red
æ2ref
æ2reg
æ8r7ei
ærei6e
æ2rek
æ6r7eld
ære5ne.
ære7nes
æ2rep
æ5rern
æresa4m
ære6skr
ære4sl
ære4sp
æ4reta
æ4retek
æ9rets
æ2rev
4ærf
ærgen5
ærhø8
æ1ri
æri6e7ne
æ4r3il
ær3ins
æri6s
ær5is.
4ærk2
ærle6ge.
4ærm
ærmå8la
ær3n
ær5ne4
ær4nå
æ2r7o6
ærom5
æroms4
ær5r
ær6sel
ær4s5il
ær1sk
ær7s6no
ær2sp
æ2r1u
ærut5
ær3v
æ2r1ø4
ærøy7e
ær3å4
æ8se.
æ2sj
æ2s1k
æ5ta
4æte
æ4te.
æt4r
æt4ta
æ5va
ævar5
æve4s
æ5vi
6ø1a2
øa7re
øau4
ø1b
øbe6lev
øbe4li
ø2bl
øbl9u
øb4r
ød3ag
ø4dak
ød3d
ød9de.
ø2de.
ø4dede
ø6def
ø4dela
ø4dem
ø4deo
ø4deri
ø4dero
ø5dj
ød1r
ød4red
ød4rek
ød4rep
ød2sc
ød6s5ek
øds7ke
øds4ko
ød6sku6
øds4mu
ød8t5om
ødt6r
ø2du
ød3und
ø4d5ur
ø6d5ø
4ø1e2
ø4ed
ø5ene
ø5ep
ø3e6re
øfe8
øf3fe
øf6j
øf8la.
øf8le.
øffe8l7a
ø5fn
øfte5s
øg1
øg2a
øg5ak
øg5al
ø7gar
ø5gas
ø3ger
øg5gl
øg8gå
ø7g4j
øglo8ve
øgn6s7p
ø2g2r
øg5re.
øg5res.
øgs2
øg4ste
øg4str
øgta5
4øg4u
ø1h
ø4i
øi4e
ø5ing
ø5isk
ø4it
ø1j
6øk.
6ø1ka
ø5kav
øka8ve.
ø6keh
ø4kelo
ø6kerada
ø6kerel
ø4ke5ru
øke1s
ø6kese
ø8kesl
ø4kest
ø4kete
ø1ki
4økj
ø5kjare
ø5kjas
ø1kje
2økk
øk5kel
øk5ket
øk4k5l
økk5r
øk3lag
øk3lan
2økna
1øko
øk5opp
ø1kr
ø8krar
øk8sa.
øk6se.
øk4ses
øk4si
øk2so
øks1t6
øks5ti
øku4r
øk5ur.
øk5ure
øk7ve
ø7ky
ø1la
ø2lah
ø6lam
øl3d
øled
ø4ledi
ø6lelu
ø4lero
ø6leta
ø4le5te
ø2lev
øl4gera
ølge5s6v
øl1j
øl2ke
ølke7s
øl4lese
øl9leti
øl6lev
ø1lo
øl7op
ølrå4
øl6sel
øl4sere
øl4se3s
øls6t4
øl5s4v
ø5luk
øl7ut
ølva6
øl4var
øl4v3ei
øl6vek
øl8vel
ølv7erk
øl4v3in
ølv5o
ølv7r
ø1ly
ø4me.
ø9met
1ømfi
ø5mi
ømini6
øm4med
øm4mero
ømmet6
øm4metr
øm3op
øm4pel
øm7s6p
øm1st
øm5svi
ø2m1u
ømå8la
øn2ad
ø6n5al
ø5nas
ø2nem
ø3nes.
ø9nese
ønhø8re.
4ønn
øn4nal
ønni4
øn4n5it
ønns5al
ønn4s3e
ønn4s5i4d
ønns5kje
ønns5kre
ønns5ku
ønns3l
ønns3t
øn2nø
ø6nom
øn2s
øn9sa.
øn5sak
øn5sam
øn5se.
øn3ser
øn3skj
øn8skjer.
ønst3r
ønst9ra
ønt1
øn2ta
øn2to
øn7u8
ø1o
ø4peda
ø6pe5i
ø4penu
ø5pero
ø4peru
øpes4
ø4pete
ø4peti
ø1pi
øp3li
øp5p
øp6pl
ø1pr
øp6s1
øpsa4
øpsla8ga
øps8leg
øp5ste
øp4s5ø
ø1ra
ø2ra.
ø2r1af
ø2r1ak
ø2r1a2m
ø4rans
ø4r3ant
øra8sa
øra6si
ø4r7au
ørd4e
ø1re
ø2rea
ør7edd
ø6redu
ø2ref
ø2reg
ø6rein
ø2rek
ørek6l
ør3eks
ør5ekt
ørele8se
ø9relet
ø4r5eng
ø2re5o4
ø2rep
ø6reret
ø4reru
øre1s2
ø5res.
ø4rese
ø6resi
ø7reskrivi
ø8reso
ø4rest
øre6s7v
ør6et
ø4reta
ør1eu
ø2rev
ør5fe
ørge5s
ø1ri
øri8m
ør4jet
ør4keri
ør4kes
ør8k9lag
ør6k5n
ør4kve
ør4kå
ørla8ga
ørm9ut
ørn4e
ør4nere
ør4nes4
ør4n3u
ør4n5ø
ør1o
ø5r6ok
ø1ros
ø4r3ost
øro4v
ør4rek
ør4rep
ørri4
ør4r5is
ør4råt
ør4sak
ørsa8ka
ørsa6me.
ør4sc
ør6ses
ør2si
ør5ski
ør4skr
ørs6lev
ør4som
ør4spe
ør2st
ørs9tar
ørste5i
ørs5tens
ørs5tig
ør3sto
ørs9u
ør2sv
ørs1å
ør9tar
ør4tek
ør6ti9a
ør4tide
ør8tien.
ør6tif
ør3to
ørum5
ø6rut
ør5v
ør1ø2s
ørø1v
ør1åp
ø1sa
øsa6me.
ø8sarar
ø1sc
ø2se.
ø2sem
øse4n5o
øseri7
øserie6
øs5jo
øs7kar
øs1l
øs4lag
ø4slu
øs2me
ø1s2p
øs8tas
øst9ast
øs6teg
øs5terse
øst9ett
østo2
øst5of
øst5ov
øst1r
øst3re
østø4
ø2s1ø2
4øt
øt3ak
ø9tar
øta4s
øt5asa
ø2te.
ø2tea
ø6tef
ø6tege
ø2tei
ø2t5eks
ø2tel
ø5tela.
ø3ten
ø4teni
ø3ter.
øte3ru
ø2te1s
øte7sn
ø4teta
øt7ri
øt1sa
øt3s4p
øt7s6å
øtså9re
øt4tero
øt6test
øtt5av
øtt5eks
øtt5eta
øtt5ete
øtt5ra
øtt7ri
øtt1s2
øttså7re
øt4tur
øt4ty
ø1tu
ø5ty
ø1u2
øug8la
øv5aa
øv5ans
øve5in
ø4vek
øve5no
øveren8
øve1s
øves4t
øve3te
ø5vik
øv6l7ut
øv7ne
øv6nø
øv9o8
øv1r
øv5reb
øv1s
øv9sa
ø5vå
øy3al
øya2n
7øyan.
9øy8ans
øy4dek
øy4dere
øyd8i
5øyeb
øy7e4de
øy2ee
øy4ele
øye4n
øy4ep
øy4erf
øy1gl
øy3ke.
øyks4
øyk5t
2øyl
øy4led
øy4leg
øy5na
øy5ni
øy3o
6øyp
øy3pe.
øy4pel
øy4ra.
øy5rer.
øyri6v
øy3rø
øy1s
øy5s4ar
øy5si
øys2l
øy4sm
øy4spi
5øysund
øy4tei
øy4tel
øy4tere
øyte5s6
øyti7da
øy1tr
øy2t3y6
øy5tø
øy4vei
5øyvå
ø1ø2
ø5å6
å1a
åak6ta
åa4n5
åan8ka.
åan6ke.
å2ar
å5aran
åau4re
å1b4
åba8ne.
åber2
åbo9ta
6å1d
å7dan
å9dar
å4ded
å4dek
å4dem
å4deo
å4dep
å4dere
å4deri
å6dero
å2des
å7di
åd4ra
åd8re
åds1
åd2sk
åd3s4la
åd7slo
åd3slå
åd1s2n
åd3s4pe
åd7spu
åd5st
åd6s7te
4å1e
å2ele
åem8na
åe2n
å7ens
å3er
å3e6re.
å1f
åfe6
åfø5re
2åg
å4ga.
åg7ald
å4ge.
åg7ei
å2ges
ågna5
åg5ne
åg4r
åg5rin
ågs6k
åg5sl
åg7sp
ågs4t
ågu4l
åg5ø
å4gå.
å1h
å1i
å1j
å1ka
å3kan
å3kar
å4karb
åk7av
å4keh
å3ken
å4kena
å4k3enh
å4kere
åke5s
å4kesl
å5kevi
å1ki
å6kid
å1kj
åk1k
åk5ka
åkk6l
åk7kr
åk7lau
åklist7
åk3læ
å1ko
åk3opp
åko4s
åk6ra
åk5røk
åk3rå
åk1s2
åks7l
åk3t4
åku8
å5k8ul
åkva8la.
åkøy8rar.
å2k3å
å1la
å5l6amp
å6larb
å9las
ål5au8
ål9av
ål3d
å2lef
ål5eini
å2lek
å2lem
å4l5enh
å4leni
åle6ris
å2le1s2
åle9s6und
å4lete
å2lev
ålgå6
å6lio
ål5j
ålla6ga
ål3or
ål4san
ål4sek
ål4ser
åls7i
ål2sp
ål4sti
ålsy8na
ål5ti
ålti5d
ål1u
ålul8la
å1ly
å2l1øy
åløy4e
ål5å6k
ålå8te.
6åm
å6me.
åm4li.
åm1om
åm5øy
å3nar
å9nas
ånd3r
ånd4sa
ånd4se
ånd4so
å4ne.
åned4
åneds5
åne5i6
å2nel
ånely6
å5nes.
å3net
å4netr
å3ni
ån5o
å9ny
å3o
åp2e
åpe4n3a
åpe4n5i
åpen3s
å5per
å6pero
å1pi
åp6j
å1pla
åp4ne.
åp7p
å1pr
åpra5
åp2s1
åp6ta
å4på
år3ak
å9ran
å7rara
ård5str
å2re.
å5rei
å6rel
åre7s
å4rest
årfi4
å7riv
år3k2
år4le.
2årn
årn5s
år3on
år3op
årpo8
år2s
års5af
års3el
år3sem
års3ko
år8sku
årsla8ga
år3sol
års3ta
år7ste
års3ti
år7sto
år5stu
års1u
års1v
år5sy
år5u4k
år3un
år5y4
å1rø
å5r8å
ås2
å1sa
ås7au
å4se.
å4see
ås5eid
å4sek
å4sem
åseri7e6
åse3s2
å4sesm
å4seso
åse5ta
ås3h
å8si.
ås5ka.
ås9kene
ås8ki
å1skj
ås7kop
å1skr
å5sku
å1sl
ås5ne
ås3ni
å5so
å1sp
ås7pl
ås5sa
ås5se
ås3si
åss3k
4å1st
å7stei
åsu4
ås3un
ås7ut
ås7væ
ås5øy
åså9
å1ta
å4ta.
åtaks5
åta2l
åta9la
åtale3
åta5le.
åta5len
å4tang
å4tark
å4t5arm
å2te.
å2tea
å4tee
å2t1ei
åte6ke.
å4teo
å9ter
å2tes
5åtferd
å5ti
åti7da
2åtn
å1to
åt7ov
6åtp
åt1re
åtri6pa.
åtri8pe.
åt1ru
åt5sk
åt1t
åt4ted
åt4ti
ått3o
åt4tri
åtts4
åt6t5æ
åt1u
åt4un
åtva5ra
åtva7re
åt5ve
å5ty
åt1øv
å3u
åun8ge.
å1v
åv4a
å2ve7d
å4veg
åve5l
å4veni
å9ver.
å2vev
åv7s6
å7vy
åvæ4re.
å1ø8
åøy4}
\hyphenation{% Changed 06.08.2005
atten-de
aust-røn
aviser
betre
bortan-for
bortre
Dansk-øya
der-etter
dess-uak-tet
dit-over
finger-spitzen-ge-fühl
finger-spitz-ge-fühl
fram-ifrå
før-enn
her-etter
her-etter-dags
hvor-etter
hvor-over
høyt-ærede
gi-vet-vis
lands-øl
lands-ølet
lands-ølets
langt-ifra
ned-imot
noens
Not-odden
Not-oddens
nøye-reg-nen-de
opp-imot
oven-ikjøpet
promp-te
spleen
sel-ves-te
smal-enden
sørpe-is
sørpe-isen
skrov-is
skrov-isen
Steins-land
syd-enden
tvert-om
velan
velet
welt-schmerz
}

